@@ -23,46 +23,59 @@
 
 typedef enum OPTION_choice {
     OPT_COMMON,
-    OPT_INFORM, OPT_OUTFORM, OPT_IN, OPT_OUT, OPT_TEXT,
-    OPT_CHECK, OPT_LIST_CURVES, OPT_NO_SEED, OPT_NOOUT, OPT_NAME,
-    OPT_CONV_FORM, OPT_PARAM_ENC, OPT_GENKEY, OPT_ENGINE, OPT_CHECK_NAMED,
-    OPT_R_ENUM, OPT_PROV_ENUM
+    OPT_INFORM,
+    OPT_OUTFORM,
+    OPT_IN,
+    OPT_OUT,
+    OPT_TEXT,
+    OPT_CHECK,
+    OPT_LIST_CURVES,
+    OPT_NO_SEED,
+    OPT_NOOUT,
+    OPT_NAME,
+    OPT_CONV_FORM,
+    OPT_PARAM_ENC,
+    OPT_GENKEY,
+    OPT_ENGINE,
+    OPT_CHECK_NAMED,
+    OPT_R_ENUM,
+    OPT_PROV_ENUM
 } OPTION_CHOICE;
 
 const OPTIONS ecparam_options[] = {
     OPT_SECTION("General"),
-    {"help", OPT_HELP, '-', "Display this summary"},
-    {"list_curves", OPT_LIST_CURVES, '-',
-     "Prints a list of all curve 'short names'"},
+    { "help", OPT_HELP, '-', "Display this summary" },
+    { "list_curves", OPT_LIST_CURVES, '-',
+        "Prints a list of all curve 'short names'" },
 #ifndef OPENSSL_NO_ENGINE
-    {"engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device"},
+    { "engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device" },
 #endif
 
-    {"genkey", OPT_GENKEY, '-', "Generate ec key"},
-    {"in", OPT_IN, '<', "Input file  - default stdin"},
-    {"inform", OPT_INFORM, 'F', "Input format - default PEM (DER or PEM)"},
-    {"out", OPT_OUT, '>', "Output file - default stdout"},
-    {"outform", OPT_OUTFORM, 'F', "Output format - default PEM"},
+    { "genkey", OPT_GENKEY, '-', "Generate ec key" },
+    { "in", OPT_IN, '<', "Input file  - default stdin" },
+    { "inform", OPT_INFORM, 'F', "Input format - default PEM (DER or PEM)" },
+    { "out", OPT_OUT, '>', "Output file - default stdout" },
+    { "outform", OPT_OUTFORM, 'F', "Output format - default PEM" },
 
     OPT_SECTION("Output"),
-    {"text", OPT_TEXT, '-', "Print the ec parameters in text form"},
-    {"noout", OPT_NOOUT, '-', "Do not print the ec parameter"},
-    {"param_enc", OPT_PARAM_ENC, 's',
-     "Specifies the way the ec parameters are encoded"},
+    { "text", OPT_TEXT, '-', "Print the ec parameters in text form" },
+    { "noout", OPT_NOOUT, '-', "Do not print the ec parameter" },
+    { "param_enc", OPT_PARAM_ENC, 's',
+        "Specifies the way the ec parameters are encoded" },
 
     OPT_SECTION("Parameter"),
-    {"check", OPT_CHECK, '-', "Validate the ec parameters"},
-    {"check_named", OPT_CHECK_NAMED, '-',
-     "Check that named EC curve parameters have not been modified"},
-    {"no_seed", OPT_NO_SEED, '-',
-     "If 'explicit' parameters are chosen do not use the seed"},
-    {"name", OPT_NAME, 's',
-     "Use the ec parameters with specified 'short name'"},
-    {"conv_form", OPT_CONV_FORM, 's', "Specifies the point conversion form "},
+    { "check", OPT_CHECK, '-', "Validate the ec parameters" },
+    { "check_named", OPT_CHECK_NAMED, '-',
+        "Check that named EC curve parameters have not been modified" },
+    { "no_seed", OPT_NO_SEED, '-',
+        "If 'explicit' parameters are chosen do not use the seed" },
+    { "name", OPT_NAME, 's',
+        "Use the ec parameters with specified 'short name'" },
+    { "conv_form", OPT_CONV_FORM, 's', "Specifies the point conversion form " },
 
     OPT_R_OPTIONS,
     OPT_PROV_OPTIONS,
-    {NULL}
+    { NULL }
 };
 
 static int list_builtin_curves(BIO *out)
@@ -116,7 +129,7 @@ int ecparam_main(int argc, char **argv)
         switch (o) {
         case OPT_EOF:
         case OPT_ERR:
- opthelp:
+        opthelp:
             BIO_printf(bio_err, "%s: Use -help for summary.\n", prog);
             goto end;
         case OPT_HELP:
@@ -186,8 +199,7 @@ int ecparam_main(int argc, char **argv)
     }
 
     /* No extra args. */
-    argc = opt_num_rest();
-    if (argc != 0)
+    if (!opt_check_rest_arg(NULL))
         goto opthelp;
 
     if (!app_RAND_load())
@@ -211,28 +223,30 @@ int ecparam_main(int argc, char **argv)
 
         if (strcmp(curve_name, "secp192r1") == 0) {
             BIO_printf(bio_err,
-                       "using curve name prime192v1 instead of secp192r1\n");
+                "using curve name prime192v1 instead of secp192r1\n");
             curve_name = SN_X9_62_prime192v1;
         } else if (strcmp(curve_name, "secp256r1") == 0) {
             BIO_printf(bio_err,
-                       "using curve name prime256v1 instead of secp256r1\n");
+                "using curve name prime256v1 instead of secp256r1\n");
             curve_name = SN_X9_62_prime256v1;
         }
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_GROUP_NAME,
-                                                curve_name, 0);
+            curve_name, 0);
         if (asn1_encoding != NULL)
             *p++ = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_EC_ENCODING,
-                                                    asn1_encoding, 0);
+                asn1_encoding, 0);
         if (point_format != NULL)
             *p++ = OSSL_PARAM_construct_utf8_string(
-                       OSSL_PKEY_PARAM_EC_POINT_CONVERSION_FORMAT,
-                       point_format, 0);
+                OSSL_PKEY_PARAM_EC_POINT_CONVERSION_FORMAT,
+                point_format, 0);
         *p = OSSL_PARAM_construct_end();
 
         if (OPENSSL_strcasecmp(curve_name, "SM2") == 0)
-            gctx_params = EVP_PKEY_CTX_new_from_name(NULL, "sm2", NULL);
+            gctx_params = EVP_PKEY_CTX_new_from_name(app_get0_libctx(), "sm2",
+                app_get0_propq());
         else
-            gctx_params = EVP_PKEY_CTX_new_from_name(NULL, "ec", NULL);
+            gctx_params = EVP_PKEY_CTX_new_from_name(app_get0_libctx(), "ec",
+                app_get0_propq());
         if (gctx_params == NULL
             || EVP_PKEY_keygen_init(gctx_params) <= 0
             || EVP_PKEY_CTX_set_params(gctx_params, params) <= 0
@@ -241,20 +255,28 @@ int ecparam_main(int argc, char **argv)
             goto end;
         }
     } else {
-        params_key = load_keyparams(infile, informat, 1, "EC", "EC parameters");
-        if (params_key == NULL || !EVP_PKEY_is_a(params_key, "EC"))
+        params_key = load_keyparams_suppress(infile, informat, 1, "EC",
+            "EC parameters", 1);
+        if (params_key == NULL)
+            params_key = load_keyparams_suppress(infile, informat, 1, "SM2",
+                "SM2 parameters", 1);
+
+        if (params_key == NULL) {
+            BIO_printf(bio_err, "Unable to load parameters from %s\n", infile);
             goto end;
+        }
+
         if (point_format
             && !EVP_PKEY_set_utf8_string_param(
-                    params_key, OSSL_PKEY_PARAM_EC_POINT_CONVERSION_FORMAT,
-                    point_format)) {
+                params_key, OSSL_PKEY_PARAM_EC_POINT_CONVERSION_FORMAT,
+                point_format)) {
             BIO_printf(bio_err, "unable to set point conversion format\n");
             goto end;
         }
 
         if (asn1_encoding != NULL
             && !EVP_PKEY_set_utf8_string_param(
-                    params_key, OSSL_PKEY_PARAM_EC_ENCODING, asn1_encoding)) {
+                params_key, OSSL_PKEY_PARAM_EC_ENCODING, asn1_encoding)) {
             BIO_printf(bio_err, "unable to set asn1 encoding format\n");
             goto end;
         }
@@ -262,7 +284,7 @@ int ecparam_main(int argc, char **argv)
 
     if (no_seed
         && !EVP_PKEY_set_octet_string_param(params_key, OSSL_PKEY_PARAM_EC_SEED,
-                                            NULL, 0)) {
+            NULL, 0)) {
         BIO_printf(bio_err, "unable to clear seed\n");
         goto end;
     }
@@ -278,12 +300,13 @@ int ecparam_main(int argc, char **argv)
 
         if (check_named
             && !EVP_PKEY_set_utf8_string_param(params_key,
-                                           OSSL_PKEY_PARAM_EC_GROUP_CHECK_TYPE,
-                                           OSSL_PKEY_EC_GROUP_CHECK_NAMED)) {
-                BIO_printf(bio_err, "unable to set check_type\n");
-                goto end;
+                OSSL_PKEY_PARAM_EC_GROUP_CHECK_TYPE,
+                OSSL_PKEY_EC_GROUP_CHECK_NAMED)) {
+            BIO_printf(bio_err, "unable to set check_type\n");
+            goto end;
         }
-        pctx = EVP_PKEY_CTX_new_from_pkey(NULL, params_key, NULL);
+        pctx = EVP_PKEY_CTX_new_from_pkey(app_get0_libctx(), params_key,
+            app_get0_propq());
         if (pctx == NULL || EVP_PKEY_param_check(pctx) <= 0) {
             BIO_printf(bio_err, "failed\n");
             goto end;
@@ -296,8 +319,8 @@ int ecparam_main(int argc, char **argv)
 
     if (!noout) {
         ectx_params = OSSL_ENCODER_CTX_new_for_pkey(
-                          params_key, OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS,
-                          outformat == FORMAT_ASN1 ? "DER" : "PEM", NULL, NULL);
+            params_key, OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS,
+            outformat == FORMAT_ASN1 ? "DER" : "PEM", NULL, NULL);
         if (!OSSL_ENCODER_to_bio(ectx_params, out)) {
             BIO_printf(bio_err, "unable to write elliptic curve parameters\n");
             goto end;
@@ -313,7 +336,8 @@ int ecparam_main(int argc, char **argv)
          *    EVP_PKEY_CTX_set_group_name(gctx, curvename);
          *    EVP_PKEY_keygen(gctx, &key) <= 0)
          */
-        gctx_key = EVP_PKEY_CTX_new_from_pkey(NULL, params_key, NULL);
+        gctx_key = EVP_PKEY_CTX_new_from_pkey(app_get0_libctx(), params_key,
+            app_get0_propq());
         if (EVP_PKEY_keygen_init(gctx_key) <= 0
             || EVP_PKEY_keygen(gctx_key, &key) <= 0) {
             BIO_printf(bio_err, "unable to generate key\n");
@@ -321,11 +345,11 @@ int ecparam_main(int argc, char **argv)
         }
         assert(private);
         ectx_key = OSSL_ENCODER_CTX_new_for_pkey(
-                       key, OSSL_KEYMGMT_SELECT_ALL,
-                       outformat == FORMAT_ASN1 ? "DER" : "PEM", NULL, NULL);
+            key, OSSL_KEYMGMT_SELECT_ALL,
+            outformat == FORMAT_ASN1 ? "DER" : "PEM", NULL, NULL);
         if (!OSSL_ENCODER_to_bio(ectx_key, out)) {
             BIO_printf(bio_err, "unable to write elliptic "
-                       "curve parameters\n");
+                                "curve parameters\n");
             goto end;
         }
     }
