@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2018-2023 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -161,68 +161,79 @@
     OPT_S_NOTLS1_3, OPT_S_BUGS, OPT_S_NO_COMP, OPT_S_NOTICKET,        \
     OPT_S_SERVERPREF, OPT_S_LEGACYRENEG, OPT_S_CLIENTRENEG,           \
     OPT_S_LEGACYCONN,                                                 \
-    OPT_S_ONRESUMP, OPT_S_NOLEGACYCONN, OPT_S_ALLOW_NO_DHE_KEX,       \
+    OPT_S_ONRESUMP, OPT_S_NOLEGACYCONN,                               \
+    OPT_S_ALLOW_NO_DHE_KEX, OPT_S_PREFER_NO_DHE_KEX,                  \
     OPT_S_PRIORITIZE_CHACHA,                                          \
     OPT_S_STRICT, OPT_S_SIGALGS, OPT_S_CLIENTSIGALGS, OPT_S_GROUPS,   \
     OPT_S_CURVES, OPT_S_NAMEDCURVE, OPT_S_CIPHER, OPT_S_CIPHERSUITES, \
     OPT_S_RECORD_PADDING, OPT_S_DEBUGBROKE, OPT_S_COMP,               \
     OPT_S_MINPROTO, OPT_S_MAXPROTO,                                   \
-    OPT_S_NO_RENEGOTIATION, OPT_S_NO_MIDDLEBOX, OPT_S_NO_ETM, OPT_S__LAST
+    OPT_S_NO_RENEGOTIATION, OPT_S_NO_MIDDLEBOX, OPT_S_NO_ETM,         \
+    OPT_S_NO_EMS,                                                     \
+    OPT_S_NO_TX_CERT_COMP,                                            \
+    OPT_S_NO_RX_CERT_COMP,                                            \
+    OPT_S__LAST
 
-#define OPT_S_OPTIONS                                                                               \
-    OPT_SECTION("TLS/SSL"),                                                                         \
-        { "no_ssl3", OPT_S_NOSSL3, '-', "Just disable SSLv3" },                                     \
-        { "no_tls1", OPT_S_NOTLS1, '-', "Just disable TLSv1" },                                     \
-        { "no_tls1_1", OPT_S_NOTLS1_1, '-', "Just disable TLSv1.1" },                               \
-        { "no_tls1_2", OPT_S_NOTLS1_2, '-', "Just disable TLSv1.2" },                               \
-        { "no_tls1_3", OPT_S_NOTLS1_3, '-', "Just disable TLSv1.3" },                               \
-        { "bugs", OPT_S_BUGS, '-', "Turn on SSL bug compatibility" },                               \
-        { "no_comp", OPT_S_NO_COMP, '-', "Disable SSL/TLS compression (default)" },                 \
-        { "comp", OPT_S_COMP, '-', "Use SSL/TLS-level compression" },                               \
-        { "no_ticket", OPT_S_NOTICKET, '-',                                                         \
-            "Disable use of TLS session tickets" },                                                 \
-        { "serverpref", OPT_S_SERVERPREF, '-', "Use server's cipher preferences" },                 \
-        { "legacy_renegotiation", OPT_S_LEGACYRENEG, '-',                                           \
-            "Enable use of legacy renegotiation (dangerous)" },                                     \
-        { "client_renegotiation", OPT_S_CLIENTRENEG, '-',                                           \
-            "Allow client-initiated renegotiation" },                                               \
-        { "no_renegotiation", OPT_S_NO_RENEGOTIATION, '-',                                          \
-            "Disable all renegotiation." },                                                         \
-        { "legacy_server_connect", OPT_S_LEGACYCONN, '-',                                           \
-            "Allow initial connection to servers that don't support RI" },                          \
-        { "no_resumption_on_reneg", OPT_S_ONRESUMP, '-',                                            \
-            "Disallow session resumption on renegotiation" },                                       \
-        { "no_legacy_server_connect", OPT_S_NOLEGACYCONN, '-',                                      \
-            "Disallow initial connection to servers that don't support RI" },                       \
-        { "allow_no_dhe_kex", OPT_S_ALLOW_NO_DHE_KEX, '-',                                          \
-            "In TLSv1.3 allow non-(ec)dhe based key exchange on resumption" },                      \
-        { "prioritize_chacha", OPT_S_PRIORITIZE_CHACHA, '-',                                        \
-            "Prioritize ChaCha ciphers when preferred by clients" },                                \
-        { "strict", OPT_S_STRICT, '-',                                                              \
-            "Enforce strict certificate checks as per TLS standard" },                              \
-        { "sigalgs", OPT_S_SIGALGS, 's',                                                            \
-            "Signature algorithms to support (colon-separated list)" },                             \
-        { "client_sigalgs", OPT_S_CLIENTSIGALGS, 's',                                               \
-            "Signature algorithms to support for client certificate"                                \
-            " authentication (colon-separated list)" },                                             \
-        { "groups", OPT_S_GROUPS, 's',                                                              \
-            "Groups to advertise (colon-separated list)" },                                         \
-        { "curves", OPT_S_CURVES, 's',                                                              \
-            "Groups to advertise (colon-separated list)" },                                         \
-        { "named_curve", OPT_S_NAMEDCURVE, 's',                                                     \
-            "Elliptic curve used for ECDHE (server-side only)" },                                   \
-        { "cipher", OPT_S_CIPHER, 's', "Specify TLSv1.2 and below cipher list to be used" },        \
-        { "ciphersuites", OPT_S_CIPHERSUITES, 's', "Specify TLSv1.3 ciphersuites to be used" },     \
-        { "min_protocol", OPT_S_MINPROTO, 's', "Specify the minimum protocol version to be used" }, \
-        { "max_protocol", OPT_S_MAXPROTO, 's', "Specify the maximum protocol version to be used" }, \
-        { "record_padding", OPT_S_RECORD_PADDING, 's',                                              \
-            "Block size to pad TLS 1.3 records to." },                                              \
-        { "debug_broken_protocol", OPT_S_DEBUGBROKE, '-',                                           \
-            "Perform all sorts of protocol violations for testing purposes" },                      \
-        { "no_middlebox", OPT_S_NO_MIDDLEBOX, '-',                                                  \
-            "Disable TLSv1.3 middlebox compat mode" },                                              \
-        { "no_etm", OPT_S_NO_ETM, '-',                                                              \
-            "Disable Encrypt-then-Mac extension" }
+#define OPT_S_OPTIONS                                                                                           \
+    OPT_SECTION("TLS/SSL"),                                                                                     \
+        { "no_ssl3", OPT_S_NOSSL3, '-', "Just disable SSLv3" },                                                 \
+        { "no_tls1", OPT_S_NOTLS1, '-', "Just disable TLSv1" },                                                 \
+        { "no_tls1_1", OPT_S_NOTLS1_1, '-', "Just disable TLSv1.1" },                                           \
+        { "no_tls1_2", OPT_S_NOTLS1_2, '-', "Just disable TLSv1.2" },                                           \
+        { "no_tls1_3", OPT_S_NOTLS1_3, '-', "Just disable TLSv1.3" },                                           \
+        { "bugs", OPT_S_BUGS, '-', "Turn on SSL bug compatibility" },                                           \
+        { "no_comp", OPT_S_NO_COMP, '-', "Disable SSL/TLS compression (default)" },                             \
+        { "comp", OPT_S_COMP, '-', "Use SSL/TLS-level compression" },                                           \
+        { "no_tx_cert_comp", OPT_S_NO_TX_CERT_COMP, '-', "Disable sending TLSv1.3 compressed certificates" },   \
+        { "no_rx_cert_comp", OPT_S_NO_RX_CERT_COMP, '-', "Disable receiving TLSv1.3 compressed certificates" }, \
+        { "no_ticket", OPT_S_NOTICKET, '-',                                                                     \
+            "Disable use of TLS session tickets" },                                                             \
+        { "serverpref", OPT_S_SERVERPREF, '-', "Use server's cipher preferences" },                             \
+        { "legacy_renegotiation", OPT_S_LEGACYRENEG, '-',                                                       \
+            "Enable use of legacy renegotiation (dangerous)" },                                                 \
+        { "client_renegotiation", OPT_S_CLIENTRENEG, '-',                                                       \
+            "Allow client-initiated renegotiation" },                                                           \
+        { "no_renegotiation", OPT_S_NO_RENEGOTIATION, '-',                                                      \
+            "Disable all renegotiation." },                                                                     \
+        { "legacy_server_connect", OPT_S_LEGACYCONN, '-',                                                       \
+            "Allow initial connection to servers that don't support RI" },                                      \
+        { "no_resumption_on_reneg", OPT_S_ONRESUMP, '-',                                                        \
+            "Disallow session resumption on renegotiation" },                                                   \
+        { "no_legacy_server_connect", OPT_S_NOLEGACYCONN, '-',                                                  \
+            "Disallow initial connection to servers that don't support RI" },                                   \
+        { "allow_no_dhe_kex", OPT_S_ALLOW_NO_DHE_KEX, '-',                                                      \
+            "In TLSv1.3 allow non-(ec)dhe based key exchange on resumption" },                                  \
+        { "prefer_no_dhe_kex", OPT_S_PREFER_NO_DHE_KEX, '-',                                                    \
+            "In TLSv1.3 prefer non-(ec)dhe over (ec)dhe-based key exchange on resumption" },                    \
+        { "prioritize_chacha", OPT_S_PRIORITIZE_CHACHA, '-',                                                    \
+            "Prioritize ChaCha ciphers when preferred by clients" },                                            \
+        { "strict", OPT_S_STRICT, '-',                                                                          \
+            "Enforce strict certificate checks as per TLS standard" },                                          \
+        { "sigalgs", OPT_S_SIGALGS, 's',                                                                        \
+            "Signature algorithms to support (colon-separated list)" },                                         \
+        { "client_sigalgs", OPT_S_CLIENTSIGALGS, 's',                                                           \
+            "Signature algorithms to support for client certificate"                                            \
+            " authentication (colon-separated list)" },                                                         \
+        { "groups", OPT_S_GROUPS, 's',                                                                          \
+            "Groups to advertise (colon-separated list)" },                                                     \
+        { "curves", OPT_S_CURVES, 's',                                                                          \
+            "Groups to advertise (colon-separated list)" },                                                     \
+        { "named_curve", OPT_S_NAMEDCURVE, 's',                                                                 \
+            "Elliptic curve used for ECDHE (server-side only)" },                                               \
+        { "cipher", OPT_S_CIPHER, 's', "Specify TLSv1.2 and below cipher list to be used" },                    \
+        { "ciphersuites", OPT_S_CIPHERSUITES, 's', "Specify TLSv1.3 ciphersuites to be used" },                 \
+        { "min_protocol", OPT_S_MINPROTO, 's', "Specify the minimum protocol version to be used" },             \
+        { "max_protocol", OPT_S_MAXPROTO, 's', "Specify the maximum protocol version to be used" },             \
+        { "record_padding", OPT_S_RECORD_PADDING, 's',                                                          \
+            "Block size to pad TLS 1.3 records to." },                                                          \
+        { "debug_broken_protocol", OPT_S_DEBUGBROKE, '-',                                                       \
+            "Perform all sorts of protocol violations for testing purposes" },                                  \
+        { "no_middlebox", OPT_S_NO_MIDDLEBOX, '-',                                                              \
+            "Disable TLSv1.3 middlebox compat mode" },                                                          \
+        { "no_etm", OPT_S_NO_ETM, '-',                                                                          \
+            "Disable Encrypt-then-Mac extension" },                                                             \
+        { "no_ems", OPT_S_NO_EMS, '-',                                                                          \
+            "Disable Extended master secret extension" }
 
 #define OPT_S_CASES               \
     OPT_S__FIRST:                 \
@@ -236,6 +247,8 @@
     case OPT_S_BUGS:              \
     case OPT_S_NO_COMP:           \
     case OPT_S_COMP:              \
+    case OPT_S_NO_TX_CERT_COMP:   \
+    case OPT_S_NO_RX_CERT_COMP:   \
     case OPT_S_NOTICKET:          \
     case OPT_S_SERVERPREF:        \
     case OPT_S_LEGACYRENEG:       \
@@ -244,6 +257,7 @@
     case OPT_S_ONRESUMP:          \
     case OPT_S_NOLEGACYCONN:      \
     case OPT_S_ALLOW_NO_DHE_KEX:  \
+    case OPT_S_PREFER_NO_DHE_KEX: \
     case OPT_S_PRIORITIZE_CHACHA: \
     case OPT_S_STRICT:            \
     case OPT_S_SIGALGS:           \
@@ -259,7 +273,8 @@
     case OPT_S_MAXPROTO:          \
     case OPT_S_DEBUGBROKE:        \
     case OPT_S_NO_MIDDLEBOX:      \
-    case OPT_S_NO_ETM
+    case OPT_S_NO_ETM:            \
+    case OPT_S_NO_EMS
 
 #define IS_NO_PROT_FLAG(o)                                         \
     (o == OPT_S_NOSSL3 || o == OPT_S_NOTLS1 || o == OPT_S_NOTLS1_1 \
@@ -319,11 +334,28 @@ extern const char OPT_PARAM_STR[];
 typedef struct options_st {
     const char *name;
     int retval;
-    /*
-     * value type: - no value (also the value zero), n number, p positive
-     * number, u unsigned, l long, s string, < input file, > output file,
-     * f any format, F der/pem format, E der/pem/engine format identifier.
-     * l, n and u include zero; p does not.
+    /*-
+     * value type:
+     *
+     *   '-' no value (also the value zero)
+     *   'n' number (type 'int')
+     *   'p' positive number (type 'int')
+     *   'u' unsigned number (type 'unsigned long')
+     *   'l' number (type 'unsigned long')
+     *   'M' number (type 'intmax_t')
+     *   'U' unsigned number (type 'uintmax_t')
+     *   's' string
+     *   '<' input file
+     *   '>' output file
+     *   '/' directory
+     *   'f' any format                    [OPT_FMT_ANY]
+     *   'F' der/pem format                [OPT_FMT_PEMDER]
+     *   'A' any ASN1, der/pem/b64 format  [OPT_FMT_ASN1]
+     *   'E' der/pem/engine format         [OPT_FMT_PDE]
+     *   'c' pem/der/smime format          [OPT_FMT_PDS]
+     *
+     * The 'l', 'n' and 'u' value types include the values zero,
+     * the 'p' value type does not.
      */
     int valtype;
     const char *helpstr;
@@ -343,20 +375,24 @@ typedef struct string_int_pair_st {
 } OPT_PAIR, STRINT_PAIR;
 
 /* Flags to pass into opt_format; see FORMAT_xxx, below. */
-#define OPT_FMT_PEMDER (1L << 1)
-#define OPT_FMT_PKCS12 (1L << 2)
-#define OPT_FMT_SMIME (1L << 3)
-#define OPT_FMT_ENGINE (1L << 4)
-#define OPT_FMT_MSBLOB (1L << 5)
-/* (1L <<  6) was OPT_FMT_NETSCAPE, but wasn't used */
-#define OPT_FMT_NSS (1L << 7)
-#define OPT_FMT_TEXT (1L << 8)
-#define OPT_FMT_HTTP (1L << 9)
-#define OPT_FMT_PVK (1L << 10)
+#define OPT_FMT_PEM (1L << 1)
+#define OPT_FMT_DER (1L << 2)
+#define OPT_FMT_B64 (1L << 3)
+#define OPT_FMT_PKCS12 (1L << 4)
+#define OPT_FMT_SMIME (1L << 5)
+#define OPT_FMT_ENGINE (1L << 6)
+#define OPT_FMT_MSBLOB (1L << 7)
+#define OPT_FMT_NSS (1L << 8)
+#define OPT_FMT_TEXT (1L << 9)
+#define OPT_FMT_HTTP (1L << 10)
+#define OPT_FMT_PVK (1L << 11)
+
+#define OPT_FMT_PEMDER (OPT_FMT_PEM | OPT_FMT_DER)
+#define OPT_FMT_ASN1 (OPT_FMT_PEM | OPT_FMT_DER | OPT_FMT_B64)
 #define OPT_FMT_PDE (OPT_FMT_PEMDER | OPT_FMT_ENGINE)
 #define OPT_FMT_PDS (OPT_FMT_PEMDER | OPT_FMT_SMIME)
 #define OPT_FMT_ANY ( \
-    OPT_FMT_PEMDER | OPT_FMT_PKCS12 | OPT_FMT_SMIME | OPT_FMT_ENGINE | OPT_FMT_MSBLOB | OPT_FMT_NSS | OPT_FMT_TEXT | OPT_FMT_HTTP | OPT_FMT_PVK)
+    OPT_FMT_PEM | OPT_FMT_DER | OPT_FMT_B64 | OPT_FMT_PKCS12 | OPT_FMT_SMIME | OPT_FMT_ENGINE | OPT_FMT_MSBLOB | OPT_FMT_NSS | OPT_FMT_TEXT | OPT_FMT_HTTP | OPT_FMT_PVK)
 
 /* Divide options into sections when displaying usage */
 #define OPT_SECTION(sec) { OPT_SECTION_STR, 1, '-', sec " options:\n" }
@@ -374,13 +410,16 @@ int opt_next(void);
 char *opt_flag(void);
 char *opt_arg(void);
 char *opt_unknown(void);
+void reset_unknown(void);
 int opt_cipher(const char *name, EVP_CIPHER **cipherp);
 int opt_cipher_any(const char *name, EVP_CIPHER **cipherp);
 int opt_cipher_silent(const char *name, EVP_CIPHER **cipherp);
+int opt_check_md(const char *name);
 int opt_md(const char *name, EVP_MD **mdp);
 int opt_md_silent(const char *name, EVP_MD **mdp);
 
 int opt_int(const char *arg, int *result);
+void opt_set_unknown_name(const char *name);
 int opt_int_arg(void);
 int opt_long(const char *arg, long *result);
 int opt_ulong(const char *arg, unsigned long *result);
@@ -401,6 +440,7 @@ int opt_provider_option_given(void);
 
 char **opt_rest(void);
 int opt_num_rest(void);
+int opt_check_rest_arg(const char *expected);
 
 /* Returns non-zero if legacy paths are still available */
 int opt_legacy_okay(void);
