@@ -13,26 +13,32 @@
 
 typedef enum OPTION_choice {
     OPT_COMMON,
-    OPT_CONFIGDIR, OPT_ENGINESDIR, OPT_MODULESDIR, OPT_DSOEXT, OPT_DIRNAMESEP,
-    OPT_LISTSEP, OPT_SEEDS, OPT_CPUSETTINGS
+    OPT_CONFIGDIR,
+    OPT_ENGINESDIR,
+    OPT_MODULESDIR,
+    OPT_DSOEXT,
+    OPT_DIRNAMESEP,
+    OPT_LISTSEP,
+    OPT_SEEDS,
+    OPT_CPUSETTINGS
 } OPTION_CHOICE;
 
 const OPTIONS info_options[] = {
 
     OPT_SECTION("General"),
-    {"help", OPT_HELP, '-', "Display this summary"},
+    { "help", OPT_HELP, '-', "Display this summary" },
 
     OPT_SECTION("Output"),
-    {"configdir", OPT_CONFIGDIR, '-', "Default configuration file directory"},
-    {"enginesdir", OPT_ENGINESDIR, '-', "Default engine module directory"},
-    {"modulesdir", OPT_MODULESDIR, '-',
-     "Default module directory (other than engine modules)"},
-    {"dsoext", OPT_DSOEXT, '-', "Configured extension for modules"},
-    {"dirnamesep", OPT_DIRNAMESEP, '-', "Directory-filename separator"},
-    {"listsep", OPT_LISTSEP, '-', "List separator character"},
-    {"seeds", OPT_SEEDS, '-', "Seed sources"},
-    {"cpusettings", OPT_CPUSETTINGS, '-', "CPU settings info"},
-    {NULL}
+    { "configdir", OPT_CONFIGDIR, '-', "Default configuration file directory" },
+    { "enginesdir", OPT_ENGINESDIR, '-', "Default engine module directory" },
+    { "modulesdir", OPT_MODULESDIR, '-',
+        "Default module directory (other than engine modules)" },
+    { "dsoext", OPT_DSOEXT, '-', "Configured extension for modules" },
+    { "dirnamesep", OPT_DIRNAMESEP, '-', "Directory-filename separator" },
+    { "listsep", OPT_LISTSEP, '-', "List separator character" },
+    { "seeds", OPT_SEEDS, '-', "Seed sources" },
+    { "cpusettings", OPT_CPUSETTINGS, '-', "CPU settings info" },
+    { NULL }
 };
 
 int info_main(int argc, char **argv)
@@ -45,7 +51,7 @@ int info_main(int argc, char **argv)
     while ((o = opt_next()) != OPT_EOF) {
         switch (o) {
         default:
-opthelp:
+        opthelp:
             BIO_printf(bio_err, "%s: Use -help for summary.\n", prog);
             goto end;
         case OPT_HELP:
@@ -99,6 +105,6 @@ opthelp:
 
     BIO_printf(bio_out, "%s\n", OPENSSL_info(type));
     ret = 0;
- end:
+end:
     return ret;
 }
