@@ -15,90 +15,112 @@
 #include <openssl/evp.h>
 #include <sys/stat.h>
 
-#define KEY_NONE        0
-#define KEY_PRIVKEY     1
-#define KEY_PUBKEY      2
-#define KEY_CERT        3
+#define KEY_NONE 0
+#define KEY_PRIVKEY 1
+#define KEY_PUBKEY 2
+#define KEY_CERT 3
 
 static EVP_PKEY_CTX *init_ctx(const char *kdfalg, int *pkeysize,
-                              const char *keyfile, int keyform, int key_type,
-                              char *passinarg, int pkey_op, ENGINE *e,
-                              const int impl, int rawin, EVP_PKEY **ppkey,
-                              EVP_MD_CTX *mctx, const char *digestname,
-                              OSSL_LIB_CTX *libctx, const char *propq);
+    const char *keyfile, int keyform, int key_type,
+    char *passinarg, int pkey_op, ENGINE *e,
+    const int impl, int rawin, EVP_PKEY **ppkey,
+    EVP_MD_CTX *mctx, const char *digestname,
+    OSSL_LIB_CTX *libctx, const char *propq);
 
 static int setup_peer(EVP_PKEY_CTX *ctx, int peerform, const char *file,
-                      ENGINE *e);
+    ENGINE *e);
 
 static int do_keyop(EVP_PKEY_CTX *ctx, int pkey_op,
-                    unsigned char *out, size_t *poutlen,
-                    const unsigned char *in, size_t inlen);
+    unsigned char *out, size_t *poutlen,
+    const unsigned char *in, size_t inlen);
 
 static int do_raw_keyop(int pkey_op, EVP_MD_CTX *mctx,
-                        EVP_PKEY *pkey, BIO *in,
-                        int filesize, unsigned char *sig, int siglen,
-                        unsigned char **out, size_t *poutlen);
+    EVP_PKEY *pkey, BIO *in,
+    int filesize, unsigned char *sig, int siglen,
+    unsigned char **out, size_t *poutlen);
 
 typedef enum OPTION_choice {
     OPT_COMMON,
-    OPT_ENGINE, OPT_ENGINE_IMPL, OPT_IN, OPT_OUT,
-    OPT_PUBIN, OPT_CERTIN, OPT_ASN1PARSE, OPT_HEXDUMP, OPT_SIGN,
-    OPT_VERIFY, OPT_VERIFYRECOVER, OPT_REV, OPT_ENCRYPT, OPT_DECRYPT,
-    OPT_DERIVE, OPT_SIGFILE, OPT_INKEY, OPT_PEERKEY, OPT_PASSIN,
-    OPT_PEERFORM, OPT_KEYFORM, OPT_PKEYOPT, OPT_PKEYOPT_PASSIN, OPT_KDF,
-    OPT_KDFLEN, OPT_R_ENUM, OPT_PROV_ENUM,
+    OPT_ENGINE,
+    OPT_ENGINE_IMPL,
+    OPT_IN,
+    OPT_OUT,
+    OPT_PUBIN,
+    OPT_CERTIN,
+    OPT_ASN1PARSE,
+    OPT_HEXDUMP,
+    OPT_SIGN,
+    OPT_VERIFY,
+    OPT_VERIFYRECOVER,
+    OPT_REV,
+    OPT_ENCRYPT,
+    OPT_DECRYPT,
+    OPT_DERIVE,
+    OPT_SIGFILE,
+    OPT_INKEY,
+    OPT_PEERKEY,
+    OPT_PASSIN,
+    OPT_PEERFORM,
+    OPT_KEYFORM,
+    OPT_PKEYOPT,
+    OPT_PKEYOPT_PASSIN,
+    OPT_KDF,
+    OPT_KDFLEN,
+    OPT_R_ENUM,
+    OPT_PROV_ENUM,
     OPT_CONFIG,
-    OPT_RAWIN, OPT_DIGEST
+    OPT_RAWIN,
+    OPT_DIGEST
 } OPTION_CHOICE;
 
 const OPTIONS pkeyutl_options[] = {
     OPT_SECTION("General"),
-    {"help", OPT_HELP, '-', "Display this summary"},
+    { "help", OPT_HELP, '-', "Display this summary" },
 #ifndef OPENSSL_NO_ENGINE
-    {"engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device"},
-    {"engine_impl", OPT_ENGINE_IMPL, '-',
-     "Also use engine given by -engine for crypto operations"},
+    { "engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device" },
+    { "engine_impl", OPT_ENGINE_IMPL, '-',
+        "Also use engine given by -engine for crypto operations" },
 #endif
-    {"sign", OPT_SIGN, '-', "Sign input data with private key"},
-    {"verify", OPT_VERIFY, '-', "Verify with public key"},
-    {"encrypt", OPT_ENCRYPT, '-', "Encrypt input data with public key"},
-    {"decrypt", OPT_DECRYPT, '-', "Decrypt input data with private key"},
-    {"derive", OPT_DERIVE, '-', "Derive shared secret"},
+    { "sign", OPT_SIGN, '-', "Sign input data with private key" },
+    { "verify", OPT_VERIFY, '-', "Verify with public key" },
+    { "encrypt", OPT_ENCRYPT, '-', "Encrypt input data with public key" },
+    { "decrypt", OPT_DECRYPT, '-', "Decrypt input data with private key" },
+    { "derive", OPT_DERIVE, '-', "Derive shared secret" },
     OPT_CONFIG_OPTION,
 
     OPT_SECTION("Input"),
-    {"in", OPT_IN, '<', "Input file - default stdin"},
-    {"rawin", OPT_RAWIN, '-', "Indicate the input data is in raw form"},
-    {"inkey", OPT_INKEY, 's', "Input key, by default private key"},
-    {"pubin", OPT_PUBIN, '-', "Input key is a public key"},
-    {"passin", OPT_PASSIN, 's', "Input file pass phrase source"},
-    {"peerkey", OPT_PEERKEY, 's', "Peer key file used in key derivation"},
-    {"peerform", OPT_PEERFORM, 'E', "Peer key format (DER/PEM/P12/ENGINE)"},
-    {"certin", OPT_CERTIN, '-', "Input is a cert with a public key"},
-    {"rev", OPT_REV, '-', "Reverse the order of the input buffer"},
-    {"sigfile", OPT_SIGFILE, '<', "Signature file (verify operation only)"},
-    {"keyform", OPT_KEYFORM, 'E', "Private key format (ENGINE, other values ignored)"},
+    { "in", OPT_IN, '<', "Input file - default stdin" },
+    { "rawin", OPT_RAWIN, '-', "Indicate the input data is in raw form" },
+    { "inkey", OPT_INKEY, 's', "Input key, by default private key" },
+    { "pubin", OPT_PUBIN, '-', "Input key is a public key" },
+    { "passin", OPT_PASSIN, 's', "Input file pass phrase source" },
+    { "peerkey", OPT_PEERKEY, 's', "Peer key file used in key derivation" },
+    { "peerform", OPT_PEERFORM, 'E', "Peer key format (DER/PEM/P12/ENGINE)" },
+    { "certin", OPT_CERTIN, '-', "Input is a cert with a public key" },
+    { "rev", OPT_REV, '-', "Reverse the order of the input buffer" },
+    { "sigfile", OPT_SIGFILE, '<', "Signature file (verify operation only)" },
+    { "keyform", OPT_KEYFORM, 'E', "Private key format (ENGINE, other values ignored)" },
 
     OPT_SECTION("Output"),
-    {"out", OPT_OUT, '>', "Output file - default stdout"},
-    {"asn1parse", OPT_ASN1PARSE, '-',
-     "parse the output as ASN.1 data to check its DER encoding and print errors"},
-    {"hexdump", OPT_HEXDUMP, '-', "Hex dump output"},
-    {"verifyrecover", OPT_VERIFYRECOVER, '-',
-     "Verify RSA signature, recovering original signature input data"},
+    { "out", OPT_OUT, '>', "Output file - default stdout" },
+    { "asn1parse", OPT_ASN1PARSE, '-',
+        "parse the output as ASN.1 data to check its DER encoding and print errors" },
+    { "hexdump", OPT_HEXDUMP, '-', "Hex dump output" },
+    { "verifyrecover", OPT_VERIFYRECOVER, '-',
+        "Verify RSA signature, recovering original signature input data" },
 
     OPT_SECTION("Signing/Derivation"),
-    {"digest", OPT_DIGEST, 's',
-     "Specify the digest algorithm when signing the raw input data"},
-    {"pkeyopt", OPT_PKEYOPT, 's', "Public key options as opt:value"},
-    {"pkeyopt_passin", OPT_PKEYOPT_PASSIN, 's',
-     "Public key option that is read as a passphrase argument opt:passphrase"},
-    {"kdf", OPT_KDF, 's', "Use KDF algorithm"},
-    {"kdflen", OPT_KDFLEN, 'p', "KDF algorithm output length"},
+    { "digest", OPT_DIGEST, 's',
+        "Specify the digest algorithm when signing the raw input data" },
+    { "pkeyopt", OPT_PKEYOPT, 's', "Public key options as opt:value" },
+    { "pkeyopt_passin", OPT_PKEYOPT_PASSIN, 's',
+        "Public key option that is read as a passphrase argument opt:passphrase" },
+    { "kdf", OPT_KDF, 's', "Use KDF algorithm" },
+    { "kdflen", OPT_KDFLEN, 'p', "KDF algorithm output length" },
 
     OPT_R_OPTIONS,
     OPT_PROV_OPTIONS,
-    {NULL}
+    { NULL }
 };
 
 int pkeyutl_main(int argc, char **argv)
@@ -135,7 +157,7 @@ int pkeyutl_main(int argc, char **argv)
         switch (o) {
         case OPT_EOF:
         case OPT_ERR:
- opthelp:
+        opthelp:
             BIO_printf(bio_err, "%s: Use -help for summary.\n", prog);
             goto end;
         case OPT_HELP:
@@ -229,17 +251,13 @@ int pkeyutl_main(int argc, char **argv)
             rev = 1;
             break;
         case OPT_PKEYOPT:
-            if ((pkeyopts == NULL &&
-                 (pkeyopts = sk_OPENSSL_STRING_new_null()) == NULL) ||
-                sk_OPENSSL_STRING_push(pkeyopts, opt_arg()) == 0) {
+            if ((pkeyopts == NULL && (pkeyopts = sk_OPENSSL_STRING_new_null()) == NULL) || sk_OPENSSL_STRING_push(pkeyopts, opt_arg()) == 0) {
                 BIO_puts(bio_err, "out of memory\n");
                 goto end;
             }
             break;
         case OPT_PKEYOPT_PASSIN:
-            if ((pkeyopts_passin == NULL &&
-                 (pkeyopts_passin = sk_OPENSSL_STRING_new_null()) == NULL) ||
-                sk_OPENSSL_STRING_push(pkeyopts_passin, opt_arg()) == 0) {
+            if ((pkeyopts_passin == NULL && (pkeyopts_passin = sk_OPENSSL_STRING_new_null()) == NULL) || sk_OPENSSL_STRING_push(pkeyopts_passin, opt_arg()) == 0) {
                 BIO_puts(bio_err, "out of memory\n");
                 goto end;
             }
@@ -262,37 +280,37 @@ int pkeyutl_main(int argc, char **argv)
 
     if (rawin && pkey_op != EVP_PKEY_OP_SIGN && pkey_op != EVP_PKEY_OP_VERIFY) {
         BIO_printf(bio_err,
-                   "%s: -rawin can only be used with -sign or -verify\n",
-                   prog);
+            "%s: -rawin can only be used with -sign or -verify\n",
+            prog);
         goto opthelp;
     }
 
     if (digestname != NULL && !rawin) {
         BIO_printf(bio_err,
-                   "%s: -digest can only be used with -rawin\n",
-                   prog);
+            "%s: -digest can only be used with -rawin\n",
+            prog);
         goto opthelp;
     }
 
     if (rawin && rev) {
         BIO_printf(bio_err, "%s: -rev cannot be used with raw input\n",
-                   prog);
+            prog);
         goto opthelp;
     }
 
     if (kdfalg != NULL) {
         if (kdflen == 0) {
             BIO_printf(bio_err,
-                       "%s: no KDF length given (-kdflen parameter).\n", prog);
+                "%s: no KDF length given (-kdflen parameter).\n", prog);
             goto opthelp;
         }
     } else if (inkey == NULL) {
         BIO_printf(bio_err,
-                   "%s: no private key given (-inkey parameter).\n", prog);
+            "%s: no private key given (-inkey parameter).\n", prog);
         goto opthelp;
     } else if (peerkey != NULL && pkey_op != EVP_PKEY_OP_DERIVE) {
         BIO_printf(bio_err,
-                   "%s: no peer key given (-peerkey parameter).\n", prog);
+            "%s: no peer key given (-peerkey parameter).\n", prog);
         goto opthelp;
     }
 
@@ -303,8 +321,8 @@ int pkeyutl_main(int argc, char **argv)
         }
     }
     ctx = init_ctx(kdfalg, &keysize, inkey, keyform, key_type,
-                   passinarg, pkey_op, e, engine_impl, rawin, &pkey,
-                   mctx, digestname, libctx, app_get0_propq());
+        passinarg, pkey_op, e, engine_impl, rawin, &pkey,
+        mctx, digestname, libctx, app_get0_propq());
     if (ctx == NULL) {
         BIO_printf(bio_err, "%s: Error initializing context\n", prog);
         goto end;
@@ -322,7 +340,7 @@ int pkeyutl_main(int argc, char **argv)
 
             if (pkey_ctrl_string(ctx, opt) <= 0) {
                 BIO_printf(bio_err, "%s: Can't set parameter \"%s\":\n",
-                           prog, opt);
+                    prog, opt);
                 goto end;
             }
         }
@@ -343,7 +361,7 @@ int pkeyutl_main(int argc, char **argv)
 
                 BIO_snprintf(passwd_buf, sizeof(passwd_buf), "Enter %s: ", opt);
                 r = EVP_read_pw_string(passwd_buf, sizeof(passwd_buf) - 1,
-                                       passwd_buf, 0);
+                    passwd_buf, 0);
                 if (r < 0) {
                     if (r == -2)
                         BIO_puts(bio_err, "user abort\n");
@@ -369,7 +387,7 @@ int pkeyutl_main(int argc, char **argv)
 
             if (EVP_PKEY_CTX_ctrl_str(ctx, opt, passwd) <= 0) {
                 BIO_printf(bio_err, "%s: Can't set parameter \"%s\":\n",
-                           prog, opt);
+                    prog, opt);
                 OPENSSL_free(passwd);
                 goto end;
             }
@@ -379,13 +397,13 @@ int pkeyutl_main(int argc, char **argv)
 
     if (sigfile != NULL && (pkey_op != EVP_PKEY_OP_VERIFY)) {
         BIO_printf(bio_err,
-                   "%s: Signature file specified for non verify\n", prog);
+            "%s: Signature file specified for non verify\n", prog);
         goto end;
     }
 
     if (sigfile == NULL && (pkey_op == EVP_PKEY_OP_VERIFY)) {
         BIO_printf(bio_err,
-                   "%s: No signature file specified for verify\n", prog);
+            "%s: No signature file specified for verify\n", prog);
         goto end;
     }
 
@@ -441,21 +459,21 @@ int pkeyutl_main(int argc, char **argv)
 
     /* Sanity check the input if the input is not raw */
     if (!rawin
-            && buf_inlen > EVP_MAX_MD_SIZE
-            && (pkey_op == EVP_PKEY_OP_SIGN
-                || pkey_op == EVP_PKEY_OP_VERIFY)) {
+        && buf_inlen > EVP_MAX_MD_SIZE
+        && (pkey_op == EVP_PKEY_OP_SIGN
+            || pkey_op == EVP_PKEY_OP_VERIFY)) {
         BIO_printf(bio_err,
-                   "Error: The input data looks too long to be a hash\n");
+            "Error: The input data looks too long to be a hash\n");
         goto end;
     }
 
     if (pkey_op == EVP_PKEY_OP_VERIFY) {
         if (rawin) {
             rv = do_raw_keyop(pkey_op, mctx, pkey, in, filesize, sig, siglen,
-                              NULL, 0);
+                NULL, 0);
         } else {
             rv = EVP_PKEY_verify(ctx, sig, (size_t)siglen,
-                                 buf_in, (size_t)buf_inlen);
+                buf_in, (size_t)buf_inlen);
         }
         if (rv == 1) {
             BIO_puts(out, "Signature Verified Successfully\n");
@@ -468,20 +486,20 @@ int pkeyutl_main(int argc, char **argv)
     if (rawin) {
         /* rawin allocates the buffer in do_raw_keyop() */
         rv = do_raw_keyop(pkey_op, mctx, pkey, in, filesize, NULL, 0,
-                          &buf_out, (size_t *)&buf_outlen);
+            &buf_out, (size_t *)&buf_outlen);
     } else {
         if (kdflen != 0) {
             buf_outlen = kdflen;
             rv = 1;
         } else {
             rv = do_keyop(ctx, pkey_op, NULL, (size_t *)&buf_outlen,
-                          buf_in, (size_t)buf_inlen);
+                buf_in, (size_t)buf_inlen);
         }
         if (rv > 0 && buf_outlen != 0) {
             buf_out = app_malloc(buf_outlen, "buffer output");
             rv = do_keyop(ctx, pkey_op,
-                          buf_out, (size_t *)&buf_outlen,
-                          buf_in, (size_t)buf_inlen);
+                buf_out, (size_t *)&buf_outlen,
+                buf_in, (size_t)buf_inlen);
         }
     }
     if (rv <= 0) {
@@ -503,7 +521,7 @@ int pkeyutl_main(int argc, char **argv)
         BIO_write(out, buf_out, buf_outlen);
     }
 
- end:
+end:
     if (ret != 0)
         ERR_print_errors(bio_err);
     EVP_MD_CTX_free(mctx);
@@ -522,11 +540,11 @@ int pkeyutl_main(int argc, char **argv)
 }
 
 static EVP_PKEY_CTX *init_ctx(const char *kdfalg, int *pkeysize,
-                              const char *keyfile, int keyform, int key_type,
-                              char *passinarg, int pkey_op, ENGINE *e,
-                              const int engine_impl, int rawin,
-                              EVP_PKEY **ppkey, EVP_MD_CTX *mctx, const char *digestname,
-                              OSSL_LIB_CTX *libctx, const char *propq)
+    const char *keyfile, int keyform, int key_type,
+    char *passinarg, int pkey_op, ENGINE *e,
+    const int engine_impl, int rawin,
+    EVP_PKEY **ppkey, EVP_MD_CTX *mctx, const char *digestname,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     EVP_PKEY *pkey = NULL;
     EVP_PKEY_CTX *ctx = NULL;
@@ -536,7 +554,7 @@ static EVP_PKEY_CTX *init_ctx(const char *kdfalg, int *pkeysize,
     X509 *x;
 
     if (((pkey_op == EVP_PKEY_OP_SIGN) || (pkey_op == EVP_PKEY_OP_DECRYPT)
-         || (pkey_op == EVP_PKEY_OP_DERIVE))
+            || (pkey_op == EVP_PKEY_OP_DERIVE))
         && (key_type != KEY_PRIVKEY && kdfalg == NULL)) {
         BIO_printf(bio_err, "A private key is needed for this operation\n");
         goto end;
@@ -564,7 +582,6 @@ static EVP_PKEY_CTX *init_ctx(const char *kdfalg, int *pkeysize,
 
     case KEY_NONE:
         break;
-
     }
 
 #ifndef OPENSSL_NO_ENGINE
@@ -579,7 +596,7 @@ static EVP_PKEY_CTX *init_ctx(const char *kdfalg, int *pkeysize,
             kdfnid = OBJ_ln2nid(kdfalg);
             if (kdfnid == NID_undef) {
                 BIO_printf(bio_err, "The given KDF \"%s\" is unknown.\n",
-                           kdfalg);
+                    kdfalg);
                 goto end;
             }
         }
@@ -610,12 +627,12 @@ static EVP_PKEY_CTX *init_ctx(const char *kdfalg, int *pkeysize,
         switch (pkey_op) {
         case EVP_PKEY_OP_SIGN:
             rv = EVP_DigestSignInit_ex(mctx, NULL, digestname, libctx, propq,
-                                       pkey, NULL);
+                pkey, NULL);
             break;
 
         case EVP_PKEY_OP_VERIFY:
             rv = EVP_DigestVerifyInit_ex(mctx, NULL, digestname, libctx, propq,
-                                         pkey, NULL);
+                pkey, NULL);
             break;
         }
 
@@ -652,14 +669,13 @@ static EVP_PKEY_CTX *init_ctx(const char *kdfalg, int *pkeysize,
         ctx = NULL;
     }
 
- end:
+end:
     OPENSSL_free(passin);
     return ctx;
-
 }
 
 static int setup_peer(EVP_PKEY_CTX *ctx, int peerform, const char *file,
-                      ENGINE *e)
+    ENGINE *e)
 {
     EVP_PKEY *peer = NULL;
     ENGINE *engine = NULL;
@@ -680,8 +696,8 @@ static int setup_peer(EVP_PKEY_CTX *ctx, int peerform, const char *file,
 }
 
 static int do_keyop(EVP_PKEY_CTX *ctx, int pkey_op,
-                    unsigned char *out, size_t *poutlen,
-                    const unsigned char *in, size_t inlen)
+    unsigned char *out, size_t *poutlen,
+    const unsigned char *in, size_t inlen)
 {
     int rv = 0;
     switch (pkey_op) {
@@ -704,7 +720,6 @@ static int do_keyop(EVP_PKEY_CTX *ctx, int pkey_op,
     case EVP_PKEY_OP_DERIVE:
         rv = EVP_PKEY_derive(ctx, out, poutlen);
         break;
-
     }
     return rv;
 }
@@ -712,9 +727,9 @@ static int do_keyop(EVP_PKEY_CTX *ctx, int pkey_op,
 #define TBUF_MAXSIZE 2048
 
 static int do_raw_keyop(int pkey_op, EVP_MD_CTX *mctx,
-                        EVP_PKEY *pkey, BIO *in,
-                        int filesize, unsigned char *sig, int siglen,
-                        unsigned char **out, size_t *poutlen)
+    EVP_PKEY *pkey, BIO *in,
+    int filesize, unsigned char *sig, int siglen,
+    unsigned char **out, size_t *poutlen)
 {
     int rv = 0;
     unsigned char tbuf[TBUF_MAXSIZE];
@@ -723,10 +738,10 @@ static int do_raw_keyop(int pkey_op, EVP_MD_CTX *mctx,
 
     /* Some algorithms only support oneshot digests */
     if (EVP_PKEY_get_id(pkey) == EVP_PKEY_ED25519
-            || EVP_PKEY_get_id(pkey) == EVP_PKEY_ED448) {
+        || EVP_PKEY_get_id(pkey) == EVP_PKEY_ED448) {
         if (filesize < 0) {
             BIO_printf(bio_err,
-                       "Error: unable to determine file size for oneshot operation\n");
+                "Error: unable to determine file size for oneshot operation\n");
             goto end;
         }
         mbuf = app_malloc(filesize, "oneshot sign/verify buffer");
@@ -796,7 +811,7 @@ static int do_raw_keyop(int pkey_op, EVP_MD_CTX *mctx,
         break;
     }
 
- end:
+end:
     OPENSSL_free(mbuf);
     return rv;
 }
