@@ -1,5 +1,5 @@
 /*
- * Copyright 2015-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2015-2024 The OpenSSL Project Authors. All Rights Reserved.
  * Copyright (c) 2013-2014 Timo Teräs <timo.teras@gmail.com>
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
@@ -11,15 +11,14 @@
 #include "apps.h"
 #include "progs.h"
 
-#if defined(OPENSSL_SYS_UNIX) || defined(__APPLE__) || \
-    (defined(__VMS) && defined(__DECC) && __CRTL_VER >= 80300000)
-# include <unistd.h>
-# include <stdio.h>
-# include <limits.h>
-# include <errno.h>
-# include <string.h>
-# include <ctype.h>
-# include <sys/stat.h>
+#if defined(OPENSSL_SYS_UNIX) || defined(__APPLE__) || (defined(__VMS) && defined(__DECC) && __CRTL_VER >= 80300000)
+#include <unistd.h>
+#include <stdio.h>
+#include <limits.h>
+#include <errno.h>
+#include <string.h>
+#include <ctype.h>
+#include <sys/stat.h>
 
 /*
  * Make sure that the processing of symbol names is treated the same as when
@@ -27,32 +26,32 @@
  * include/openssl/__DECC_INCLUDE_PROLOGUE.H and __DECC_INCLUDE_EPILOGUE.H),
  * but not for internal headers.
  */
-# ifdef __VMS
-#  pragma names save
-#  pragma names as_is,shortened
-# endif
+#ifdef __VMS
+#pragma names save
+#pragma names as_is, shortened
+#endif
 
-# include "internal/o_dir.h"
+#include "internal/o_dir.h"
 
-# ifdef __VMS
-#  pragma names restore
-# endif
+#ifdef __VMS
+#pragma names restore
+#endif
 
-# include <openssl/evp.h>
-# include <openssl/pem.h>
-# include <openssl/x509.h>
+#include <openssl/evp.h>
+#include <openssl/pem.h>
+#include <openssl/x509.h>
 
-# ifndef PATH_MAX
-#  define PATH_MAX 4096
-# endif
-# define MAX_COLLISIONS  256
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
+#define MAX_COLLISIONS 256
 
-# if defined(OPENSSL_SYS_VXWORKS)
+#if defined(OPENSSL_SYS_VXWORKS)
 /*
  * VxWorks has no symbolic links
  */
 
-#  define lstat(path, buf) stat(path, buf)
+#define lstat(path, buf) stat(path, buf)
 
 int symlink(const char *target, const char *linkpath)
 {
@@ -65,7 +64,7 @@ ssize_t readlink(const char *pathname, char *buf, size_t bufsiz)
     errno = ENOSYS;
     return -1;
 }
-# endif
+#endif
 
 typedef struct hentry_st {
     struct hentry_st *next;
@@ -85,14 +84,16 @@ typedef struct bucket_st {
 
 enum Type {
     /* Keep in sync with |suffixes|, below. */
-    TYPE_CERT=0, TYPE_CRL=1
+    TYPE_CERT = 0,
+    TYPE_CRL = 1
 };
 
 enum Hash {
-    HASH_OLD, HASH_NEW, HASH_BOTH
+    HASH_OLD,
+    HASH_NEW,
+    HASH_BOTH
 };
 
-
 static int evpmdsize;
 static const EVP_MD *evpmd;
 static int remove_links = 1;
@@ -102,7 +103,6 @@ static BUCKET *hash_table[257];
 static const char *suffixes[] = { "", "r" };
 static const char *extensions[] = { "pem", "crt", "cer", "crl" };
 
-
 static void bit_set(unsigned char *set, unsigned int bit)
 {
     set[bit >> 3] |= 1 << (bit & 0x7);
@@ -113,13 +113,12 @@ static int bit_isset(unsigned char *set, unsigned int bit)
     return set[bit >> 3] & (1 << (bit & 0x7));
 }
 
-
 /*
  * Process an entry; return number of errors.
  */
 static int add_entry(enum Type type, unsigned int hash, const char *filename,
-                      const unsigned char *digest, int need_symlink,
-                      unsigned short old_id)
+    const unsigned char *digest, int need_symlink,
+    unsigned short old_id)
 {
     static BUCKET nilbucket;
     static HENTRY nilhentry;
@@ -142,9 +141,9 @@ static int add_entry(enum Type type, unsigned int hash, const char *filename,
     for (ep = bp->first_entry; ep; ep = ep->next) {
         if (digest && memcmp(digest, ep->digest, evpmdsize) == 0) {
             BIO_printf(bio_err,
-                       "%s: warning: skipping duplicate %s in %s\n",
-                       opt_getprog(),
-                       type == TYPE_CERT ? "certificate" : "CRL", filename);
+                "%s: warning: skipping duplicate %s in %s\n",
+                opt_getprog(),
+                type == TYPE_CERT ? "certificate" : "CRL", filename);
             return 0;
         }
         if (strcmp(filename, ep->filename) == 0) {
@@ -157,8 +156,8 @@ static int add_entry(enum Type type, unsigned int hash, const char *filename,
     if (ep == NULL) {
         if (bp->num_needed >= MAX_COLLISIONS) {
             BIO_printf(bio_err,
-                       "%s: error: hash table overflow for %s\n",
-                       opt_getprog(), filename);
+                "%s: error: hash table overflow for %s\n",
+                opt_getprog(), filename);
             return 1;
         }
         ep = app_malloc(sizeof(*ep), "collision bucket");
@@ -211,7 +210,8 @@ static int handle_symlink(const char *filename, const char *fullpath)
         return -1;
     for (type = OSSL_NELEM(suffixes) - 1; type > 0; type--)
         if (OPENSSL_strncasecmp(&filename[i],
-                                suffixes[type], strlen(suffixes[type])) == 0)
+                suffixes[type], strlen(suffixes[type]))
+            == 0)
             break;
 
     i += strlen(suffixes[type]);
@@ -233,7 +233,7 @@ static int handle_symlink(const char *filename, const char *fullpath)
  */
 static int do_file(const char *filename, const char *fullpath, enum Hash h)
 {
-    STACK_OF (X509_INFO) *inf = NULL;
+    STACK_OF(X509_INFO) *inf = NULL;
     X509_INFO *x;
     const X509_NAME *name = NULL;
     BIO *b;
@@ -255,7 +255,7 @@ static int do_file(const char *filename, const char *fullpath, enum Hash h)
     /* Does it have X.509 data in it? */
     if ((b = BIO_new_file(fullpath, "r")) == NULL) {
         BIO_printf(bio_err, "%s: error: skipping %s, cannot open file\n",
-                   opt_getprog(), filename);
+            opt_getprog(), filename);
         errs++;
         goto end;
     }
@@ -266,9 +266,9 @@ static int do_file(const char *filename, const char *fullpath, enum Hash h)
 
     if (sk_X509_INFO_num(inf) != 1) {
         BIO_printf(bio_err,
-                   "%s: warning: skipping %s,"
-                   "it does not contain exactly one certificate or CRL\n",
-                   opt_getprog(), filename);
+            "%s: warning: skipping %s, "
+            "it does not contain exactly one certificate or CRL\n",
+            opt_getprog(), filename);
         /* This is not an error. */
         goto end;
     }
@@ -296,21 +296,20 @@ static int do_file(const char *filename, const char *fullpath, enum Hash h)
     if (name != NULL) {
         if (h == HASH_NEW || h == HASH_BOTH) {
             int ok;
-            unsigned long hash_value =
-                X509_NAME_hash_ex(name,
-                                  app_get0_libctx(), app_get0_propq(), &ok);
+            unsigned long hash_value = X509_NAME_hash_ex(name,
+                app_get0_libctx(), app_get0_propq(), &ok);
 
             if (ok) {
                 errs += add_entry(type, hash_value, filename, digest, 1, ~0);
             } else {
                 BIO_printf(bio_err, "%s: error calculating SHA1 hash value\n",
-                           opt_getprog());
+                    opt_getprog());
                 errs++;
             }
         }
         if ((h == HASH_OLD) || (h == HASH_BOTH))
             errs += add_entry(type, X509_NAME_hash_old(name),
-                              filename, digest, 1, ~0);
+                filename, digest, 1, ~0);
     }
 
 end:
@@ -327,17 +326,17 @@ static int ends_with_dirsep(const char *path)
 {
     if (*path != '\0')
         path += strlen(path) - 1;
-# if defined __VMS
+#if defined __VMS
     if (*path == ']' || *path == '>' || *path == ':')
         return 1;
-# elif defined _WIN32
+#elif defined _WIN32
     if (*path == '\\')
         return 1;
-# endif
+#endif
     return *path == '/';
 }
 
-static int sk_strcmp(const char * const *a, const char * const *b)
+static int sk_strcmp(const char *const *a, const char *const *b)
 {
     return strcmp(*a, *b);
 }
@@ -381,7 +380,7 @@ static int do_dir(const char *dirname, enum Hash h)
         size_t fname_len = strlen(filename);
 
         if ((copy = OPENSSL_strdup(filename)) == NULL
-                || sk_OPENSSL_STRING_push(files, copy) == 0) {
+            || sk_OPENSSL_STRING_push(files, copy) == 0) {
             OPENSSL_free(copy);
             OPENSSL_DIR_end(&d);
             BIO_puts(bio_err, "out of memory\n");
@@ -401,7 +400,8 @@ static int do_dir(const char *dirname, enum Hash h)
     for (n = 0; n < numfiles; ++n) {
         filename = sk_OPENSSL_STRING_value(files, n);
         if (BIO_snprintf(buf, buflen, "%s%s%s",
-                         dirname, pathsep, filename) >= buflen)
+                dirname, pathsep, filename)
+            >= buflen)
             continue;
         if (lstat(buf, &st) < 0)
             continue;
@@ -424,47 +424,47 @@ static int do_dir(const char *dirname, enum Hash h)
                 if (ep->old_id < bp->num_needed) {
                     /* Link exists, and is used as-is */
                     BIO_snprintf(buf, buflen, "%08x.%s%d", bp->hash,
-                                 suffixes[bp->type], ep->old_id);
+                        suffixes[bp->type], ep->old_id);
                     if (verbose)
                         BIO_printf(bio_out, "link %s -> %s\n",
-                                   ep->filename, buf);
+                            ep->filename, buf);
                 } else if (ep->need_symlink) {
                     /* New link needed (it may replace something) */
                     while (bit_isset(idmask, nextid))
                         nextid++;
 
                     BIO_snprintf(buf, buflen, "%s%s%08x.%s%d",
-                                 dirname, pathsep, bp->hash,
-                                 suffixes[bp->type], nextid);
+                        dirname, pathsep, bp->hash,
+                        suffixes[bp->type], nextid);
                     if (verbose)
                         BIO_printf(bio_out, "link %s -> %s\n",
-                                   ep->filename, &buf[dirlen]);
+                            ep->filename, &buf[dirlen]);
                     if (unlink(buf) < 0 && errno != ENOENT) {
                         BIO_printf(bio_err,
-                                   "%s: Can't unlink %s, %s\n",
-                                   opt_getprog(), buf, strerror(errno));
+                            "%s: Can't unlink %s, %s\n",
+                            opt_getprog(), buf, strerror(errno));
                         errs++;
                     }
                     if (symlink(ep->filename, buf) < 0) {
                         BIO_printf(bio_err,
-                                   "%s: Can't symlink %s, %s\n",
-                                   opt_getprog(), ep->filename,
-                                   strerror(errno));
+                            "%s: Can't symlink %s, %s\n",
+                            opt_getprog(), ep->filename,
+                            strerror(errno));
                         errs++;
                     }
                     bit_set(idmask, nextid);
                 } else if (remove_links) {
                     /* Link to be deleted */
                     BIO_snprintf(buf, buflen, "%s%s%08x.%s%d",
-                                 dirname, pathsep, bp->hash,
-                                 suffixes[bp->type], ep->old_id);
+                        dirname, pathsep, bp->hash,
+                        suffixes[bp->type], ep->old_id);
                     if (verbose)
                         BIO_printf(bio_out, "unlink %s\n",
-                                   &buf[dirlen]);
+                            &buf[dirlen]);
                     if (unlink(buf) < 0 && errno != ENOENT) {
                         BIO_printf(bio_err,
-                                   "%s: Can't unlink %s, %s\n",
-                                   opt_getprog(), buf, strerror(errno));
+                            "%s: Can't unlink %s, %s\n",
+                            opt_getprog(), buf, strerror(errno));
                         errs++;
                     }
                 }
@@ -476,7 +476,7 @@ static int do_dir(const char *dirname, enum Hash h)
         hash_table[i] = NULL;
     }
 
- err:
+err:
     sk_OPENSSL_STRING_pop_free(files, str_free);
     OPENSSL_free(buf);
     return errs;
@@ -484,31 +484,33 @@ static int do_dir(const char *dirname, enum Hash h)
 
 typedef enum OPTION_choice {
     OPT_COMMON,
-    OPT_COMPAT, OPT_OLD, OPT_N, OPT_VERBOSE,
+    OPT_COMPAT,
+    OPT_OLD,
+    OPT_N,
+    OPT_VERBOSE,
     OPT_PROV_ENUM
 } OPTION_CHOICE;
 
 const OPTIONS rehash_options[] = {
-    {OPT_HELP_STR, 1, '-', "Usage: %s [options] [directory...]\n"},
+    { OPT_HELP_STR, 1, '-', "Usage: %s [options] [directory...]\n" },
 
     OPT_SECTION("General"),
-    {"help", OPT_HELP, '-', "Display this summary"},
-    {"h", OPT_HELP, '-', "Display this summary"},
-    {"compat", OPT_COMPAT, '-', "Create both new- and old-style hash links"},
-    {"old", OPT_OLD, '-', "Use old-style hash to generate links"},
-    {"n", OPT_N, '-', "Do not remove existing links"},
+    { "help", OPT_HELP, '-', "Display this summary" },
+    { "h", OPT_HELP, '-', "Display this summary" },
+    { "compat", OPT_COMPAT, '-', "Create both new- and old-style hash links" },
+    { "old", OPT_OLD, '-', "Use old-style hash to generate links" },
+    { "n", OPT_N, '-', "Do not remove existing links" },
 
     OPT_SECTION("Output"),
-    {"v", OPT_VERBOSE, '-', "Verbose output"},
+    { "v", OPT_VERBOSE, '-', "Verbose output" },
 
     OPT_PROV_OPTIONS,
 
     OPT_PARAMETERS(),
-    {"directory", 0, 0, "One or more directories to process (optional)"},
-    {NULL}
+    { "directory", 0, 0, "One or more directories to process (optional)" },
+    { NULL }
 };
 
-
 int rehash_main(int argc, char **argv)
 {
     const char *env, *prog;
@@ -571,13 +573,13 @@ int rehash_main(int argc, char **argv)
         errs += do_dir(X509_get_default_cert_dir(), h);
     }
 
- end:
+end:
     return errs;
 }
 
 #else
 const OPTIONS rehash_options[] = {
-    {NULL}
+    { NULL }
 };
 
 int rehash_main(int argc, char **argv)
