@@ -14,57 +14,67 @@
 #include <openssl/err.h>
 #include <openssl/pem.h>
 #include <openssl/store.h>
-#include <openssl/x509v3.h>      /* s2i_ASN1_INTEGER */
+#include <openssl/x509v3.h> /* s2i_ASN1_INTEGER */
 
 static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
-                   int expected, int criterion, OSSL_STORE_SEARCH *search,
-                   int text, int noout, int recursive, int indent, BIO *out,
-                   const char *prog, OSSL_LIB_CTX *libctx);
+    int expected, int criterion, OSSL_STORE_SEARCH *search,
+    int text, int noout, int recursive, int indent, BIO *out,
+    const char *prog, OSSL_LIB_CTX *libctx);
 
 typedef enum OPTION_choice {
     OPT_COMMON,
-    OPT_ENGINE, OPT_OUT, OPT_PASSIN,
-    OPT_NOOUT, OPT_TEXT, OPT_RECURSIVE,
-    OPT_SEARCHFOR_CERTS, OPT_SEARCHFOR_KEYS, OPT_SEARCHFOR_CRLS,
-    OPT_CRITERION_SUBJECT, OPT_CRITERION_ISSUER, OPT_CRITERION_SERIAL,
-    OPT_CRITERION_FINGERPRINT, OPT_CRITERION_ALIAS,
-    OPT_MD, OPT_PROV_ENUM
+    OPT_ENGINE,
+    OPT_OUT,
+    OPT_PASSIN,
+    OPT_NOOUT,
+    OPT_TEXT,
+    OPT_RECURSIVE,
+    OPT_SEARCHFOR_CERTS,
+    OPT_SEARCHFOR_KEYS,
+    OPT_SEARCHFOR_CRLS,
+    OPT_CRITERION_SUBJECT,
+    OPT_CRITERION_ISSUER,
+    OPT_CRITERION_SERIAL,
+    OPT_CRITERION_FINGERPRINT,
+    OPT_CRITERION_ALIAS,
+    OPT_MD,
+    OPT_PROV_ENUM
 } OPTION_CHOICE;
 
 const OPTIONS storeutl_options[] = {
-    {OPT_HELP_STR, 1, '-', "Usage: %s [options] uri\n"},
+    { OPT_HELP_STR, 1, '-', "Usage: %s [options] uri\n" },
 
     OPT_SECTION("General"),
-    {"help", OPT_HELP, '-', "Display this summary"},
-    {"", OPT_MD, '-', "Any supported digest"},
+    { "help", OPT_HELP, '-', "Display this summary" },
+    { "", OPT_MD, '-', "Any supported digest" },
 #ifndef OPENSSL_NO_ENGINE
-    {"engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device"},
+    { "engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device" },
 #endif
 
     OPT_SECTION("Search"),
-    {"certs", OPT_SEARCHFOR_CERTS, '-', "Search for certificates only"},
-    {"keys", OPT_SEARCHFOR_KEYS, '-', "Search for keys only"},
-    {"crls", OPT_SEARCHFOR_CRLS, '-', "Search for CRLs only"},
-    {"subject", OPT_CRITERION_SUBJECT, 's', "Search by subject"},
-    {"issuer", OPT_CRITERION_ISSUER, 's', "Search by issuer and serial, issuer name"},
-    {"serial", OPT_CRITERION_SERIAL, 's', "Search by issuer and serial, serial number"},
-    {"fingerprint", OPT_CRITERION_FINGERPRINT, 's', "Search by public key fingerprint, given in hex"},
-    {"alias", OPT_CRITERION_ALIAS, 's', "Search by alias"},
-    {"r", OPT_RECURSIVE, '-', "Recurse through names"},
+    { "certs", OPT_SEARCHFOR_CERTS, '-', "Search for certificates only" },
+    { "keys", OPT_SEARCHFOR_KEYS, '-', "Search for keys only" },
+    { "crls", OPT_SEARCHFOR_CRLS, '-', "Search for CRLs only" },
+    { "subject", OPT_CRITERION_SUBJECT, 's', "Search by subject" },
+    { "issuer", OPT_CRITERION_ISSUER, 's', "Search by issuer and serial, issuer name" },
+    { "serial", OPT_CRITERION_SERIAL, 's', "Search by issuer and serial, serial number" },
+    { "fingerprint", OPT_CRITERION_FINGERPRINT, 's', "Search by public key fingerprint, given in hex" },
+    { "alias", OPT_CRITERION_ALIAS, 's', "Search by alias" },
+    { "r", OPT_RECURSIVE, '-', "Recurse through names" },
 
     OPT_SECTION("Input"),
-    {"passin", OPT_PASSIN, 's', "Input file pass phrase source"},
+    { "passin", OPT_PASSIN, 's', "Input file pass phrase source" },
 
     OPT_SECTION("Output"),
-    {"out", OPT_OUT, '>', "Output file - default stdout"},
-    {"text", OPT_TEXT, '-', "Print a text form of the objects"},
-    {"noout", OPT_NOOUT, '-', "No PEM output, just status"},
+    { "out", OPT_OUT, '>', "Output file - default stdout" },
+    { "text", OPT_TEXT, '-', "Print a text form of the objects" },
+    { "noout", OPT_NOOUT, '-', "No PEM output, just status" },
 
     OPT_PROV_OPTIONS,
 
     OPT_PARAMETERS(),
-    {"uri", 0, 0, "URI of the store object"},
-    {NULL}
+    { "uri", 0, 0, "URI of the store object" },
+    { NULL }
 };
 
 int storeutl_main(int argc, char *argv[])
@@ -93,7 +103,7 @@ int storeutl_main(int argc, char *argv[])
         switch (o) {
         case OPT_EOF:
         case OPT_ERR:
- opthelp:
+        opthelp:
             BIO_printf(bio_err, "%s: Use -help for summary.\n", prog);
             goto end;
         case OPT_HELP:
@@ -120,7 +130,7 @@ int storeutl_main(int argc, char *argv[])
         case OPT_SEARCHFOR_CRLS:
             if (expected != 0) {
                 BIO_printf(bio_err, "%s: only one search type can be given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             {
@@ -128,9 +138,9 @@ int storeutl_main(int argc, char *argv[])
                     enum OPTION_choice choice;
                     int type;
                 } map[] = {
-                    {OPT_SEARCHFOR_CERTS, OSSL_STORE_INFO_CERT},
-                    {OPT_SEARCHFOR_KEYS, OSSL_STORE_INFO_PKEY},
-                    {OPT_SEARCHFOR_CRLS, OSSL_STORE_INFO_CRL},
+                    { OPT_SEARCHFOR_CERTS, OSSL_STORE_INFO_CERT },
+                    { OPT_SEARCHFOR_KEYS, OSSL_STORE_INFO_PKEY },
+                    { OPT_SEARCHFOR_CRLS, OSSL_STORE_INFO_CRL },
                 };
                 size_t i;
 
@@ -150,13 +160,13 @@ int storeutl_main(int argc, char *argv[])
         case OPT_CRITERION_SUBJECT:
             if (criterion != 0) {
                 BIO_printf(bio_err, "%s: criterion already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             criterion = OSSL_STORE_SEARCH_BY_NAME;
             if (subject != NULL) {
                 BIO_printf(bio_err, "%s: subject already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             subject = parse_name(opt_arg(), MBSTRING_UTF8, 1, "subject");
@@ -167,13 +177,13 @@ int storeutl_main(int argc, char *argv[])
             if (criterion != 0
                 && criterion != OSSL_STORE_SEARCH_BY_ISSUER_SERIAL) {
                 BIO_printf(bio_err, "%s: criterion already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             criterion = OSSL_STORE_SEARCH_BY_ISSUER_SERIAL;
             if (issuer != NULL) {
                 BIO_printf(bio_err, "%s: issuer already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             issuer = parse_name(opt_arg(), MBSTRING_UTF8, 1, "issuer");
@@ -184,31 +194,31 @@ int storeutl_main(int argc, char *argv[])
             if (criterion != 0
                 && criterion != OSSL_STORE_SEARCH_BY_ISSUER_SERIAL) {
                 BIO_printf(bio_err, "%s: criterion already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             criterion = OSSL_STORE_SEARCH_BY_ISSUER_SERIAL;
             if (serial != NULL) {
                 BIO_printf(bio_err, "%s: serial number already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             if ((serial = s2i_ASN1_INTEGER(NULL, opt_arg())) == NULL) {
                 BIO_printf(bio_err, "%s: can't parse serial number argument.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             break;
         case OPT_CRITERION_FINGERPRINT:
             if (criterion != 0) {
                 BIO_printf(bio_err, "%s: criterion already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             criterion = OSSL_STORE_SEARCH_BY_KEY_FINGERPRINT;
             if (fingerprint != NULL) {
                 BIO_printf(bio_err, "%s: fingerprint already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             {
@@ -217,8 +227,8 @@ int storeutl_main(int argc, char *argv[])
                 if ((fingerprint = OPENSSL_hexstr2buf(opt_arg(), &tmplen))
                     == NULL) {
                     BIO_printf(bio_err,
-                               "%s: can't parse fingerprint argument.\n",
-                               prog);
+                        "%s: can't parse fingerprint argument.\n",
+                        prog);
                     goto end;
                 }
                 fingerprintlen = (size_t)tmplen;
@@ -227,18 +237,18 @@ int storeutl_main(int argc, char *argv[])
         case OPT_CRITERION_ALIAS:
             if (criterion != 0) {
                 BIO_printf(bio_err, "%s: criterion already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             criterion = OSSL_STORE_SEARCH_BY_ALIAS;
             if (alias != NULL) {
                 BIO_printf(bio_err, "%s: alias already given.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             if ((alias = OPENSSL_strdup(opt_arg())) == NULL) {
                 BIO_printf(bio_err, "%s: can't parse alias argument.\n",
-                           prog);
+                    prog);
                 goto end;
             }
             break;
@@ -274,8 +284,8 @@ int storeutl_main(int argc, char *argv[])
         case OSSL_STORE_SEARCH_BY_ISSUER_SERIAL:
             if (issuer == NULL || serial == NULL) {
                 BIO_printf(bio_err,
-                           "%s: both -issuer and -serial must be given.\n",
-                           prog);
+                    "%s: both -issuer and -serial must be given.\n",
+                    prog);
                 goto end;
             }
             if ((search = OSSL_STORE_SEARCH_by_issuer_serial(issuer, serial))
@@ -286,8 +296,8 @@ int storeutl_main(int argc, char *argv[])
             break;
         case OSSL_STORE_SEARCH_BY_KEY_FINGERPRINT:
             if ((search = OSSL_STORE_SEARCH_by_key_fingerprint(digest,
-                                                               fingerprint,
-                                                               fingerprintlen))
+                     fingerprint,
+                     fingerprintlen))
                 == NULL) {
                 ERR_print_errors(bio_err);
                 goto end;
@@ -314,10 +324,10 @@ int storeutl_main(int argc, char *argv[])
         goto end;
 
     ret = process(argv[0], get_ui_method(), &pw_cb_data,
-                  expected, criterion, search,
-                  text, noout, recursive, 0, out, prog, libctx);
+        expected, criterion, search,
+        text, noout, recursive, 0, out, prog, libctx);
 
- end:
+end:
     EVP_MD_free(digest);
     OPENSSL_free(fingerprint);
     OPENSSL_free(alias);
@@ -334,26 +344,34 @@ int storeutl_main(int argc, char *argv[])
 static int indent_printf(int indent, BIO *bio, const char *format, ...)
 {
     va_list args;
-    int ret;
+    int ret, vret;
+
+    ret = BIO_printf(bio, "%*s", indent, "");
+    if (ret < 0)
+        return ret;
 
     va_start(args, format);
-
-    ret = BIO_printf(bio, "%*s", indent, "") + BIO_vprintf(bio, format, args);
-
+    vret = BIO_vprintf(bio, format, args);
     va_end(args);
-    return ret;
+
+    if (vret < 0)
+        return vret;
+    if (vret > INT_MAX - ret)
+        return INT_MAX;
+
+    return ret + vret;
 }
 
 static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
-                   int expected, int criterion, OSSL_STORE_SEARCH *search,
-                   int text, int noout, int recursive, int indent, BIO *out,
-                   const char *prog, OSSL_LIB_CTX *libctx)
+    int expected, int criterion, OSSL_STORE_SEARCH *search,
+    int text, int noout, int recursive, int indent, BIO *out,
+    const char *prog, OSSL_LIB_CTX *libctx)
 {
     OSSL_STORE_CTX *store_ctx = NULL;
     int ret = 1, items = 0;
 
     if ((store_ctx = OSSL_STORE_open_ex(uri, libctx, app_get0_propq(), uimeth, uidata,
-                                        NULL, NULL, NULL))
+             NULL, NULL, NULL))
         == NULL) {
         BIO_printf(bio_err, "Couldn't open file or uri %s\n", uri);
         ERR_print_errors(bio_err);
@@ -370,8 +388,8 @@ static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
     if (criterion != 0) {
         if (!OSSL_STORE_supports_search(store_ctx, criterion)) {
             BIO_printf(bio_err,
-                       "%s: the store scheme doesn't support the given search criteria.\n",
-                       prog);
+                "%s: the store scheme doesn't support the given search criteria.\n",
+                prog);
             goto end2;
         }
 
@@ -387,8 +405,7 @@ static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
     for (;;) {
         OSSL_STORE_INFO *info = OSSL_STORE_load(store_ctx);
         int type = info == NULL ? 0 : OSSL_STORE_INFO_get_type(info);
-        const char *infostr =
-            info == NULL ? NULL : OSSL_STORE_INFO_type_string(type);
+        const char *infostr = info == NULL ? NULL : OSSL_STORE_INFO_type_string(type);
 
         if (info == NULL) {
             if (OSSL_STORE_error(store_ctx)) {
@@ -406,8 +423,8 @@ static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
                 break;
 
             BIO_printf(bio_err,
-                       "ERROR: OSSL_STORE_load() returned NULL without "
-                       "eof or error indications\n");
+                "ERROR: OSSL_STORE_load() returned NULL without "
+                "eof or error indications\n");
             BIO_printf(bio_err, "       This is an error in the loader\n");
             ERR_print_errors(bio_err);
             ret++;
@@ -418,7 +435,7 @@ static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
             const char *name = OSSL_STORE_INFO_get0_NAME(info);
             const char *desc = OSSL_STORE_INFO_get0_NAME_description(info);
             indent_printf(indent, bio_out, "%d: %s: %s\n", items, infostr,
-                          name);
+                name);
             if (desc != NULL)
                 indent_printf(indent, bio_out, "%s\n", desc);
         } else {
@@ -435,33 +452,33 @@ static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
             if (recursive) {
                 const char *suburi = OSSL_STORE_INFO_get0_NAME(info);
                 ret += process(suburi, uimeth, uidata,
-                               expected, criterion, search,
-                               text, noout, recursive, indent + 2, out, prog,
-                               libctx);
+                    expected, criterion, search,
+                    text, noout, recursive, indent + 2, out, prog,
+                    libctx);
             }
             break;
         case OSSL_STORE_INFO_PARAMS:
             if (text)
                 EVP_PKEY_print_params(out, OSSL_STORE_INFO_get0_PARAMS(info),
-                                      0, NULL);
+                    0, NULL);
             if (!noout)
                 PEM_write_bio_Parameters(out,
-                                         OSSL_STORE_INFO_get0_PARAMS(info));
+                    OSSL_STORE_INFO_get0_PARAMS(info));
             break;
         case OSSL_STORE_INFO_PUBKEY:
             if (text)
                 EVP_PKEY_print_public(out, OSSL_STORE_INFO_get0_PUBKEY(info),
-                                      0, NULL);
+                    0, NULL);
             if (!noout)
                 PEM_write_bio_PUBKEY(out, OSSL_STORE_INFO_get0_PUBKEY(info));
             break;
         case OSSL_STORE_INFO_PKEY:
             if (text)
                 EVP_PKEY_print_private(out, OSSL_STORE_INFO_get0_PKEY(info),
-                                       0, NULL);
+                    0, NULL);
             if (!noout)
                 PEM_write_bio_PrivateKey(out, OSSL_STORE_INFO_get0_PKEY(info),
-                                         NULL, NULL, 0, NULL, NULL);
+                    NULL, NULL, 0, NULL, NULL);
             break;
         case OSSL_STORE_INFO_CERT:
             if (text)
@@ -485,7 +502,7 @@ static int process(const char *uri, const UI_METHOD *uimeth, PW_CB_DATA *uidata,
     }
     indent_printf(indent, out, "Total found: %d\n", items);
 
- end2:
+end2:
     if (!OSSL_STORE_close(store_ctx)) {
         ERR_print_errors(bio_err);
         ret++;
