@@ -21,117 +21,138 @@
 #include <openssl/bn.h>
 
 /* Request nonce length, in bits (must be a multiple of 8). */
-#define NONCE_LENGTH            64
+#define NONCE_LENGTH 64
 
 /* Name of config entry that defines the OID file. */
-#define ENV_OID_FILE            "oid_file"
+#define ENV_OID_FILE "oid_file"
 
 /* Is |EXACTLY_ONE| of three pointers set? */
 #define EXACTLY_ONE(a, b, c) \
-        (( a && !b && !c) || \
-         ( b && !a && !c) || \
-         ( c && !a && !b))
+    ((a && !b && !c) || (b && !a && !c) || (c && !a && !b))
 
 static ASN1_OBJECT *txt2obj(const char *oid);
 static CONF *load_config_file(const char *configfile);
 
 /* Query related functions. */
 static int query_command(const char *data, const char *digest,
-                         const EVP_MD *md, const char *policy, int no_nonce,
-                         int cert, const char *in, const char *out, int text);
+    const EVP_MD *md, const char *policy, int no_nonce,
+    int cert, const char *in, const char *out, int text);
 static TS_REQ *create_query(BIO *data_bio, const char *digest, const EVP_MD *md,
-                            const char *policy, int no_nonce, int cert);
+    const char *policy, int no_nonce, int cert);
 static int create_digest(BIO *input, const char *digest,
-                         const EVP_MD *md, unsigned char **md_value);
+    const EVP_MD *md, unsigned char **md_value);
 static ASN1_INTEGER *create_nonce(int bits);
 
 /* Reply related functions. */
 static int reply_command(CONF *conf, const char *section, const char *engine,
-                         const char *queryfile, const char *passin, const char *inkey,
-                         const EVP_MD *md, const char *signer, const char *chain,
-                         const char *policy, const char *in, int token_in,
-                         const char *out, int token_out, int text);
+    const char *queryfile, const char *passin, const char *inkey,
+    const EVP_MD *md, const char *signer, const char *chain,
+    const char *policy, const char *in, int token_in,
+    const char *out, int token_out, int text);
 static TS_RESP *read_PKCS7(BIO *in_bio);
 static TS_RESP *create_response(CONF *conf, const char *section, const char *engine,
-                                const char *queryfile, const char *passin,
-                                const char *inkey, const EVP_MD *md, const char *signer,
-                                const char *chain, const char *policy);
+    const char *queryfile, const char *passin,
+    const char *inkey, const EVP_MD *md, const char *signer,
+    const char *chain, const char *policy);
 static ASN1_INTEGER *serial_cb(TS_RESP_CTX *ctx, void *data);
 static ASN1_INTEGER *next_serial(const char *serialfile);
 static int save_ts_serial(const char *serialfile, ASN1_INTEGER *serial);
 
 /* Verify related functions. */
 static int verify_command(const char *data, const char *digest, const char *queryfile,
-                          const char *in, int token_in,
-                          const char *CApath, const char *CAfile,
-                          const char *CAstore,
-                          char *untrusted, X509_VERIFY_PARAM *vpm);
+    const char *in, int token_in,
+    const char *CApath, const char *CAfile,
+    const char *CAstore,
+    char *untrusted, X509_VERIFY_PARAM *vpm);
 static TS_VERIFY_CTX *create_verify_ctx(const char *data, const char *digest,
-                                        const char *queryfile,
-                                        const char *CApath, const char *CAfile,
-                                        const char *CAstore,
-                                        char *untrusted,
-                                        X509_VERIFY_PARAM *vpm);
+    const char *queryfile,
+    const char *CApath, const char *CAfile,
+    const char *CAstore,
+    char *untrusted,
+    X509_VERIFY_PARAM *vpm);
 static X509_STORE *create_cert_store(const char *CApath, const char *CAfile,
-                                     const char *CAstore, X509_VERIFY_PARAM *vpm);
+    const char *CAstore, X509_VERIFY_PARAM *vpm);
 static int verify_cb(int ok, X509_STORE_CTX *ctx);
 
 typedef enum OPTION_choice {
     OPT_COMMON,
-    OPT_ENGINE, OPT_CONFIG, OPT_SECTION, OPT_QUERY, OPT_DATA,
-    OPT_DIGEST, OPT_TSPOLICY, OPT_NO_NONCE, OPT_CERT,
-    OPT_IN, OPT_TOKEN_IN, OPT_OUT, OPT_TOKEN_OUT, OPT_TEXT,
-    OPT_REPLY, OPT_QUERYFILE, OPT_PASSIN, OPT_INKEY, OPT_SIGNER,
-    OPT_CHAIN, OPT_VERIFY, OPT_CAPATH, OPT_CAFILE, OPT_CASTORE, OPT_UNTRUSTED,
-    OPT_MD, OPT_V_ENUM, OPT_R_ENUM, OPT_PROV_ENUM
+    OPT_ENGINE,
+    OPT_CONFIG,
+    OPT_SECTION,
+    OPT_QUERY,
+    OPT_DATA,
+    OPT_DIGEST,
+    OPT_TSPOLICY,
+    OPT_NO_NONCE,
+    OPT_CERT,
+    OPT_IN,
+    OPT_TOKEN_IN,
+    OPT_OUT,
+    OPT_TOKEN_OUT,
+    OPT_TEXT,
+    OPT_REPLY,
+    OPT_QUERYFILE,
+    OPT_PASSIN,
+    OPT_INKEY,
+    OPT_SIGNER,
+    OPT_CHAIN,
+    OPT_VERIFY,
+    OPT_CAPATH,
+    OPT_CAFILE,
+    OPT_CASTORE,
+    OPT_UNTRUSTED,
+    OPT_MD,
+    OPT_V_ENUM,
+    OPT_R_ENUM,
+    OPT_PROV_ENUM
 } OPTION_CHOICE;
 
 const OPTIONS ts_options[] = {
     OPT_SECTION("General"),
-    {"help", OPT_HELP, '-', "Display this summary"},
-    {"config", OPT_CONFIG, '<', "Configuration file"},
-    {"section", OPT_SECTION, 's', "Section to use within config file"},
+    { "help", OPT_HELP, '-', "Display this summary" },
+    { "config", OPT_CONFIG, '<', "Configuration file" },
+    { "section", OPT_SECTION, 's', "Section to use within config file" },
 #ifndef OPENSSL_NO_ENGINE
-    {"engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device"},
+    { "engine", OPT_ENGINE, 's', "Use engine, possibly a hardware device" },
 #endif
-    {"inkey", OPT_INKEY, 's', "File with private key for reply"},
-    {"signer", OPT_SIGNER, 's', "Signer certificate file"},
-    {"chain", OPT_CHAIN, '<', "File with signer CA chain"},
-    {"CAfile", OPT_CAFILE, '<', "File with trusted CA certs"},
-    {"CApath", OPT_CAPATH, '/', "Path to trusted CA files"},
-    {"CAstore", OPT_CASTORE, ':', "URI to trusted CA store"},
-    {"untrusted", OPT_UNTRUSTED, '<', "Extra untrusted certs"},
-    {"token_in", OPT_TOKEN_IN, '-', "Input is a PKCS#7 file"},
-    {"token_out", OPT_TOKEN_OUT, '-', "Output is a PKCS#7 file"},
-    {"passin", OPT_PASSIN, 's', "Input file pass phrase source"},
-    {"", OPT_MD, '-', "Any supported digest"},
+    { "inkey", OPT_INKEY, 's', "File with private key for reply" },
+    { "signer", OPT_SIGNER, 's', "Signer certificate file" },
+    { "chain", OPT_CHAIN, '<', "File with signer CA chain" },
+    { "CAfile", OPT_CAFILE, '<', "File with trusted CA certs" },
+    { "CApath", OPT_CAPATH, '/', "Path to trusted CA files" },
+    { "CAstore", OPT_CASTORE, ':', "URI to trusted CA store" },
+    { "untrusted", OPT_UNTRUSTED, '<', "Extra untrusted certs" },
+    { "token_in", OPT_TOKEN_IN, '-', "Input is a PKCS#7 file" },
+    { "token_out", OPT_TOKEN_OUT, '-', "Output is a PKCS#7 file" },
+    { "passin", OPT_PASSIN, 's', "Input file pass phrase source" },
+    { "", OPT_MD, '-', "Any supported digest" },
 
     OPT_SECTION("Query"),
-    {"query", OPT_QUERY, '-', "Generate a TS query"},
-    {"data", OPT_DATA, '<', "File to hash"},
-    {"digest", OPT_DIGEST, 's', "Digest (as a hex string)"},
-    {"queryfile", OPT_QUERYFILE, '<', "File containing a TS query"},
-    {"cert", OPT_CERT, '-', "Put cert request into query"},
-    {"in", OPT_IN, '<', "Input file"},
+    { "query", OPT_QUERY, '-', "Generate a TS query" },
+    { "data", OPT_DATA, '<', "File to hash" },
+    { "digest", OPT_DIGEST, 's', "Digest (as a hex string)" },
+    { "queryfile", OPT_QUERYFILE, '<', "File containing a TS query" },
+    { "cert", OPT_CERT, '-', "Put cert request into query" },
+    { "in", OPT_IN, '<', "Input file" },
 
     OPT_SECTION("Verify"),
-    {"verify", OPT_VERIFY, '-', "Verify a TS response"},
-    {"reply", OPT_REPLY, '-', "Generate a TS reply"},
-    {"tspolicy", OPT_TSPOLICY, 's', "Policy OID to use"},
-    {"no_nonce", OPT_NO_NONCE, '-', "Do not include a nonce"},
-    {"out", OPT_OUT, '>', "Output file"},
-    {"text", OPT_TEXT, '-', "Output text (not DER)"},
+    { "verify", OPT_VERIFY, '-', "Verify a TS response" },
+    { "reply", OPT_REPLY, '-', "Generate a TS reply" },
+    { "tspolicy", OPT_TSPOLICY, 's', "Policy OID to use" },
+    { "no_nonce", OPT_NO_NONCE, '-', "Do not include a nonce" },
+    { "out", OPT_OUT, '>', "Output file" },
+    { "text", OPT_TEXT, '-', "Output text (not DER)" },
 
     OPT_R_OPTIONS,
     OPT_V_OPTIONS,
     OPT_PROV_OPTIONS,
-    {NULL}
+    { NULL }
 };
 
 /*
  * This command is so complex, special help is needed.
  */
-static char* opt_helplist[] = {
+static char *opt_helplist[] = {
     "",
     "Typical uses:",
     " openssl ts -query [-rand file...] [-config file] [-data file]",
@@ -187,7 +208,7 @@ int ts_main(int argc, char **argv)
         switch (o) {
         case OPT_EOF:
         case OPT_ERR:
- opthelp:
+        opthelp:
             BIO_printf(bio_err, "%s: Use -help for summary.\n", prog);
             goto end;
         case OPT_HELP:
@@ -303,8 +324,7 @@ int ts_main(int argc, char **argv)
 
     if (!opt_md(digestname, &md))
         goto opthelp;
-    if (mode == OPT_REPLY && passin &&
-        !app_passwd(passin, NULL, &password, NULL)) {
+    if (mode == OPT_REPLY && passin && !app_passwd(passin, NULL, &password, NULL)) {
         BIO_printf(bio_err, "Error getting password.\n");
         goto end;
     }
@@ -321,7 +341,7 @@ int ts_main(int argc, char **argv)
         if ((data != NULL) && (digest != NULL))
             goto opthelp;
         ret = !query_command(data, digest, md, policy, no_nonce, cert,
-                             in, out, text);
+            in, out, text);
     } else if (mode == OPT_REPLY) {
         if (vpmtouched)
             goto opthelp;
@@ -332,20 +352,20 @@ int ts_main(int argc, char **argv)
                 goto opthelp;
         }
         ret = !reply_command(conf, section, engine, queryfile,
-                             password, inkey, md, signer, chain, policy,
-                             in, token_in, out, token_out, text);
+            password, inkey, md, signer, chain, policy,
+            in, token_in, out, token_out, text);
 
     } else if (mode == OPT_VERIFY) {
         if ((in == NULL) || !EXACTLY_ONE(queryfile, data, digest))
             goto opthelp;
         ret = !verify_command(data, digest, queryfile, in, token_in,
-                              CApath, CAfile, CAstore, untrusted,
-                              vpmtouched ? vpm : NULL);
+            CApath, CAfile, CAstore, untrusted,
+            vpmtouched ? vpm : NULL);
     } else {
         goto opthelp;
     }
 
- end:
+end:
     X509_VERIFY_PARAM_free(vpm);
     EVP_MD_free(md);
     NCONF_free(conf);
@@ -395,8 +415,8 @@ static CONF *load_config_file(const char *configfile)
  * Query-related method definitions.
  */
 static int query_command(const char *data, const char *digest, const EVP_MD *md,
-                         const char *policy, int no_nonce,
-                         int cert, const char *in, const char *out, int text)
+    const char *policy, int no_nonce,
+    int cert, const char *in, const char *out, int text)
 {
     int ret = 0;
     TS_REQ *query = NULL;
@@ -432,7 +452,7 @@ static int query_command(const char *data, const char *digest, const EVP_MD *md,
 
     ret = 1;
 
- end:
+end:
     ERR_print_errors(bio_err);
     BIO_free_all(in_bio);
     BIO_free_all(data_bio);
@@ -442,7 +462,7 @@ static int query_command(const char *data, const char *digest, const EVP_MD *md,
 }
 
 static TS_REQ *create_query(BIO *data_bio, const char *digest, const EVP_MD *md,
-                            const char *policy, int no_nonce, int cert)
+    const char *policy, int no_nonce, int cert)
 {
     int ret = 0;
     TS_REQ *ts_req = NULL;
@@ -490,7 +510,7 @@ static TS_REQ *create_query(BIO *data_bio, const char *digest, const EVP_MD *md,
         goto err;
 
     ret = 1;
- err:
+err:
     if (!ret) {
         TS_REQ_free(ts_req);
         ts_req = NULL;
@@ -506,7 +526,7 @@ static TS_REQ *create_query(BIO *data_bio, const char *digest, const EVP_MD *md,
 }
 
 static int create_digest(BIO *input, const char *digest, const EVP_MD *md,
-                         unsigned char **md_value)
+    unsigned char **md_value)
 {
     int md_value_len;
     int rv = 0;
@@ -539,12 +559,13 @@ static int create_digest(BIO *input, const char *digest, const EVP_MD *md,
         *md_value = OPENSSL_hexstr2buf(digest, &digest_len);
         if (*md_value == NULL || md_value_len != digest_len) {
             BIO_printf(bio_err, "bad digest, %d bytes "
-                       "must be specified\n", md_value_len);
+                                "must be specified\n",
+                md_value_len);
             goto err;
         }
     }
     rv = md_value_len;
- err:
+err:
     if (rv <= 0) {
         OPENSSL_free(*md_value);
         *md_value = NULL;
@@ -577,7 +598,7 @@ static ASN1_INTEGER *create_nonce(int bits)
     memcpy(nonce->data, buf + i, nonce->length);
     return nonce;
 
- err:
+err:
     BIO_printf(bio_err, "could not create nonce\n");
     ASN1_INTEGER_free(nonce);
     return NULL;
@@ -588,10 +609,10 @@ static ASN1_INTEGER *create_nonce(int bits)
  */
 
 static int reply_command(CONF *conf, const char *section, const char *engine,
-                         const char *queryfile, const char *passin, const char *inkey,
-                         const EVP_MD *md, const char *signer, const char *chain,
-                         const char *policy, const char *in, int token_in,
-                         const char *out, int token_out, int text)
+    const char *queryfile, const char *passin, const char *inkey,
+    const EVP_MD *md, const char *signer, const char *chain,
+    const char *policy, const char *in, int token_in,
+    const char *out, int token_out, int text)
 {
     int ret = 0;
     TS_RESP *response = NULL;
@@ -611,7 +632,7 @@ static int reply_command(CONF *conf, const char *section, const char *engine,
         }
     } else {
         response = create_response(conf, section, engine, queryfile,
-                                   passin, inkey, md, signer, chain, policy);
+            passin, inkey, md, signer, chain, policy);
         if (response != NULL)
             BIO_printf(bio_err, "Response has been generated.\n");
         else
@@ -623,7 +644,7 @@ static int reply_command(CONF *conf, const char *section, const char *engine,
     /* Write response. */
     if (text) {
         if ((out_bio = bio_open_default(out, 'w', FORMAT_TEXT)) == NULL)
-        goto end;
+            goto end;
         if (token_out) {
             TS_TST_INFO *tst_info = TS_RESP_get_tst_info(response);
             if (!TS_TST_INFO_print_bio(out_bio, tst_info))
@@ -647,7 +668,7 @@ static int reply_command(CONF *conf, const char *section, const char *engine,
 
     ret = 1;
 
- end:
+end:
     ERR_print_errors(bio_err);
     BIO_free_all(in_bio);
     BIO_free_all(query_bio);
@@ -680,11 +701,11 @@ static TS_RESP *read_PKCS7(BIO *in_bio)
     if (!TS_RESP_set_status_info(resp, si))
         goto end;
     TS_RESP_set_tst_info(resp, token, tst_info);
-    token = NULL;               /* Ownership is lost. */
-    tst_info = NULL;            /* Ownership is lost. */
+    token = NULL; /* Ownership is lost. */
+    tst_info = NULL; /* Ownership is lost. */
     ret = 1;
 
- end:
+end:
     PKCS7_free(token);
     TS_TST_INFO_free(tst_info);
     if (!ret) {
@@ -696,9 +717,9 @@ static TS_RESP *read_PKCS7(BIO *in_bio)
 }
 
 static TS_RESP *create_response(CONF *conf, const char *section, const char *engine,
-                                const char *queryfile, const char *passin,
-                                const char *inkey, const EVP_MD *md, const char *signer,
-                                const char *chain, const char *policy)
+    const char *queryfile, const char *passin,
+    const char *inkey, const EVP_MD *md, const char *signer,
+    const char *chain, const char *policy)
 {
     int ret = 0;
     TS_RESP *response = NULL;
@@ -728,7 +749,7 @@ static TS_RESP *create_response(CONF *conf, const char *section, const char *eng
         if (!TS_RESP_CTX_set_signer_digest(resp_ctx, md))
             goto end;
     } else if (!TS_CONF_set_signer_digest(conf, section, NULL, resp_ctx)) {
-            goto end;
+        goto end;
     }
 
     if (!TS_CONF_set_ess_cert_id_digest(conf, section, resp_ctx))
@@ -753,7 +774,7 @@ static TS_RESP *create_response(CONF *conf, const char *section, const char *eng
         goto end;
     ret = 1;
 
- end:
+end:
     if (!ret) {
         TS_RESP_free(response);
         response = NULL;
@@ -770,8 +791,8 @@ static ASN1_INTEGER *serial_cb(TS_RESP_CTX *ctx, void *data)
 
     if (serial == NULL) {
         TS_RESP_CTX_set_status_info(ctx, TS_STATUS_REJECTION,
-                                    "Error during serial number "
-                                    "generation.");
+            "Error during serial number "
+            "generation.");
         TS_RESP_CTX_add_failure_info(ctx, TS_INFO_ADD_INFO_NOT_AVAILABLE);
     } else {
         save_ts_serial(serial_file, serial);
@@ -793,14 +814,15 @@ static ASN1_INTEGER *next_serial(const char *serialfile)
     if ((in = BIO_new_file(serialfile, "r")) == NULL) {
         ERR_clear_error();
         BIO_printf(bio_err, "Warning: could not open file %s for "
-                   "reading, using serial number: 1\n", serialfile);
+                            "reading, using serial number: 1\n",
+            serialfile);
         if (!ASN1_INTEGER_set(serial, 1))
             goto err;
     } else {
         char buf[1024];
         if (!a2i_ASN1_INTEGER(in, serial, buf, sizeof(buf))) {
             BIO_printf(bio_err, "unable to load number from %s\n",
-                       serialfile);
+                serialfile);
             goto err;
         }
         if ((bn = ASN1_INTEGER_to_BN(serial, NULL)) == NULL)
@@ -814,7 +836,7 @@ static ASN1_INTEGER *next_serial(const char *serialfile)
     }
     ret = 1;
 
- err:
+err:
     if (!ret) {
         ASN1_INTEGER_free(serial);
         serial = NULL;
@@ -836,24 +858,23 @@ static int save_ts_serial(const char *serialfile, ASN1_INTEGER *serial)
     if (BIO_puts(out, "\n") <= 0)
         goto err;
     ret = 1;
- err:
+err:
     if (!ret)
         BIO_printf(bio_err, "could not save serial number to %s\n",
-                   serialfile);
+            serialfile);
     BIO_free_all(out);
     return ret;
 }
 
-
 /*
  * Verify-related method definitions.
  */
 
 static int verify_command(const char *data, const char *digest, const char *queryfile,
-                          const char *in, int token_in,
-                          const char *CApath, const char *CAfile,
-                          const char *CAstore, char *untrusted,
-                          X509_VERIFY_PARAM *vpm)
+    const char *in, int token_in,
+    const char *CApath, const char *CAfile,
+    const char *CAstore, char *untrusted,
+    X509_VERIFY_PARAM *vpm)
 {
     BIO *in_bio = NULL;
     PKCS7 *token = NULL;
@@ -872,15 +893,16 @@ static int verify_command(const char *data, const char *digest, const char *quer
     }
 
     if ((verify_ctx = create_verify_ctx(data, digest, queryfile,
-                                        CApath, CAfile, CAstore, untrusted,
-                                        vpm)) == NULL)
+             CApath, CAfile, CAstore, untrusted,
+             vpm))
+        == NULL)
         goto end;
 
     ret = token_in
         ? TS_RESP_verify_token(verify_ctx, token)
         : TS_RESP_verify_response(verify_ctx, response);
 
- end:
+end:
     printf("Verification: ");
     if (ret)
         printf("OK\n");
@@ -897,11 +919,11 @@ static int verify_command(const char *data, const char *digest, const char *quer
 }
 
 static TS_VERIFY_CTX *create_verify_ctx(const char *data, const char *digest,
-                                        const char *queryfile,
-                                        const char *CApath, const char *CAfile,
-                                        const char *CAstore,
-                                        char *untrusted,
-                                        X509_VERIFY_PARAM *vpm)
+    const char *queryfile,
+    const char *CApath, const char *CAfile,
+    const char *CAstore,
+    char *untrusted,
+    X509_VERIFY_PARAM *vpm)
 {
     TS_VERIFY_CTX *ctx = NULL;
     STACK_OF(X509) *certs;
@@ -950,20 +972,20 @@ static TS_VERIFY_CTX *create_verify_ctx(const char *data, const char *digest,
 
     /* Initialising the X509_STORE object. */
     if (TS_VERIFY_CTX_set_store(ctx,
-                                create_cert_store(CApath, CAfile, CAstore, vpm))
-            == NULL)
+            create_cert_store(CApath, CAfile, CAstore, vpm))
+        == NULL)
         goto err;
 
     /* Loading any extra untrusted certificates. */
     if (untrusted != NULL) {
         certs = load_certs_multifile(untrusted, NULL, "extra untrusted certs",
-                                     vpm);
+            vpm);
         if (certs == NULL || TS_VERIFY_CTX_set_certs(ctx, certs) == NULL)
             goto err;
     }
     ret = 1;
 
- err:
+err:
     if (!ret) {
         TS_VERIFY_CTX_free(ctx);
         ctx = NULL;
@@ -974,7 +996,7 @@ static TS_VERIFY_CTX *create_verify_ctx(const char *data, const char *digest,
 }
 
 static X509_STORE *create_cert_store(const char *CApath, const char *CAfile,
-                                     const char *CAstore, X509_VERIFY_PARAM *vpm)
+    const char *CAstore, X509_VERIFY_PARAM *vpm)
 {
     X509_STORE *cert_ctx = NULL;
     X509_LOOKUP *lookup = NULL;
@@ -1006,7 +1028,8 @@ static X509_STORE *create_cert_store(const char *CApath, const char *CAfile,
             goto err;
         }
         if (X509_LOOKUP_load_file_ex(lookup, CAfile, X509_FILETYPE_PEM, libctx,
-                                      propq) <= 0) {
+                propq)
+            <= 0) {
             BIO_printf(bio_err, "Error loading file %s\n", CAfile);
             goto err;
         }
@@ -1029,7 +1052,7 @@ static X509_STORE *create_cert_store(const char *CApath, const char *CAfile,
 
     return cert_ctx;
 
- err:
+err:
     X509_STORE_free(cert_ctx);
     return NULL;
 }
