@@ -1,5 +1,5 @@
 /*
- * Copyright 2016-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2016-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -29,6 +29,8 @@ int BIO_get_new_index(void)
     }
     if (!CRYPTO_UP_REF(&bio_type_count, &newval))
         return -1;
+    if (newval > BIO_TYPE_MASK)
+        return -1;
     return newval;
 }
 
@@ -37,7 +39,7 @@ BIO_METHOD *BIO_meth_new(int type, const char *name)
     BIO_METHOD *biom = OPENSSL_zalloc(sizeof(BIO_METHOD));
 
     if (biom == NULL
-            || (biom->name = OPENSSL_strdup(name)) == NULL) {
+        || (biom->name = OPENSSL_strdup(name)) == NULL) {
         OPENSSL_free(biom);
         return NULL;
     }
@@ -53,13 +55,13 @@ void BIO_meth_free(BIO_METHOD *biom)
     }
 }
 
-int (*BIO_meth_get_write(const BIO_METHOD *biom)) (BIO *, const char *, int)
+int (*BIO_meth_get_write(const BIO_METHOD *biom))(BIO *, const char *, int)
 {
     return biom->bwrite_old;
 }
 
-int (*BIO_meth_get_write_ex(const BIO_METHOD *biom)) (BIO *, const char *, size_t,
-                                                size_t *)
+int (*BIO_meth_get_write_ex(const BIO_METHOD *biom))(BIO *, const char *, size_t,
+    size_t *)
 {
     return biom->bwrite;
 }
@@ -85,7 +87,7 @@ int bwrite_conv(BIO *bio, const char *data, size_t datal, size_t *written)
 }
 
 int BIO_meth_set_write(BIO_METHOD *biom,
-                       int (*bwrite) (BIO *, const char *, int))
+    int (*bwrite)(BIO *, const char *, int))
 {
     biom->bwrite_old = bwrite;
     biom->bwrite = bwrite_conv;
@@ -93,19 +95,19 @@ int BIO_meth_set_write(BIO_METHOD *biom,
 }
 
 int BIO_meth_set_write_ex(BIO_METHOD *biom,
-                       int (*bwrite) (BIO *, const char *, size_t, size_t *))
+    int (*bwrite)(BIO *, const char *, size_t, size_t *))
 {
     biom->bwrite_old = NULL;
     biom->bwrite = bwrite;
     return 1;
 }
 
-int (*BIO_meth_get_read(const BIO_METHOD *biom)) (BIO *, char *, int)
+int (*BIO_meth_get_read(const BIO_METHOD *biom))(BIO *, char *, int)
 {
     return biom->bread_old;
 }
 
-int (*BIO_meth_get_read_ex(const BIO_METHOD *biom)) (BIO *, char *, size_t, size_t *)
+int (*BIO_meth_get_read_ex(const BIO_METHOD *biom))(BIO *, char *, size_t, size_t *)
 {
     return biom->bread;
 }
@@ -131,7 +133,7 @@ int bread_conv(BIO *bio, char *data, size_t datal, size_t *readbytes)
 }
 
 int BIO_meth_set_read(BIO_METHOD *biom,
-                      int (*bread) (BIO *, char *, int))
+    int (*bread)(BIO *, char *, int))
 {
     biom->bread_old = bread;
     biom->bread = bread_conv;
@@ -139,102 +141,104 @@ int BIO_meth_set_read(BIO_METHOD *biom,
 }
 
 int BIO_meth_set_read_ex(BIO_METHOD *biom,
-                         int (*bread) (BIO *, char *, size_t, size_t *))
+    int (*bread)(BIO *, char *, size_t, size_t *))
 {
     biom->bread_old = NULL;
     biom->bread = bread;
     return 1;
 }
 
-int (*BIO_meth_get_puts(const BIO_METHOD *biom)) (BIO *, const char *)
+int (*BIO_meth_get_puts(const BIO_METHOD *biom))(BIO *, const char *)
 {
     return biom->bputs;
 }
 
 int BIO_meth_set_puts(BIO_METHOD *biom,
-                      int (*bputs) (BIO *, const char *))
+    int (*bputs)(BIO *, const char *))
 {
     biom->bputs = bputs;
     return 1;
 }
 
-int (*BIO_meth_get_gets(const BIO_METHOD *biom)) (BIO *, char *, int)
+int (*BIO_meth_get_gets(const BIO_METHOD *biom))(BIO *, char *, int)
 {
     return biom->bgets;
 }
 
 int BIO_meth_set_gets(BIO_METHOD *biom,
-                      int (*bgets) (BIO *, char *, int))
+    int (*bgets)(BIO *, char *, int))
 {
     biom->bgets = bgets;
     return 1;
 }
 
-long (*BIO_meth_get_ctrl(const BIO_METHOD *biom)) (BIO *, int, long, void *)
+long (*BIO_meth_get_ctrl(const BIO_METHOD *biom))(BIO *, int, long, void *)
 {
     return biom->ctrl;
 }
 
 int BIO_meth_set_ctrl(BIO_METHOD *biom,
-                      long (*ctrl) (BIO *, int, long, void *))
+    long (*ctrl)(BIO *, int, long, void *))
 {
     biom->ctrl = ctrl;
     return 1;
 }
 
-int (*BIO_meth_get_create(const BIO_METHOD *biom)) (BIO *)
+int (*BIO_meth_get_create(const BIO_METHOD *biom))(BIO *)
 {
     return biom->create;
 }
 
-int BIO_meth_set_create(BIO_METHOD *biom, int (*create) (BIO *))
+int BIO_meth_set_create(BIO_METHOD *biom, int (*create)(BIO *))
 {
     biom->create = create;
     return 1;
 }
 
-int (*BIO_meth_get_destroy(const BIO_METHOD *biom)) (BIO *)
+int (*BIO_meth_get_destroy(const BIO_METHOD *biom))(BIO *)
 {
     return biom->destroy;
 }
 
-int BIO_meth_set_destroy(BIO_METHOD *biom, int (*destroy) (BIO *))
+int BIO_meth_set_destroy(BIO_METHOD *biom, int (*destroy)(BIO *))
 {
     biom->destroy = destroy;
     return 1;
 }
 
-long (*BIO_meth_get_callback_ctrl(const BIO_METHOD *biom)) (BIO *, int, BIO_info_cb *)
+long (*BIO_meth_get_callback_ctrl(const BIO_METHOD *biom))(BIO *, int, BIO_info_cb *)
 {
     return biom->callback_ctrl;
 }
 
 int BIO_meth_set_callback_ctrl(BIO_METHOD *biom,
-                               long (*callback_ctrl) (BIO *, int,
-                                                      BIO_info_cb *))
+    long (*callback_ctrl)(BIO *, int,
+        BIO_info_cb *))
 {
     biom->callback_ctrl = callback_ctrl;
     return 1;
 }
 
 int BIO_meth_set_sendmmsg(BIO_METHOD *biom,
-                          int (*bsendmmsg) (BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *))
+    int (*bsendmmsg)(BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *))
 {
     biom->bsendmmsg = bsendmmsg;
     return 1;
 }
 
-int (*BIO_meth_get_sendmmsg(const BIO_METHOD *biom))(BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *) {
+int (*BIO_meth_get_sendmmsg(const BIO_METHOD *biom))(BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *)
+{
     return biom->bsendmmsg;
 }
 
 int BIO_meth_set_recvmmsg(BIO_METHOD *biom,
-                          int (*brecvmmsg) (BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *))
+    int (*brecvmmsg)(BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *))
 {
     biom->brecvmmsg = brecvmmsg;
     return 1;
 }
 
-int (*BIO_meth_get_recvmmsg(const BIO_METHOD *biom))(BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *) {
+int (*BIO_meth_get_recvmmsg(const BIO_METHOD *biom))(BIO *, BIO_MSG *, size_t, size_t, uint64_t, size_t *)
+{
     return biom->brecvmmsg;
 }
