@@ -10,18 +10,18 @@
 #include "bn_local.h"
 #include "internal/cryptlib.h"
 
-#define BN_NIST_192_TOP (192+BN_BITS2-1)/BN_BITS2
-#define BN_NIST_224_TOP (224+BN_BITS2-1)/BN_BITS2
-#define BN_NIST_256_TOP (256+BN_BITS2-1)/BN_BITS2
-#define BN_NIST_384_TOP (384+BN_BITS2-1)/BN_BITS2
-#define BN_NIST_521_TOP (521+BN_BITS2-1)/BN_BITS2
+#define BN_NIST_192_TOP (192 + BN_BITS2 - 1) / BN_BITS2
+#define BN_NIST_224_TOP (224 + BN_BITS2 - 1) / BN_BITS2
+#define BN_NIST_256_TOP (256 + BN_BITS2 - 1) / BN_BITS2
+#define BN_NIST_384_TOP (384 + BN_BITS2 - 1) / BN_BITS2
+#define BN_NIST_521_TOP (521 + BN_BITS2 - 1) / BN_BITS2
 
 /* pre-computed tables are "carry-less" values of modulus*(i+1) */
 #if BN_BITS2 == 64
 static const BN_ULONG _nist_p_192[][BN_NIST_192_TOP] = {
-    {0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFEULL, 0xFFFFFFFFFFFFFFFFULL},
-    {0xFFFFFFFFFFFFFFFEULL, 0xFFFFFFFFFFFFFFFDULL, 0xFFFFFFFFFFFFFFFFULL},
-    {0xFFFFFFFFFFFFFFFDULL, 0xFFFFFFFFFFFFFFFCULL, 0xFFFFFFFFFFFFFFFFULL}
+    { 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFEULL, 0xFFFFFFFFFFFFFFFFULL },
+    { 0xFFFFFFFFFFFFFFFEULL, 0xFFFFFFFFFFFFFFFDULL, 0xFFFFFFFFFFFFFFFFULL },
+    { 0xFFFFFFFFFFFFFFFDULL, 0xFFFFFFFFFFFFFFFCULL, 0xFFFFFFFFFFFFFFFFULL }
 };
 
 static const BN_ULONG _nist_p_192_sqr[] = {
@@ -30,11 +30,11 @@ static const BN_ULONG _nist_p_192_sqr[] = {
 };
 
 static const BN_ULONG _nist_p_224[][BN_NIST_224_TOP] = {
-    {0x0000000000000001ULL, 0xFFFFFFFF00000000ULL,
-     0xFFFFFFFFFFFFFFFFULL, 0x00000000FFFFFFFFULL},
-    {0x0000000000000002ULL, 0xFFFFFFFE00000000ULL,
-     0xFFFFFFFFFFFFFFFFULL, 0x00000001FFFFFFFFULL} /* this one is
-                                                    * "carry-full" */
+    { 0x0000000000000001ULL, 0xFFFFFFFF00000000ULL,
+        0xFFFFFFFFFFFFFFFFULL, 0x00000000FFFFFFFFULL },
+    { 0x0000000000000002ULL, 0xFFFFFFFE00000000ULL,
+        0xFFFFFFFFFFFFFFFFULL, 0x00000001FFFFFFFFULL } /* this one is
+                                                        * "carry-full" */
 };
 
 static const BN_ULONG _nist_p_224_sqr[] = {
@@ -45,16 +45,16 @@ static const BN_ULONG _nist_p_224_sqr[] = {
 };
 
 static const BN_ULONG _nist_p_256[][BN_NIST_256_TOP] = {
-    {0xFFFFFFFFFFFFFFFFULL, 0x00000000FFFFFFFFULL,
-     0x0000000000000000ULL, 0xFFFFFFFF00000001ULL},
-    {0xFFFFFFFFFFFFFFFEULL, 0x00000001FFFFFFFFULL,
-     0x0000000000000000ULL, 0xFFFFFFFE00000002ULL},
-    {0xFFFFFFFFFFFFFFFDULL, 0x00000002FFFFFFFFULL,
-     0x0000000000000000ULL, 0xFFFFFFFD00000003ULL},
-    {0xFFFFFFFFFFFFFFFCULL, 0x00000003FFFFFFFFULL,
-     0x0000000000000000ULL, 0xFFFFFFFC00000004ULL},
-    {0xFFFFFFFFFFFFFFFBULL, 0x00000004FFFFFFFFULL,
-     0x0000000000000000ULL, 0xFFFFFFFB00000005ULL},
+    { 0xFFFFFFFFFFFFFFFFULL, 0x00000000FFFFFFFFULL,
+        0x0000000000000000ULL, 0xFFFFFFFF00000001ULL },
+    { 0xFFFFFFFFFFFFFFFEULL, 0x00000001FFFFFFFFULL,
+        0x0000000000000000ULL, 0xFFFFFFFE00000002ULL },
+    { 0xFFFFFFFFFFFFFFFDULL, 0x00000002FFFFFFFFULL,
+        0x0000000000000000ULL, 0xFFFFFFFD00000003ULL },
+    { 0xFFFFFFFFFFFFFFFCULL, 0x00000003FFFFFFFFULL,
+        0x0000000000000000ULL, 0xFFFFFFFC00000004ULL },
+    { 0xFFFFFFFFFFFFFFFBULL, 0x00000004FFFFFFFFULL,
+        0x0000000000000000ULL, 0xFFFFFFFB00000005ULL },
 };
 
 static const BN_ULONG _nist_p_256_sqr[] = {
@@ -65,16 +65,16 @@ static const BN_ULONG _nist_p_256_sqr[] = {
 };
 
 static const BN_ULONG _nist_p_384[][BN_NIST_384_TOP] = {
-    {0x00000000FFFFFFFFULL, 0xFFFFFFFF00000000ULL, 0xFFFFFFFFFFFFFFFEULL,
-     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL},
-    {0x00000001FFFFFFFEULL, 0xFFFFFFFE00000000ULL, 0xFFFFFFFFFFFFFFFDULL,
-     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL},
-    {0x00000002FFFFFFFDULL, 0xFFFFFFFD00000000ULL, 0xFFFFFFFFFFFFFFFCULL,
-     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL},
-    {0x00000003FFFFFFFCULL, 0xFFFFFFFC00000000ULL, 0xFFFFFFFFFFFFFFFBULL,
-     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL},
-    {0x00000004FFFFFFFBULL, 0xFFFFFFFB00000000ULL, 0xFFFFFFFFFFFFFFFAULL,
-     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL},
+    { 0x00000000FFFFFFFFULL, 0xFFFFFFFF00000000ULL, 0xFFFFFFFFFFFFFFFEULL,
+        0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL },
+    { 0x00000001FFFFFFFEULL, 0xFFFFFFFE00000000ULL, 0xFFFFFFFFFFFFFFFDULL,
+        0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL },
+    { 0x00000002FFFFFFFDULL, 0xFFFFFFFD00000000ULL, 0xFFFFFFFFFFFFFFFCULL,
+        0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL },
+    { 0x00000003FFFFFFFCULL, 0xFFFFFFFC00000000ULL, 0xFFFFFFFFFFFFFFFBULL,
+        0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL },
+    { 0x00000004FFFFFFFBULL, 0xFFFFFFFB00000000ULL, 0xFFFFFFFFFFFFFFFAULL,
+        0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL },
 };
 
 static const BN_ULONG _nist_p_384_sqr[] = {
@@ -84,13 +84,11 @@ static const BN_ULONG _nist_p_384_sqr[] = {
     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL
 };
 
-static const BN_ULONG _nist_p_521[] =
-    { 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL,
+static const BN_ULONG _nist_p_521[] = { 0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL,
     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL,
     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL,
     0xFFFFFFFFFFFFFFFFULL, 0xFFFFFFFFFFFFFFFFULL,
-    0x00000000000001FFULL
-};
+    0x00000000000001FFULL };
 
 static const BN_ULONG _nist_p_521_sqr[] = {
     0x0000000000000001ULL, 0x0000000000000000ULL, 0x0000000000000000ULL,
@@ -102,9 +100,9 @@ static const BN_ULONG _nist_p_521_sqr[] = {
 };
 #elif BN_BITS2 == 32
 static const BN_ULONG _nist_p_192[][BN_NIST_192_TOP] = {
-    {0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
-    {0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
-    {0xFFFFFFFD, 0xFFFFFFFF, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF}
+    { 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
+    { 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFD, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
+    { 0xFFFFFFFD, 0xFFFFFFFF, 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF }
 };
 
 static const BN_ULONG _nist_p_192_sqr[] = {
@@ -113,10 +111,10 @@ static const BN_ULONG _nist_p_192_sqr[] = {
 };
 
 static const BN_ULONG _nist_p_224[][BN_NIST_224_TOP] = {
-    {0x00000001, 0x00000000, 0x00000000, 0xFFFFFFFF,
-     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
-    {0x00000002, 0x00000000, 0x00000000, 0xFFFFFFFE,
-     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF}
+    { 0x00000001, 0x00000000, 0x00000000, 0xFFFFFFFF,
+        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
+    { 0x00000002, 0x00000000, 0x00000000, 0xFFFFFFFE,
+        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF }
 };
 
 static const BN_ULONG _nist_p_224_sqr[] = {
@@ -127,16 +125,16 @@ static const BN_ULONG _nist_p_224_sqr[] = {
 };
 
 static const BN_ULONG _nist_p_256[][BN_NIST_256_TOP] = {
-    {0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000000,
-     0x00000000, 0x00000000, 0x00000001, 0xFFFFFFFF},
-    {0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000001,
-     0x00000000, 0x00000000, 0x00000002, 0xFFFFFFFE},
-    {0xFFFFFFFD, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000002,
-     0x00000000, 0x00000000, 0x00000003, 0xFFFFFFFD},
-    {0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000003,
-     0x00000000, 0x00000000, 0x00000004, 0xFFFFFFFC},
-    {0xFFFFFFFB, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000004,
-     0x00000000, 0x00000000, 0x00000005, 0xFFFFFFFB},
+    { 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000000,
+        0x00000000, 0x00000000, 0x00000001, 0xFFFFFFFF },
+    { 0xFFFFFFFE, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000001,
+        0x00000000, 0x00000000, 0x00000002, 0xFFFFFFFE },
+    { 0xFFFFFFFD, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000002,
+        0x00000000, 0x00000000, 0x00000003, 0xFFFFFFFD },
+    { 0xFFFFFFFC, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000003,
+        0x00000000, 0x00000000, 0x00000004, 0xFFFFFFFC },
+    { 0xFFFFFFFB, 0xFFFFFFFF, 0xFFFFFFFF, 0x00000004,
+        0x00000000, 0x00000000, 0x00000005, 0xFFFFFFFB },
 };
 
 static const BN_ULONG _nist_p_256_sqr[] = {
@@ -147,16 +145,16 @@ static const BN_ULONG _nist_p_256_sqr[] = {
 };
 
 static const BN_ULONG _nist_p_384[][BN_NIST_384_TOP] = {
-    {0xFFFFFFFF, 0x00000000, 0x00000000, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFF,
-     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
-    {0xFFFFFFFE, 0x00000001, 0x00000000, 0xFFFFFFFE, 0xFFFFFFFD, 0xFFFFFFFF,
-     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
-    {0xFFFFFFFD, 0x00000002, 0x00000000, 0xFFFFFFFD, 0xFFFFFFFC, 0xFFFFFFFF,
-     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
-    {0xFFFFFFFC, 0x00000003, 0x00000000, 0xFFFFFFFC, 0xFFFFFFFB, 0xFFFFFFFF,
-     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
-    {0xFFFFFFFB, 0x00000004, 0x00000000, 0xFFFFFFFB, 0xFFFFFFFA, 0xFFFFFFFF,
-     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF},
+    { 0xFFFFFFFF, 0x00000000, 0x00000000, 0xFFFFFFFF, 0xFFFFFFFE, 0xFFFFFFFF,
+        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
+    { 0xFFFFFFFE, 0x00000001, 0x00000000, 0xFFFFFFFE, 0xFFFFFFFD, 0xFFFFFFFF,
+        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
+    { 0xFFFFFFFD, 0x00000002, 0x00000000, 0xFFFFFFFD, 0xFFFFFFFC, 0xFFFFFFFF,
+        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
+    { 0xFFFFFFFC, 0x00000003, 0x00000000, 0xFFFFFFFC, 0xFFFFFFFB, 0xFFFFFFFF,
+        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
+    { 0xFFFFFFFB, 0x00000004, 0x00000000, 0xFFFFFFFB, 0xFFFFFFFA, 0xFFFFFFFF,
+        0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF },
 };
 
 static const BN_ULONG _nist_p_384_sqr[] = {
@@ -169,8 +167,7 @@ static const BN_ULONG _nist_p_384_sqr[] = {
 static const BN_ULONG _nist_p_521[] = { 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
     0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF,
-    0xFFFFFFFF, 0x000001FF
-};
+    0xFFFFFFFF, 0x000001FF };
 
 static const BN_ULONG _nist_p_521_sqr[] = {
     0x00000001, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000,
@@ -181,7 +178,7 @@ static const BN_ULONG _nist_p_521_sqr[] = {
     0xFFFFFFFF, 0xFFFFFFFF, 0x0003FFFF
 };
 #else
-# error "unsupported BN_BITS2"
+#error "unsupported BN_BITS2"
 #endif
 
 static const BIGNUM ossl_bignum_nist_p_192 = {
@@ -263,15 +260,15 @@ const BIGNUM *BN_get0_nist_prime_521(void)
  * paid for making it a macro.
  */
 #define nist_cp_bn_0(dst, src_in, top, max) \
-{                                           \
-    int ii;                                 \
-    const BN_ULONG *src = src_in;           \
+    {                                       \
+        int ii;                             \
+        const BN_ULONG *src = src_in;       \
                                             \
-    for (ii = 0; ii < top; ii++)            \
-        (dst)[ii] = src[ii];                \
-    for (; ii < max; ii++)                  \
-        (dst)[ii] = 0;                      \
-}
+        for (ii = 0; ii < top; ii++)        \
+            (dst)[ii] = src[ii];            \
+        for (; ii < max; ii++)              \
+            (dst)[ii] = 0;                  \
+    }
 
 static void nist_cp_bn(BN_ULONG *dst, const BN_ULONG *src, int top)
 {
@@ -282,42 +279,42 @@ static void nist_cp_bn(BN_ULONG *dst, const BN_ULONG *src, int top)
 }
 
 #if BN_BITS2 == 64
-# define bn_cp_64(to, n, from, m)        (to)[n] = (m>=0)?((from)[m]):0;
-# define bn_64_set_0(to, n)              (to)[n] = (BN_ULONG)0;
+#define bn_cp_64(to, n, from, m) (to)[n] = (m >= 0) ? ((from)[m]) : 0;
+#define bn_64_set_0(to, n) (to)[n] = (BN_ULONG)0;
 /*
  * two following macros are implemented under assumption that they
  * are called in a sequence with *ascending* n, i.e. as they are...
  */
-# define bn_cp_32_naked(to, n, from, m)  (((n)&1)?(to[(n)/2]|=((m)&1)?(from[(m)/2]&BN_MASK2h):(from[(m)/2]<<32))\
-                                                :(to[(n)/2] =((m)&1)?(from[(m)/2]>>32):(from[(m)/2]&BN_MASK2l)))
-# define bn_32_set_0(to, n)              (((n)&1)?(to[(n)/2]&=BN_MASK2l):(to[(n)/2]=0));
-# define bn_cp_32(to,n,from,m)           ((m)>=0)?bn_cp_32_naked(to,n,from,m):bn_32_set_0(to,n)
-# if defined(L_ENDIAN)
-#  if defined(__arch64__)
-#   define NIST_INT64 long
-#  else
-#   define NIST_INT64 long long
-#  endif
-# endif
+#define bn_cp_32_naked(to, n, from, m) (((n) & 1) ? (to[(n) / 2] |= ((m) & 1) ? (from[(m) / 2] & BN_MASK2h) : (from[(m) / 2] << 32)) \
+                                                  : (to[(n) / 2] = ((m) & 1) ? (from[(m) / 2] >> 32) : (from[(m) / 2] & BN_MASK2l)))
+#define bn_32_set_0(to, n) (((n) & 1) ? (to[(n) / 2] &= BN_MASK2l) : (to[(n) / 2] = 0));
+#define bn_cp_32(to, n, from, m) ((m) >= 0) ? bn_cp_32_naked(to, n, from, m) : bn_32_set_0(to, n)
+#if defined(L_ENDIAN)
+#if defined(__arch64__)
+#define NIST_INT64 long
 #else
-# define bn_cp_64(to, n, from, m) \
-        { \
-        bn_cp_32(to, (n)*2, from, (m)*2); \
-        bn_cp_32(to, (n)*2+1, from, (m)*2+1); \
-        }
-# define bn_64_set_0(to, n) \
-        { \
-        bn_32_set_0(to, (n)*2); \
-        bn_32_set_0(to, (n)*2+1); \
-        }
-# define bn_cp_32(to, n, from, m)        (to)[n] = (m>=0)?((from)[m]):0;
-# define bn_32_set_0(to, n)              (to)[n] = (BN_ULONG)0;
-# if defined(_WIN32) && !defined(__GNUC__)
-#  define NIST_INT64 __int64
-# elif defined(BN_LLONG)
-#  define NIST_INT64 long long
-# endif
-#endif                          /* BN_BITS2 != 64 */
+#define NIST_INT64 long long
+#endif
+#endif
+#else
+#define bn_cp_64(to, n, from, m)                      \
+    {                                                 \
+        bn_cp_32(to, (n) * 2, from, (m) * 2);         \
+        bn_cp_32(to, (n) * 2 + 1, from, (m) * 2 + 1); \
+    }
+#define bn_64_set_0(to, n)            \
+    {                                 \
+        bn_32_set_0(to, (n) * 2);     \
+        bn_32_set_0(to, (n) * 2 + 1); \
+    }
+#define bn_cp_32(to, n, from, m) (to)[n] = (m >= 0) ? ((from)[m]) : 0;
+#define bn_32_set_0(to, n) (to)[n] = (BN_ULONG)0;
+#if defined(_WIN32) && !defined(__GNUC__)
+#define NIST_INT64 __int64
+#elif defined(BN_LLONG)
+#define NIST_INT64 long long
+#endif
+#endif /* BN_BITS2 != 64 */
 
 #ifdef NIST_INT64
 /* Helpers to load/store a 32-bit word (uint32_t) from/into a memory
@@ -341,23 +338,22 @@ static ossl_inline void store_lo32(void *ptr, NIST_INT64 val)
 }
 #endif /* NIST_INT64 */
 
-#define nist_set_192(to, from, a1, a2, a3) \
-        { \
-        bn_cp_64(to, 0, from, (a3) - 3) \
-        bn_cp_64(to, 1, from, (a2) - 3) \
-        bn_cp_64(to, 2, from, (a1) - 3) \
-        }
+#define nist_set_192(to, from, a1, a2, a3)      \
+    {                                           \
+        bn_cp_64(to, 0, from, (a3) - 3)         \
+            bn_cp_64(to, 1, from, (a2) - 3)     \
+                bn_cp_64(to, 2, from, (a1) - 3) \
+    }
 
 int BN_nist_mod_192(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
-                    BN_CTX *ctx)
+    BN_CTX *ctx)
 {
     int top = a->top, i;
     int carry;
     register BN_ULONG *r_d, *a_d = a->d;
     union {
         BN_ULONG bn[BN_NIST_192_TOP];
-        unsigned int ui[BN_NIST_192_TOP * sizeof(BN_ULONG) /
-                        sizeof(unsigned int)];
+        unsigned int ui[BN_NIST_192_TOP * sizeof(BN_ULONG) / sizeof(unsigned int)];
     } buf;
     BN_ULONG c_d[BN_NIST_192_TOP], *res;
     static const BIGNUM ossl_bignum_nist_p_192_sqr = {
@@ -388,11 +384,11 @@ int BN_nist_mod_192(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
         r_d = a_d;
 
     nist_cp_bn_0(buf.bn, a_d + BN_NIST_192_TOP, top - BN_NIST_192_TOP,
-                 BN_NIST_192_TOP);
+        BN_NIST_192_TOP);
 
 #if defined(NIST_INT64)
     {
-        NIST_INT64 acc;         /* accumulator */
+        NIST_INT64 acc; /* accumulator */
         unsigned int *rp = (unsigned int *)r_d;
         const unsigned int *bp = (const unsigned int *)buf.ui;
 
@@ -444,13 +440,13 @@ int BN_nist_mod_192(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
         nist_set_192(t_d, buf.bn, 4, 4, 0);
         carry += (int)bn_add_words(r_d, r_d, t_d, BN_NIST_192_TOP);
         nist_set_192(t_d, buf.bn, 5, 5, 5)
-            carry += (int)bn_add_words(r_d, r_d, t_d, BN_NIST_192_TOP);
+            carry
+            += (int)bn_add_words(r_d, r_d, t_d, BN_NIST_192_TOP);
     }
 #endif
     if (carry > 0)
-        carry =
-            (int)bn_sub_words(r_d, r_d, _nist_p_192[carry - 1],
-                              BN_NIST_192_TOP);
+        carry = (int)bn_sub_words(r_d, r_d, _nist_p_192[carry - 1],
+            BN_NIST_192_TOP);
     else
         carry = 1;
 
@@ -470,30 +466,29 @@ int BN_nist_mod_192(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
     return 1;
 }
 
-typedef BN_ULONG (*bn_addsub_f) (BN_ULONG *, const BN_ULONG *,
-                                 const BN_ULONG *, int);
+typedef BN_ULONG (*bn_addsub_f)(BN_ULONG *, const BN_ULONG *,
+    const BN_ULONG *, int);
 
-#define nist_set_224(to, from, a1, a2, a3, a4, a5, a6, a7) \
-        { \
-        bn_cp_32(to, 0, from, (a7) - 7) \
-        bn_cp_32(to, 1, from, (a6) - 7) \
-        bn_cp_32(to, 2, from, (a5) - 7) \
-        bn_cp_32(to, 3, from, (a4) - 7) \
-        bn_cp_32(to, 4, from, (a3) - 7) \
-        bn_cp_32(to, 5, from, (a2) - 7) \
-        bn_cp_32(to, 6, from, (a1) - 7) \
-        }
+#define nist_set_224(to, from, a1, a2, a3, a4, a5, a6, a7)      \
+    {                                                           \
+        bn_cp_32(to, 0, from, (a7) - 7)                         \
+            bn_cp_32(to, 1, from, (a6) - 7)                     \
+                bn_cp_32(to, 2, from, (a5) - 7)                 \
+                    bn_cp_32(to, 3, from, (a4) - 7)             \
+                        bn_cp_32(to, 4, from, (a3) - 7)         \
+                            bn_cp_32(to, 5, from, (a2) - 7)     \
+                                bn_cp_32(to, 6, from, (a1) - 7) \
+    }
 
 int BN_nist_mod_224(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
-                    BN_CTX *ctx)
+    BN_CTX *ctx)
 {
     int top = a->top, i;
     int carry;
     BN_ULONG *r_d, *a_d = a->d;
     union {
         BN_ULONG bn[BN_NIST_224_TOP];
-        unsigned int ui[BN_NIST_224_TOP * sizeof(BN_ULONG) /
-                        sizeof(unsigned int)];
+        unsigned int ui[BN_NIST_224_TOP * sizeof(BN_ULONG) / sizeof(unsigned int)];
     } buf;
     BN_ULONG c_d[BN_NIST_224_TOP], *res;
     bn_addsub_f adjust;
@@ -524,22 +519,22 @@ int BN_nist_mod_224(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
     } else
         r_d = a_d;
 
-#if BN_BITS2==64
+#if BN_BITS2 == 64
     /* copy upper 256 bits of 448 bit number ... */
     nist_cp_bn_0(c_d, a_d + (BN_NIST_224_TOP - 1),
-                 top - (BN_NIST_224_TOP - 1), BN_NIST_224_TOP);
+        top - (BN_NIST_224_TOP - 1), BN_NIST_224_TOP);
     /* ... and right shift by 32 to obtain upper 224 bits */
     nist_set_224(buf.bn, c_d, 14, 13, 12, 11, 10, 9, 8);
     /* truncate lower part to 224 bits too */
     r_d[BN_NIST_224_TOP - 1] &= BN_MASK2l;
 #else
     nist_cp_bn_0(buf.bn, a_d + BN_NIST_224_TOP, top - BN_NIST_224_TOP,
-                 BN_NIST_224_TOP);
+        BN_NIST_224_TOP);
 #endif
 
-#if defined(NIST_INT64) && BN_BITS2!=64
+#if defined(NIST_INT64) && BN_BITS2 != 64
     {
-        NIST_INT64 acc;         /* accumulator */
+        NIST_INT64 acc; /* accumulator */
         unsigned int *rp = (unsigned int *)r_d;
         const unsigned int *bp = (const unsigned int *)buf.ui;
 
@@ -588,9 +583,9 @@ int BN_nist_mod_224(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
         rp[6] = (unsigned int)acc;
 
         carry = (int)(acc >> 32);
-# if BN_BITS2==64
+#if BN_BITS2 == 64
         rp[7] = carry;
-# endif
+#endif
     }
 #else
     {
@@ -605,17 +600,16 @@ int BN_nist_mod_224(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
         nist_set_224(t_d, buf.bn, 0, 0, 0, 0, 13, 12, 11);
         carry -= (int)bn_sub_words(r_d, r_d, t_d, BN_NIST_224_TOP);
 
-# if BN_BITS2==64
+#if BN_BITS2 == 64
         carry = (int)(r_d[BN_NIST_224_TOP - 1] >> 32);
-# endif
+#endif
     }
 #endif
     adjust = bn_sub_words;
     if (carry > 0) {
-        carry =
-            (int)bn_sub_words(r_d, r_d, _nist_p_224[carry - 1],
-                              BN_NIST_224_TOP);
-#if BN_BITS2==64
+        carry = (int)bn_sub_words(r_d, r_d, _nist_p_224[carry - 1],
+            BN_NIST_224_TOP);
+#if BN_BITS2 == 64
         carry = (int)(~(r_d[BN_NIST_224_TOP - 1] >> 32)) & 1;
 #endif
     } else if (carry < 0) {
@@ -626,15 +620,14 @@ int BN_nist_mod_224(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
          * compared to the modulus and conditionally adjusted by
          * *subtracting* the latter.
          */
-        carry =
-            (int)bn_add_words(r_d, r_d, _nist_p_224[-carry - 1],
-                              BN_NIST_224_TOP);
+        carry = (int)bn_add_words(r_d, r_d, _nist_p_224[-carry - 1],
+            BN_NIST_224_TOP);
         adjust = carry ? bn_sub_words : bn_add_words;
     } else
         carry = 1;
 
     /* otherwise it's effectively same as in BN_nist_mod_192... */
-    res = ((*adjust) (c_d, r_d, _nist_p_224[0], BN_NIST_224_TOP) && carry)
+    res = ((*adjust)(c_d, r_d, _nist_p_224[0], BN_NIST_224_TOP) && carry)
         ? r_d
         : c_d;
     nist_cp_bn(r_d, res, BN_NIST_224_TOP);
@@ -644,28 +637,27 @@ int BN_nist_mod_224(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
     return 1;
 }
 
-#define nist_set_256(to, from, a1, a2, a3, a4, a5, a6, a7, a8) \
-        { \
-        bn_cp_32(to, 0, from, (a8) - 8) \
-        bn_cp_32(to, 1, from, (a7) - 8) \
-        bn_cp_32(to, 2, from, (a6) - 8) \
-        bn_cp_32(to, 3, from, (a5) - 8) \
-        bn_cp_32(to, 4, from, (a4) - 8) \
-        bn_cp_32(to, 5, from, (a3) - 8) \
-        bn_cp_32(to, 6, from, (a2) - 8) \
-        bn_cp_32(to, 7, from, (a1) - 8) \
-        }
+#define nist_set_256(to, from, a1, a2, a3, a4, a5, a6, a7, a8)      \
+    {                                                               \
+        bn_cp_32(to, 0, from, (a8) - 8)                             \
+            bn_cp_32(to, 1, from, (a7) - 8)                         \
+                bn_cp_32(to, 2, from, (a6) - 8)                     \
+                    bn_cp_32(to, 3, from, (a5) - 8)                 \
+                        bn_cp_32(to, 4, from, (a4) - 8)             \
+                            bn_cp_32(to, 5, from, (a3) - 8)         \
+                                bn_cp_32(to, 6, from, (a2) - 8)     \
+                                    bn_cp_32(to, 7, from, (a1) - 8) \
+    }
 
 int BN_nist_mod_256(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
-                    BN_CTX *ctx)
+    BN_CTX *ctx)
 {
     int i, top = a->top;
     int carry = 0;
     register BN_ULONG *a_d = a->d, *r_d;
     union {
         BN_ULONG bn[BN_NIST_256_TOP];
-        unsigned int ui[BN_NIST_256_TOP * sizeof(BN_ULONG) /
-                        sizeof(unsigned int)];
+        unsigned int ui[BN_NIST_256_TOP * sizeof(BN_ULONG) / sizeof(unsigned int)];
     } buf;
     BN_ULONG c_d[BN_NIST_256_TOP], *res;
     bn_addsub_f adjust;
@@ -697,11 +689,11 @@ int BN_nist_mod_256(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
         r_d = a_d;
 
     nist_cp_bn_0(buf.bn, a_d + BN_NIST_256_TOP, top - BN_NIST_256_TOP,
-                 BN_NIST_256_TOP);
+        BN_NIST_256_TOP);
 
 #if defined(NIST_INT64)
     {
-        NIST_INT64 acc;         /* accumulator */
+        NIST_INT64 acc; /* accumulator */
         unsigned int *rp = (unsigned int *)r_d;
         const unsigned int *bp = (const unsigned int *)buf.ui;
 
@@ -850,24 +842,21 @@ int BN_nist_mod_256(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
          */
         nist_set_256(t_d, buf.bn, 13, 0, 11, 10, 9, 0, 15, 14);
         carry -= (int)bn_sub_words(r_d, r_d, t_d, BN_NIST_256_TOP);
-
     }
 #endif
     /* see BN_nist_mod_224 for explanation */
     adjust = bn_sub_words;
     if (carry > 0)
-        carry =
-            (int)bn_sub_words(r_d, r_d, _nist_p_256[carry - 1],
-                              BN_NIST_256_TOP);
+        carry = (int)bn_sub_words(r_d, r_d, _nist_p_256[carry - 1],
+            BN_NIST_256_TOP);
     else if (carry < 0) {
-        carry =
-            (int)bn_add_words(r_d, r_d, _nist_p_256[-carry - 1],
-                              BN_NIST_256_TOP);
+        carry = (int)bn_add_words(r_d, r_d, _nist_p_256[-carry - 1],
+            BN_NIST_256_TOP);
         adjust = carry ? bn_sub_words : bn_add_words;
     } else
         carry = 1;
 
-    res = ((*adjust) (c_d, r_d, _nist_p_256[0], BN_NIST_256_TOP) && carry)
+    res = ((*adjust)(c_d, r_d, _nist_p_256[0], BN_NIST_256_TOP) && carry)
         ? r_d
         : c_d;
     nist_cp_bn(r_d, res, BN_NIST_256_TOP);
@@ -877,32 +866,31 @@ int BN_nist_mod_256(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
     return 1;
 }
 
-#define nist_set_384(to,from,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11,a12) \
-        { \
-        bn_cp_32(to, 0, from,  (a12) - 12) \
-        bn_cp_32(to, 1, from,  (a11) - 12) \
-        bn_cp_32(to, 2, from,  (a10) - 12) \
-        bn_cp_32(to, 3, from,  (a9) - 12)  \
-        bn_cp_32(to, 4, from,  (a8) - 12)  \
-        bn_cp_32(to, 5, from,  (a7) - 12)  \
-        bn_cp_32(to, 6, from,  (a6) - 12)  \
-        bn_cp_32(to, 7, from,  (a5) - 12)  \
-        bn_cp_32(to, 8, from,  (a4) - 12)  \
-        bn_cp_32(to, 9, from,  (a3) - 12)  \
-        bn_cp_32(to, 10, from, (a2) - 12)  \
-        bn_cp_32(to, 11, from, (a1) - 12)  \
-        }
+#define nist_set_384(to, from, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12)     \
+    {                                                                                 \
+        bn_cp_32(to, 0, from, (a12) - 12)                                             \
+            bn_cp_32(to, 1, from, (a11) - 12)                                         \
+                bn_cp_32(to, 2, from, (a10) - 12)                                     \
+                    bn_cp_32(to, 3, from, (a9) - 12)                                  \
+                        bn_cp_32(to, 4, from, (a8) - 12)                              \
+                            bn_cp_32(to, 5, from, (a7) - 12)                          \
+                                bn_cp_32(to, 6, from, (a6) - 12)                      \
+                                    bn_cp_32(to, 7, from, (a5) - 12)                  \
+                                        bn_cp_32(to, 8, from, (a4) - 12)              \
+                                            bn_cp_32(to, 9, from, (a3) - 12)          \
+                                                bn_cp_32(to, 10, from, (a2) - 12)     \
+                                                    bn_cp_32(to, 11, from, (a1) - 12) \
+    }
 
 int BN_nist_mod_384(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
-                    BN_CTX *ctx)
+    BN_CTX *ctx)
 {
     int i, top = a->top;
     int carry = 0;
     register BN_ULONG *r_d, *a_d = a->d;
     union {
         BN_ULONG bn[BN_NIST_384_TOP];
-        unsigned int ui[BN_NIST_384_TOP * sizeof(BN_ULONG) /
-                        sizeof(unsigned int)];
+        unsigned int ui[BN_NIST_384_TOP * sizeof(BN_ULONG) / sizeof(unsigned int)];
     } buf;
     BN_ULONG c_d[BN_NIST_384_TOP], *res;
     bn_addsub_f adjust;
@@ -934,11 +922,11 @@ int BN_nist_mod_384(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
         r_d = a_d;
 
     nist_cp_bn_0(buf.bn, a_d + BN_NIST_384_TOP, top - BN_NIST_384_TOP,
-                 BN_NIST_384_TOP);
+        BN_NIST_384_TOP);
 
 #if defined(NIST_INT64)
     {
-        NIST_INT64 acc;         /* accumulator */
+        NIST_INT64 acc; /* accumulator */
         unsigned int *rp = (unsigned int *)r_d;
         const unsigned int *bp = (const unsigned int *)buf.ui;
 
@@ -1077,9 +1065,8 @@ int BN_nist_mod_384(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
             }
             *ap = c;
         }
-        carry =
-            (int)bn_add_words(r_d + (128 / BN_BITS2), r_d + (128 / BN_BITS2),
-                              t_d, BN_NIST_256_TOP);
+        carry = (int)bn_add_words(r_d + (128 / BN_BITS2), r_d + (128 / BN_BITS2),
+            t_d, BN_NIST_256_TOP);
         /*
          * S2
          */
@@ -1088,13 +1075,13 @@ int BN_nist_mod_384(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
          * S3
          */
         nist_set_384(t_d, buf.bn, 20, 19, 18, 17, 16, 15, 14, 13, 12, 23, 22,
-                     21);
+            21);
         carry += (int)bn_add_words(r_d, r_d, t_d, BN_NIST_384_TOP);
         /*
          * S4
          */
         nist_set_384(t_d, buf.bn, 19, 18, 17, 16, 15, 14, 13, 12, 20, 0, 23,
-                     0);
+            0);
         carry += (int)bn_add_words(r_d, r_d, t_d, BN_NIST_384_TOP);
         /*
          * S5
@@ -1110,7 +1097,7 @@ int BN_nist_mod_384(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
          * D1
          */
         nist_set_384(t_d, buf.bn, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12,
-                     23);
+            23);
         carry -= (int)bn_sub_words(r_d, r_d, t_d, BN_NIST_384_TOP);
         /*
          * D2
@@ -1122,24 +1109,21 @@ int BN_nist_mod_384(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
          */
         nist_set_384(t_d, buf.bn, 0, 0, 0, 0, 0, 0, 0, 23, 23, 0, 0, 0);
         carry -= (int)bn_sub_words(r_d, r_d, t_d, BN_NIST_384_TOP);
-
     }
 #endif
     /* see BN_nist_mod_224 for explanation */
     adjust = bn_sub_words;
     if (carry > 0)
-        carry =
-            (int)bn_sub_words(r_d, r_d, _nist_p_384[carry - 1],
-                              BN_NIST_384_TOP);
+        carry = (int)bn_sub_words(r_d, r_d, _nist_p_384[carry - 1],
+            BN_NIST_384_TOP);
     else if (carry < 0) {
-        carry =
-            (int)bn_add_words(r_d, r_d, _nist_p_384[-carry - 1],
-                              BN_NIST_384_TOP);
+        carry = (int)bn_add_words(r_d, r_d, _nist_p_384[-carry - 1],
+            BN_NIST_384_TOP);
         adjust = carry ? bn_sub_words : bn_add_words;
     } else
         carry = 1;
 
-    res = ((*adjust) (c_d, r_d, _nist_p_384[0], BN_NIST_384_TOP) && carry)
+    res = ((*adjust)(c_d, r_d, _nist_p_384[0], BN_NIST_384_TOP) && carry)
         ? r_d
         : c_d;
     nist_cp_bn(r_d, res, BN_NIST_384_TOP);
@@ -1149,12 +1133,12 @@ int BN_nist_mod_384(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
     return 1;
 }
 
-#define BN_NIST_521_RSHIFT      (521%BN_BITS2)
-#define BN_NIST_521_LSHIFT      (BN_BITS2-BN_NIST_521_RSHIFT)
-#define BN_NIST_521_TOP_MASK    ((BN_ULONG)BN_MASK2>>BN_NIST_521_LSHIFT)
+#define BN_NIST_521_RSHIFT (521 % BN_BITS2)
+#define BN_NIST_521_LSHIFT (BN_BITS2 - BN_NIST_521_RSHIFT)
+#define BN_NIST_521_TOP_MASK ((BN_ULONG)BN_MASK2 >> BN_NIST_521_LSHIFT)
 
 int BN_nist_mod_521(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
-                    BN_CTX *ctx)
+    BN_CTX *ctx)
 {
     int top = a->top, i;
     BN_ULONG *r_d, *a_d = a->d, t_d[BN_NIST_521_TOP], val, tmp, *res;
@@ -1187,7 +1171,7 @@ int BN_nist_mod_521(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
 
     /* upper 521 bits, copy ... */
     nist_cp_bn_0(t_d, a_d + (BN_NIST_521_TOP - 1),
-                 top - (BN_NIST_521_TOP - 1), BN_NIST_521_TOP);
+        top - (BN_NIST_521_TOP - 1), BN_NIST_521_TOP);
     /* ... and right shift */
     for (val = t_d[0], i = 0; i < BN_NIST_521_TOP - 1; i++) {
 #if 0
@@ -1200,8 +1184,7 @@ int BN_nist_mod_521(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
         val = t_d[i + 1];
         t_d[i] = (tmp | val << BN_NIST_521_LSHIFT) & BN_MASK2;
 #else
-        t_d[i] = (val >> BN_NIST_521_RSHIFT |
-                  (tmp = t_d[i + 1]) << BN_NIST_521_LSHIFT) & BN_MASK2;
+        t_d[i] = (val >> BN_NIST_521_RSHIFT | (tmp = t_d[i + 1]) << BN_NIST_521_LSHIFT) & BN_MASK2;
         val = tmp;
 #endif
     }
@@ -1211,7 +1194,7 @@ int BN_nist_mod_521(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
 
     bn_add_words(r_d, r_d, t_d, BN_NIST_521_TOP);
     res = bn_sub_words(t_d, r_d, _nist_p_521,
-                       BN_NIST_521_TOP)
+              BN_NIST_521_TOP)
         ? r_d
         : t_d;
     nist_cp_bn(r_d, res, BN_NIST_521_TOP);
@@ -1221,8 +1204,9 @@ int BN_nist_mod_521(BIGNUM *r, const BIGNUM *a, const BIGNUM *field,
     return 1;
 }
 
-int (*BN_nist_mod_func(const BIGNUM *p)) (BIGNUM *r, const BIGNUM *a,
-                                          const BIGNUM *field, BN_CTX *ctx) {
+int (*BN_nist_mod_func(const BIGNUM *p))(BIGNUM *r, const BIGNUM *a,
+    const BIGNUM *field, BN_CTX *ctx)
+{
     if (BN_ucmp(&ossl_bignum_nist_p_192, p) == 0)
         return BN_nist_mod_192;
     if (BN_ucmp(&ossl_bignum_nist_p_224, p) == 0)
