@@ -35,14 +35,12 @@ ASN1_SEQUENCE(OSSL_CMP_CHALLENGE) = {
 } ASN1_SEQUENCE_END(OSSL_CMP_CHALLENGE)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_CHALLENGE)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_POPODECKEYCHALLCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
-                          OSSL_CMP_POPODECKEYCHALLCONTENT, OSSL_CMP_CHALLENGE)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_POPODECKEYCHALLCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
+    OSSL_CMP_POPODECKEYCHALLCONTENT, OSSL_CMP_CHALLENGE)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_POPODECKEYCHALLCONTENT)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_POPODECKEYRESPCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
-                          OSSL_CMP_POPODECKEYRESPCONTENT, ASN1_INTEGER)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_POPODECKEYRESPCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
+    OSSL_CMP_POPODECKEYRESPCONTENT, ASN1_INTEGER)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_POPODECKEYRESPCONTENT)
 
 ASN1_SEQUENCE(OSSL_CMP_CAKEYUPDANNCONTENT) = {
@@ -60,68 +58,66 @@ ASN1_SEQUENCE(OSSL_CMP_ERRORMSGCONTENT) = {
     ASN1_OPT(OSSL_CMP_ERRORMSGCONTENT, errorCode, ASN1_INTEGER),
     /* OSSL_CMP_PKIFREETEXT is a ASN1_UTF8STRING sequence, so used directly */
     ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ERRORMSGCONTENT, errorDetails,
-                         ASN1_UTF8STRING)
+        ASN1_UTF8STRING)
 } ASN1_SEQUENCE_END(OSSL_CMP_ERRORMSGCONTENT)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_ERRORMSGCONTENT)
 
 ASN1_ADB_TEMPLATE(infotypeandvalue_default) = ASN1_OPT(OSSL_CMP_ITAV,
-                                                       infoValue.other,
-                                                       ASN1_ANY);
+    infoValue.other,
+    ASN1_ANY);
 /* ITAV means InfoTypeAndValue */
 ASN1_ADB(OSSL_CMP_ITAV) = {
     /* OSSL_CMP_CMPCERTIFICATE is effectively X509 so it is used directly */
-    ADB_ENTRY(NID_id_it_caProtEncCert, ASN1_OPT(OSSL_CMP_ITAV,
-                                                infoValue.caProtEncCert, X509)),
+    ADB_ENTRY(NID_id_it_caProtEncCert, ASN1_OPT(OSSL_CMP_ITAV, infoValue.caProtEncCert, X509)),
     ADB_ENTRY(NID_id_it_signKeyPairTypes,
-              ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV,
-                                   infoValue.signKeyPairTypes, X509_ALGOR)),
+        ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV,
+            infoValue.signKeyPairTypes, X509_ALGOR)),
     ADB_ENTRY(NID_id_it_encKeyPairTypes,
-              ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV,
-                                   infoValue.encKeyPairTypes, X509_ALGOR)),
+        ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV,
+            infoValue.encKeyPairTypes, X509_ALGOR)),
     ADB_ENTRY(NID_id_it_preferredSymmAlg,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.preferredSymmAlg,
-                       X509_ALGOR)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.preferredSymmAlg,
+            X509_ALGOR)),
     ADB_ENTRY(NID_id_it_caKeyUpdateInfo,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.caKeyUpdateInfo,
-                       OSSL_CMP_CAKEYUPDANNCONTENT)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.caKeyUpdateInfo,
+            OSSL_CMP_CAKEYUPDANNCONTENT)),
     ADB_ENTRY(NID_id_it_currentCRL,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.currentCRL, X509_CRL)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.currentCRL, X509_CRL)),
     ADB_ENTRY(NID_id_it_unsupportedOIDs,
-              ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV,
-                                   infoValue.unsupportedOIDs, ASN1_OBJECT)),
+        ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV,
+            infoValue.unsupportedOIDs, ASN1_OBJECT)),
     ADB_ENTRY(NID_id_it_keyPairParamReq,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.keyPairParamReq,
-                       ASN1_OBJECT)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.keyPairParamReq,
+            ASN1_OBJECT)),
     ADB_ENTRY(NID_id_it_keyPairParamRep,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.keyPairParamRep,
-                       X509_ALGOR)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.keyPairParamRep,
+            X509_ALGOR)),
     ADB_ENTRY(NID_id_it_revPassphrase,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.revPassphrase,
-                       OSSL_CRMF_ENCRYPTEDVALUE)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.revPassphrase,
+            OSSL_CRMF_ENCRYPTEDVALUE)),
     ADB_ENTRY(NID_id_it_implicitConfirm,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.implicitConfirm,
-                       ASN1_NULL)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.implicitConfirm,
+            ASN1_NULL)),
     ADB_ENTRY(NID_id_it_confirmWaitTime,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.confirmWaitTime,
-                       ASN1_GENERALIZEDTIME)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.confirmWaitTime,
+            ASN1_GENERALIZEDTIME)),
     ADB_ENTRY(NID_id_it_origPKIMessage,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.origPKIMessage,
-                       OSSL_CMP_MSGS)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.origPKIMessage,
+            OSSL_CMP_MSGS)),
     ADB_ENTRY(NID_id_it_suppLangTags,
-              ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV, infoValue.suppLangTagsValue,
-                                   ASN1_UTF8STRING)),
+        ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV, infoValue.suppLangTagsValue,
+            ASN1_UTF8STRING)),
     ADB_ENTRY(NID_id_it_caCerts,
-              ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV, infoValue.caCerts, X509)),
+        ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV, infoValue.caCerts, X509)),
     ADB_ENTRY(NID_id_it_rootCaCert,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.rootCaCert, X509)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.rootCaCert, X509)),
     ADB_ENTRY(NID_id_it_rootCaKeyUpdate,
-              ASN1_OPT(OSSL_CMP_ITAV, infoValue.rootCaKeyUpdate,
-                       OSSL_CMP_ROOTCAKEYUPDATE)),
+        ASN1_OPT(OSSL_CMP_ITAV, infoValue.rootCaKeyUpdate,
+            OSSL_CMP_ROOTCAKEYUPDATE)),
     ADB_ENTRY(NID_id_it_certProfile,
-              ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV, infoValue.certProfile,
-                                   ASN1_UTF8STRING)),
-} ASN1_ADB_END(OSSL_CMP_ITAV, 0, infoType, 0,
-               &infotypeandvalue_default_tt, NULL);
+        ASN1_SEQUENCE_OF_OPT(OSSL_CMP_ITAV, infoValue.certProfile,
+            ASN1_UTF8STRING)),
+} ASN1_ADB_END(OSSL_CMP_ITAV, 0, infoType, 0, &infotypeandvalue_default_tt, NULL);
 
 ASN1_SEQUENCE(OSSL_CMP_ITAV) = {
     ASN1_SIMPLE(OSSL_CMP_ITAV, infoType, ASN1_OBJECT),
@@ -149,7 +145,7 @@ OSSL_CMP_ITAV *OSSL_CMP_ITAV_create(ASN1_OBJECT *type, ASN1_TYPE *value)
 }
 
 void OSSL_CMP_ITAV_set0(OSSL_CMP_ITAV *itav, ASN1_OBJECT *type,
-                        ASN1_TYPE *value)
+    ASN1_TYPE *value)
 {
     itav->infoType = type;
     itav->infoValue.other = value;
@@ -170,7 +166,7 @@ ASN1_TYPE *OSSL_CMP_ITAV_get0_value(const OSSL_CMP_ITAV *itav)
 }
 
 int OSSL_CMP_ITAV_push0_stack_item(STACK_OF(OSSL_CMP_ITAV) **itav_sk_p,
-                                   OSSL_CMP_ITAV *itav)
+    OSSL_CMP_ITAV *itav)
 {
     int created = 0;
 
@@ -188,7 +184,7 @@ int OSSL_CMP_ITAV_push0_stack_item(STACK_OF(OSSL_CMP_ITAV) **itav_sk_p,
         goto err;
     return 1;
 
- err:
+err:
     if (created) {
         sk_OSSL_CMP_ITAV_free(*itav_sk_p);
         *itav_sk_p = NULL;
@@ -209,7 +205,7 @@ OSSL_CMP_ITAV
 }
 
 int OSSL_CMP_ITAV_get0_certProfile(const OSSL_CMP_ITAV *itav,
-                                   STACK_OF(ASN1_UTF8STRING) **out)
+    STACK_OF(ASN1_UTF8STRING) **out)
 {
     if (itav == NULL || out == NULL) {
         ERR_raise(ERR_LIB_CMP, ERR_R_PASSED_NULL_PARAMETER);
@@ -230,8 +226,7 @@ OSSL_CMP_ITAV *OSSL_CMP_ITAV_new_caCerts(const STACK_OF(X509) *caCerts)
     if (itav == NULL)
         return NULL;
     if (sk_X509_num(caCerts) > 0
-        && (itav->infoValue.caCerts =
-            sk_X509_deep_copy(caCerts, X509_dup, X509_free)) == NULL) {
+        && (itav->infoValue.caCerts = sk_X509_deep_copy(caCerts, X509_dup, X509_free)) == NULL) {
         OSSL_CMP_ITAV_free(itav);
         return NULL;
     }
@@ -250,7 +245,8 @@ int OSSL_CMP_ITAV_get0_caCerts(const OSSL_CMP_ITAV *itav, STACK_OF(X509) **out)
         return 0;
     }
     *out = sk_X509_num(itav->infoValue.caCerts) > 0
-        ? itav->infoValue.caCerts : NULL;
+        ? itav->infoValue.caCerts
+        : NULL;
     return 1;
 }
 
@@ -261,7 +257,7 @@ OSSL_CMP_ITAV *OSSL_CMP_ITAV_new_rootCaCert(const X509 *rootCaCert)
     if (itav == NULL)
         return NULL;
     if (rootCaCert != NULL
-            && (itav->infoValue.rootCaCert = X509_dup(rootCaCert)) == NULL) {
+        && (itav->infoValue.rootCaCert = X509_dup(rootCaCert)) == NULL) {
         OSSL_CMP_ITAV_free(itav);
         return NULL;
     }
@@ -283,8 +279,8 @@ int OSSL_CMP_ITAV_get0_rootCaCert(const OSSL_CMP_ITAV *itav, X509 **out)
     return 1;
 }
 OSSL_CMP_ITAV *OSSL_CMP_ITAV_new_rootCaKeyUpdate(const X509 *newWithNew,
-                                                 const X509 *newWithOld,
-                                                 const X509 *oldWithNew)
+    const X509 *newWithOld,
+    const X509 *oldWithNew)
 {
     OSSL_CMP_ITAV *itav;
     OSSL_CMP_ROOTCAKEYUPDATE *upd = NULL;
@@ -310,15 +306,15 @@ OSSL_CMP_ITAV *OSSL_CMP_ITAV_new_rootCaKeyUpdate(const X509 *newWithNew,
     itav->infoValue.rootCaKeyUpdate = upd;
     return itav;
 
- err:
+err:
     OSSL_CMP_ROOTCAKEYUPDATE_free(upd);
     return NULL;
 }
 
 int OSSL_CMP_ITAV_get0_rootCaKeyUpdate(const OSSL_CMP_ITAV *itav,
-                                       X509 **newWithNew,
-                                       X509 **newWithOld,
-                                       X509 **oldWithNew)
+    X509 **newWithNew,
+    X509 **newWithOld,
+    X509 **oldWithNew)
 {
     OSSL_CMP_ROOTCAKEYUPDATE *upd;
 
@@ -360,7 +356,7 @@ int ossl_cmp_asn1_get_int(const ASN1_INTEGER *a)
 }
 
 static int ossl_cmp_msg_cb(int operation, ASN1_VALUE **pval,
-                           ossl_unused const ASN1_ITEM *it, void *exarg)
+    ossl_unused const ASN1_ITEM *it, void *exarg)
 {
     OSSL_CMP_MSG *msg = (OSSL_CMP_MSG *)*pval;
 
@@ -369,28 +365,22 @@ static int ossl_cmp_msg_cb(int operation, ASN1_VALUE **pval,
         OPENSSL_free(msg->propq);
         break;
 
-    case ASN1_OP_DUP_POST:
-        {
-            OSSL_CMP_MSG *old = exarg;
+    case ASN1_OP_DUP_POST: {
+        OSSL_CMP_MSG *old = exarg;
 
-            if (!ossl_cmp_msg_set0_libctx(msg, old->libctx, old->propq))
-                return 0;
-        }
-        break;
-    case ASN1_OP_GET0_LIBCTX:
-        {
-            OSSL_LIB_CTX **libctx = exarg;
+        if (!ossl_cmp_msg_set0_libctx(msg, old->libctx, old->propq))
+            return 0;
+    } break;
+    case ASN1_OP_GET0_LIBCTX: {
+        OSSL_LIB_CTX **libctx = exarg;
 
-            *libctx = msg->libctx;
-        }
-        break;
-    case ASN1_OP_GET0_PROPQ:
-        {
-            const char **propq = exarg;
+        *libctx = msg->libctx;
+    } break;
+    case ASN1_OP_GET0_PROPQ: {
+        const char **propq = exarg;
 
-            *propq = msg->propq;
-        }
-        break;
+        *propq = msg->propq;
+    } break;
     default:
         break;
     }
@@ -402,17 +392,17 @@ ASN1_CHOICE(OSSL_CMP_CERTORENCCERT) = {
     /* OSSL_CMP_CMPCERTIFICATE is effectively X509 so it is used directly */
     ASN1_EXP(OSSL_CMP_CERTORENCCERT, value.certificate, X509, 0),
     ASN1_EXP(OSSL_CMP_CERTORENCCERT, value.encryptedCert,
-             OSSL_CRMF_ENCRYPTEDVALUE, 1),
+        OSSL_CRMF_ENCRYPTEDVALUE, 1),
 } ASN1_CHOICE_END(OSSL_CMP_CERTORENCCERT)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_CERTORENCCERT)
 
 ASN1_SEQUENCE(OSSL_CMP_CERTIFIEDKEYPAIR) = {
     ASN1_SIMPLE(OSSL_CMP_CERTIFIEDKEYPAIR, certOrEncCert,
-                OSSL_CMP_CERTORENCCERT),
+        OSSL_CMP_CERTORENCCERT),
     ASN1_EXP_OPT(OSSL_CMP_CERTIFIEDKEYPAIR, privateKey,
-                 OSSL_CRMF_ENCRYPTEDVALUE, 0),
+        OSSL_CRMF_ENCRYPTEDVALUE, 0),
     ASN1_EXP_OPT(OSSL_CMP_CERTIFIEDKEYPAIR, publicationInfo,
-                 OSSL_CRMF_PKIPUBLICATIONINFO, 1)
+        OSSL_CRMF_PKIPUBLICATIONINFO, 1)
 } ASN1_SEQUENCE_END(OSSL_CMP_CERTIFIEDKEYPAIR)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_CERTIFIEDKEYPAIR)
 
@@ -422,15 +412,14 @@ ASN1_SEQUENCE(OSSL_CMP_REVDETAILS) = {
 } ASN1_SEQUENCE_END(OSSL_CMP_REVDETAILS)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_REVDETAILS)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_REVREQCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_REVREQCONTENT,
-                          OSSL_CMP_REVDETAILS)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_REVREQCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_REVREQCONTENT,
+    OSSL_CMP_REVDETAILS)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_REVREQCONTENT)
 
 ASN1_SEQUENCE(OSSL_CMP_REVREPCONTENT) = {
     ASN1_SEQUENCE_OF(OSSL_CMP_REVREPCONTENT, status, OSSL_CMP_PKISI),
     ASN1_EXP_SEQUENCE_OF_OPT(OSSL_CMP_REVREPCONTENT, revCerts, OSSL_CRMF_CERTID,
-                             0),
+        0),
     ASN1_EXP_SEQUENCE_OF_OPT(OSSL_CMP_REVREPCONTENT, crls, X509_CRL, 1)
 } ASN1_SEQUENCE_END(OSSL_CMP_REVREPCONTENT)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_REVREPCONTENT)
@@ -440,12 +429,11 @@ ASN1_SEQUENCE(OSSL_CMP_KEYRECREPCONTENT) = {
     ASN1_EXP_OPT(OSSL_CMP_KEYRECREPCONTENT, newSigCert, X509, 0),
     ASN1_EXP_SEQUENCE_OF_OPT(OSSL_CMP_KEYRECREPCONTENT, caCerts, X509, 1),
     ASN1_EXP_SEQUENCE_OF_OPT(OSSL_CMP_KEYRECREPCONTENT, keyPairHist,
-                             OSSL_CMP_CERTIFIEDKEYPAIR, 2)
+        OSSL_CMP_CERTIFIEDKEYPAIR, 2)
 } ASN1_SEQUENCE_END(OSSL_CMP_KEYRECREPCONTENT)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_KEYRECREPCONTENT)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_PKISTATUS) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_UNIVERSAL, 0, status, ASN1_INTEGER)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_PKISTATUS) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_UNIVERSAL, 0, status, ASN1_INTEGER)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_PKISTATUS)
 
 ASN1_SEQUENCE(OSSL_CMP_PKISI) = {
@@ -466,16 +454,15 @@ ASN1_SEQUENCE(OSSL_CMP_CERTSTATUS) = {
 } ASN1_SEQUENCE_END(OSSL_CMP_CERTSTATUS)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_CERTSTATUS)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_CERTCONFIRMCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_CERTCONFIRMCONTENT,
-                          OSSL_CMP_CERTSTATUS)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_CERTCONFIRMCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_CERTCONFIRMCONTENT,
+    OSSL_CMP_CERTSTATUS)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_CERTCONFIRMCONTENT)
 
 ASN1_SEQUENCE(OSSL_CMP_CERTRESPONSE) = {
     ASN1_SIMPLE(OSSL_CMP_CERTRESPONSE, certReqId, ASN1_INTEGER),
     ASN1_SIMPLE(OSSL_CMP_CERTRESPONSE, status, OSSL_CMP_PKISI),
     ASN1_OPT(OSSL_CMP_CERTRESPONSE, certifiedKeyPair,
-             OSSL_CMP_CERTIFIEDKEYPAIR),
+        OSSL_CMP_CERTIFIEDKEYPAIR),
     ASN1_OPT(OSSL_CMP_CERTRESPONSE, rspInfo, ASN1_OCTET_STRING)
 } ASN1_SEQUENCE_END(OSSL_CMP_CERTRESPONSE)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_CERTRESPONSE)
@@ -485,9 +472,8 @@ ASN1_SEQUENCE(OSSL_CMP_POLLREQ) = {
 } ASN1_SEQUENCE_END(OSSL_CMP_POLLREQ)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_POLLREQ)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_POLLREQCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_POLLREQCONTENT,
-                          OSSL_CMP_POLLREQ)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_POLLREQCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_POLLREQCONTENT,
+    OSSL_CMP_POLLREQ)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_POLLREQCONTENT)
 
 ASN1_SEQUENCE(OSSL_CMP_POLLREP) = {
@@ -497,10 +483,9 @@ ASN1_SEQUENCE(OSSL_CMP_POLLREP) = {
 } ASN1_SEQUENCE_END(OSSL_CMP_POLLREP)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_POLLREP)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_POLLREPCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
-                          OSSL_CMP_POLLREPCONTENT,
-                          OSSL_CMP_POLLREP)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_POLLREPCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
+    OSSL_CMP_POLLREPCONTENT,
+    OSSL_CMP_POLLREP)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_POLLREPCONTENT)
 
 ASN1_SEQUENCE(OSSL_CMP_CERTREPMESSAGE) = {
@@ -510,19 +495,16 @@ ASN1_SEQUENCE(OSSL_CMP_CERTREPMESSAGE) = {
 } ASN1_SEQUENCE_END(OSSL_CMP_CERTREPMESSAGE)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_CERTREPMESSAGE)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_GENMSGCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_GENMSGCONTENT,
-                          OSSL_CMP_ITAV)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_GENMSGCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_GENMSGCONTENT,
+    OSSL_CMP_ITAV)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_GENMSGCONTENT)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_GENREPCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_GENREPCONTENT,
-                          OSSL_CMP_ITAV)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_GENREPCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_GENREPCONTENT,
+    OSSL_CMP_ITAV)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_GENREPCONTENT)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_CRLANNCONTENT) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
-                          OSSL_CMP_CRLANNCONTENT, X509_CRL)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_CRLANNCONTENT) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0,
+    OSSL_CMP_CRLANNCONTENT, X509_CRL)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_CRLANNCONTENT)
 
 ASN1_CHOICE(OSSL_CMP_PKIBODY) = {
@@ -532,9 +514,9 @@ ASN1_CHOICE(OSSL_CMP_PKIBODY) = {
     ASN1_EXP(OSSL_CMP_PKIBODY, value.cp, OSSL_CMP_CERTREPMESSAGE, 3),
     ASN1_EXP(OSSL_CMP_PKIBODY, value.p10cr, X509_REQ, 4),
     ASN1_EXP(OSSL_CMP_PKIBODY, value.popdecc,
-             OSSL_CMP_POPODECKEYCHALLCONTENT, 5),
+        OSSL_CMP_POPODECKEYCHALLCONTENT, 5),
     ASN1_EXP(OSSL_CMP_PKIBODY, value.popdecr,
-             OSSL_CMP_POPODECKEYRESPCONTENT, 6),
+        OSSL_CMP_POPODECKEYRESPCONTENT, 6),
     ASN1_EXP(OSSL_CMP_PKIBODY, value.kur, OSSL_CRMF_MSGS, 7),
     ASN1_EXP(OSSL_CMP_PKIBODY, value.kup, OSSL_CMP_CERTREPMESSAGE, 8),
     ASN1_EXP(OSSL_CMP_PKIBODY, value.krr, OSSL_CRMF_MSGS, 9),
@@ -572,7 +554,7 @@ ASN1_SEQUENCE(OSSL_CMP_PKIHEADER) = {
     /* OSSL_CMP_PKIFREETEXT is a ASN1_UTF8STRING sequence, so used directly */
     ASN1_EXP_SEQUENCE_OF_OPT(OSSL_CMP_PKIHEADER, freeText, ASN1_UTF8STRING, 7),
     ASN1_EXP_SEQUENCE_OF_OPT(OSSL_CMP_PKIHEADER, generalInfo,
-                             OSSL_CMP_ITAV, 8)
+        OSSL_CMP_ITAV, 8)
 } ASN1_SEQUENCE_END(OSSL_CMP_PKIHEADER)
 IMPLEMENT_ASN1_FUNCTIONS(OSSL_CMP_PKIHEADER)
 
@@ -591,7 +573,6 @@ ASN1_SEQUENCE_cb(OSSL_CMP_MSG, ossl_cmp_msg_cb) = {
 } ASN1_SEQUENCE_END_cb(OSSL_CMP_MSG, OSSL_CMP_MSG)
 IMPLEMENT_ASN1_DUP_FUNCTION(OSSL_CMP_MSG)
 
-ASN1_ITEM_TEMPLATE(OSSL_CMP_MSGS) =
-    ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_MSGS,
-                          OSSL_CMP_MSG)
+ASN1_ITEM_TEMPLATE(OSSL_CMP_MSGS) = ASN1_EX_TEMPLATE_TYPE(ASN1_TFLG_SEQUENCE_OF, 0, OSSL_CMP_MSGS,
+    OSSL_CMP_MSG)
 ASN1_ITEM_TEMPLATE_END(OSSL_CMP_MSGS)
