@@ -21,7 +21,7 @@
 #include <openssl/cmp_util.h>
 
 #define IS_CREP(t) ((t) == OSSL_CMP_PKIBODY_IP || (t) == OSSL_CMP_PKIBODY_CP \
-                        || (t) == OSSL_CMP_PKIBODY_KUP)
+    || (t) == OSSL_CMP_PKIBODY_KUP)
 
 /*-
  * Evaluate whether there's an exception (violating the standard) configured for
@@ -29,9 +29,9 @@
  * Returns 1 on acceptance, 0 on rejection, or -1 on (internal) error.
  */
 static int unprotected_exception(const OSSL_CMP_CTX *ctx,
-                                 const OSSL_CMP_MSG *rep,
-                                 int invalid_protection,
-                                 ossl_unused int expected_type)
+    const OSSL_CMP_MSG *rep,
+    int invalid_protection,
+    ossl_unused int expected_type)
 {
     int rcvd_type = OSSL_CMP_MSG_get_bodytype(rep /* may be NULL */);
     const char *msg_type = NULL;
@@ -46,18 +46,16 @@ static int unprotected_exception(const OSSL_CMP_CTX *ctx,
     case OSSL_CMP_PKIBODY_ERROR:
         msg_type = "error response";
         break;
-    case OSSL_CMP_PKIBODY_RP:
-        {
-            OSSL_CMP_PKISI *si =
-                ossl_cmp_revrepcontent_get_pkisi(rep->body->value.rp,
-                                                 OSSL_CMP_REVREQSID);
+    case OSSL_CMP_PKIBODY_RP: {
+        OSSL_CMP_PKISI *si = ossl_cmp_revrepcontent_get_pkisi(rep->body->value.rp,
+            OSSL_CMP_REVREQSID);
 
-            if (si == NULL)
-                return -1;
-            if (ossl_cmp_pkisi_get_status(si) == OSSL_CMP_PKISTATUS_rejection)
-                msg_type = "revocation response message with rejection status";
-            break;
-        }
+        if (si == NULL)
+            return -1;
+        if (ossl_cmp_pkisi_get_status(si) == OSSL_CMP_PKISTATUS_rejection)
+            msg_type = "revocation response message with rejection status";
+        break;
+    }
     case OSSL_CMP_PKIBODY_PKICONF:
         msg_type = "PKI Confirmation message";
         break;
@@ -65,8 +63,7 @@ static int unprotected_exception(const OSSL_CMP_CTX *ctx,
         if (IS_CREP(rcvd_type)) {
             int any_rid = OSSL_CMP_CERTREQID_NONE;
             OSSL_CMP_CERTREPMESSAGE *crepmsg = rep->body->value.ip;
-            OSSL_CMP_CERTRESPONSE *crep =
-                ossl_cmp_certrepmessage_get0_certresponse(crepmsg, any_rid);
+            OSSL_CMP_CERTRESPONSE *crep = ossl_cmp_certrepmessage_get0_certresponse(crepmsg, any_rid);
 
             if (sk_OSSL_CMP_CERTRESPONSE_num(crepmsg->response) > 1)
                 return -1;
@@ -80,7 +77,7 @@ static int unprotected_exception(const OSSL_CMP_CTX *ctx,
     if (msg_type == NULL)
         return 0;
     ossl_cmp_log2(WARN, ctx, "ignoring %s protection of %s",
-                  invalid_protection ? "invalid" : "missing", msg_type);
+        invalid_protection ? "invalid" : "missing", msg_type);
     return 1;
 }
 
@@ -100,7 +97,7 @@ static int save_statusInfo(OSSL_CMP_CTX *ctx, OSSL_CMP_PKISI *si)
     ctx->failInfoCode = ossl_cmp_pkisi_get_pkifailureinfo(si);
 
     if (!ossl_cmp_ctx_set0_statusString(ctx, sk_ASN1_UTF8STRING_new_null())
-            || (ctx->statusString == NULL))
+        || (ctx->statusString == NULL))
         return 0;
 
     ss = si->statusString; /* may be NULL */
@@ -116,6 +113,23 @@ static int save_statusInfo(OSSL_CMP_CTX *ctx, OSSL_CMP_PKISI *si)
     return 1;
 }
 
+static int is_crep_with_waiting(const OSSL_CMP_MSG *resp, int rid)
+{
+    OSSL_CMP_CERTREPMESSAGE *crepmsg;
+    OSSL_CMP_CERTRESPONSE *crep;
+    int bt = OSSL_CMP_MSG_get_bodytype(resp);
+
+    if (!IS_CREP(bt))
+        return 0;
+
+    crepmsg = resp->body->value.ip; /* same for cp and kup */
+    crep = ossl_cmp_certrepmessage_get0_certresponse(crepmsg, rid);
+
+    return (crep != NULL
+        && ossl_cmp_pkisi_get_status(crep->status)
+            == OSSL_CMP_PKISTATUS_waiting);
+}
+
 /*-
  * Perform the generic aspects of sending a request and receiving a response.
  * Returns 1 on success and provides the received PKIMESSAGE in *rep.
@@ -123,13 +137,11 @@ static int save_statusInfo(OSSL_CMP_CTX *ctx, OSSL_CMP_PKISI *si)
  * Regardless of success, caller is responsible for freeing *rep (unless NULL).
  */
 static int send_receive_check(OSSL_CMP_CTX *ctx, const OSSL_CMP_MSG *req,
-                              OSSL_CMP_MSG **rep, int expected_type)
+    OSSL_CMP_MSG **rep, int expected_type)
 {
-    int begin_transaction =
-        expected_type != OSSL_CMP_PKIBODY_POLLREP
+    int begin_transaction = expected_type != OSSL_CMP_PKIBODY_POLLREP
         && expected_type != OSSL_CMP_PKIBODY_PKICONF;
-    const char *req_type_str =
-        ossl_cmp_bodytype_to_string(OSSL_CMP_MSG_get_bodytype(req));
+    const char *req_type_str = ossl_cmp_bodytype_to_string(OSSL_CMP_MSG_get_bodytype(req));
     const char *expected_type_str = ossl_cmp_bodytype_to_string(expected_type);
     int bak_msg_timeout = ctx->msg_timeout;
     int bt;
@@ -163,17 +175,17 @@ static int send_receive_check(OSSL_CMP_CTX *ctx, const OSSL_CMP_MSG *req,
     /* should print error queue since transfer_cb may call ERR_clear_error() */
     OSSL_CMP_CTX_print_errors(ctx);
 
-    ossl_cmp_log1(INFO, ctx, "sending %s", req_type_str);
+    if (ctx->server != NULL)
+        ossl_cmp_log1(INFO, ctx, "sending %s", req_type_str);
 
     *rep = (*transfer_cb)(ctx, req);
     ctx->msg_timeout = bak_msg_timeout;
 
     if (*rep == NULL) {
         ERR_raise_data(ERR_LIB_CMP,
-                       ctx->total_timeout != 0 && time(NULL) >= ctx->end_time ?
-                       CMP_R_TOTAL_TIMEOUT : CMP_R_TRANSFER_ERROR,
-                       "request sent: %s, expected response: %s",
-                       req_type_str, expected_type_str);
+            ctx->total_timeout != 0 && time(NULL) >= ctx->end_time ? CMP_R_TOTAL_TIMEOUT : CMP_R_TRANSFER_ERROR,
+            "request sent: %s, expected response: %s",
+            req_type_str, expected_type_str);
         return 0;
     }
 
@@ -183,45 +195,55 @@ static int send_receive_check(OSSL_CMP_CTX *ctx, const OSSL_CMP_MSG *req,
      * Still we use this preliminary value already for a progress report because
      * the following msg verification may also produce log entries and may fail.
      */
-    ossl_cmp_log1(INFO, ctx, "received %s", ossl_cmp_bodytype_to_string(bt));
+    ossl_cmp_log2(INFO, ctx, "received %s%s", ossl_cmp_bodytype_to_string(bt),
+        ossl_cmp_is_error_with_waiting(*rep) ? " (waiting)" : "");
 
     /* copy received extraCerts to ctx->extraCertsIn so they can be retrieved */
     if (bt != OSSL_CMP_PKIBODY_POLLREP && bt != OSSL_CMP_PKIBODY_PKICONF
-            && !ossl_cmp_ctx_set1_extraCertsIn(ctx, (*rep)->extraCerts))
+        && !ossl_cmp_ctx_set1_extraCertsIn(ctx, (*rep)->extraCerts))
         return 0;
 
     if (!ossl_cmp_msg_check_update(ctx, *rep, unprotected_exception,
-                                   expected_type))
+            expected_type))
         return 0;
 
+    /*
+     * rep can have the expected response type, which during polling is pollRep.
+     * When polling, also any other non-error response (the final response)
+     * is fine here. When not yet polling, delayed delivery may be initiated
+     * by the server returning an error message with 'waiting' status (or a
+     * response message of expected type ip/cp/kup with 'waiting' status).
+     */
     if (bt == expected_type
-        /* as an answer to polling, there could be IP/CP/KUP: */
-            || (IS_CREP(bt) && expected_type == OSSL_CMP_PKIBODY_POLLREP))
+        || (expected_type == OSSL_CMP_PKIBODY_POLLREP
+                ? bt != OSSL_CMP_PKIBODY_ERROR
+                : ossl_cmp_is_error_with_waiting(*rep)))
         return 1;
 
     /* received message type is not one of the expected ones (e.g., error) */
-    ERR_raise(ERR_LIB_CMP, bt == OSSL_CMP_PKIBODY_ERROR ? CMP_R_RECEIVED_ERROR :
-              CMP_R_UNEXPECTED_PKIBODY); /* in next line for mkerr.pl */
+    ERR_raise(ERR_LIB_CMP, bt == OSSL_CMP_PKIBODY_ERROR ? CMP_R_RECEIVED_ERROR : CMP_R_UNEXPECTED_PKIBODY); /* in next line for mkerr.pl */
 
     if (bt != OSSL_CMP_PKIBODY_ERROR) {
         ERR_add_error_data(3, "message type is '",
-                           ossl_cmp_bodytype_to_string(bt), "'");
+            ossl_cmp_bodytype_to_string(bt), "'");
     } else {
         OSSL_CMP_ERRORMSGCONTENT *emc = (*rep)->body->value.error;
         OSSL_CMP_PKISI *si = emc->pKIStatusInfo;
         char buf[OSSL_CMP_PKISI_BUFLEN];
 
         if (save_statusInfo(ctx, si)
-                && OSSL_CMP_CTX_snprint_PKIStatus(ctx, buf,
-                                                  sizeof(buf)) != NULL)
+            && OSSL_CMP_CTX_snprint_PKIStatus(ctx, buf,
+                   sizeof(buf))
+                != NULL)
             ERR_add_error_data(1, buf);
         if (emc->errorCode != NULL
-                && BIO_snprintf(buf, sizeof(buf), "; errorCode: %08lX",
-                                ASN1_INTEGER_get(emc->errorCode)) > 0)
+            && BIO_snprintf(buf, sizeof(buf), "; errorCode: %08lX",
+                   ASN1_INTEGER_get(emc->errorCode))
+                > 0)
             ERR_add_error_data(1, buf);
         if (emc->errorDetails != NULL) {
             char *text = ossl_sk_ASN1_UTF8STRING2text(emc->errorDetails, ", ",
-                                                      OSSL_CMP_PKISI_BUFLEN - 1);
+                OSSL_CMP_PKISI_BUFLEN - 1);
 
             if (text != NULL && *text != '\0')
                 ERR_add_error_data(2, "; errorDetails: ", text);
@@ -238,7 +260,7 @@ static int send_receive_check(OSSL_CMP_CTX *ctx, const OSSL_CMP_MSG *req,
 
 /*-
  * When a 'waiting' PKIStatus has been received, this function is used to
- * poll, which should yield a pollRep or finally a CertRepMessage in ip/cp/kup.
+ * poll, which should yield a pollRep or the final response.
  * On receiving a pollRep, which includes a checkAfter value, it return this
  * value if sleep == 0, else it sleeps as long as indicated and retries.
  *
@@ -249,16 +271,17 @@ static int send_receive_check(OSSL_CMP_CTX *ctx, const OSSL_CMP_MSG *req,
  * Returns -1 on receiving pollRep if sleep == 0, setting the checkAfter value.
  * Returns 1 on success and provides the received PKIMESSAGE in *rep.
  *           In this case the caller is responsible for freeing *rep.
- * Returns 0 on error (which includes the case that timeout has been reached).
+ * Returns 0 on error (which includes the cases that timeout has been reached
+ *           or a response with 'waiting' status has been received).
  */
 static int poll_for_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
-                             OSSL_CMP_MSG **rep, int *checkAfter)
+    OSSL_CMP_MSG **rep, int *checkAfter)
 {
     OSSL_CMP_MSG *preq = NULL;
     OSSL_CMP_MSG *prep = NULL;
 
     ossl_cmp_info(ctx,
-                  "received 'waiting' PKIStatus, starting to poll for response");
+        "received 'waiting' PKIStatus, starting to poll for response");
     *rep = NULL;
     for (;;) {
         if ((preq = ossl_cmp_pollReq_new(ctx, rid)) == NULL)
@@ -287,35 +310,37 @@ static int poll_for_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
                 ERR_raise(ERR_LIB_CMP, CMP_R_BAD_CHECKAFTER_IN_POLLREP);
                 goto err;
             }
-            if (check_after < 0 || (uint64_t)check_after
-                > (sleep ? ULONG_MAX / 1000 : INT_MAX)) {
+            if (check_after < 0 || (uint64_t)check_after > (sleep ? ULONG_MAX / 1000 : INT_MAX)) {
                 ERR_raise(ERR_LIB_CMP, CMP_R_CHECKAFTER_OUT_OF_RANGE);
                 if (BIO_snprintf(str, OSSL_CMP_PKISI_BUFLEN, "value = %jd",
-                                 check_after) >= 0)
+                        check_after)
+                    >= 0)
                     ERR_add_error_data(1, str);
                 goto err;
             }
 
             if (pollRep->reason == NULL
-                    || (len = BIO_snprintf(str, OSSL_CMP_PKISI_BUFLEN,
-                                           " with reason = '")) < 0) {
+                || (len = BIO_snprintf(str, OSSL_CMP_PKISI_BUFLEN,
+                        " with reason = '"))
+                    < 0) {
                 *str = '\0';
             } else {
                 char *text = ossl_sk_ASN1_UTF8STRING2text(pollRep->reason, ", ",
-                                                          sizeof(str) - len - 2);
+                    sizeof(str) - len - 2);
 
                 if (text == NULL
-                        || BIO_snprintf(str + len, sizeof(str) - len,
-                                        "%s'", text) < 0)
+                    || BIO_snprintf(str + len, sizeof(str) - len,
+                           "%s'", text)
+                        < 0)
                     *str = '\0';
                 OPENSSL_free(text);
             }
             ossl_cmp_log2(INFO, ctx,
-                          "received polling response%s; checkAfter = %ld seconds",
-                          str, check_after);
+                "received polling response%s; checkAfter = %ld seconds",
+                str, check_after);
 
             if (ctx->total_timeout != 0) { /* timeout is not infinite */
-                const int exp = 5; /* expected max time per msg round trip */
+                const int exp = OSSL_CMP_EXPECTED_RESP_TIME;
                 int64_t time_left = (int64_t)(ctx->end_time - exp - time(NULL));
 
                 if (time_left <= 0) {
@@ -338,9 +363,19 @@ static int poll_for_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
                     *checkAfter = (int)check_after;
                 return -1; /* exits the loop */
             }
+        } else if (is_crep_with_waiting(prep, rid)
+            || ossl_cmp_is_error_with_waiting(prep)) {
+            /* received status must not be 'waiting' */
+            (void)ossl_cmp_exchange_error(ctx, OSSL_CMP_PKISTATUS_rejection,
+                OSSL_CMP_CTX_FAILINFO_badRequest,
+                "polling already started",
+                0 /* errorCode */, NULL);
+            ERR_raise(ERR_LIB_CMP, CMP_R_UNEXPECTED_PKISTATUS);
+            goto err;
         } else {
-            ossl_cmp_info(ctx, "received ip/cp/kup after polling");
-            /* any other body type has been rejected by send_receive_check() */
+            ossl_cmp_info(ctx, "received final response after polling");
+            if (!ossl_cmp_ctx_set1_first_senderNonce(ctx, NULL))
+                goto err;
             break;
         }
     }
@@ -351,18 +386,71 @@ static int poll_for_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
     *rep = prep;
 
     return 1;
- err:
+err:
+    (void)ossl_cmp_ctx_set1_first_senderNonce(ctx, NULL);
     OSSL_CMP_MSG_free(preq);
     OSSL_CMP_MSG_free(prep);
     return 0;
 }
 
+static int save_senderNonce_if_waiting(OSSL_CMP_CTX *ctx,
+    const OSSL_CMP_MSG *rep, int rid)
+{
+    /*
+     * Lightweight CMP Profile section 4.4 states: the senderNonce of the
+     * preceding request message because this value will be needed for checking
+     * the recipNonce of the final response to be received after polling.
+     */
+    if ((is_crep_with_waiting(rep, rid)
+            || ossl_cmp_is_error_with_waiting(rep))
+        && !ossl_cmp_ctx_set1_first_senderNonce(ctx, ctx->senderNonce))
+        return 0;
+
+    return 1;
+}
+
+/*
+ * Send request and get response possibly with polling initiated by error msg.
+ * Polling for ip/cp/kup/ with 'waiting' status is handled by cert_response().
+ */
+static int send_receive_also_delayed(OSSL_CMP_CTX *ctx, const OSSL_CMP_MSG *req,
+    OSSL_CMP_MSG **rep, int expected_type)
+{
+
+    if (!send_receive_check(ctx, req, rep, expected_type))
+        return 0;
+
+    if (ossl_cmp_is_error_with_waiting(*rep)) {
+        if (!save_senderNonce_if_waiting(ctx, *rep, OSSL_CMP_CERTREQID_NONE))
+            return 0;
+        /* not modifying ctx->status during certConf and error exchanges */
+        if (expected_type != OSSL_CMP_PKIBODY_PKICONF
+            && !save_statusInfo(ctx, (*rep)->body->value.error->pKIStatusInfo))
+            return 0;
+
+        OSSL_CMP_MSG_free(*rep);
+        *rep = NULL;
+
+        if (poll_for_response(ctx, 1 /* can sleep */, OSSL_CMP_CERTREQID_NONE,
+                rep, NULL /* checkAfter */)
+            <= 0) {
+            ERR_raise(ERR_LIB_CMP, CMP_R_POLLING_FAILED);
+            return 0;
+        }
+    }
+    if (OSSL_CMP_MSG_get_bodytype(*rep) != expected_type) {
+        ERR_raise(ERR_LIB_CMP, CMP_R_UNEXPECTED_PKIBODY);
+        return 0;
+    }
+
+    return 1;
+}
 /*
  * Send certConf for IR, CR or KUR sequences and check response,
  * not modifying ctx->status during the certConf exchange
  */
 int ossl_cmp_exchange_certConf(OSSL_CMP_CTX *ctx, int certReqId,
-                               int fail_info, const char *txt)
+    int fail_info, const char *txt)
 {
     OSSL_CMP_MSG *certConf;
     OSSL_CMP_MSG *PKIconf = NULL;
@@ -373,9 +461,10 @@ int ossl_cmp_exchange_certConf(OSSL_CMP_CTX *ctx, int certReqId,
     if (certConf == NULL)
         goto err;
 
-    res = send_receive_check(ctx, certConf, &PKIconf, OSSL_CMP_PKIBODY_PKICONF);
+    res = send_receive_also_delayed(ctx, certConf, &PKIconf,
+        OSSL_CMP_PKIBODY_PKICONF);
 
- err:
+err:
     OSSL_CMP_MSG_free(certConf);
     OSSL_CMP_MSG_free(PKIconf);
     return res;
@@ -383,7 +472,7 @@ int ossl_cmp_exchange_certConf(OSSL_CMP_CTX *ctx, int certReqId,
 
 /* Send given error and check response */
 int ossl_cmp_exchange_error(OSSL_CMP_CTX *ctx, int status, int fail_info,
-                            const char *txt, int errorCode, const char *details)
+    const char *txt, int errorCode, const char *details)
 {
     OSSL_CMP_MSG *error = NULL;
     OSSL_CMP_PKISI *si = NULL;
@@ -397,9 +486,10 @@ int ossl_cmp_exchange_error(OSSL_CMP_CTX *ctx, int status, int fail_info,
     if ((error = ossl_cmp_error_new(ctx, si, errorCode, details, 0)) == NULL)
         goto err;
 
-    res = send_receive_check(ctx, error, &PKIconf, OSSL_CMP_PKIBODY_PKICONF);
+    res = send_receive_also_delayed(ctx, error,
+        &PKIconf, OSSL_CMP_PKIBODY_PKICONF);
 
- err:
+err:
     OSSL_CMP_MSG_free(error);
     OSSL_CMP_PKISI_free(si);
     OSSL_CMP_MSG_free(PKIconf);
@@ -412,7 +502,7 @@ int ossl_cmp_exchange_error(OSSL_CMP_CTX *ctx, int status, int fail_info,
  * Returns NULL if not found or on error.
  */
 static X509 *get1_cert_status(OSSL_CMP_CTX *ctx, int bodytype,
-                              OSSL_CMP_CERTRESPONSE *crep)
+    OSSL_CMP_CERTRESPONSE *crep)
 {
     char buf[OSSL_CMP_PKISI_BUFLEN];
     X509 *crt = NULL;
@@ -423,7 +513,7 @@ static X509 *get1_cert_status(OSSL_CMP_CTX *ctx, int bodytype,
     switch (ossl_cmp_pkisi_get_status(crep->status)) {
     case OSSL_CMP_PKISTATUS_waiting:
         ossl_cmp_err(ctx,
-                     "received \"waiting\" status for cert when actually aiming to extract cert");
+            "received \"waiting\" status for cert when actually aiming to extract cert");
         ERR_raise(ERR_LIB_CMP, CMP_R_ENCOUNTERED_WAITING);
         goto err;
     case OSSL_CMP_PKISTATUS_grantedWithMods:
@@ -438,11 +528,11 @@ static X509 *get1_cert_status(OSSL_CMP_CTX *ctx, int bodytype,
         goto err;
     case OSSL_CMP_PKISTATUS_revocationWarning:
         ossl_cmp_warn(ctx,
-                      "received \"revocationWarning\" - a revocation of the cert is imminent");
+            "received \"revocationWarning\" - a revocation of the cert is imminent");
         break;
     case OSSL_CMP_PKISTATUS_revocationNotification:
         ossl_cmp_warn(ctx,
-                      "received \"revocationNotification\" - a revocation of the cert has occurred");
+            "received \"revocationNotification\" - a revocation of the cert has occurred");
         break;
     case OSSL_CMP_PKISTATUS_keyUpdateWarning:
         if (bodytype != OSSL_CMP_PKIBODY_KUR) {
@@ -452,8 +542,8 @@ static X509 *get1_cert_status(OSSL_CMP_CTX *ctx, int bodytype,
         break;
     default:
         ossl_cmp_log1(ERROR, ctx,
-                      "received unsupported PKIStatus %d for certificate",
-                      ctx->status);
+            "received unsupported PKIStatus %d for certificate",
+            ctx->status);
         ERR_raise(ERR_LIB_CMP, CMP_R_UNKNOWN_PKISTATUS);
         goto err;
     }
@@ -463,7 +553,7 @@ static X509 *get1_cert_status(OSSL_CMP_CTX *ctx, int bodytype,
 
     return crt;
 
- err:
+err:
     if (OSSL_CMP_CTX_snprint_PKIStatus(ctx, buf, sizeof(buf)) != NULL)
         ERR_add_error_data(1, buf);
     return NULL;
@@ -487,7 +577,7 @@ static X509 *get1_cert_status(OSSL_CMP_CTX *ctx, int bodytype,
  * an EE must be able to validate the certificates it gets enrolled.
  */
 int OSSL_CMP_certConf_cb(OSSL_CMP_CTX *ctx, X509 *cert, int fail_info,
-                         const char **text)
+    const char **text)
 {
     X509_STORE *out_trusted = OSSL_CMP_CTX_get_certConf_cb_arg(ctx);
     STACK_OF(X509) *chain = NULL;
@@ -500,7 +590,7 @@ int OSSL_CMP_certConf_cb(OSSL_CMP_CTX *ctx, X509 *cert, int fail_info,
     if (out_trusted == NULL) {
         ossl_cmp_debug(ctx, "trying to build chain for newly enrolled cert");
         chain = X509_build_chain(cert, ctx->untrusted, out_trusted,
-                                 0, ctx->libctx, ctx->propq);
+            0, ctx->libctx, ctx->propq);
     } else {
         X509_STORE_CTX *csc = X509_STORE_CTX_new_ex(ctx->libctx, ctx->propq);
 
@@ -511,16 +601,16 @@ int OSSL_CMP_certConf_cb(OSSL_CMP_CTX *ctx, X509 *cert, int fail_info,
             goto err;
         /* disable any cert status/revocation checking etc. */
         X509_VERIFY_PARAM_clear_flags(X509_STORE_CTX_get0_param(csc),
-                                      ~(X509_V_FLAG_USE_CHECK_TIME
-                                        | X509_V_FLAG_NO_CHECK_TIME
-                                        | X509_V_FLAG_PARTIAL_CHAIN
-                                        | X509_V_FLAG_POLICY_CHECK));
+            ~(X509_V_FLAG_USE_CHECK_TIME
+                | X509_V_FLAG_NO_CHECK_TIME
+                | X509_V_FLAG_PARTIAL_CHAIN
+                | X509_V_FLAG_POLICY_CHECK));
         if (X509_verify_cert(csc) <= 0)
             goto err;
 
-        if (!ossl_x509_add_certs_new(&chain,  X509_STORE_CTX_get0_chain(csc),
-                                     X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP
-                                     | X509_ADD_FLAG_NO_SS)) {
+        if (!ossl_x509_add_certs_new(&chain, X509_STORE_CTX_get0_chain(csc),
+                X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP
+                    | X509_ADD_FLAG_NO_SS)) {
             sk_X509_free(chain);
             chain = NULL;
         }
@@ -536,14 +626,14 @@ int OSSL_CMP_certConf_cb(OSSL_CMP_CTX *ctx, X509 *cert, int fail_info,
             fail_info = 1 << OSSL_CMP_PKIFAILUREINFO_incorrectData;
         } else {
             ossl_cmp_debug(ctx,
-                           "success validating newly enrolled cert");
+                "success validating newly enrolled cert");
         }
     } else if (chain == NULL) {
         ossl_cmp_warn(ctx, "could not build approximate chain for newly enrolled cert, resorting to received extraCerts");
         chain = OSSL_CMP_CTX_get1_extraCertsIn(ctx);
     } else {
         ossl_cmp_debug(ctx,
-                       "success building approximate chain for newly enrolled cert");
+            "success building approximate chain for newly enrolled cert");
     }
     (void)ossl_cmp_ctx_set1_newChain(ctx, chain);
     OSSL_STACK_OF_X509_free(chain);
@@ -560,55 +650,85 @@ int OSSL_CMP_certConf_cb(OSSL_CMP_CTX *ctx, X509 *cert, int fail_info,
  * Regardless of success, caller is responsible for freeing *resp (unless NULL).
  */
 static int cert_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
-                         OSSL_CMP_MSG **resp, int *checkAfter,
-                         ossl_unused int req_type,
-                         ossl_unused int expected_type)
+    OSSL_CMP_MSG **resp, int *checkAfter,
+    ossl_unused int req_type,
+    ossl_unused int expected_type)
 {
     EVP_PKEY *rkey = ossl_cmp_ctx_get0_newPubkey(ctx);
     int fail_info = 0; /* no failure */
     const char *txt = NULL;
-    OSSL_CMP_CERTREPMESSAGE *crepmsg;
-    OSSL_CMP_CERTRESPONSE *crep;
+    OSSL_CMP_CERTREPMESSAGE *crepmsg = NULL;
+    OSSL_CMP_CERTRESPONSE *crep = NULL;
     OSSL_CMP_certConf_cb_t cb;
     X509 *cert;
     char *subj = NULL;
     int ret = 1;
+    int rcvd_type;
+    OSSL_CMP_PKISI *si;
 
     if (!ossl_assert(ctx != NULL))
         return 0;
 
- retry:
-    crepmsg = (*resp)->body->value.ip; /* same for cp and kup */
-    if (sk_OSSL_CMP_CERTRESPONSE_num(crepmsg->response) > 1) {
-        ERR_raise(ERR_LIB_CMP, CMP_R_MULTIPLE_RESPONSES_NOT_SUPPORTED);
-        return 0;
-    }
-    crep = ossl_cmp_certrepmessage_get0_certresponse(crepmsg, rid);
-    if (crep == NULL)
-        return 0;
-    if (!save_statusInfo(ctx, crep->status))
-        return 0;
-    if (rid == OSSL_CMP_CERTREQID_NONE) { /* used for OSSL_CMP_PKIBODY_P10CR */
-        rid = ossl_cmp_asn1_get_int(crep->certReqId);
-        if (rid < OSSL_CMP_CERTREQID_NONE) {
-            ERR_raise(ERR_LIB_CMP, CMP_R_BAD_REQUEST_ID);
+retry:
+    rcvd_type = OSSL_CMP_MSG_get_bodytype(*resp);
+    if (IS_CREP(rcvd_type)) {
+        crepmsg = (*resp)->body->value.ip; /* same for cp and kup */
+        if (sk_OSSL_CMP_CERTRESPONSE_num(crepmsg->response) > 1) {
+            ERR_raise(ERR_LIB_CMP, CMP_R_MULTIPLE_RESPONSES_NOT_SUPPORTED);
             return 0;
         }
+        crep = ossl_cmp_certrepmessage_get0_certresponse(crepmsg, rid);
+        if (crep == NULL)
+            return 0;
+        si = crep->status;
+
+        if (rid == OSSL_CMP_CERTREQID_NONE) {
+            /* for OSSL_CMP_PKIBODY_P10CR learn CertReqId from response */
+            rid = ossl_cmp_asn1_get_int(crep->certReqId);
+            if (rid < OSSL_CMP_CERTREQID_NONE) {
+                ERR_raise(ERR_LIB_CMP, CMP_R_BAD_REQUEST_ID);
+                return 0;
+            }
+        }
+    } else if (rcvd_type == OSSL_CMP_PKIBODY_ERROR) {
+        si = (*resp)->body->value.error->pKIStatusInfo;
+    } else {
+        ERR_raise(ERR_LIB_CMP, CMP_R_UNEXPECTED_PKIBODY);
+        return 0;
     }
 
-    if (ossl_cmp_pkisi_get_status(crep->status) == OSSL_CMP_PKISTATUS_waiting) {
+    if (!save_statusInfo(ctx, si))
+        return 0;
+
+    if (ossl_cmp_pkisi_get_status(si) == OSSL_CMP_PKISTATUS_waiting) {
+        /*
+         * Here we allow both and error message with waiting indication
+         * as well as a certificate response with waiting indication, where
+         * its flavor (ip, cp, or kup) may not strictly match ir/cr/p10cr/kur.
+         */
         OSSL_CMP_MSG_free(*resp);
         *resp = NULL;
         if ((ret = poll_for_response(ctx, sleep, rid, resp, checkAfter)) != 0) {
             if (ret == -1) /* at this point implies sleep == 0 */
                 return ret; /* waiting */
-            goto retry; /* got ip/cp/kup, which may still indicate 'waiting' */
+            goto retry; /* got some response other than pollRep */
         } else {
             ERR_raise(ERR_LIB_CMP, CMP_R_POLLING_FAILED);
             return 0;
         }
     }
 
+    /* at this point, we have received ip/cp/kup/error without waiting */
+    if (rcvd_type == OSSL_CMP_PKIBODY_ERROR) {
+        ERR_raise(ERR_LIB_CMP, CMP_R_RECEIVED_ERROR);
+        return 0;
+    }
+    /* here we are strict on the flavor of ip/cp/kup: must match request */
+    if (rcvd_type != expected_type) {
+        ERR_raise(ERR_LIB_CMP, CMP_R_UNEXPECTED_PKIBODY);
+        return 0;
+    }
+
     cert = get1_cert_status(ctx, (*resp)->body->type, crep);
     if (cert == NULL) {
         ERR_add_error_data(1, "; cannot extract certificate from response");
@@ -623,14 +743,14 @@ static int cert_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
      * if the CMP server returned certificates in the caPubs field, copy them
      * to the context so that they can be retrieved if necessary
      */
-    if (crepmsg->caPubs != NULL
-            && !ossl_cmp_ctx_set1_caPubs(ctx, crepmsg->caPubs))
+    if (crepmsg != NULL && crepmsg->caPubs != NULL
+        && !ossl_cmp_ctx_set1_caPubs(ctx, crepmsg->caPubs))
         return 0;
 
     subj = X509_NAME_oneline(X509_get_subject_name(cert), NULL, 0);
     if (rkey != NULL
         /* X509_check_private_key() also works if rkey is just public key */
-            && !(X509_check_private_key(ctx->newCert, rkey))) {
+        && !(X509_check_private_key(ctx->newCert, rkey))) {
         fail_info = 1 << OSSL_CMP_PKIFAILUREINFO_incorrectData;
         txt = "public key in new certificate does not match our enrollment key";
         /*-
@@ -649,17 +769,17 @@ static int cert_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
      */
     cb = ctx->certConf_cb != NULL ? ctx->certConf_cb : OSSL_CMP_certConf_cb;
     if ((fail_info = cb(ctx, ctx->newCert, fail_info, &txt)) != 0
-            && txt == NULL)
+        && txt == NULL)
         txt = "CMP client did not accept it";
     if (fail_info != 0) /* immediately log error before any certConf exchange */
         ossl_cmp_log1(ERROR, ctx,
-                      "rejecting newly enrolled cert with subject: %s", subj);
+            "rejecting newly enrolled cert with subject: %s", subj);
     /*
      * certConf exchange should better be moved to do_certreq_seq() such that
      * also more low-level errors with CertReqMessages get reported to server
      */
     if (!ctx->disableConfirm
-            && !ossl_cmp_hdr_has_implicitConfirm((*resp)->header)) {
+        && !ossl_cmp_hdr_has_implicitConfirm((*resp)->header)) {
         if (!ossl_cmp_exchange_certConf(ctx, rid, fail_info, txt))
             ret = 0;
     }
@@ -667,8 +787,8 @@ static int cert_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
     /* not throwing failure earlier as transfer_cb may call ERR_clear_error() */
     if (fail_info != 0) {
         ERR_raise_data(ERR_LIB_CMP, CMP_R_CERTIFICATE_NOT_ACCEPTED,
-                       "rejecting newly enrolled cert with subject: %s; %s",
-                       subj, txt);
+            "rejecting newly enrolled cert with subject: %s; %s",
+            subj, txt);
         ctx->status = OSSL_CMP_PKISTATUS_rejection;
         ret = 0;
     }
@@ -677,8 +797,8 @@ static int cert_response(OSSL_CMP_CTX *ctx, int sleep, int rid,
 }
 
 static int initial_certreq(OSSL_CMP_CTX *ctx,
-                           int req_type, const OSSL_CRMF_MSG *crm,
-                           OSSL_CMP_MSG **p_rep, int rep_type)
+    int req_type, const OSSL_CRMF_MSG *crm,
+    OSSL_CMP_MSG **p_rep, int rep_type)
 {
     OSSL_CMP_MSG *req;
     int res;
@@ -698,7 +818,7 @@ static int initial_certreq(OSSL_CMP_CTX *ctx,
 }
 
 int OSSL_CMP_try_certreq(OSSL_CMP_CTX *ctx, int req_type,
-                         const OSSL_CRMF_MSG *crm, int *checkAfter)
+    const OSSL_CRMF_MSG *crm, int *checkAfter)
 {
     OSSL_CMP_MSG *rep = NULL;
     int is_p10 = req_type == OSSL_CMP_PKIBODY_P10CR;
@@ -714,19 +834,22 @@ int OSSL_CMP_try_certreq(OSSL_CMP_CTX *ctx, int req_type,
     if (ctx->status != OSSL_CMP_PKISTATUS_waiting) { /* not polling already */
         if (!initial_certreq(ctx, req_type, crm, &rep, rep_type))
             goto err;
+
+        if (!save_senderNonce_if_waiting(ctx, rep, rid))
+            goto err;
     } else {
         if (req_type < 0)
             return ossl_cmp_exchange_error(ctx, OSSL_CMP_PKISTATUS_rejection,
-                                           0, "polling aborted",
-                                           0 /* errorCode */, "by application");
+                0, "polling aborted",
+                0 /* errorCode */, "by application");
         res = poll_for_response(ctx, 0 /* no sleep */, rid, &rep, checkAfter);
         if (res <= 0) /* waiting or error */
             return res;
     }
     res = cert_response(ctx, 0 /* no sleep */, rid, &rep, checkAfter,
-                        req_type, rep_type);
+        req_type, rep_type);
 
- err:
+err:
     OSSL_CMP_MSG_free(rep);
     return res;
 }
@@ -739,7 +862,7 @@ int OSSL_CMP_try_certreq(OSSL_CMP_CTX *ctx, int req_type,
  * Returns pointer to received certificate, or NULL if none was received.
  */
 X509 *OSSL_CMP_exec_certreq(OSSL_CMP_CTX *ctx, int req_type,
-                            const OSSL_CRMF_MSG *crm)
+    const OSSL_CRMF_MSG *crm)
 {
     OSSL_CMP_MSG *rep = NULL;
     int is_p10 = req_type == OSSL_CMP_PKIBODY_P10CR;
@@ -755,12 +878,15 @@ X509 *OSSL_CMP_exec_certreq(OSSL_CMP_CTX *ctx, int req_type,
     if (!initial_certreq(ctx, req_type, crm, &rep, rep_type))
         goto err;
 
+    if (!save_senderNonce_if_waiting(ctx, rep, rid))
+        goto err;
+
     if (cert_response(ctx, 1 /* sleep */, rid, &rep, NULL, req_type, rep_type)
         <= 0)
         goto err;
 
     result = ctx->newCert;
- err:
+err:
     OSSL_CMP_MSG_free(rep);
     return result;
 }
@@ -792,7 +918,7 @@ int OSSL_CMP_exec_RR_ses(OSSL_CMP_CTX *ctx)
         goto end;
 
     ctx->status = OSSL_CMP_PKISTATUS_trans;
-    if (!send_receive_check(ctx, rr, &rp, OSSL_CMP_PKIBODY_RP))
+    if (!send_receive_also_delayed(ctx, rr, &rp, OSSL_CMP_PKIBODY_RP))
         goto end;
 
     rrep = rp->body->value.rp;
@@ -831,7 +957,7 @@ int OSSL_CMP_exec_RR_ses(OSSL_CMP_CTX *ctx)
     case OSSL_CMP_PKISTATUS_revocationNotification:
         /* interpretation as warning or error depends on CA */
         ossl_cmp_warn(ctx,
-                      "revocation accepted (PKIStatus=revocationNotification)");
+            "revocation accepted (PKIStatus=revocationNotification)");
         ret = 1;
         break;
     case OSSL_CMP_PKISTATUS_waiting:
@@ -846,11 +972,9 @@ int OSSL_CMP_exec_RR_ses(OSSL_CMP_CTX *ctx)
     /* check any present CertId in optional revCerts field */
     if (sk_OSSL_CRMF_CERTID_num(rrep->revCerts) >= 1) {
         OSSL_CRMF_CERTID *cid;
-        OSSL_CRMF_CERTTEMPLATE *tmpl =
-            sk_OSSL_CMP_REVDETAILS_value(rr->body->value.rr, rsid)->certDetails;
+        OSSL_CRMF_CERTTEMPLATE *tmpl = sk_OSSL_CMP_REVDETAILS_value(rr->body->value.rr, rsid)->certDetails;
         const X509_NAME *issuer = OSSL_CRMF_CERTTEMPLATE_get0_issuer(tmpl);
-        const ASN1_INTEGER *serial =
-            OSSL_CRMF_CERTTEMPLATE_get0_serialNumber(tmpl);
+        const ASN1_INTEGER *serial = OSSL_CRMF_CERTTEMPLATE_get0_serialNumber(tmpl);
 
         if (sk_OSSL_CRMF_CERTID_num(rrep->revCerts) != num_RevDetails) {
             ERR_raise(ERR_LIB_CMP, CMP_R_WRONG_RP_COMPONENT_COUNT);
@@ -870,7 +994,8 @@ int OSSL_CMP_exec_RR_ses(OSSL_CMP_CTX *ctx)
 #endif
         }
         if (ASN1_INTEGER_cmp(serial,
-                             OSSL_CRMF_CERTID_get0_serialNumber(cid)) != 0) {
+                OSSL_CRMF_CERTID_get0_serialNumber(cid))
+            != 0) {
 #ifndef FUZZING_BUILD_MODE_UNSAFE_FOR_PRODUCTION
             ERR_raise(ERR_LIB_CMP, CMP_R_WRONG_SERIAL_IN_RP);
             ret = 0;
@@ -886,12 +1011,12 @@ int OSSL_CMP_exec_RR_ses(OSSL_CMP_CTX *ctx)
         goto err;
     }
 
- err:
+err:
     if (ret == 0
-            && OSSL_CMP_CTX_snprint_PKIStatus(ctx, buf, sizeof(buf)) != NULL)
+        && OSSL_CMP_CTX_snprint_PKIStatus(ctx, buf, sizeof(buf)) != NULL)
         ERR_add_error_data(1, buf);
 
- end:
+end:
     OSSL_CMP_MSG_free(rr);
     OSSL_CMP_MSG_free(rp);
     return ret;
@@ -913,7 +1038,7 @@ STACK_OF(OSSL_CMP_ITAV) *OSSL_CMP_exec_GENM_ses(OSSL_CMP_CTX *ctx)
         goto err;
 
     ctx->status = OSSL_CMP_PKISTATUS_trans;
-    if (!send_receive_check(ctx, genm, &genp, OSSL_CMP_PKIBODY_GENP))
+    if (!send_receive_also_delayed(ctx, genm, &genp, OSSL_CMP_PKIBODY_GENP))
         goto err;
     ctx->status = OSSL_CMP_PKISTATUS_accepted;
 
@@ -923,7 +1048,7 @@ STACK_OF(OSSL_CMP_ITAV) *OSSL_CMP_exec_GENM_ses(OSSL_CMP_CTX *ctx)
     /* received stack of itavs not to be freed with the genp */
     genp->body->value.genp = NULL;
 
- err:
+err:
     OSSL_CMP_MSG_free(genm);
     OSSL_CMP_MSG_free(genp);
 
