@@ -1,5 +1,5 @@
 /*
- * Copyright 2007-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2007-2024 The OpenSSL Project Authors. All Rights Reserved.
  * Copyright Nokia 2007-2019
  * Copyright Siemens AG 2015-2019
  *
@@ -25,7 +25,7 @@ OSSL_CMP_MSG *OSSL_CMP_MSG_new(OSSL_LIB_CTX *libctx, const char *propq)
     OSSL_CMP_MSG *msg = NULL;
 
     msg = (OSSL_CMP_MSG *)ASN1_item_new_ex(ASN1_ITEM_rptr(OSSL_CMP_MSG),
-                                           libctx, propq);
+        libctx, propq);
     if (!ossl_cmp_msg_set0_libctx(msg, libctx, propq)) {
         OSSL_CMP_MSG_free(msg);
         msg = NULL;
@@ -44,7 +44,7 @@ void OSSL_CMP_MSG_free(OSSL_CMP_MSG *msg)
  * Use OSSL_CMP_MSG_new() instead if possible.
  */
 int ossl_cmp_msg_set0_libctx(OSSL_CMP_MSG *msg, OSSL_LIB_CTX *libctx,
-                             const char *propq)
+    const char *propq)
 {
     if (msg != NULL) {
         msg->libctx = libctx;
@@ -71,11 +71,33 @@ OSSL_CMP_PKIHEADER *OSSL_CMP_MSG_get0_header(const OSSL_CMP_MSG *msg)
 const char *ossl_cmp_bodytype_to_string(int type)
 {
     static const char *type_names[] = {
-        "IR", "IP", "CR", "CP", "P10CR",
-        "POPDECC", "POPDECR", "KUR", "KUP",
-        "KRR", "KRP", "RR", "RP", "CCR", "CCP",
-        "CKUANN", "CANN", "RANN", "CRLANN", "PKICONF", "NESTED",
-        "GENM", "GENP", "ERROR", "CERTCONF", "POLLREQ", "POLLREP",
+        "IR",
+        "IP",
+        "CR",
+        "CP",
+        "P10CR",
+        "POPDECC",
+        "POPDECR",
+        "KUR",
+        "KUP",
+        "KRR",
+        "KRP",
+        "RR",
+        "RP",
+        "CCR",
+        "CCP",
+        "CKUANN",
+        "CANN",
+        "RANN",
+        "CRLANN",
+        "PKICONF",
+        "NESTED",
+        "GENM",
+        "GENP",
+        "ERROR",
+        "CERTCONF",
+        "POLLREQ",
+        "POLLREP",
     };
 
     if (type < 0 || type > OSSL_CMP_PKIBODY_TYPE_MAX)
@@ -100,6 +122,34 @@ int OSSL_CMP_MSG_get_bodytype(const OSSL_CMP_MSG *msg)
     return msg->body->type;
 }
 
+X509_PUBKEY *OSSL_CMP_MSG_get0_certreq_publickey(const OSSL_CMP_MSG *msg)
+{
+    const OSSL_CRMF_MSGS *reqs;
+    const OSSL_CRMF_MSG *crm;
+    const OSSL_CRMF_CERTTEMPLATE *tmpl;
+    X509_PUBKEY *pubkey;
+
+    switch (OSSL_CMP_MSG_get_bodytype(msg)) {
+    case OSSL_CMP_PKIBODY_IR:
+    case OSSL_CMP_PKIBODY_CR:
+    case OSSL_CMP_PKIBODY_KUR:
+        reqs = msg->body->value.ir; /* value.ir is same for cr and kur */
+        if ((crm = sk_OSSL_CRMF_MSG_value(reqs, 0)) == NULL) {
+            ERR_raise(ERR_LIB_CMP, CMP_R_CERTREQMSG_NOT_FOUND);
+            return NULL;
+        }
+        if ((tmpl = OSSL_CRMF_MSG_get0_tmpl(crm)) == NULL
+            || (pubkey = OSSL_CRMF_CERTTEMPLATE_get0_publicKey(tmpl)) == NULL) {
+            ERR_raise(ERR_LIB_CMP, CRMF_R_POPO_MISSING_PUBLIC_KEY);
+            return NULL;
+        }
+        return pubkey;
+    default:
+        ERR_raise(ERR_LIB_CMP, CMP_R_UNEXPECTED_PKIBODY);
+        return NULL;
+    }
+}
+
 /* Add an extension to the referenced extension stack, which may be NULL */
 static int add1_extension(X509_EXTENSIONS **pexts, int nid, int crit, void *ex)
 {
@@ -119,7 +169,7 @@ static int add1_extension(X509_EXTENSIONS **pexts, int nid, int crit, void *ex)
 
 /* Add extension list to the referenced extension stack, which may be NULL */
 static int add_extensions(STACK_OF(X509_EXTENSION) **target,
-                          const STACK_OF(X509_EXTENSION) *exts)
+    const STACK_OF(X509_EXTENSION) *exts)
 {
     int i;
 
@@ -167,11 +217,11 @@ OSSL_CMP_MSG *ossl_cmp_msg_create(OSSL_CMP_CTX *ctx, int bodytype)
     if ((msg = OSSL_CMP_MSG_new(ctx->libctx, ctx->propq)) == NULL)
         return NULL;
     if (!ossl_cmp_hdr_init(ctx, msg->header)
-            || !ossl_cmp_msg_set_bodytype(msg, bodytype))
+        || !ossl_cmp_msg_set_bodytype(msg, bodytype))
         goto err;
     if (ctx->geninfo_ITAVs != NULL
-            && !ossl_cmp_hdr_generalInfo_push1_items(msg->header,
-                                                     ctx->geninfo_ITAVs))
+        && !ossl_cmp_hdr_generalInfo_push1_items(msg->header,
+            ctx->geninfo_ITAVs))
         goto err;
 
     switch (bodytype) {
@@ -208,8 +258,7 @@ OSSL_CMP_MSG *ossl_cmp_msg_create(OSSL_CMP_CTX *ctx, int bodytype)
         return msg;
 
     case OSSL_CMP_PKIBODY_CERTCONF:
-        if ((msg->body->value.certConf =
-             sk_OSSL_CMP_CERTSTATUS_new_null()) == NULL)
+        if ((msg->body->value.certConf = sk_OSSL_CMP_CERTSTATUS_new_null()) == NULL)
             goto err;
         return msg;
     case OSSL_CMP_PKIBODY_PKICONF:
@@ -243,17 +292,17 @@ OSSL_CMP_MSG *ossl_cmp_msg_create(OSSL_CMP_CTX *ctx, int bodytype)
         goto err;
     }
 
- err:
+err:
     OSSL_CMP_MSG_free(msg);
     return NULL;
 }
 
-#define HAS_SAN(ctx) \
+#define HAS_SAN(ctx)                                 \
     (sk_GENERAL_NAME_num((ctx)->subjectAltNames) > 0 \
-         || OSSL_CMP_CTX_reqExtensions_have_SAN(ctx) == 1)
+        || OSSL_CMP_CTX_reqExtensions_have_SAN(ctx) == 1)
 
 static const X509_NAME *determine_subj(OSSL_CMP_CTX *ctx, int for_KUR,
-                                       const X509_NAME *ref_subj)
+    const X509_NAME *ref_subj)
 {
     if (ctx->subjectName != NULL)
         return IS_NULL_DN(ctx->subjectName) ? NULL : ctx->subjectName;
@@ -275,8 +324,7 @@ OSSL_CRMF_MSG *OSSL_CMP_CTX_setup_CRM(OSSL_CMP_CTX *ctx, int for_KUR, int rid)
     /* refcert defaults to current client cert */
     EVP_PKEY *rkey = ossl_cmp_ctx_get0_newPubkey(ctx);
     STACK_OF(GENERAL_NAME) *default_sans = NULL;
-    const X509_NAME *ref_subj =
-        refcert != NULL ? X509_get_subject_name(refcert) : NULL;
+    const X509_NAME *ref_subj = refcert != NULL ? X509_get_subject_name(refcert) : NULL;
     const X509_NAME *subject = determine_subj(ctx, for_KUR, ref_subj);
     const X509_NAME *issuer = ctx->issuer != NULL || refcert == NULL
         ? (IS_NULL_DN(ctx->issuer) ? NULL : ctx->issuer)
@@ -298,13 +346,13 @@ OSSL_CRMF_MSG *OSSL_CMP_CTX_setup_CRM(OSSL_CMP_CTX *ctx, int for_KUR, int rid)
     if ((crm = OSSL_CRMF_MSG_new()) == NULL)
         return NULL;
     if (!OSSL_CRMF_MSG_set_certReqId(crm, rid)
-            /*
-             * fill certTemplate, corresponding to CertificationRequestInfo
-             * of PKCS#10. The rkey param cannot be NULL so far -
-             * it could be NULL if centralized key creation was supported
-             */
-            || !OSSL_CRMF_CERTTEMPLATE_fill(OSSL_CRMF_MSG_get0_tmpl(crm), rkey,
-                                            subject, issuer, NULL /* serial */))
+        /*
+         * fill certTemplate, corresponding to CertificationRequestInfo
+         * of PKCS#10. The rkey param cannot be NULL so far -
+         * it could be NULL if centralized key creation was supported
+         */
+        || !OSSL_CRMF_CERTTEMPLATE_fill(OSSL_CRMF_MSG_get0_tmpl(crm), rkey,
+            subject, issuer, NULL /* serial */))
         goto err;
     if (ctx->days != 0) {
         time_t now = time(NULL);
@@ -312,8 +360,8 @@ OSSL_CRMF_MSG *OSSL_CMP_CTX_setup_CRM(OSSL_CMP_CTX *ctx, int for_KUR, int rid)
         ASN1_TIME *notAfter = ASN1_TIME_adj(NULL, now, ctx->days, 0);
 
         if (notBefore == NULL
-                || notAfter == NULL
-                || !OSSL_CRMF_MSG_set0_validity(crm, notBefore, notAfter)) {
+            || notAfter == NULL
+            || !OSSL_CRMF_MSG_set0_validity(crm, notBefore, notAfter)) {
             ASN1_TIME_free(notBefore);
             ASN1_TIME_free(notAfter);
             goto err;
@@ -322,24 +370,24 @@ OSSL_CRMF_MSG *OSSL_CMP_CTX_setup_CRM(OSSL_CMP_CTX *ctx, int for_KUR, int rid)
 
     /* extensions */
     if (ctx->p10CSR != NULL
-            && (exts = X509_REQ_get_extensions(ctx->p10CSR)) == NULL)
+        && (exts = X509_REQ_get_extensions(ctx->p10CSR)) == NULL)
         goto err;
     if (!ctx->SubjectAltName_nodefault && !HAS_SAN(ctx) && refcert != NULL
         && (default_sans = X509V3_get_d2i(X509_get0_extensions(refcert),
-                                          NID_subject_alt_name, NULL, NULL))
-        != NULL
-            && !add1_extension(&exts, NID_subject_alt_name, crit, default_sans))
+                NID_subject_alt_name, NULL, NULL))
+            != NULL
+        && !add1_extension(&exts, NID_subject_alt_name, crit, default_sans))
         goto err;
     if (ctx->reqExtensions != NULL /* augment/override existing ones */
-            && !add_extensions(&exts, ctx->reqExtensions))
+        && !add_extensions(&exts, ctx->reqExtensions))
         goto err;
     if (sk_GENERAL_NAME_num(ctx->subjectAltNames) > 0
-            && !add1_extension(&exts, NID_subject_alt_name,
-                               crit, ctx->subjectAltNames))
+        && !add1_extension(&exts, NID_subject_alt_name,
+            crit, ctx->subjectAltNames))
         goto err;
     if (ctx->policies != NULL
-            && !add1_extension(&exts, NID_certificate_policies,
-                               ctx->setPoliciesCritical, ctx->policies))
+        && !add1_extension(&exts, NID_certificate_policies,
+            ctx->setPoliciesCritical, ctx->policies))
         goto err;
     if (!OSSL_CRMF_MSG_set0_extensions(crm, exts))
         goto err;
@@ -348,9 +396,8 @@ OSSL_CRMF_MSG *OSSL_CMP_CTX_setup_CRM(OSSL_CMP_CTX *ctx, int for_KUR, int rid)
 
     /* for KUR, set OldCertId according to D.6 */
     if (for_KUR && refcert != NULL) {
-        OSSL_CRMF_CERTID *cid =
-            OSSL_CRMF_CERTID_gen(X509_get_issuer_name(refcert),
-                                 X509_get0_serialNumber(refcert));
+        OSSL_CRMF_CERTID *cid = OSSL_CRMF_CERTID_gen(X509_get_issuer_name(refcert),
+            X509_get0_serialNumber(refcert));
         int ret;
 
         if (cid == NULL)
@@ -363,18 +410,18 @@ OSSL_CRMF_MSG *OSSL_CMP_CTX_setup_CRM(OSSL_CMP_CTX *ctx, int for_KUR, int rid)
 
     goto end;
 
- err:
+err:
     OSSL_CRMF_MSG_free(crm);
     crm = NULL;
 
- end:
+end:
     sk_X509_EXTENSION_pop_free(exts, X509_EXTENSION_free);
     sk_GENERAL_NAME_pop_free(default_sans, GENERAL_NAME_free);
     return crm;
 }
 
 OSSL_CMP_MSG *ossl_cmp_certreq_new(OSSL_CMP_CTX *ctx, int type,
-                                   const OSSL_CRMF_MSG *crm)
+    const OSSL_CRMF_MSG *crm)
 {
     OSSL_CMP_MSG *msg;
     OSSL_CRMF_MSG *local_crm = NULL;
@@ -383,7 +430,7 @@ OSSL_CMP_MSG *ossl_cmp_certreq_new(OSSL_CMP_CTX *ctx, int type,
         return NULL;
 
     if (type != OSSL_CMP_PKIBODY_IR && type != OSSL_CMP_PKIBODY_CR
-            && type != OSSL_CMP_PKIBODY_KUR && type != OSSL_CMP_PKIBODY_P10CR) {
+        && type != OSSL_CMP_PKIBODY_KUR && type != OSSL_CMP_PKIBODY_P10CR) {
         ERR_raise(ERR_LIB_CMP, CMP_R_INVALID_ARGS);
         return NULL;
     }
@@ -411,12 +458,12 @@ OSSL_CMP_MSG *ossl_cmp_certreq_new(OSSL_CMP_CTX *ctx, int type,
         }
         if (crm == NULL) {
             local_crm = OSSL_CMP_CTX_setup_CRM(ctx,
-                                               type == OSSL_CMP_PKIBODY_KUR,
-                                               OSSL_CMP_CERTREQID);
+                type == OSSL_CMP_PKIBODY_KUR,
+                OSSL_CMP_CERTREQID);
             if (local_crm == NULL
                 || !OSSL_CRMF_MSG_create_popo(ctx->popoMethod, local_crm,
-                                              privkey, ctx->digest,
-                                              ctx->libctx, ctx->propq))
+                    privkey, ctx->digest,
+                    ctx->libctx, ctx->propq))
                 goto err;
         } else {
             if ((local_crm = OSSL_CRMF_MSG_dup(crm)) == NULL)
@@ -434,7 +481,7 @@ OSSL_CMP_MSG *ossl_cmp_certreq_new(OSSL_CMP_CTX *ctx, int type,
 
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_CERTREQ);
     OSSL_CRMF_MSG_free(local_crm);
     OSSL_CMP_MSG_free(msg);
@@ -442,10 +489,10 @@ OSSL_CMP_MSG *ossl_cmp_certreq_new(OSSL_CMP_CTX *ctx, int type,
 }
 
 OSSL_CMP_MSG *ossl_cmp_certrep_new(OSSL_CMP_CTX *ctx, int bodytype,
-                                   int certReqId, const OSSL_CMP_PKISI *si,
-                                   X509 *cert, const X509 *encryption_recip,
-                                   STACK_OF(X509) *chain, STACK_OF(X509) *caPubs,
-                                   int unprotectedErrors)
+    int certReqId, const OSSL_CMP_PKISI *si,
+    X509 *cert, const X509 *encryption_recip,
+    STACK_OF(X509) *chain, STACK_OF(X509) *caPubs,
+    int unprotectedErrors)
 {
     OSSL_CMP_MSG *msg = NULL;
     OSSL_CMP_CERTREPMESSAGE *repMsg = NULL;
@@ -468,12 +515,12 @@ OSSL_CMP_MSG *ossl_cmp_certrep_new(OSSL_CMP_CTX *ctx, int bodytype,
         goto err;
     OSSL_CMP_PKISI_free(resp->status);
     if ((resp->status = OSSL_CMP_PKISI_dup(si)) == NULL
-            || !ASN1_INTEGER_set(resp->certReqId, certReqId))
+        || !ASN1_INTEGER_set(resp->certReqId, certReqId))
         goto err;
 
     status = ossl_cmp_pkisi_get_status(resp->status);
     if (status != OSSL_CMP_PKISTATUS_rejection
-            && status != OSSL_CMP_PKISTATUS_waiting && cert != NULL) {
+        && status != OSSL_CMP_PKISTATUS_waiting && cert != NULL) {
         if (encryption_recip != NULL) {
             ERR_raise(ERR_LIB_CMP, ERR_R_UNSUPPORTED);
             goto err;
@@ -482,8 +529,7 @@ OSSL_CMP_MSG *ossl_cmp_certrep_new(OSSL_CMP_CTX *ctx, int bodytype,
         if ((resp->certifiedKeyPair = OSSL_CMP_CERTIFIEDKEYPAIR_new())
             == NULL)
             goto err;
-        resp->certifiedKeyPair->certOrEncCert->type =
-            OSSL_CMP_CERTORENCCERT_CERTIFICATE;
+        resp->certifiedKeyPair->certOrEncCert->type = OSSL_CMP_CERTORENCCERT_CERTIFICATE;
         if (!X509_up_ref(cert))
             goto err;
         resp->certifiedKeyPair->certOrEncCert->value.certificate = cert;
@@ -494,21 +540,21 @@ OSSL_CMP_MSG *ossl_cmp_certrep_new(OSSL_CMP_CTX *ctx, int bodytype,
     resp = NULL;
 
     if (bodytype == OSSL_CMP_PKIBODY_IP && caPubs != NULL
-            && (repMsg->caPubs = X509_chain_up_ref(caPubs)) == NULL)
+        && (repMsg->caPubs = X509_chain_up_ref(caPubs)) == NULL)
         goto err;
     if (sk_X509_num(chain) > 0
         && !ossl_x509_add_certs_new(&msg->extraCerts, chain,
-                                    X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP))
+            X509_ADD_FLAG_UP_REF | X509_ADD_FLAG_NO_DUP))
         goto err;
 
     if (!unprotectedErrors
-            || ossl_cmp_pkisi_get_status(si) != OSSL_CMP_PKISTATUS_rejection)
+        || ossl_cmp_pkisi_get_status(si) != OSSL_CMP_PKISTATUS_rejection)
         if (!ossl_cmp_msg_protect(ctx, msg))
             goto err;
 
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_CERTREP);
     OSSL_CMP_CERTRESPONSE_free(resp);
     OSSL_CMP_MSG_free(msg);
@@ -526,8 +572,8 @@ OSSL_CMP_MSG *ossl_cmp_rr_new(OSSL_CMP_CTX *ctx)
     int ret;
 
     if (!ossl_assert(ctx != NULL
-                     && (ctx->oldCert != NULL || ctx->p10CSR != NULL
-                         || (ctx->serialNumber != NULL && ctx->issuer != NULL))))
+            && (ctx->oldCert != NULL || ctx->p10CSR != NULL
+                || (ctx->serialNumber != NULL && ctx->issuer != NULL))))
         return NULL;
 
     if ((rd = OSSL_CMP_REVDETAILS_new()) == NULL)
@@ -542,21 +588,20 @@ OSSL_CMP_MSG *ossl_cmp_rr_new(OSSL_CMP_CTX *ctx)
     } else if (ctx->p10CSR != NULL) {
         pubkey = X509_REQ_get0_pubkey(ctx->p10CSR);
         subject = X509_REQ_get_subject_name(ctx->p10CSR);
-    }
-    else {
+    } else {
         goto err;
     }
 
     /* Fill the template from the contents of the certificate to be revoked */
     ret = OSSL_CRMF_CERTTEMPLATE_fill(rd->certDetails, pubkey, subject,
-                                      issuer, serialNumber);
+        issuer, serialNumber);
     if (!ret)
         goto err;
 
     /* revocation reason code is optional */
     if (ctx->revocationReason != CRL_REASON_NONE
-            && !add_crl_reason_extension(&rd->crlEntryDetails,
-                                         ctx->revocationReason))
+        && !add_crl_reason_extension(&rd->crlEntryDetails,
+            ctx->revocationReason))
         goto err;
 
     if ((msg = ossl_cmp_msg_create(ctx, OSSL_CMP_PKIBODY_RR)) == NULL)
@@ -572,7 +617,7 @@ OSSL_CMP_MSG *ossl_cmp_rr_new(OSSL_CMP_CTX *ctx)
 
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_RR);
     OSSL_CMP_MSG_free(msg);
     OSSL_CMP_REVDETAILS_free(rd);
@@ -580,7 +625,7 @@ OSSL_CMP_MSG *ossl_cmp_rr_new(OSSL_CMP_CTX *ctx)
 }
 
 OSSL_CMP_MSG *ossl_cmp_rp_new(OSSL_CMP_CTX *ctx, const OSSL_CMP_PKISI *si,
-                              const OSSL_CRMF_CERTID *cid, int unprotectedErrors)
+    const OSSL_CRMF_CERTID *cid, int unprotectedErrors)
 {
     OSSL_CMP_REVREPCONTENT *rep = NULL;
     OSSL_CMP_PKISI *si1 = NULL;
@@ -614,13 +659,13 @@ OSSL_CMP_MSG *ossl_cmp_rp_new(OSSL_CMP_CTX *ctx, const OSSL_CMP_PKISI *si,
     }
 
     if (!unprotectedErrors
-            || ossl_cmp_pkisi_get_status(si) != OSSL_CMP_PKISTATUS_rejection)
+        || ossl_cmp_pkisi_get_status(si) != OSSL_CMP_PKISTATUS_rejection)
         if (!ossl_cmp_msg_protect(ctx, msg))
             goto err;
 
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_RP);
     OSSL_CMP_MSG_free(msg);
     return NULL;
@@ -638,7 +683,7 @@ OSSL_CMP_MSG *ossl_cmp_pkiconf_new(OSSL_CMP_CTX *ctx)
     if (ossl_cmp_msg_protect(ctx, msg))
         return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_PKICONF);
     OSSL_CMP_MSG_free(msg);
     return NULL;
@@ -653,7 +698,7 @@ int ossl_cmp_msg_gen_push0_ITAV(OSSL_CMP_MSG *msg, OSSL_CMP_ITAV *itav)
 
     bodytype = OSSL_CMP_MSG_get_bodytype(msg);
     if (bodytype != OSSL_CMP_PKIBODY_GENM
-            && bodytype != OSSL_CMP_PKIBODY_GENP) {
+        && bodytype != OSSL_CMP_PKIBODY_GENP) {
         ERR_raise(ERR_LIB_CMP, CMP_R_INVALID_ARGS);
         return 0;
     }
@@ -663,7 +708,7 @@ int ossl_cmp_msg_gen_push0_ITAV(OSSL_CMP_MSG *msg, OSSL_CMP_ITAV *itav)
 }
 
 int ossl_cmp_msg_gen_push1_ITAVs(OSSL_CMP_MSG *msg,
-                                 const STACK_OF(OSSL_CMP_ITAV) *itavs)
+    const STACK_OF(OSSL_CMP_ITAV) *itavs)
 {
     int i;
     OSSL_CMP_ITAV *itav = NULL;
@@ -674,7 +719,7 @@ int ossl_cmp_msg_gen_push1_ITAVs(OSSL_CMP_MSG *msg,
     for (i = 0; i < sk_OSSL_CMP_ITAV_num(itavs); i++) {
         itav = OSSL_CMP_ITAV_dup(sk_OSSL_CMP_ITAV_value(itavs, i));
         if (itav == NULL
-                || !ossl_cmp_msg_gen_push0_ITAV(msg, itav)) {
+            || !ossl_cmp_msg_gen_push0_ITAV(msg, itav)) {
             OSSL_CMP_ITAV_free(itav);
             return 0;
         }
@@ -687,8 +732,8 @@ int ossl_cmp_msg_gen_push1_ITAVs(OSSL_CMP_MSG *msg,
  * returns a pointer to the PKIMessage on success, NULL on error
  */
 static OSSL_CMP_MSG *gen_new(OSSL_CMP_CTX *ctx,
-                             const STACK_OF(OSSL_CMP_ITAV) *itavs,
-                             int body_type, int err_code)
+    const STACK_OF(OSSL_CMP_ITAV) *itavs,
+    int body_type, int err_code)
 {
     OSSL_CMP_MSG *msg = NULL;
 
@@ -706,7 +751,7 @@ static OSSL_CMP_MSG *gen_new(OSSL_CMP_CTX *ctx,
 
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, err_code);
     OSSL_CMP_MSG_free(msg);
     return NULL;
@@ -715,19 +760,19 @@ static OSSL_CMP_MSG *gen_new(OSSL_CMP_CTX *ctx,
 OSSL_CMP_MSG *ossl_cmp_genm_new(OSSL_CMP_CTX *ctx)
 {
     return gen_new(ctx, ctx->genm_ITAVs,
-                   OSSL_CMP_PKIBODY_GENM, CMP_R_ERROR_CREATING_GENM);
+        OSSL_CMP_PKIBODY_GENM, CMP_R_ERROR_CREATING_GENM);
 }
 
 OSSL_CMP_MSG *ossl_cmp_genp_new(OSSL_CMP_CTX *ctx,
-                                const STACK_OF(OSSL_CMP_ITAV) *itavs)
+    const STACK_OF(OSSL_CMP_ITAV) *itavs)
 {
     return gen_new(ctx, itavs,
-                   OSSL_CMP_PKIBODY_GENP, CMP_R_ERROR_CREATING_GENP);
+        OSSL_CMP_PKIBODY_GENP, CMP_R_ERROR_CREATING_GENP);
 }
 
 OSSL_CMP_MSG *ossl_cmp_error_new(OSSL_CMP_CTX *ctx, const OSSL_CMP_PKISI *si,
-                                 int64_t errorCode, const char *details,
-                                 int unprotected)
+    int64_t errorCode, const char *details,
+    int unprotected)
 {
     OSSL_CMP_MSG *msg = NULL;
     const char *lib = NULL, *reason = NULL;
@@ -748,7 +793,7 @@ OSSL_CMP_MSG *ossl_cmp_error_new(OSSL_CMP_CTX *ctx, const OSSL_CMP_PKISI *si,
     if (!ASN1_INTEGER_set_int64(msg->body->value.error->errorCode, errorCode))
         goto err;
     if (errorCode > 0
-            && (uint64_t)errorCode < ((uint64_t)ERR_SYSTEM_FLAG << 1)) {
+        && (uint64_t)errorCode < ((uint64_t)ERR_SYSTEM_FLAG << 1)) {
         lib = ERR_lib_error_string((unsigned long)errorCode);
         reason = ERR_reason_error_string((unsigned long)errorCode);
     }
@@ -757,13 +802,13 @@ OSSL_CMP_MSG *ossl_cmp_error_new(OSSL_CMP_CTX *ctx, const OSSL_CMP_PKISI *si,
             goto err;
         msg->body->value.error->errorDetails = ft;
         if (lib != NULL && *lib != '\0'
-                && !ossl_cmp_sk_ASN1_UTF8STRING_push_str(ft, lib, -1))
+            && !ossl_cmp_sk_ASN1_UTF8STRING_push_str(ft, lib, -1))
             goto err;
         if (reason != NULL && *reason != '\0'
-                && !ossl_cmp_sk_ASN1_UTF8STRING_push_str(ft, reason, -1))
+            && !ossl_cmp_sk_ASN1_UTF8STRING_push_str(ft, reason, -1))
             goto err;
         if (details != NULL
-                && !ossl_cmp_sk_ASN1_UTF8STRING_push_str(ft, details, -1))
+            && !ossl_cmp_sk_ASN1_UTF8STRING_push_str(ft, details, -1))
             goto err;
     }
 
@@ -771,7 +816,7 @@ OSSL_CMP_MSG *ossl_cmp_error_new(OSSL_CMP_CTX *ctx, const OSSL_CMP_PKISI *si,
         goto err;
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_ERROR);
     OSSL_CMP_MSG_free(msg);
     return NULL;
@@ -783,7 +828,7 @@ OSSL_CMP_MSG *ossl_cmp_error_new(OSSL_CMP_CTX *ctx, const OSSL_CMP_PKISI *si,
  * to confirm that the certificate was received successfully.
  */
 int ossl_cmp_certstatus_set0_certHash(OSSL_CMP_CERTSTATUS *certStatus,
-                                      ASN1_OCTET_STRING *hash)
+    ASN1_OCTET_STRING *hash)
 {
     if (!ossl_assert(certStatus != NULL))
         return 0;
@@ -793,7 +838,7 @@ int ossl_cmp_certstatus_set0_certHash(OSSL_CMP_CERTSTATUS *certStatus,
 }
 
 OSSL_CMP_MSG *ossl_cmp_certConf_new(OSSL_CMP_CTX *ctx, int certReqId,
-                                    int fail_info, const char *text)
+    int fail_info, const char *text)
 {
     OSSL_CMP_MSG *msg = NULL;
     OSSL_CMP_CERTSTATUS *certStatus = NULL;
@@ -803,8 +848,8 @@ OSSL_CMP_MSG *ossl_cmp_certConf_new(OSSL_CMP_CTX *ctx, int certReqId,
     OSSL_CMP_PKISI *sinfo;
 
     if (!ossl_assert(ctx != NULL && ctx->newCert != NULL
-                     && (certReqId == OSSL_CMP_CERTREQID
-                         || certReqId == OSSL_CMP_CERTREQID_NONE)))
+            && (certReqId == OSSL_CMP_CERTREQID
+                || certReqId == OSSL_CMP_CERTREQID_NONE)))
         return NULL;
 
     if ((unsigned)fail_info > OSSL_CMP_PKIFAILUREINFO_MAX_BIT_PATTERN) {
@@ -854,9 +899,7 @@ OSSL_CMP_MSG *ossl_cmp_certConf_new(OSSL_CMP_CTX *ctx, int certReqId,
      * be provided in the statusInfo field, perhaps for auditing purposes at
      * the CA/RA.
      */
-    sinfo = fail_info != 0 ?
-        OSSL_CMP_STATUSINFO_new(OSSL_CMP_PKISTATUS_rejection, fail_info, text) :
-        OSSL_CMP_STATUSINFO_new(OSSL_CMP_PKISTATUS_accepted, 0, text);
+    sinfo = fail_info != 0 ? OSSL_CMP_STATUSINFO_new(OSSL_CMP_PKISTATUS_rejection, fail_info, text) : OSSL_CMP_STATUSINFO_new(OSSL_CMP_PKISTATUS_accepted, 0, text);
     if (sinfo == NULL)
         goto err;
     certStatus->statusInfo = sinfo;
@@ -866,7 +909,7 @@ OSSL_CMP_MSG *ossl_cmp_certConf_new(OSSL_CMP_CTX *ctx, int certReqId,
 
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_CERTCONF);
     OSSL_CMP_MSG_free(msg);
     ASN1_OCTET_STRING_free(certHash);
@@ -885,8 +928,8 @@ OSSL_CMP_MSG *ossl_cmp_pollReq_new(OSSL_CMP_CTX *ctx, int crid)
         goto err;
 
     if ((preq = OSSL_CMP_POLLREQ_new()) == NULL
-            || !ASN1_INTEGER_set(preq->certReqId, crid)
-            || !sk_OSSL_CMP_POLLREQ_push(msg->body->value.pollReq, preq))
+        || !ASN1_INTEGER_set(preq->certReqId, crid)
+        || !sk_OSSL_CMP_POLLREQ_push(msg->body->value.pollReq, preq))
         goto err;
 
     preq = NULL;
@@ -895,7 +938,7 @@ OSSL_CMP_MSG *ossl_cmp_pollReq_new(OSSL_CMP_CTX *ctx, int crid)
 
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_POLLREQ);
     OSSL_CMP_POLLREQ_free(preq);
     OSSL_CMP_MSG_free(msg);
@@ -903,7 +946,7 @@ OSSL_CMP_MSG *ossl_cmp_pollReq_new(OSSL_CMP_CTX *ctx, int crid)
 }
 
 OSSL_CMP_MSG *ossl_cmp_pollRep_new(OSSL_CMP_CTX *ctx, int crid,
-                                   int64_t poll_after)
+    int64_t poll_after)
 {
     OSSL_CMP_MSG *msg;
     OSSL_CMP_POLLREP *prep;
@@ -926,7 +969,7 @@ OSSL_CMP_MSG *ossl_cmp_pollRep_new(OSSL_CMP_CTX *ctx, int crid,
         goto err;
     return msg;
 
- err:
+err:
     ERR_raise(ERR_LIB_CMP, CMP_R_ERROR_CREATING_POLLREP);
     OSSL_CMP_MSG_free(msg);
     return NULL;
@@ -984,8 +1027,7 @@ static int suitable_rid(const ASN1_INTEGER *certReqId, int rid)
         return 1;
 
     trid = ossl_cmp_asn1_get_int(certReqId);
-
-    if (trid == OSSL_CMP_CERTREQID_NONE) {
+    if (trid <= OSSL_CMP_CERTREQID_INVALID) {
         ERR_raise(ERR_LIB_CMP, CMP_R_BAD_REQUEST_ID);
         return 0;
     }
@@ -999,7 +1041,7 @@ static int suitable_rid(const ASN1_INTEGER *certReqId, int rid)
  */
 OSSL_CMP_POLLREP *
 ossl_cmp_pollrepcontent_get0_pollrep(const OSSL_CMP_POLLREPCONTENT *prc,
-                                     int rid)
+    int rid)
 {
     OSSL_CMP_POLLREP *pollRep = NULL;
     int i;
@@ -1014,7 +1056,7 @@ ossl_cmp_pollrepcontent_get0_pollrep(const OSSL_CMP_POLLREPCONTENT *prc,
     }
 
     ERR_raise_data(ERR_LIB_CMP, CMP_R_CERTRESPONSE_NOT_FOUND,
-                   "expected certReqId = %d", rid);
+        "expected certReqId = %d", rid);
     return NULL;
 }
 
@@ -1025,7 +1067,7 @@ ossl_cmp_pollrepcontent_get0_pollrep(const OSSL_CMP_POLLREPCONTENT *prc,
  */
 OSSL_CMP_CERTRESPONSE *
 ossl_cmp_certrepmessage_get0_certresponse(const OSSL_CMP_CERTREPMESSAGE *crm,
-                                          int rid)
+    int rid)
 {
     OSSL_CMP_CERTRESPONSE *crep = NULL;
     int i;
@@ -1040,7 +1082,7 @@ ossl_cmp_certrepmessage_get0_certresponse(const OSSL_CMP_CERTREPMESSAGE *crm,
     }
 
     ERR_raise_data(ERR_LIB_CMP, CMP_R_CERTRESPONSE_NOT_FOUND,
-                   "expected certReqId = %d", rid);
+        "expected certReqId = %d", rid);
     return NULL;
 }
 
@@ -1050,7 +1092,7 @@ ossl_cmp_certrepmessage_get0_certresponse(const OSSL_CMP_CERTREPMESSAGE *crm,
  * Returns a pointer to a copy of the found certificate, or NULL if not found.
  */
 X509 *ossl_cmp_certresponse_get1_cert(const OSSL_CMP_CTX *ctx,
-                                      const OSSL_CMP_CERTRESPONSE *crep)
+    const OSSL_CMP_CERTRESPONSE *crep)
 {
     OSSL_CMP_CERTORENCCERT *coec;
     X509 *crt = NULL;
@@ -1060,7 +1102,7 @@ X509 *ossl_cmp_certresponse_get1_cert(const OSSL_CMP_CTX *ctx,
         return NULL;
 
     if (crep->certifiedKeyPair
-            && (coec = crep->certifiedKeyPair->certOrEncCert) != NULL) {
+        && (coec = crep->certifiedKeyPair->certOrEncCert) != NULL) {
         switch (coec->type) {
         case OSSL_CMP_CERTORENCCERT_CERTIFICATE:
             crt = X509_dup(coec->value.certificate);
@@ -1073,10 +1115,9 @@ X509 *ossl_cmp_certresponse_get1_cert(const OSSL_CMP_CTX *ctx,
                 ERR_raise(ERR_LIB_CMP, CMP_R_MISSING_PRIVATE_KEY);
                 return NULL;
             }
-            crt =
-                OSSL_CRMF_ENCRYPTEDVALUE_get1_encCert(coec->value.encryptedCert,
-                                                      ctx->libctx, ctx->propq,
-                                                      pkey);
+            crt = OSSL_CRMF_ENCRYPTEDVALUE_get1_encCert(coec->value.encryptedCert,
+                ctx->libctx, ctx->propq,
+                pkey);
             break;
         default:
             ERR_raise(ERR_LIB_CMP, CMP_R_UNKNOWN_CERT_TYPE);
@@ -1099,7 +1140,7 @@ int OSSL_CMP_MSG_update_transactionID(OSSL_CMP_CTX *ctx, OSSL_CMP_MSG *msg)
     if (!ossl_cmp_hdr_set_transactionID(ctx, msg->header))
         return 0;
     return msg->header->protectionAlg == NULL
-            || ossl_cmp_msg_protect(ctx, msg);
+        || ossl_cmp_msg_protect(ctx, msg);
 }
 
 int OSSL_CMP_MSG_update_recipNonce(OSSL_CMP_CTX *ctx, OSSL_CMP_MSG *msg)
@@ -1111,13 +1152,13 @@ int OSSL_CMP_MSG_update_recipNonce(OSSL_CMP_CTX *ctx, OSSL_CMP_MSG *msg)
     if (ctx->recipNonce == NULL) /* nothing to do for 1st msg in transaction */
         return 1;
     if (!ossl_cmp_asn1_octet_string_set1(&msg->header->recipNonce,
-                                         ctx->recipNonce))
+            ctx->recipNonce))
         return 0;
     return msg->header->protectionAlg == NULL || ossl_cmp_msg_protect(ctx, msg);
 }
 
 OSSL_CMP_MSG *OSSL_CMP_MSG_read(const char *file, OSSL_LIB_CTX *libctx,
-                                const char *propq)
+    const char *propq)
 {
     OSSL_CMP_MSG *msg;
     BIO *bio = NULL;
@@ -1134,7 +1175,7 @@ OSSL_CMP_MSG *OSSL_CMP_MSG_read(const char *file, OSSL_LIB_CTX *libctx,
     }
 
     if ((bio = BIO_new_file(file, "rb")) == NULL
-            || d2i_OSSL_CMP_MSG_bio(bio, &msg) == NULL) {
+        || d2i_OSSL_CMP_MSG_bio(bio, &msg) == NULL) {
         OSSL_CMP_MSG_free(msg);
         msg = NULL;
     }
@@ -1161,25 +1202,25 @@ int OSSL_CMP_MSG_write(const char *file, const OSSL_CMP_MSG *msg)
 }
 
 OSSL_CMP_MSG *d2i_OSSL_CMP_MSG(OSSL_CMP_MSG **msg, const unsigned char **in,
-                               long len)
+    long len)
 {
     OSSL_LIB_CTX *libctx = NULL;
     const char *propq = NULL;
 
     if (msg != NULL && *msg != NULL) {
-        libctx  = (*msg)->libctx;
+        libctx = (*msg)->libctx;
         propq = (*msg)->propq;
     }
 
     return (OSSL_CMP_MSG *)ASN1_item_d2i_ex((ASN1_VALUE **)msg, in, len,
-                                            ASN1_ITEM_rptr(OSSL_CMP_MSG),
-                                            libctx, propq);
+        ASN1_ITEM_rptr(OSSL_CMP_MSG),
+        libctx, propq);
 }
 
 int i2d_OSSL_CMP_MSG(const OSSL_CMP_MSG *msg, unsigned char **out)
 {
     return ASN1_item_i2d((const ASN1_VALUE *)msg, out,
-                         ASN1_ITEM_rptr(OSSL_CMP_MSG));
+        ASN1_ITEM_rptr(OSSL_CMP_MSG));
 }
 
 OSSL_CMP_MSG *d2i_OSSL_CMP_MSG_bio(BIO *bio, OSSL_CMP_MSG **msg)
@@ -1188,15 +1229,25 @@ OSSL_CMP_MSG *d2i_OSSL_CMP_MSG_bio(BIO *bio, OSSL_CMP_MSG **msg)
     const char *propq = NULL;
 
     if (msg != NULL && *msg != NULL) {
-        libctx  = (*msg)->libctx;
+        libctx = (*msg)->libctx;
         propq = (*msg)->propq;
     }
 
     return ASN1_item_d2i_bio_ex(ASN1_ITEM_rptr(OSSL_CMP_MSG), bio, msg, libctx,
-                                propq);
+        propq);
 }
 
 int i2d_OSSL_CMP_MSG_bio(BIO *bio, const OSSL_CMP_MSG *msg)
 {
     return ASN1_i2d_bio_of(OSSL_CMP_MSG, i2d_OSSL_CMP_MSG, bio, msg);
 }
+
+int ossl_cmp_is_error_with_waiting(const OSSL_CMP_MSG *msg)
+{
+    if (!ossl_assert(msg != NULL))
+        return 0;
+
+    return (OSSL_CMP_MSG_get_bodytype(msg) == OSSL_CMP_PKIBODY_ERROR
+        && ossl_cmp_pkisi_get_status(msg->body->value.error->pKIStatusInfo)
+            == OSSL_CMP_PKISTATUS_waiting);
+}
