@@ -42,8 +42,7 @@ static CMS_SignedData *cms_signed_data_init(CMS_ContentInfo *cms)
             return NULL;
         }
         cms->d.signedData->version = 1;
-        cms->d.signedData->encapContentInfo->eContentType =
-            OBJ_nid2obj(NID_pkcs7_data);
+        cms->d.signedData->encapContentInfo->eContentType = OBJ_nid2obj(NID_pkcs7_data);
         cms->d.signedData->encapContentInfo->partial = 1;
         ASN1_OBJECT_free(cms->contentType);
         cms->contentType = OBJ_nid2obj(NID_pkcs7_signed);
@@ -109,7 +108,6 @@ static void cms_sd_set_version(CMS_SignedData *sd)
 
     if (sd->version < 1)
         sd->version = 1;
-
 }
 
 /*
@@ -130,7 +128,8 @@ static int cms_set_si_contentType_attr(CMS_ContentInfo *cms, CMS_SignerInfo *si)
 
     /* Add the contentType attribute */
     return CMS_signed_add1_attr_by_NID(si, NID_pkcs9_contentType,
-                                       V_ASN1_OBJECT, ctype, -1) > 0;
+               V_ASN1_OBJECT, ctype, -1)
+        > 0;
 }
 
 /* Copy an existing messageDigest value */
@@ -150,20 +149,19 @@ static int cms_copy_messageDigest(CMS_ContentInfo *cms, CMS_SignerInfo *si)
         if (CMS_signed_get_attr_count(sitmp) < 0)
             continue;
         if (OBJ_cmp(si->digestAlgorithm->algorithm,
-                    sitmp->digestAlgorithm->algorithm))
+                sitmp->digestAlgorithm->algorithm))
             continue;
         messageDigest = CMS_signed_get0_data_by_OBJ(sitmp,
-                                                    OBJ_nid2obj
-                                                    (NID_pkcs9_messageDigest),
-                                                    -3, V_ASN1_OCTET_STRING);
+            OBJ_nid2obj(NID_pkcs9_messageDigest),
+            -3, V_ASN1_OCTET_STRING);
         if (!messageDigest) {
             ERR_raise(ERR_LIB_CMS, CMS_R_ERROR_READING_MESSAGEDIGEST_ATTRIBUTE);
             return 0;
         }
 
         if (CMS_signed_add1_attr_by_NID(si, NID_pkcs9_messageDigest,
-                                        V_ASN1_OCTET_STRING,
-                                        messageDigest, -1))
+                V_ASN1_OCTET_STRING,
+                messageDigest, -1))
             return 1;
         else
             return 0;
@@ -173,7 +171,7 @@ static int cms_copy_messageDigest(CMS_ContentInfo *cms, CMS_SignerInfo *si)
 }
 
 int ossl_cms_set1_SignerIdentifier(CMS_SignerIdentifier *sid, X509 *cert,
-                                   int type, const CMS_CTX *ctx)
+    int type, const CMS_CTX *ctx)
 {
     switch (type) {
     case CMS_SIGNERINFO_ISSUER_SERIAL:
@@ -197,9 +195,9 @@ int ossl_cms_set1_SignerIdentifier(CMS_SignerIdentifier *sid, X509 *cert,
 }
 
 int ossl_cms_SignerIdentifier_get0_signer_id(CMS_SignerIdentifier *sid,
-                                             ASN1_OCTET_STRING **keyid,
-                                             X509_NAME **issuer,
-                                             ASN1_INTEGER **sno)
+    ASN1_OCTET_STRING **keyid,
+    X509_NAME **issuer,
+    ASN1_INTEGER **sno)
 {
     if (sid->type == CMS_SIGNERINFO_ISSUER_SERIAL) {
         if (issuer)
@@ -283,7 +281,7 @@ static int cms_sd_asn1_ctrl(CMS_SignerInfo *si, int cmd)
 
 /* Add SigningCertificate signed attribute to the signer info. */
 static int ossl_cms_add1_signing_cert(CMS_SignerInfo *si,
-                                      const ESS_SIGNING_CERT *sc)
+    const ESS_SIGNING_CERT *sc)
 {
     ASN1_STRING *seq = NULL;
     unsigned char *p, *pp = NULL;
@@ -301,14 +299,14 @@ static int ossl_cms_add1_signing_cert(CMS_SignerInfo *si,
     }
     OPENSSL_free(pp);
     ret = CMS_signed_add1_attr_by_NID(si, NID_id_smime_aa_signingCertificate,
-                                      V_ASN1_SEQUENCE, seq, -1);
+        V_ASN1_SEQUENCE, seq, -1);
     ASN1_STRING_free(seq);
     return ret;
 }
 
 /* Add SigningCertificateV2 signed attribute to the signer info. */
 static int ossl_cms_add1_signing_cert_v2(CMS_SignerInfo *si,
-                                         const ESS_SIGNING_CERT_V2 *sc)
+    const ESS_SIGNING_CERT_V2 *sc)
 {
     ASN1_STRING *seq = NULL;
     unsigned char *p, *pp = NULL;
@@ -326,14 +324,14 @@ static int ossl_cms_add1_signing_cert_v2(CMS_SignerInfo *si,
     }
     OPENSSL_free(pp);
     ret = CMS_signed_add1_attr_by_NID(si, NID_id_smime_aa_signingCertificateV2,
-                                      V_ASN1_SEQUENCE, seq, -1);
+        V_ASN1_SEQUENCE, seq, -1);
     ASN1_STRING_free(seq);
     return ret;
 }
 
 CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
-                                X509 *signer, EVP_PKEY *pk, const EVP_MD *md,
-                                unsigned int flags)
+    X509 *signer, EVP_PKEY *pk, const EVP_MD *md,
+    unsigned int flags)
 {
     CMS_SignedData *sd;
     CMS_SignerInfo *si = NULL;
@@ -388,13 +386,13 @@ CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
 
         if (EVP_PKEY_get_default_digest_nid(pk, &def_nid) <= 0) {
             ERR_raise_data(ERR_LIB_CMS, CMS_R_NO_DEFAULT_DIGEST,
-                           "pkey nid=%d", EVP_PKEY_get_id(pk));
+                "pkey nid=%d", EVP_PKEY_get_id(pk));
             goto err;
         }
         md = EVP_get_digestbynid(def_nid);
         if (md == NULL) {
             ERR_raise_data(ERR_LIB_CMS, CMS_R_NO_DEFAULT_DIGEST,
-                           "default md nid=%d", def_nid);
+                "default md nid=%d", def_nid);
             goto err;
         }
     }
@@ -428,7 +426,7 @@ CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
 
     if (!(flags & CMS_KEY_PARAM) && !cms_sd_asn1_ctrl(si, 0)) {
         ERR_raise_data(ERR_LIB_CMS, CMS_R_UNSUPPORTED_SIGNATURE_ALGORITHM,
-                       "pkey nid=%d", EVP_PKEY_get_id(pk));
+            "pkey nid=%d", EVP_PKEY_get_id(pk));
         goto err;
     }
     if (!(flags & CMS_NOATTR)) {
@@ -463,13 +461,15 @@ CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
 
             if (md == NULL || EVP_MD_is_a(md, SN_sha1)) {
                 if ((sc = OSSL_ESS_signing_cert_new_init(signer,
-                                                         NULL, 1)) == NULL)
+                         NULL, 1))
+                    == NULL)
                     goto err;
                 add_sc = ossl_cms_add1_signing_cert(si, sc);
                 ESS_SIGNING_CERT_free(sc);
             } else {
                 if ((sc2 = OSSL_ESS_signing_cert_v2_new_init(md, signer,
-                                                             NULL, 1)) == NULL)
+                         NULL, 1))
+                    == NULL)
                     goto err;
                 add_sc = ossl_cms_add1_signing_cert_v2(si, sc2);
                 ESS_SIGNING_CERT_V2_free(sc2);
@@ -482,8 +482,7 @@ CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
                 goto err;
             if (!cms_set_si_contentType_attr(cms, si))
                 goto err;
-            if (!(flags & (CMS_PARTIAL | CMS_KEY_PARAM)) &&
-                !CMS_SignerInfo_sign(si))
+            if (!(flags & (CMS_PARTIAL | CMS_KEY_PARAM)) && !CMS_SignerInfo_sign(si))
                 goto err;
         }
     }
@@ -499,8 +498,8 @@ CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
     if (flags & CMS_KEY_PARAM) {
         if (flags & CMS_NOATTR) {
             si->pctx = EVP_PKEY_CTX_new_from_pkey(ossl_cms_ctx_get0_libctx(ctx),
-                                                  si->pkey,
-                                                  ossl_cms_ctx_get0_propq(ctx));
+                si->pkey,
+                ossl_cms_ctx_get0_propq(ctx));
             if (si->pctx == NULL)
                 goto err;
             if (EVP_PKEY_sign_init(si->pctx) <= 0)
@@ -508,14 +507,14 @@ CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
             if (EVP_PKEY_CTX_set_signature_md(si->pctx, md) <= 0)
                 goto err;
         } else if (EVP_DigestSignInit_ex(si->mctx, &si->pctx,
-                                         EVP_MD_get0_name(md),
-                                         ossl_cms_ctx_get0_libctx(ctx),
-                                         ossl_cms_ctx_get0_propq(ctx),
-                                         pk, NULL) <= 0) {
+                       EVP_MD_get0_name(md),
+                       ossl_cms_ctx_get0_libctx(ctx),
+                       ossl_cms_ctx_get0_propq(ctx),
+                       pk, NULL)
+            <= 0) {
             si->pctx = NULL;
             goto err;
-        }
-        else {
+        } else {
             EVP_MD_CTX_set_flags(si->mctx, EVP_MD_CTX_FLAG_KEEP_PKEY_CTX);
         }
     }
@@ -529,10 +528,9 @@ CMS_SignerInfo *CMS_add1_signer(CMS_ContentInfo *cms,
 
     return si;
 
- err:
+err:
     M_ASN1_free_of(si, CMS_SignerInfo);
     return NULL;
-
 }
 
 void ossl_cms_SignerInfos_set_cmsctx(CMS_ContentInfo *cms)
@@ -569,18 +567,18 @@ static int cms_add1_signingTime(CMS_SignerInfo *si, ASN1_TIME *t)
     }
 
     if (CMS_signed_add1_attr_by_NID(si, NID_pkcs9_signingTime,
-                                    tt->type, tt, -1) <= 0) {
+            tt->type, tt, -1)
+        <= 0) {
         ERR_raise(ERR_LIB_CMS, ERR_R_CMS_LIB);
         goto err;
     }
 
     r = 1;
- err:
+err:
     if (t == NULL)
         ASN1_TIME_free(tt);
 
     return r;
-
 }
 
 EVP_PKEY_CTX *CMS_SignerInfo_get0_pkey_ctx(CMS_SignerInfo *si)
@@ -612,7 +610,7 @@ STACK_OF(X509) *CMS_get0_signers(CMS_ContentInfo *cms)
         si = sk_CMS_SignerInfo_value(sinfos, i);
         if (si->signer != NULL) {
             if (!ossl_x509_add_cert_new(&signers, si->signer,
-                                        X509_ADD_FLAG_DEFAULT)) {
+                    X509_ADD_FLAG_DEFAULT)) {
                 sk_X509_free(signers);
                 return NULL;
             }
@@ -633,8 +631,8 @@ void CMS_SignerInfo_set1_signer_cert(CMS_SignerInfo *si, X509 *signer)
 }
 
 int CMS_SignerInfo_get0_signer_id(CMS_SignerInfo *si,
-                                  ASN1_OCTET_STRING **keyid,
-                                  X509_NAME **issuer, ASN1_INTEGER **sno)
+    ASN1_OCTET_STRING **keyid,
+    X509_NAME **issuer, ASN1_INTEGER **sno)
 {
     return ossl_cms_SignerIdentifier_get0_signer_id(si->sid, keyid, issuer, sno);
 }
@@ -645,7 +643,7 @@ int CMS_SignerInfo_cert_cmp(CMS_SignerInfo *si, X509 *cert)
 }
 
 int CMS_set1_signers_certs(CMS_ContentInfo *cms, STACK_OF(X509) *scerts,
-                           unsigned int flags)
+    unsigned int flags)
 {
     CMS_SignedData *sd;
     CMS_SignerInfo *si;
@@ -692,8 +690,8 @@ int CMS_set1_signers_certs(CMS_ContentInfo *cms, STACK_OF(X509) *scerts,
 }
 
 void CMS_SignerInfo_get0_algs(CMS_SignerInfo *si, EVP_PKEY **pk,
-                              X509 **signer, X509_ALGOR **pdig,
-                              X509_ALGOR **psig)
+    X509 **signer, X509_ALGOR **pdig,
+    X509_ALGOR **psig)
 {
     if (pk != NULL)
         *pk = si->pkey;
@@ -711,9 +709,9 @@ ASN1_OCTET_STRING *CMS_SignerInfo_get0_signature(CMS_SignerInfo *si)
 }
 
 static int cms_SignerInfo_content_sign(CMS_ContentInfo *cms,
-                                       CMS_SignerInfo *si, BIO *chain,
-                                       const unsigned char *md,
-                                       unsigned int mdlen)
+    CMS_SignerInfo *si, BIO *chain,
+    const unsigned char *md,
+    unsigned int mdlen)
 {
     EVP_MD_CTX *mctx = EVP_MD_CTX_new();
     int r = 0;
@@ -748,7 +746,7 @@ static int cms_SignerInfo_content_sign(CMS_ContentInfo *cms,
             md = computed_md;
         }
         if (!CMS_signed_add1_attr_by_NID(si, NID_pkcs9_messageDigest,
-                                         V_ASN1_OCTET_STRING, md, mdlen))
+                V_ASN1_OCTET_STRING, md, mdlen))
             goto err;
         /* Copy content type across */
         if (!cms_set_si_contentType_attr(cms, si))
@@ -788,8 +786,8 @@ static int cms_SignerInfo_content_sign(CMS_ContentInfo *cms,
         if (siglen == 0 || (sig = OPENSSL_malloc(siglen)) == NULL)
             goto err;
         if (!EVP_SignFinal_ex(mctx, sig, &siglen, si->pkey,
-                              ossl_cms_ctx_get0_libctx(ctx),
-                              ossl_cms_ctx_get0_propq(ctx))) {
+                ossl_cms_ctx_get0_libctx(ctx),
+                ossl_cms_ctx_get0_propq(ctx))) {
             ERR_raise(ERR_LIB_CMS, CMS_R_SIGNFINAL_ERROR);
             OPENSSL_free(sig);
             goto err;
@@ -799,16 +797,15 @@ static int cms_SignerInfo_content_sign(CMS_ContentInfo *cms,
 
     r = 1;
 
- err:
+err:
     EVP_MD_CTX_free(mctx);
     EVP_PKEY_CTX_free(pctx);
     return r;
-
 }
 
 int ossl_cms_SignedData_final(CMS_ContentInfo *cms, BIO *chain,
-                              const unsigned char *precomp_md,
-                              unsigned int precomp_mdlen)
+    const unsigned char *precomp_md,
+    unsigned int precomp_mdlen)
 {
     STACK_OF(CMS_SignerInfo) *sinfos;
     CMS_SignerInfo *si;
@@ -818,7 +815,7 @@ int ossl_cms_SignedData_final(CMS_ContentInfo *cms, BIO *chain,
     for (i = 0; i < sk_CMS_SignerInfo_num(sinfos); i++) {
         si = sk_CMS_SignerInfo_value(sinfos, i);
         if (!cms_SignerInfo_content_sign(cms, si, chain,
-                                         precomp_md, precomp_mdlen))
+                precomp_md, precomp_mdlen))
             return 0;
     }
     cms->d.signedData->encapContentInfo->partial = 0;
@@ -836,7 +833,8 @@ int CMS_SignerInfo_sign(CMS_SignerInfo *si)
     char md_name[OSSL_MAX_NAME_SIZE];
 
     if (OBJ_obj2txt(md_name, sizeof(md_name),
-                    si->digestAlgorithm->algorithm, 0) <= 0)
+            si->digestAlgorithm->algorithm, 0)
+        <= 0)
         return 0;
 
     if (CMS_signed_get_attr_by_NID(si, NID_pkcs9_signingTime, -1) < 0) {
@@ -852,16 +850,17 @@ int CMS_SignerInfo_sign(CMS_SignerInfo *si)
     } else {
         EVP_MD_CTX_reset(mctx);
         if (EVP_DigestSignInit_ex(mctx, &pctx, md_name,
-                                  ossl_cms_ctx_get0_libctx(ctx),
-                                  ossl_cms_ctx_get0_propq(ctx), si->pkey,
-                                  NULL) <= 0)
+                ossl_cms_ctx_get0_libctx(ctx),
+                ossl_cms_ctx_get0_propq(ctx), si->pkey,
+                NULL)
+            <= 0)
             goto err;
         EVP_MD_CTX_set_flags(mctx, EVP_MD_CTX_FLAG_KEEP_PKEY_CTX);
         si->pctx = pctx;
     }
 
     alen = ASN1_item_i2d((ASN1_VALUE *)si->signedAttrs, &abuf,
-                         ASN1_ITEM_rptr(CMS_Attributes_Sign));
+        ASN1_ITEM_rptr(CMS_Attributes_Sign));
     if (!abuf)
         goto err;
     if (EVP_DigestSignUpdate(mctx, abuf, alen) <= 0)
@@ -881,7 +880,7 @@ int CMS_SignerInfo_sign(CMS_SignerInfo *si)
 
     return 1;
 
- err:
+err:
     OPENSSL_free(abuf);
     EVP_MD_CTX_reset(mctx);
     return 0;
@@ -933,7 +932,8 @@ int CMS_SignerInfo_verify(CMS_SignerInfo *si)
         si->pctx = NULL;
     }
     if (EVP_DigestVerifyInit_ex(mctx, &si->pctx, EVP_MD_get0_name(md), libctx,
-                                propq, si->pkey, NULL) <= 0) {
+            propq, si->pkey, NULL)
+        <= 0) {
         si->pctx = NULL;
         goto err;
     }
@@ -943,7 +943,7 @@ int CMS_SignerInfo_verify(CMS_SignerInfo *si)
         goto err;
 
     alen = ASN1_item_i2d((ASN1_VALUE *)si->signedAttrs, &abuf,
-                         ASN1_ITEM_rptr(CMS_Attributes_Verify));
+        ASN1_ITEM_rptr(CMS_Attributes_Verify));
     if (abuf == NULL || alen < 0)
         goto err;
     r = EVP_DigestVerifyUpdate(mctx, abuf, alen);
@@ -953,10 +953,10 @@ int CMS_SignerInfo_verify(CMS_SignerInfo *si)
         goto err;
     }
     r = EVP_DigestVerifyFinal(mctx,
-                              si->signature->data, si->signature->length);
+        si->signature->data, si->signature->length);
     if (r <= 0)
         ERR_raise(ERR_LIB_CMS, CMS_R_VERIFICATION_FAILURE);
- err:
+err:
     EVP_MD_free(fetched_md);
     EVP_MD_CTX_reset(mctx);
     return r;
@@ -980,7 +980,7 @@ BIO *ossl_cms_SignedData_init_bio(CMS_ContentInfo *cms)
 
         digestAlgorithm = sk_X509_ALGOR_value(sd->digestAlgorithms, i);
         mdbio = ossl_cms_DigestAlgorithm_init_bio(digestAlgorithm,
-                                                  ossl_cms_get0_cmsctx(cms));
+            ossl_cms_get0_cmsctx(cms));
         if (mdbio == NULL)
             goto err;
         if (chain != NULL)
@@ -989,7 +989,7 @@ BIO *ossl_cms_SignedData_init_bio(CMS_ContentInfo *cms)
             chain = mdbio;
     }
     return chain;
- err:
+err:
     BIO_free_all(chain);
     return NULL;
 }
@@ -1010,8 +1010,8 @@ int CMS_SignerInfo_verify_content(CMS_SignerInfo *si, BIO *chain)
     /* If we have any signed attributes look for messageDigest value */
     if (CMS_signed_get_attr_count(si) >= 0) {
         os = CMS_signed_get0_data_by_OBJ(si,
-                                         OBJ_nid2obj(NID_pkcs9_messageDigest),
-                                         -3, V_ASN1_OCTET_STRING);
+            OBJ_nid2obj(NID_pkcs9_messageDigest),
+            -3, V_ASN1_OCTET_STRING);
         if (os == NULL) {
             ERR_raise(ERR_LIB_CMS, CMS_R_ERROR_READING_MESSAGEDIGEST_ATTRIBUTE);
             goto err;
@@ -1044,8 +1044,8 @@ int CMS_SignerInfo_verify_content(CMS_SignerInfo *si, BIO *chain)
         const CMS_CTX *ctx = si->cms_ctx;
 
         pkctx = EVP_PKEY_CTX_new_from_pkey(ossl_cms_ctx_get0_libctx(ctx),
-                                           si->pkey,
-                                           ossl_cms_ctx_get0_propq(ctx));
+            si->pkey,
+            ossl_cms_ctx_get0_propq(ctx));
         if (pkctx == NULL)
             goto err;
         if (EVP_PKEY_verify_init(pkctx) <= 0)
@@ -1059,25 +1059,24 @@ int CMS_SignerInfo_verify_content(CMS_SignerInfo *si, BIO *chain)
         }
         si->pctx = NULL;
         r = EVP_PKEY_verify(pkctx, si->signature->data,
-                            si->signature->length, mval, mlen);
+            si->signature->length, mval, mlen);
         if (r <= 0) {
             ERR_raise(ERR_LIB_CMS, CMS_R_VERIFICATION_FAILURE);
             r = 0;
         }
     }
 
- err:
+err:
     EVP_PKEY_CTX_free(pkctx);
     EVP_MD_CTX_free(mctx);
     return r;
-
 }
 
 BIO *CMS_SignedData_verify(CMS_SignedData *sd, BIO *detached_data,
-                           STACK_OF(X509) *scerts, X509_STORE *store,
-                           STACK_OF(X509) *extra, STACK_OF(X509_CRL) *crls,
-                           unsigned int flags,
-                           OSSL_LIB_CTX *libctx, const char *propq)
+    STACK_OF(X509) *scerts, X509_STORE *store,
+    STACK_OF(X509) *extra, STACK_OF(X509_CRL) *crls,
+    unsigned int flags,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     CMS_ContentInfo *ci;
     BIO *bio = NULL;
@@ -1103,7 +1102,7 @@ BIO *CMS_SignedData_verify(CMS_SignedData *sd, BIO *detached_data,
             goto end;
     res = CMS_verify(ci, scerts, store, detached_data, bio, flags);
 
- end:
+end:
     if (ci != NULL)
         ci->d.signedData = NULL; /* do not indirectly free |sd| */
     CMS_ContentInfo_free(ci);
@@ -1123,13 +1122,13 @@ int CMS_add_smimecap(CMS_SignerInfo *si, STACK_OF(X509_ALGOR) *algs)
     if (smderlen <= 0)
         return 0;
     r = CMS_signed_add1_attr_by_NID(si, NID_SMIMECapabilities,
-                                    V_ASN1_SEQUENCE, smder, smderlen);
+        V_ASN1_SEQUENCE, smder, smderlen);
     OPENSSL_free(smder);
     return r;
 }
 
 int CMS_add_simple_smimecap(STACK_OF(X509_ALGOR) **algs,
-                            int algnid, int keysize)
+    int algnid, int keysize)
 {
     X509_ALGOR *alg;
     ASN1_INTEGER *key = NULL;
@@ -1141,8 +1140,7 @@ int CMS_add_simple_smimecap(STACK_OF(X509_ALGOR) **algs,
             return 0;
         }
     }
-    alg = ossl_X509_ALGOR_from_nid(algnid, key != NULL ? V_ASN1_INTEGER :
-                                   V_ASN1_UNDEF, key);
+    alg = ossl_X509_ALGOR_from_nid(algnid, key != NULL ? V_ASN1_INTEGER : V_ASN1_UNDEF, key);
     if (alg == NULL) {
         ASN1_INTEGER_free(key);
         return 0;
