@@ -23,20 +23,16 @@
 #define C448_WNAF_FIXED_TABLE_BITS 5
 #define C448_WNAF_VAR_TABLE_BITS 3
 
-#define EDWARDS_D       (-39081)
+#define EDWARDS_D (-39081)
 
 static const curve448_scalar_t precomputed_scalarmul_adjustment = {
-    {
-        {
-            SC_LIMB(0xc873d6d54a7bb0cfULL), SC_LIMB(0xe933d8d723a70aadULL),
-            SC_LIMB(0xbb124b65129c96fdULL), SC_LIMB(0x00000008335dc163ULL)
-        }
-    }
+    { { SC_LIMB(0xc873d6d54a7bb0cfULL), SC_LIMB(0xe933d8d723a70aadULL),
+        SC_LIMB(0xbb124b65129c96fdULL), SC_LIMB(0x00000008335dc163ULL) } }
 };
 
 #define TWISTED_D (EDWARDS_D - 1)
 
-#define WBITS C448_WORD_BITS   /* NB this may be different from ARCH_WORD_BITS */
+#define WBITS C448_WORD_BITS /* NB this may be different from ARCH_WORD_BITS */
 
 /* Inverse. */
 static void gf_invert(gf y, const gf x, int assert_nonzero)
@@ -44,37 +40,36 @@ static void gf_invert(gf y, const gf x, int assert_nonzero)
     mask_t ret;
     gf t1, t2;
 
-    ossl_gf_sqr(t1, x);              /* o^2 */
-    ret = gf_isr(t2, t1);       /* +-1/sqrt(o^2) = +-1/o */
+    ossl_gf_sqr(t1, x); /* o^2 */
+    ret = gf_isr(t2, t1); /* +-1/sqrt(o^2) = +-1/o */
     (void)ret;
     if (assert_nonzero)
         assert(ret);
     ossl_gf_sqr(t1, t2);
-    ossl_gf_mul(t2, t1, x);          /* not direct to y in case of alias. */
+    ossl_gf_mul(t2, t1, x); /* not direct to y in case of alias. */
     gf_copy(y, t2);
 }
 
 /** identity = (0,1) */
-const curve448_point_t ossl_curve448_point_identity =
-    { {{{{0}}}, {{{1}}}, {{{1}}}, {{{0}}}} };
+const curve448_point_t ossl_curve448_point_identity = { { { { { 0 } } }, { { { 1 } } }, { { { 1 } } }, { { { 0 } } } } };
 
 static void point_double_internal(curve448_point_t p, const curve448_point_t q,
-                                  int before_double)
+    int before_double)
 {
     gf a, b, c, d;
 
     ossl_gf_sqr(c, q->x);
     ossl_gf_sqr(a, q->y);
-    gf_add_nr(d, c, a);         /* 2+e */
+    gf_add_nr(d, c, a); /* 2+e */
     gf_add_nr(p->t, q->y, q->x); /* 2+e */
     ossl_gf_sqr(b, p->t);
-    gf_subx_nr(b, b, d, 3);     /* 4+e */
-    gf_sub_nr(p->t, a, c);      /* 3+e */
+    gf_subx_nr(b, b, d, 3); /* 4+e */
+    gf_sub_nr(p->t, a, c); /* 3+e */
     ossl_gf_sqr(p->x, q->z);
     gf_add_nr(p->z, p->x, p->x); /* 2+e */
     gf_subx_nr(a, p->z, p->t, 4); /* 6+e */
     if (GF_HEADROOM == 5)
-        gf_weak_reduce(a);      /* or 1+e */
+        gf_weak_reduce(a); /* or 1+e */
     ossl_gf_mul(p->x, a, b);
     ossl_gf_mul(p->z, p->t, a);
     ossl_gf_mul(p->y, p->t, d);
@@ -123,19 +118,19 @@ static void niels_to_pt(curve448_point_t e, const niels_t n)
 }
 
 static void add_niels_to_pt(curve448_point_t d, const niels_t e,
-                            int before_double)
+    int before_double)
 {
     gf a, b, c;
 
-    gf_sub_nr(b, d->y, d->x);   /* 3+e */
+    gf_sub_nr(b, d->y, d->x); /* 3+e */
     ossl_gf_mul(a, e->a, b);
-    gf_add_nr(b, d->x, d->y);   /* 2+e */
+    gf_add_nr(b, d->x, d->y); /* 2+e */
     ossl_gf_mul(d->y, e->b, b);
     ossl_gf_mul(d->x, e->c, d->t);
-    gf_add_nr(c, a, d->y);      /* 2+e */
-    gf_sub_nr(b, d->y, a);      /* 3+e */
+    gf_add_nr(c, a, d->y); /* 2+e */
+    gf_sub_nr(b, d->y, a); /* 3+e */
     gf_sub_nr(d->y, d->z, d->x); /* 3+e */
-    gf_add_nr(a, d->x, d->z);   /* 2+e */
+    gf_add_nr(a, d->x, d->z); /* 2+e */
     ossl_gf_mul(d->z, a, d->y);
     ossl_gf_mul(d->x, d->y, b);
     ossl_gf_mul(d->y, a, c);
@@ -144,19 +139,19 @@ static void add_niels_to_pt(curve448_point_t d, const niels_t e,
 }
 
 static void sub_niels_from_pt(curve448_point_t d, const niels_t e,
-                              int before_double)
+    int before_double)
 {
     gf a, b, c;
 
-    gf_sub_nr(b, d->y, d->x);   /* 3+e */
+    gf_sub_nr(b, d->y, d->x); /* 3+e */
     ossl_gf_mul(a, e->b, b);
-    gf_add_nr(b, d->x, d->y);   /* 2+e */
+    gf_add_nr(b, d->x, d->y); /* 2+e */
     ossl_gf_mul(d->y, e->a, b);
     ossl_gf_mul(d->x, e->c, d->t);
-    gf_add_nr(c, a, d->y);      /* 2+e */
-    gf_sub_nr(b, d->y, a);      /* 3+e */
+    gf_add_nr(c, a, d->y); /* 2+e */
+    gf_sub_nr(b, d->y, a); /* 3+e */
     gf_add_nr(d->y, d->z, d->x); /* 2+e */
-    gf_sub_nr(a, d->z, d->x);   /* 3+e */
+    gf_sub_nr(a, d->z, d->x); /* 3+e */
     ossl_gf_mul(d->z, a, d->y);
     ossl_gf_mul(d->x, d->y, b);
     ossl_gf_mul(d->y, a, c);
@@ -165,7 +160,7 @@ static void sub_niels_from_pt(curve448_point_t d, const niels_t e,
 }
 
 static void add_pniels_to_pt(curve448_point_t p, const pniels_t pn,
-                             int before_double)
+    int before_double)
 {
     gf L0;
 
@@ -175,7 +170,7 @@ static void add_pniels_to_pt(curve448_point_t p, const pniels_t pn,
 }
 
 static void sub_pniels_from_pt(curve448_point_t p, const pniels_t pn,
-                               int before_double)
+    int before_double)
 {
     gf L0;
 
@@ -186,7 +181,7 @@ static void sub_pniels_from_pt(curve448_point_t p, const pniels_t pn,
 
 c448_bool_t
 ossl_curve448_point_eq(const curve448_point_t p,
-                       const curve448_point_t q)
+    const curve448_point_t q)
 {
     mask_t succ;
     gf a, b;
@@ -220,17 +215,16 @@ ossl_curve448_point_valid(const curve448_point_t p)
     return mask_to_bool(out);
 }
 
-static ossl_inline void constant_time_lookup_niels(niels_s * RESTRICT ni,
-                                                   const niels_t *table,
-                                                   int nelts, int idx)
+static ossl_inline void constant_time_lookup_niels(niels_s *RESTRICT ni,
+    const niels_t *table,
+    int nelts, int idx)
 {
     constant_time_lookup(ni, table, sizeof(niels_s), nelts, idx);
 }
 
-void
-ossl_curve448_precomputed_scalarmul(curve448_point_t out,
-                                    const curve448_precomputed_s *table,
-                                    const curve448_scalar_t scalar)
+void ossl_curve448_precomputed_scalarmul(curve448_point_t out,
+    const curve448_precomputed_s *table,
+    const curve448_scalar_t scalar)
 {
     unsigned int i, j, k;
     const unsigned int n = COMBS_N, t = COMBS_T, s = COMBS_S;
@@ -252,8 +246,7 @@ ossl_curve448_precomputed_scalarmul(curve448_point_t out,
                 unsigned int bit = (i - 1) + s * (k + j * t);
 
                 if (bit < C448_SCALAR_BITS)
-                    tab |=
-                        (scalar1x->limb[bit / WBITS] >> (bit % WBITS) & 1) << k;
+                    tab |= (scalar1x->limb[bit / WBITS] >> (bit % WBITS) & 1) << k;
             }
 
             invert = (tab >> (t - 1)) - 1;
@@ -261,7 +254,7 @@ ossl_curve448_precomputed_scalarmul(curve448_point_t out,
             tab &= (1 << (t - 1)) - 1;
 
             constant_time_lookup_niels(ni, &table->table[j << (t - 1)],
-                                       1 << (t - 1), tab);
+                1 << (t - 1), tab);
 
             cond_neg_niels(ni, invert);
             if ((i != s) || j != 0)
@@ -275,10 +268,9 @@ ossl_curve448_precomputed_scalarmul(curve448_point_t out,
     OPENSSL_cleanse(scalar1x, sizeof(scalar1x));
 }
 
-void
-ossl_curve448_point_mul_by_ratio_and_encode_like_eddsa(
-                                    uint8_t enc[EDDSA_448_PUBLIC_BYTES],
-                                    const curve448_point_t p)
+void ossl_curve448_point_mul_by_ratio_and_encode_like_eddsa(
+    uint8_t enc[EDDSA_448_PUBLIC_BYTES],
+    const curve448_point_t p)
 {
     gf x, y, z, t;
     curve448_point_t q;
@@ -325,8 +317,8 @@ ossl_curve448_point_mul_by_ratio_and_encode_like_eddsa(
 
 c448_error_t
 ossl_curve448_point_decode_like_eddsa_and_mul_by_ratio(
-                                curve448_point_t p,
-                                const uint8_t enc[EDDSA_448_PUBLIC_BYTES])
+    curve448_point_t p,
+    const uint8_t enc[EDDSA_448_PUBLIC_BYTES])
 {
     uint8_t enc2[EDDSA_448_PUBLIC_BYTES];
     mask_t low;
@@ -341,14 +333,14 @@ ossl_curve448_point_decode_like_eddsa_and_mul_by_ratio(
     succ &= word_is_zero(enc2[EDDSA_448_PRIVATE_BYTES - 1]);
 
     ossl_gf_sqr(p->x, p->y);
-    gf_sub(p->z, ONE, p->x);    /* num = 1-y^2 */
+    gf_sub(p->z, ONE, p->x); /* num = 1-y^2 */
     gf_mulw(p->t, p->x, EDWARDS_D); /* dy^2 */
-    gf_sub(p->t, ONE, p->t);    /* denom = 1-dy^2 or 1-d + dy^2 */
+    gf_sub(p->t, ONE, p->t); /* denom = 1-dy^2 or 1-d + dy^2 */
 
     ossl_gf_mul(p->x, p->z, p->t);
     succ &= gf_isr(p->t, p->x); /* 1/sqrt(num * denom) */
 
-    ossl_gf_mul(p->x, p->t, p->z);   /* sqrt(num / denom) */
+    ossl_gf_mul(p->x, p->t, p->z); /* sqrt(num / denom) */
     gf_cond_neg(p->x, gf_lobit(p->x) ^ low);
     gf_copy(p->z, ONE);
 
@@ -384,8 +376,8 @@ ossl_curve448_point_decode_like_eddsa_and_mul_by_ratio(
 
 c448_error_t
 ossl_x448_int(uint8_t out[X_PUBLIC_BYTES],
-              const uint8_t base[X_PUBLIC_BYTES],
-              const uint8_t scalar[X_PRIVATE_BYTES])
+    const uint8_t base[X_PUBLIC_BYTES],
+    const uint8_t scalar[X_PRIVATE_BYTES])
 {
     gf x1, x2, z2, x3, z3, t1, t2;
     int t;
@@ -409,7 +401,7 @@ ossl_x448_int(uint8_t out[X_PUBLIC_BYTES],
             sb = -1;
 
         k_t = (sb >> (t % 8)) & 1;
-        k_t = 0 - k_t;             /* set to all 0s or all 1s */
+        k_t = 0 - k_t; /* set to all 0s or all 1s */
 
         swap ^= k_t;
         gf_cond_swap(x2, x3, swap);
@@ -421,26 +413,26 @@ ossl_x448_int(uint8_t out[X_PUBLIC_BYTES],
          * comments, "2+e" is saying that the coefficients are at most 2+epsilon
          * times the reduction limit.
          */
-        gf_add_nr(t1, x2, z2);  /* A = x2 + z2 */ /* 2+e */
-        gf_sub_nr(t2, x2, z2);  /* B = x2 - z2 */ /* 3+e */
-        gf_sub_nr(z2, x3, z3);  /* D = x3 - z3 */ /* 3+e */
-        ossl_gf_mul(x2, t1, z2);     /* DA */
-        gf_add_nr(z2, z3, x3);  /* C = x3 + z3 */ /* 2+e */
-        ossl_gf_mul(x3, t2, z2);     /* CB */
-        gf_sub_nr(z3, x2, x3);  /* DA-CB */ /* 3+e */
-        ossl_gf_sqr(z2, z3);         /* (DA-CB)^2 */
-        ossl_gf_mul(z3, x1, z2);     /* z3 = x1(DA-CB)^2 */
-        gf_add_nr(z2, x2, x3);  /* (DA+CB) */ /* 2+e */
-        ossl_gf_sqr(x3, z2);         /* x3 = (DA+CB)^2 */
+        gf_add_nr(t1, x2, z2); /* A = x2 + z2 */ /* 2+e */
+        gf_sub_nr(t2, x2, z2); /* B = x2 - z2 */ /* 3+e */
+        gf_sub_nr(z2, x3, z3); /* D = x3 - z3 */ /* 3+e */
+        ossl_gf_mul(x2, t1, z2); /* DA */
+        gf_add_nr(z2, z3, x3); /* C = x3 + z3 */ /* 2+e */
+        ossl_gf_mul(x3, t2, z2); /* CB */
+        gf_sub_nr(z3, x2, x3); /* DA-CB */ /* 3+e */
+        ossl_gf_sqr(z2, z3); /* (DA-CB)^2 */
+        ossl_gf_mul(z3, x1, z2); /* z3 = x1(DA-CB)^2 */
+        gf_add_nr(z2, x2, x3); /* (DA+CB) */ /* 2+e */
+        ossl_gf_sqr(x3, z2); /* x3 = (DA+CB)^2 */
 
-        ossl_gf_sqr(z2, t1);         /* AA = A^2 */
-        ossl_gf_sqr(t1, t2);         /* BB = B^2 */
-        ossl_gf_mul(x2, z2, t1);     /* x2 = AA*BB */
-        gf_sub_nr(t2, z2, t1);  /* E = AA-BB */ /* 3+e */
+        ossl_gf_sqr(z2, t1); /* AA = A^2 */
+        ossl_gf_sqr(t1, t2); /* BB = B^2 */
+        ossl_gf_mul(x2, z2, t1); /* x2 = AA*BB */
+        gf_sub_nr(t2, z2, t1); /* E = AA-BB */ /* 3+e */
 
         gf_mulw(t1, t2, -EDWARDS_D); /* E*-d = a24*E */
-        gf_add_nr(t1, t1, z2);  /* AA + a24*E */ /* 2+e */
-        ossl_gf_mul(z2, t2, t1);     /* z2 = E(AA+a24*E) */
+        gf_add_nr(t1, t1, z2); /* AA + a24*E */ /* 2+e */
+        ossl_gf_mul(z2, t2, t1); /* z2 = E(AA+a24*E) */
     }
 
     /* Finish */
@@ -462,23 +454,22 @@ ossl_x448_int(uint8_t out[X_PUBLIC_BYTES],
     return c448_succeed_if(mask_to_bool(nz));
 }
 
-void
-ossl_curve448_point_mul_by_ratio_and_encode_like_x448(uint8_t
-                                                      out[X_PUBLIC_BYTES],
-                                                      const curve448_point_t p)
+void ossl_curve448_point_mul_by_ratio_and_encode_like_x448(uint8_t
+                                                               out[X_PUBLIC_BYTES],
+    const curve448_point_t p)
 {
     curve448_point_t q;
 
     curve448_point_copy(q, p);
-    gf_invert(q->t, q->x, 0);   /* 1/x */
-    ossl_gf_mul(q->z, q->t, q->y);   /* y/x */
-    ossl_gf_sqr(q->y, q->z);         /* (y/x)^2 */
+    gf_invert(q->t, q->x, 0); /* 1/x */
+    ossl_gf_mul(q->z, q->t, q->y); /* y/x */
+    ossl_gf_sqr(q->y, q->z); /* (y/x)^2 */
     gf_serialize(out, q->y, 1);
     ossl_curve448_point_destroy(q);
 }
 
 void ossl_x448_derive_public_key(uint8_t out[X_PUBLIC_BYTES],
-                                 const uint8_t scalar[X_PRIVATE_BYTES])
+    const uint8_t scalar[X_PRIVATE_BYTES])
 {
     /* Scalar conditioning */
     uint8_t scalar2[X_PRIVATE_BYTES];
@@ -499,7 +490,7 @@ void ossl_x448_derive_public_key(uint8_t out[X_PUBLIC_BYTES],
         ossl_curve448_scalar_halve(the_scalar, the_scalar);
 
     ossl_curve448_precomputed_scalarmul(p, ossl_curve448_precomputed_base,
-                                        the_scalar);
+        the_scalar);
     ossl_curve448_point_mul_by_ratio_and_encode_like_x448(out, p);
     ossl_curve448_point_destroy(p);
 }
@@ -510,9 +501,9 @@ struct smvt_control {
 };
 
 #if defined(__GNUC__) && (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ > 3))
-# define NUMTRAILINGZEROS       __builtin_ctz
+#define NUMTRAILINGZEROS __builtin_ctz
 #else
-# define NUMTRAILINGZEROS       numtrailingzeros
+#define NUMTRAILINGZEROS numtrailingzeros
 static uint32_t numtrailingzeros(uint32_t i)
 {
     uint32_t tmp;
@@ -550,9 +541,9 @@ static uint32_t numtrailingzeros(uint32_t i)
 #endif
 
 static int recode_wnaf(struct smvt_control *control,
-                       /* [nbits/(table_bits + 1) + 3] */
-                       const curve448_scalar_t scalar,
-                       unsigned int table_bits)
+    /* [nbits/(table_bits + 1) + 3] */
+    const curve448_scalar_t scalar,
+    unsigned int table_bits)
 {
     unsigned int table_size = C448_SCALAR_BITS / (table_bits + 1) + 3;
     int position = table_size - 1; /* at the end */
@@ -577,7 +568,8 @@ static int recode_wnaf(struct smvt_control *control,
         if (w < (C448_SCALAR_BITS - 1) / 16 + 1) {
             /* Refill the 16 high bits of current */
             current += (uint32_t)((scalar->limb[w / B_OVER_16]
-                       >> (16 * (w % B_OVER_16))) << 16);
+                                      >> (16 * (w % B_OVER_16)))
+                << 16);
         }
 
         while (current & 0xFFFF) {
@@ -613,8 +605,8 @@ static int recode_wnaf(struct smvt_control *control,
 }
 
 static void prepare_wnaf_table(pniels_t *output,
-                               const curve448_point_t working,
-                               unsigned int tbits)
+    const curve448_point_t working,
+    unsigned int tbits)
 {
     curve448_point_t tmp;
     int i;
@@ -640,18 +632,15 @@ static void prepare_wnaf_table(pniels_t *output,
     OPENSSL_cleanse(twop, sizeof(twop));
 }
 
-void
-ossl_curve448_base_double_scalarmul_non_secret(curve448_point_t combo,
-                                               const curve448_scalar_t scalar1,
-                                               const curve448_point_t base2,
-                                               const curve448_scalar_t scalar2)
+void ossl_curve448_base_double_scalarmul_non_secret(curve448_point_t combo,
+    const curve448_scalar_t scalar1,
+    const curve448_point_t base2,
+    const curve448_scalar_t scalar2)
 {
     const int table_bits_var = C448_WNAF_VAR_TABLE_BITS;
     const int table_bits_pre = C448_WNAF_FIXED_TABLE_BITS;
-    struct smvt_control control_var[C448_SCALAR_BITS /
-                                    (C448_WNAF_VAR_TABLE_BITS + 1) + 3];
-    struct smvt_control control_pre[C448_SCALAR_BITS /
-                                    (C448_WNAF_FIXED_TABLE_BITS + 1) + 3];
+    struct smvt_control control_var[C448_SCALAR_BITS / (C448_WNAF_VAR_TABLE_BITS + 1) + 3];
+    struct smvt_control control_pre[C448_SCALAR_BITS / (C448_WNAF_FIXED_TABLE_BITS + 1) + 3];
     int ncb_pre = recode_wnaf(control_pre, scalar1, table_bits_pre);
     int ncb_var = recode_wnaf(control_var, scalar2, table_bits_var);
     pniels_t precmp_var[1 << C448_WNAF_VAR_TABLE_BITS];
@@ -670,8 +659,8 @@ ossl_curve448_base_double_scalarmul_non_secret(curve448_point_t combo,
     } else if (i == control_pre[0].power && i >= 0) {
         pniels_to_pt(combo, precmp_var[control_var[0].addend >> 1]);
         add_niels_to_pt(combo,
-                        ossl_curve448_wnaf_base[control_pre[0].addend >> 1],
-                        i);
+            ossl_curve448_wnaf_base[control_pre[0].addend >> 1],
+            i);
         contv++;
         contp++;
     } else {
@@ -691,12 +680,13 @@ ossl_curve448_base_double_scalarmul_non_secret(curve448_point_t combo,
 
             if (control_var[contv].addend > 0)
                 add_pniels_to_pt(combo,
-                                 precmp_var[control_var[contv].addend >> 1],
-                                 i && !cp);
+                    precmp_var[control_var[contv].addend >> 1],
+                    i && !cp);
             else
                 sub_pniels_from_pt(combo,
-                                   precmp_var[(-control_var[contv].addend)
-                                              >> 1], i && !cp);
+                    precmp_var[(-control_var[contv].addend)
+                        >> 1],
+                    i && !cp);
             contv++;
         }
 
@@ -705,12 +695,16 @@ ossl_curve448_base_double_scalarmul_non_secret(curve448_point_t combo,
 
             if (control_pre[contp].addend > 0)
                 add_niels_to_pt(combo,
-                                ossl_curve448_wnaf_base[control_pre[contp].addend
-                                                   >> 1], i);
+                    ossl_curve448_wnaf_base[control_pre[contp].addend
+                        >> 1],
+                    i);
             else
                 sub_niels_from_pt(combo,
-                                  ossl_curve448_wnaf_base[(-control_pre
-                                                      [contp].addend) >> 1], i);
+                    ossl_curve448_wnaf_base[(-control_pre
+                                                    [contp]
+                                                        .addend)
+                        >> 1],
+                    i);
             contp++;
         }
     }
@@ -732,14 +726,14 @@ void ossl_curve448_point_destroy(curve448_point_t point)
 }
 
 int ossl_x448(uint8_t out_shared_key[56], const uint8_t private_key[56],
-              const uint8_t peer_public_value[56])
+    const uint8_t peer_public_value[56])
 {
     return ossl_x448_int(out_shared_key, peer_public_value, private_key)
-           == C448_SUCCESS;
+        == C448_SUCCESS;
 }
 
 void ossl_x448_public_from_private(uint8_t out_public_value[56],
-                                   const uint8_t private_key[56])
+    const uint8_t private_key[56])
 {
     ossl_x448_derive_public_key(out_public_value, private_key);
 }
