@@ -77,6 +77,7 @@
 #include <openssl/evp.h>
 #include <openssl/rand.h>
 #include "internal/endian.h"
+#include "internal/numbers.h" /* includes SIZE_MAX */
 #include "crypto/evp.h"
 
 static int ok_write(BIO *h, const char *buf, int num);
@@ -90,9 +91,9 @@ static __owur int sig_out(BIO *b);
 static __owur int sig_in(BIO *b);
 static __owur int block_out(BIO *b);
 static __owur int block_in(BIO *b);
-#define OK_BLOCK_SIZE   (1024*4)
-#define OK_BLOCK_BLOCK  4
-#define IOBS            (OK_BLOCK_SIZE+ OK_BLOCK_BLOCK+ 3*EVP_MAX_MD_SIZE)
+#define OK_BLOCK_SIZE (1024 * 4)
+#define OK_BLOCK_BLOCK 4
+#define IOBS (OK_BLOCK_SIZE + OK_BLOCK_BLOCK + 3 * EVP_MAX_MD_SIZE)
 #define WELLKNOWN "The quick brown fox jumped over the lazy dog's back."
 
 typedef struct ok_struct {
@@ -100,11 +101,11 @@ typedef struct ok_struct {
     size_t buf_off;
     size_t buf_len_save;
     size_t buf_off_save;
-    int cont;                   /* <= 0 when finished */
+    int cont; /* <= 0 when finished */
     int finished;
     EVP_MD_CTX *md;
-    int blockout;               /* output block is ready */
-    int sigio;                  /* must process signature */
+    int blockout; /* output block is ready */
+    int sigio; /* must process signature */
     unsigned char buf[IOBS];
 } BIO_OK_CTX;
 
@@ -115,8 +116,8 @@ static const BIO_METHOD methods_ok = {
     ok_write,
     bread_conv,
     ok_read,
-    NULL,                       /* ok_puts, */
-    NULL,                       /* ok_gets, */
+    NULL, /* ok_puts, */
+    NULL, /* ok_gets, */
     ok_ctrl,
     ok_new,
     ok_free,
@@ -203,7 +204,7 @@ static int ok_read(BIO *b, char *out, int outl)
                 if (ctx->buf_len_save > ctx->buf_off_save) {
                     ctx->buf_len = ctx->buf_len_save - ctx->buf_off_save;
                     memmove(ctx->buf, &(ctx->buf[ctx->buf_off_save]),
-                            ctx->buf_len);
+                        ctx->buf_len);
                 } else {
                     ctx->buf_len = 0;
                 }
@@ -220,7 +221,7 @@ static int ok_read(BIO *b, char *out, int outl)
         i = BIO_read(next, &(ctx->buf[ctx->buf_len]), n);
 
         if (i <= 0)
-            break;              /* nothing new */
+            break; /* nothing new */
 
         ctx->buf_len += i;
 
@@ -243,7 +244,6 @@ static int ok_read(BIO *b, char *out, int outl)
         /* invalid block -- cancel */
         if (ctx->cont <= 0)
             break;
-
     }
 
     BIO_clear_retry_flags(b);
@@ -295,8 +295,7 @@ static int ok_write(BIO *b, const char *in, int inl)
         if ((in == NULL) || (inl <= 0))
             return 0;
 
-        n = (inl + ctx->buf_len > OK_BLOCK_SIZE + OK_BLOCK_BLOCK) ?
-            (int)(OK_BLOCK_SIZE + OK_BLOCK_BLOCK - ctx->buf_len) : inl;
+        n = (inl + ctx->buf_len > OK_BLOCK_SIZE + OK_BLOCK_BLOCK) ? (int)(OK_BLOCK_SIZE + OK_BLOCK_BLOCK - ctx->buf_len) : inl;
 
         memcpy(&ctx->buf[ctx->buf_len], in, n);
         ctx->buf_len += n;
@@ -340,14 +339,14 @@ static long ok_ctrl(BIO *b, int cmd, long num, void *ptr)
         ctx->sigio = 1;
         ret = BIO_ctrl(next, cmd, num, ptr);
         break;
-    case BIO_CTRL_EOF:         /* More to read */
+    case BIO_CTRL_EOF: /* More to read */
         if (ctx->cont <= 0)
             ret = 1;
         else
             ret = BIO_ctrl(next, cmd, num, ptr);
         break;
-    case BIO_CTRL_PENDING:     /* More to read in buffer */
-    case BIO_CTRL_WPENDING:    /* More to read in buffer */
+    case BIO_CTRL_PENDING: /* More to read in buffer */
+    case BIO_CTRL_WPENDING: /* More to read in buffer */
         ret = ctx->blockout ? ctx->buf_len - ctx->buf_off : 0;
         if (ret <= 0)
             ret = BIO_ctrl(next, cmd, num, ptr);
@@ -466,7 +465,7 @@ static int sig_out(BIO *b)
     ctx->blockout = 1;
     ctx->sigio = 0;
     return 1;
- berr:
+berr:
     BIO_clear_retry_flags(b);
     return 0;
 }
@@ -508,7 +507,7 @@ static int sig_in(BIO *b)
         ctx->sigio = 0;
         if (ctx->buf_len != ctx->buf_off) {
             memmove(ctx->buf, &(ctx->buf[ctx->buf_off]),
-                    ctx->buf_len - ctx->buf_off);
+                ctx->buf_len - ctx->buf_off);
         }
         ctx->buf_len -= ctx->buf_off;
         ctx->buf_off = 0;
@@ -516,7 +515,7 @@ static int sig_in(BIO *b)
         ctx->cont = 0;
     }
     return 1;
- berr:
+berr:
     BIO_clear_retry_flags(b);
     return 0;
 }
@@ -540,14 +539,14 @@ static int block_out(BIO *b)
     ctx->buf[2] = (unsigned char)(tl >> 8);
     ctx->buf[3] = (unsigned char)(tl);
     if (!EVP_DigestUpdate(md,
-                          (unsigned char *)&(ctx->buf[OK_BLOCK_BLOCK]), tl))
+            (unsigned char *)&(ctx->buf[OK_BLOCK_BLOCK]), tl))
         goto berr;
     if (!EVP_DigestFinal_ex(md, &(ctx->buf[ctx->buf_len]), NULL))
         goto berr;
     ctx->buf_len += md_size;
     ctx->blockout = 1;
     return 1;
- berr:
+berr:
     BIO_clear_retry_flags(b);
     return 0;
 }
@@ -568,9 +567,9 @@ static int block_in(BIO *b)
 
     assert(sizeof(tl) >= OK_BLOCK_BLOCK); /* always true */
     tl = ((size_t)ctx->buf[0] << 24)
-           | ((size_t)ctx->buf[1] << 16)
-           | ((size_t)ctx->buf[2] << 8)
-           | ((size_t)ctx->buf[3]);
+        | ((size_t)ctx->buf[1] << 16)
+        | ((size_t)ctx->buf[2] << 8)
+        | ((size_t)ctx->buf[3]);
 
     if (tl > OK_BLOCK_SIZE)
         goto berr;
@@ -582,7 +581,7 @@ static int block_in(BIO *b)
         return 1;
 
     if (!EVP_DigestUpdate(md,
-                          (unsigned char *)&(ctx->buf[OK_BLOCK_BLOCK]), tl))
+            (unsigned char *)&(ctx->buf[OK_BLOCK_BLOCK]), tl))
         goto berr;
     if (!EVP_DigestFinal_ex(md, tmp, NULL))
         goto berr;
@@ -597,7 +596,7 @@ static int block_in(BIO *b)
         ctx->cont = 0;
     }
     return 1;
- berr:
+berr:
     BIO_clear_retry_flags(b);
     return 0;
 }
