@@ -1,5 +1,5 @@
 /*
- * Copyright 2017-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2017-2021 The OpenSSL Project Authors. All Rights Reserved.
  * Copyright (c) 2017, Oracle and/or its affiliates.  All rights reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
@@ -12,13 +12,13 @@
 
 #include "internal/cryptlib.h"
 #ifndef OPENSSL_NO_ARIA
-# include <openssl/evp.h>
-# include <openssl/modes.h>
-# include <openssl/rand.h>
-# include "crypto/aria.h"
-# include "crypto/evp.h"
-# include "crypto/modes.h"
-# include "evp_local.h"
+#include <openssl/evp.h>
+#include <openssl/modes.h>
+#include <openssl/rand.h>
+#include "crypto/aria.h"
+#include "crypto/evp.h"
+#include "crypto/modes.h"
+#include "evp_local.h"
 
 /* ARIA subkey Structure */
 typedef struct {
@@ -30,15 +30,15 @@ typedef struct {
     union {
         OSSL_UNION_ALIGN;
         ARIA_KEY ks;
-    } ks;                       /* ARIA subkey to use */
-    int key_set;                /* Set if key initialised */
-    int iv_set;                 /* Set if an iv is set */
+    } ks; /* ARIA subkey to use */
+    int key_set; /* Set if key initialised */
+    int iv_set; /* Set if an iv is set */
     GCM128_CONTEXT gcm;
-    unsigned char *iv;          /* Temporary IV store */
-    int ivlen;                  /* IV length */
+    unsigned char *iv; /* Temporary IV store */
+    int ivlen; /* IV length */
     int taglen;
-    int iv_gen;                 /* It is OK to generate IVs */
-    int tls_aad_len;            /* TLS AAD length */
+    int iv_gen; /* It is OK to generate IVs */
+    int tls_aad_len; /* TLS AAD length */
 } EVP_ARIA_GCM_CTX;
 
 /* ARIA CCM context */
@@ -46,134 +46,137 @@ typedef struct {
     union {
         OSSL_UNION_ALIGN;
         ARIA_KEY ks;
-    } ks;                       /* ARIA key schedule to use */
-    int key_set;                /* Set if key initialised */
-    int iv_set;                 /* Set if an iv is set */
-    int tag_set;                /* Set if tag is valid */
-    int len_set;                /* Set if message length set */
-    int L, M;                   /* L and M parameters from RFC3610 */
-    int tls_aad_len;            /* TLS AAD length */
+    } ks; /* ARIA key schedule to use */
+    int key_set; /* Set if key initialised */
+    int iv_set; /* Set if an iv is set */
+    int tag_set; /* Set if tag is valid */
+    int len_set; /* Set if message length set */
+    int L, M; /* L and M parameters from RFC3610 */
+    int tls_aad_len; /* TLS AAD length */
     CCM128_CONTEXT ccm;
     ccm128_f str;
 } EVP_ARIA_CCM_CTX;
 
 /* The subkey for ARIA is generated. */
 static int aria_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
-                            const unsigned char *iv, int enc)
+    const unsigned char *iv, int enc)
 {
     int ret;
     int mode = EVP_CIPHER_CTX_get_mode(ctx);
 
     if (enc || (mode != EVP_CIPH_ECB_MODE && mode != EVP_CIPH_CBC_MODE))
         ret = ossl_aria_set_encrypt_key(key,
-                                        EVP_CIPHER_CTX_get_key_length(ctx) * 8,
-                                        EVP_CIPHER_CTX_get_cipher_data(ctx));
+            EVP_CIPHER_CTX_get_key_length(ctx) * 8,
+            EVP_CIPHER_CTX_get_cipher_data(ctx));
     else
         ret = ossl_aria_set_decrypt_key(key,
-                                        EVP_CIPHER_CTX_get_key_length(ctx) * 8,
-                                        EVP_CIPHER_CTX_get_cipher_data(ctx));
+            EVP_CIPHER_CTX_get_key_length(ctx) * 8,
+            EVP_CIPHER_CTX_get_cipher_data(ctx));
     if (ret < 0) {
-        ERR_raise(ERR_LIB_EVP,EVP_R_ARIA_KEY_SETUP_FAILED);
+        ERR_raise(ERR_LIB_EVP, EVP_R_ARIA_KEY_SETUP_FAILED);
         return 0;
     }
     return 1;
 }
 
 static void aria_cbc_encrypt(const unsigned char *in, unsigned char *out,
-                             size_t len, const ARIA_KEY *key,
-                             unsigned char *ivec, const int enc)
+    size_t len, const ARIA_KEY *key,
+    unsigned char *ivec, const int enc)
 {
 
     if (enc)
         CRYPTO_cbc128_encrypt(in, out, len, key, ivec,
-                              (block128_f) ossl_aria_encrypt);
+            (block128_f)ossl_aria_encrypt);
     else
         CRYPTO_cbc128_decrypt(in, out, len, key, ivec,
-                              (block128_f) ossl_aria_encrypt);
+            (block128_f)ossl_aria_encrypt);
 }
 
 static void aria_cfb128_encrypt(const unsigned char *in, unsigned char *out,
-                                size_t length, const ARIA_KEY *key,
-                                unsigned char *ivec, int *num, const int enc)
+    size_t length, const ARIA_KEY *key,
+    unsigned char *ivec, int *num, const int enc)
 {
 
     CRYPTO_cfb128_encrypt(in, out, length, key, ivec, num, enc,
-                          (block128_f) ossl_aria_encrypt);
+        (block128_f)ossl_aria_encrypt);
 }
 
 static void aria_cfb1_encrypt(const unsigned char *in, unsigned char *out,
-                              size_t length, const ARIA_KEY *key,
-                              unsigned char *ivec, int *num, const int enc)
+    size_t length, const ARIA_KEY *key,
+    unsigned char *ivec, int *num, const int enc)
 {
     CRYPTO_cfb128_1_encrypt(in, out, length, key, ivec, num, enc,
-                            (block128_f) ossl_aria_encrypt);
+        (block128_f)ossl_aria_encrypt);
 }
 
 static void aria_cfb8_encrypt(const unsigned char *in, unsigned char *out,
-                              size_t length, const ARIA_KEY *key,
-                              unsigned char *ivec, int *num, const int enc)
+    size_t length, const ARIA_KEY *key,
+    unsigned char *ivec, int *num, const int enc)
 {
     CRYPTO_cfb128_8_encrypt(in, out, length, key, ivec, num, enc,
-                            (block128_f) ossl_aria_encrypt);
+        (block128_f)ossl_aria_encrypt);
 }
 
 static void aria_ecb_encrypt(const unsigned char *in, unsigned char *out,
-                             const ARIA_KEY *key, const int enc)
+    const ARIA_KEY *key, const int enc)
 {
     ossl_aria_encrypt(in, out, key);
 }
 
 static void aria_ofb128_encrypt(const unsigned char *in, unsigned char *out,
-                             size_t length, const ARIA_KEY *key,
-                             unsigned char *ivec, int *num)
+    size_t length, const ARIA_KEY *key,
+    unsigned char *ivec, int *num)
 {
     CRYPTO_ofb128_encrypt(in, out, length, key, ivec, num,
-                         (block128_f) ossl_aria_encrypt);
+        (block128_f)ossl_aria_encrypt);
 }
 
 IMPLEMENT_BLOCK_CIPHER(aria_128, ks, aria, EVP_ARIA_KEY,
-                        NID_aria_128, 16, 16, 16, 128,
-                        0, aria_init_key, NULL,
-                        EVP_CIPHER_set_asn1_iv,
-                        EVP_CIPHER_get_asn1_iv,
-                        NULL)
+    NID_aria_128, 16, 16, 16, 128,
+    0, aria_init_key, NULL,
+    EVP_CIPHER_set_asn1_iv,
+    EVP_CIPHER_get_asn1_iv,
+    NULL)
 IMPLEMENT_BLOCK_CIPHER(aria_192, ks, aria, EVP_ARIA_KEY,
-                        NID_aria_192, 16, 24, 16, 128,
-                        0, aria_init_key, NULL,
-                        EVP_CIPHER_set_asn1_iv,
-                        EVP_CIPHER_get_asn1_iv,
-                        NULL)
+    NID_aria_192, 16, 24, 16, 128,
+    0, aria_init_key, NULL,
+    EVP_CIPHER_set_asn1_iv,
+    EVP_CIPHER_get_asn1_iv,
+    NULL)
 IMPLEMENT_BLOCK_CIPHER(aria_256, ks, aria, EVP_ARIA_KEY,
-                        NID_aria_256, 16, 32, 16, 128,
-                        0, aria_init_key, NULL,
-                        EVP_CIPHER_set_asn1_iv,
-                        EVP_CIPHER_get_asn1_iv,
-                        NULL)
+    NID_aria_256, 16, 32, 16, 128,
+    0, aria_init_key, NULL,
+    EVP_CIPHER_set_asn1_iv,
+    EVP_CIPHER_get_asn1_iv,
+    NULL)
 
-# define IMPLEMENT_ARIA_CFBR(ksize,cbits) \
-                IMPLEMENT_CFBR(aria,aria,EVP_ARIA_KEY,ks,ksize,cbits,16,0)
-IMPLEMENT_ARIA_CFBR(128,1)
-IMPLEMENT_ARIA_CFBR(192,1)
-IMPLEMENT_ARIA_CFBR(256,1)
-IMPLEMENT_ARIA_CFBR(128,8)
-IMPLEMENT_ARIA_CFBR(192,8)
-IMPLEMENT_ARIA_CFBR(256,8)
+#define IMPLEMENT_ARIA_CFBR(ksize, cbits) \
+    IMPLEMENT_CFBR(aria, aria, EVP_ARIA_KEY, ks, ksize, cbits, 16, 0)
+IMPLEMENT_ARIA_CFBR(128, 1)
+IMPLEMENT_ARIA_CFBR(192, 1)
+IMPLEMENT_ARIA_CFBR(256, 1)
+IMPLEMENT_ARIA_CFBR(128, 8)
+IMPLEMENT_ARIA_CFBR(192, 8)
+IMPLEMENT_ARIA_CFBR(256, 8)
 
-# define BLOCK_CIPHER_generic(nid,keylen,blocksize,ivlen,nmode,mode,MODE,flags) \
-static const EVP_CIPHER aria_##keylen##_##mode = { \
-        nid##_##keylen##_##nmode,blocksize,keylen/8,ivlen, \
-        flags|EVP_CIPH_##MODE##_MODE,   \
-        EVP_ORIG_GLOBAL,                \
-        aria_init_key,                  \
-        aria_##mode##_cipher,           \
-        NULL,                           \
-        sizeof(EVP_ARIA_KEY),           \
-        NULL,NULL,NULL,NULL };          \
-const EVP_CIPHER *EVP_aria_##keylen##_##mode(void) \
-{ return &aria_##keylen##_##mode; }
+#define BLOCK_CIPHER_generic(nid, keylen, blocksize, ivlen, nmode, mode, MODE, flags) \
+    static const EVP_CIPHER aria_##keylen##_##mode = {                                \
+        nid##_##keylen##_##nmode, blocksize, keylen / 8, ivlen,                       \
+        flags | EVP_CIPH_##MODE##_MODE,                                               \
+        EVP_ORIG_GLOBAL,                                                              \
+        aria_init_key,                                                                \
+        aria_##mode##_cipher,                                                         \
+        NULL,                                                                         \
+        sizeof(EVP_ARIA_KEY),                                                         \
+        NULL, NULL, NULL, NULL                                                        \
+    };                                                                                \
+    const EVP_CIPHER *EVP_aria_##keylen##_##mode(void)                                \
+    {                                                                                 \
+        return &aria_##keylen##_##mode;                                               \
+    }
 
 static int aria_ctr_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                               const unsigned char *in, size_t len)
+    const unsigned char *in, size_t len)
 {
     int n = EVP_CIPHER_CTX_get_num(ctx);
     unsigned int num;
@@ -184,20 +187,20 @@ static int aria_ctr_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
     num = (unsigned int)n;
 
     CRYPTO_ctr128_encrypt(in, out, len, &dat->ks, ctx->iv,
-                          EVP_CIPHER_CTX_buf_noconst(ctx), &num,
-                          (block128_f) ossl_aria_encrypt);
+        EVP_CIPHER_CTX_buf_noconst(ctx), &num,
+        (block128_f)ossl_aria_encrypt);
     EVP_CIPHER_CTX_set_num(ctx, num);
     return 1;
 }
 
 BLOCK_CIPHER_generic(NID_aria, 128, 1, 16, ctr, ctr, CTR, 0)
-BLOCK_CIPHER_generic(NID_aria, 192, 1, 16, ctr, ctr, CTR, 0)
-BLOCK_CIPHER_generic(NID_aria, 256, 1, 16, ctr, ctr, CTR, 0)
+    BLOCK_CIPHER_generic(NID_aria, 192, 1, 16, ctr, ctr, CTR, 0)
+        BLOCK_CIPHER_generic(NID_aria, 256, 1, 16, ctr, ctr, CTR, 0)
 
-/* Authenticated cipher modes (GCM/CCM) */
+    /* Authenticated cipher modes (GCM/CCM) */
 
-/* increment counter (64-bit int) by 1 */
-static void ctr64_inc(unsigned char *counter)
+    /* increment counter (64-bit int) by 1 */
+    static void ctr64_inc(unsigned char *counter)
 {
     int n = 8;
     unsigned char c;
@@ -213,21 +216,21 @@ static void ctr64_inc(unsigned char *counter)
 }
 
 static int aria_gcm_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
-                                 const unsigned char *iv, int enc)
+    const unsigned char *iv, int enc)
 {
     int ret;
-    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX,ctx);
+    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX, ctx);
 
     if (!iv && !key)
         return 1;
     if (key) {
         ret = ossl_aria_set_encrypt_key(key,
-                                        EVP_CIPHER_CTX_get_key_length(ctx) * 8,
-                                        &gctx->ks.ks);
+            EVP_CIPHER_CTX_get_key_length(ctx) * 8,
+            &gctx->ks.ks);
         CRYPTO_gcm128_init(&gctx->gcm, &gctx->ks,
-                           (block128_f) ossl_aria_encrypt);
+            (block128_f)ossl_aria_encrypt);
         if (ret < 0) {
-            ERR_raise(ERR_LIB_EVP,EVP_R_ARIA_KEY_SETUP_FAILED);
+            ERR_raise(ERR_LIB_EVP, EVP_R_ARIA_KEY_SETUP_FAILED);
             return 0;
         }
 
@@ -255,7 +258,7 @@ static int aria_gcm_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
 
 static int aria_gcm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
 {
-    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX,c);
+    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX, c);
 
     switch (type) {
     case EVP_CTRL_INIT:
@@ -279,10 +282,8 @@ static int aria_gcm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
         if ((arg > EVP_MAX_IV_LENGTH) && (arg > gctx->ivlen)) {
             if (gctx->iv != c->iv)
                 OPENSSL_free(gctx->iv);
-            if ((gctx->iv = OPENSSL_malloc(arg)) == NULL) {
-                ERR_raise(ERR_LIB_EVP, ERR_R_MALLOC_FAILURE);
+            if ((gctx->iv = OPENSSL_malloc(arg)) == NULL)
                 return 0;
-            }
         }
         gctx->ivlen = arg;
         return 1;
@@ -353,8 +354,7 @@ static int aria_gcm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
         memcpy(EVP_CIPHER_CTX_buf_noconst(c), ptr, arg);
         gctx->tls_aad_len = arg;
         {
-            unsigned int len =
-                EVP_CIPHER_CTX_buf_noconst(c)[arg - 2] << 8
+            unsigned int len = EVP_CIPHER_CTX_buf_noconst(c)[arg - 2] << 8
                 | EVP_CIPHER_CTX_buf_noconst(c)[arg - 1];
             /* Correct length for explicit IV */
             if (len < EVP_GCM_TLS_EXPLICIT_IV_LEN)
@@ -372,37 +372,33 @@ static int aria_gcm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
         /* Extra padding: tag appended to record */
         return EVP_GCM_TLS_TAG_LEN;
 
-    case EVP_CTRL_COPY:
-        {
-            EVP_CIPHER_CTX *out = ptr;
-            EVP_ARIA_GCM_CTX *gctx_out = EVP_C_DATA(EVP_ARIA_GCM_CTX,out);
-            if (gctx->gcm.key) {
-                if (gctx->gcm.key != &gctx->ks)
-                    return 0;
-                gctx_out->gcm.key = &gctx_out->ks;
-            }
-            if (gctx->iv == c->iv)
-                gctx_out->iv = out->iv;
-            else {
-                if ((gctx_out->iv = OPENSSL_malloc(gctx->ivlen)) == NULL) {
-                    ERR_raise(ERR_LIB_EVP, ERR_R_MALLOC_FAILURE);
-                    return 0;
-                }
-                memcpy(gctx_out->iv, gctx->iv, gctx->ivlen);
-            }
-            return 1;
+    case EVP_CTRL_COPY: {
+        EVP_CIPHER_CTX *out = ptr;
+        EVP_ARIA_GCM_CTX *gctx_out = EVP_C_DATA(EVP_ARIA_GCM_CTX, out);
+        if (gctx->gcm.key) {
+            if (gctx->gcm.key != &gctx->ks)
+                return 0;
+            gctx_out->gcm.key = &gctx_out->ks;
         }
+        if (gctx->iv == c->iv)
+            gctx_out->iv = out->iv;
+        else {
+            if ((gctx_out->iv = OPENSSL_malloc(gctx->ivlen)) == NULL)
+                return 0;
+            memcpy(gctx_out->iv, gctx->iv, gctx->ivlen);
+        }
+        return 1;
+    }
 
     default:
         return -1;
-
     }
 }
 
 static int aria_gcm_tls_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                              const unsigned char *in, size_t len)
+    const unsigned char *in, size_t len)
 {
-    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX,ctx);
+    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX, ctx);
     int rv = -1;
 
     /* Encrypt/decrypt must be performed in place */
@@ -413,13 +409,13 @@ static int aria_gcm_tls_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
      * Set IV from start of buffer or generate IV and write to start of
      * buffer.
      */
-    if (EVP_CIPHER_CTX_ctrl(ctx, EVP_CIPHER_CTX_is_encrypting(ctx) ?
-                            EVP_CTRL_GCM_IV_GEN : EVP_CTRL_GCM_SET_IV_INV,
-                            EVP_GCM_TLS_EXPLICIT_IV_LEN, out) <= 0)
+    if (EVP_CIPHER_CTX_ctrl(ctx, EVP_CIPHER_CTX_is_encrypting(ctx) ? EVP_CTRL_GCM_IV_GEN : EVP_CTRL_GCM_SET_IV_INV,
+            EVP_GCM_TLS_EXPLICIT_IV_LEN, out)
+        <= 0)
         goto err;
     /* Use saved AAD */
     if (CRYPTO_gcm128_aad(&gctx->gcm, EVP_CIPHER_CTX_buf_noconst(ctx),
-                          gctx->tls_aad_len))
+            gctx->tls_aad_len))
         goto err;
     /* Fix buffer and length to point to payload */
     in += EVP_GCM_TLS_EXPLICIT_IV_LEN;
@@ -439,26 +435,26 @@ static int aria_gcm_tls_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
             goto err;
         /* Retrieve tag */
         CRYPTO_gcm128_tag(&gctx->gcm, EVP_CIPHER_CTX_buf_noconst(ctx),
-                          EVP_GCM_TLS_TAG_LEN);
+            EVP_GCM_TLS_TAG_LEN);
         /* If tag mismatch wipe buffer */
         if (CRYPTO_memcmp(EVP_CIPHER_CTX_buf_noconst(ctx), in + len,
-                          EVP_GCM_TLS_TAG_LEN)) {
+                EVP_GCM_TLS_TAG_LEN)) {
             OPENSSL_cleanse(out, len);
             goto err;
         }
         rv = len;
     }
 
- err:
+err:
     gctx->iv_set = 0;
     gctx->tls_aad_len = -1;
     return rv;
 }
 
 static int aria_gcm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                          const unsigned char *in, size_t len)
+    const unsigned char *in, size_t len)
 {
-    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX,ctx);
+    EVP_ARIA_GCM_CTX *gctx = EVP_C_DATA(EVP_ARIA_GCM_CTX, ctx);
 
     /* If not set up, return error */
     if (!gctx->key_set)
@@ -486,8 +482,9 @@ static int aria_gcm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
         if (gctx->taglen < 0)
             return -1;
         if (CRYPTO_gcm128_finish(&gctx->gcm,
-                                 EVP_CIPHER_CTX_buf_noconst(ctx),
-                                 gctx->taglen) != 0)
+                EVP_CIPHER_CTX_buf_noconst(ctx),
+                gctx->taglen)
+            != 0)
             return -1;
         gctx->iv_set = 0;
         return 0;
@@ -510,22 +507,22 @@ static int aria_gcm_cleanup(EVP_CIPHER_CTX *ctx)
 }
 
 static int aria_ccm_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
-                            const unsigned char *iv, int enc)
+    const unsigned char *iv, int enc)
 {
     int ret;
-    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX,ctx);
+    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX, ctx);
 
     if (!iv && !key)
         return 1;
 
     if (key) {
         ret = ossl_aria_set_encrypt_key(key,
-                                        EVP_CIPHER_CTX_get_key_length(ctx) * 8,
-                                        &cctx->ks.ks);
+            EVP_CIPHER_CTX_get_key_length(ctx) * 8,
+            &cctx->ks.ks);
         CRYPTO_ccm128_init(&cctx->ccm, cctx->M, cctx->L,
-                           &cctx->ks, (block128_f) ossl_aria_encrypt);
+            &cctx->ks, (block128_f)ossl_aria_encrypt);
         if (ret < 0) {
-            ERR_raise(ERR_LIB_EVP,EVP_R_ARIA_KEY_SETUP_FAILED);
+            ERR_raise(ERR_LIB_EVP, EVP_R_ARIA_KEY_SETUP_FAILED);
             return 0;
         }
         cctx->str = NULL;
@@ -540,7 +537,7 @@ static int aria_ccm_init_key(EVP_CIPHER_CTX *ctx, const unsigned char *key,
 
 static int aria_ccm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
 {
-    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX,c);
+    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX, c);
 
     switch (type) {
     case EVP_CTRL_INIT:
@@ -564,8 +561,7 @@ static int aria_ccm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
         memcpy(EVP_CIPHER_CTX_buf_noconst(c), ptr, arg);
         cctx->tls_aad_len = arg;
         {
-            uint16_t len =
-                EVP_CIPHER_CTX_buf_noconst(c)[arg - 2] << 8
+            uint16_t len = EVP_CIPHER_CTX_buf_noconst(c)[arg - 2] << 8
                 | EVP_CIPHER_CTX_buf_noconst(c)[arg - 1];
             /* Correct length for explicit IV */
             if (len < EVP_CCM_TLS_EXPLICIT_IV_LEN)
@@ -621,17 +617,16 @@ static int aria_ccm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
         cctx->len_set = 0;
         return 1;
 
-    case EVP_CTRL_COPY:
-        {
-            EVP_CIPHER_CTX *out = ptr;
-            EVP_ARIA_CCM_CTX *cctx_out = EVP_C_DATA(EVP_ARIA_CCM_CTX,out);
-            if (cctx->ccm.key) {
-                if (cctx->ccm.key != &cctx->ks)
-                    return 0;
-                cctx_out->ccm.key = &cctx_out->ks;
-            }
-            return 1;
+    case EVP_CTRL_COPY: {
+        EVP_CIPHER_CTX *out = ptr;
+        EVP_ARIA_CCM_CTX *cctx_out = EVP_C_DATA(EVP_ARIA_CCM_CTX, out);
+        if (cctx->ccm.key) {
+            if (cctx->ccm.key != &cctx->ks)
+                return 0;
+            cctx_out->ccm.key = &cctx_out->ks;
         }
+        return 1;
+    }
 
     default:
         return -1;
@@ -639,9 +634,9 @@ static int aria_ccm_ctrl(EVP_CIPHER_CTX *c, int type, int arg, void *ptr)
 }
 
 static int aria_ccm_tls_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                              const unsigned char *in, size_t len)
+    const unsigned char *in, size_t len)
 {
-    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX,ctx);
+    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX, ctx);
     CCM128_CONTEXT *ccm = &cctx->ccm;
 
     /* Encrypt/decrypt must be performed in place */
@@ -650,18 +645,18 @@ static int aria_ccm_tls_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
     /* If encrypting set explicit IV from sequence number (start of AAD) */
     if (EVP_CIPHER_CTX_is_encrypting(ctx))
         memcpy(out, EVP_CIPHER_CTX_buf_noconst(ctx),
-               EVP_CCM_TLS_EXPLICIT_IV_LEN);
+            EVP_CCM_TLS_EXPLICIT_IV_LEN);
     /* Get rest of IV from explicit IV */
     memcpy(ctx->iv + EVP_CCM_TLS_FIXED_IV_LEN, in,
-           EVP_CCM_TLS_EXPLICIT_IV_LEN);
+        EVP_CCM_TLS_EXPLICIT_IV_LEN);
     /* Correct length value */
     len -= EVP_CCM_TLS_EXPLICIT_IV_LEN + cctx->M;
     if (CRYPTO_ccm128_setiv(ccm, ctx->iv, 15 - cctx->L,
-                            len))
-            return -1;
+            len))
+        return -1;
     /* Use saved AAD */
     CRYPTO_ccm128_aad(ccm, EVP_CIPHER_CTX_buf_noconst(ctx),
-                      cctx->tls_aad_len);
+        cctx->tls_aad_len);
     /* Fix buffer to point to payload */
     in += EVP_CCM_TLS_EXPLICIT_IV_LEN;
     out += EVP_CCM_TLS_EXPLICIT_IV_LEN;
@@ -687,9 +682,9 @@ static int aria_ccm_tls_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
 }
 
 static int aria_ccm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
-                          const unsigned char *in, size_t len)
+    const unsigned char *in, size_t len)
 {
-    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX,ctx);
+    EVP_ARIA_CCM_CTX *cctx = EVP_C_DATA(EVP_ARIA_CCM_CTX, ctx);
     CCM128_CONTEXT *ccm = &cctx->ccm;
 
     /* If not set up, return error */
@@ -739,12 +734,12 @@ static int aria_ccm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
     } else {
         int rv = -1;
         if (cctx->str ? !CRYPTO_ccm128_decrypt_ccm64(ccm, in, out, len,
-                                                     cctx->str) :
-            !CRYPTO_ccm128_decrypt(ccm, in, out, len)) {
+                            cctx->str)
+                      : !CRYPTO_ccm128_decrypt(ccm, in, out, len)) {
             unsigned char tag[16];
             if (CRYPTO_ccm128_tag(ccm, tag, cctx->M)) {
                 if (!CRYPTO_memcmp(tag, EVP_CIPHER_CTX_buf_noconst(ctx),
-                                   cctx->M))
+                        cctx->M))
                     rv = len;
             }
         }
@@ -757,34 +752,37 @@ static int aria_ccm_cipher(EVP_CIPHER_CTX *ctx, unsigned char *out,
     }
 }
 
-#define aria_ccm_cleanup    NULL
+#define aria_ccm_cleanup NULL
 
-#define ARIA_AUTH_FLAGS  (EVP_CIPH_FLAG_DEFAULT_ASN1 \
-                          | EVP_CIPH_CUSTOM_IV | EVP_CIPH_FLAG_CUSTOM_CIPHER \
-                          | EVP_CIPH_ALWAYS_CALL_INIT | EVP_CIPH_CTRL_INIT \
-                          | EVP_CIPH_CUSTOM_COPY | EVP_CIPH_FLAG_AEAD_CIPHER \
-                          | EVP_CIPH_CUSTOM_IV_LENGTH)
+#define ARIA_AUTH_FLAGS (EVP_CIPH_FLAG_DEFAULT_ASN1    \
+    | EVP_CIPH_CUSTOM_IV | EVP_CIPH_FLAG_CUSTOM_CIPHER \
+    | EVP_CIPH_ALWAYS_CALL_INIT | EVP_CIPH_CTRL_INIT   \
+    | EVP_CIPH_CUSTOM_COPY | EVP_CIPH_FLAG_AEAD_CIPHER \
+    | EVP_CIPH_CUSTOM_IV_LENGTH)
 
-#define BLOCK_CIPHER_aead(nid,keylen,blocksize,ivlen,nmode,mode,MODE,flags) \
-static const EVP_CIPHER aria_##keylen##_##mode = { \
-        nid##_##keylen##_##nmode,                  \
-        blocksize, keylen/8, ivlen,                \
-        ARIA_AUTH_FLAGS|EVP_CIPH_##MODE##_MODE,    \
-        EVP_ORIG_GLOBAL,                           \
-        aria_##mode##_init_key,                    \
-        aria_##mode##_cipher,                      \
-        aria_##mode##_cleanup,                     \
-        sizeof(EVP_ARIA_##MODE##_CTX),             \
-        NULL,NULL,aria_##mode##_ctrl,NULL };       \
-const EVP_CIPHER *EVP_aria_##keylen##_##mode(void) \
-{ return (EVP_CIPHER*)&aria_##keylen##_##mode; }
+#define BLOCK_CIPHER_aead(keylen, mode, MODE)          \
+    static const EVP_CIPHER aria_##keylen##_##mode = { \
+        NID_aria_##keylen##_##mode,                    \
+        1, keylen / 8, 12,                             \
+        ARIA_AUTH_FLAGS | EVP_CIPH_##MODE##_MODE,      \
+        EVP_ORIG_GLOBAL,                               \
+        aria_##mode##_init_key,                        \
+        aria_##mode##_cipher,                          \
+        aria_##mode##_cleanup,                         \
+        sizeof(EVP_ARIA_##MODE##_CTX),                 \
+        NULL, NULL, aria_##mode##_ctrl, NULL           \
+    };                                                 \
+    const EVP_CIPHER *EVP_aria_##keylen##_##mode(void) \
+    {                                                  \
+        return (EVP_CIPHER *)&aria_##keylen##_##mode;  \
+    }
 
-BLOCK_CIPHER_aead(NID_aria, 128, 1, 12, gcm, gcm, GCM, 0)
-BLOCK_CIPHER_aead(NID_aria, 192, 1, 12, gcm, gcm, GCM, 0)
-BLOCK_CIPHER_aead(NID_aria, 256, 1, 12, gcm, gcm, GCM, 0)
+BLOCK_CIPHER_aead(128, gcm, GCM)
+    BLOCK_CIPHER_aead(192, gcm, GCM)
+        BLOCK_CIPHER_aead(256, gcm, GCM)
 
-BLOCK_CIPHER_aead(NID_aria, 128, 1, 12, ccm, ccm, CCM, 0)
-BLOCK_CIPHER_aead(NID_aria, 192, 1, 12, ccm, ccm, CCM, 0)
-BLOCK_CIPHER_aead(NID_aria, 256, 1, 12, ccm, ccm, CCM, 0)
+            BLOCK_CIPHER_aead(128, ccm, CCM)
+                BLOCK_CIPHER_aead(192, ccm, CCM)
+                    BLOCK_CIPHER_aead(256, ccm, CCM)
 
 #endif
