@@ -1,5 +1,5 @@
 /*
- * Copyright 2000-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2000-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -12,18 +12,17 @@
 
 #define EVP_CTRL_RET_UNSUPPORTED -1
 
-
 struct evp_md_ctx_st {
-    const EVP_MD *reqdigest;    /* The original requested digest */
+    const EVP_MD *reqdigest; /* The original requested digest */
     const EVP_MD *digest;
-    ENGINE *engine;             /* functional reference if 'digest' is
-                                 * ENGINE-provided */
+    ENGINE *engine; /* functional reference if 'digest' is
+                     * ENGINE-provided */
     unsigned long flags;
     void *md_data;
     /* Public key context for sign/verify */
     EVP_PKEY_CTX *pctx;
     /* Update function: usually copied from EVP_MD */
-    int (*update) (EVP_MD_CTX *ctx, const void *data, size_t count);
+    int (*update)(EVP_MD_CTX *ctx, const void *data, size_t count);
 
     /*
      * Opaque ctx returned from a providers digest algorithm implementation
@@ -31,24 +30,24 @@ struct evp_md_ctx_st {
      */
     void *algctx;
     EVP_MD *fetched_digest;
-} /* EVP_MD_CTX */ ;
+} /* EVP_MD_CTX */;
 
 struct evp_cipher_ctx_st {
     const EVP_CIPHER *cipher;
-    ENGINE *engine;             /* functional reference if 'cipher' is
-                                 * ENGINE-provided */
-    int encrypt;                /* encrypt or decrypt */
-    int buf_len;                /* number we have left */
+    ENGINE *engine; /* functional reference if 'cipher' is
+                     * ENGINE-provided */
+    int encrypt; /* encrypt or decrypt */
+    int buf_len; /* number we have left */
     unsigned char oiv[EVP_MAX_IV_LENGTH]; /* original iv */
     unsigned char iv[EVP_MAX_IV_LENGTH]; /* working iv */
     unsigned char buf[EVP_MAX_BLOCK_LENGTH]; /* saved partial block */
-    int num;                    /* used by cfb/ofb/ctr mode */
+    int num; /* used by cfb/ofb/ctr mode */
     /* FIXME: Should this even exist? It appears unused */
-    void *app_data;             /* application stuff */
-    int key_len;                /* May change for variable length cipher */
-    int iv_len;                 /* IV length */
-    unsigned long flags;        /* Various flags */
-    void *cipher_data;          /* per EVP data */
+    void *app_data; /* application stuff */
+    int key_len; /* May change for variable length cipher */
+    int iv_len; /* IV length */
+    unsigned long flags; /* Various flags */
+    void *cipher_data; /* per EVP data */
     int final_used;
     int block_mask;
     unsigned char final[EVP_MAX_BLOCK_LENGTH]; /* possible final block */
@@ -59,10 +58,10 @@ struct evp_cipher_ctx_st {
      */
     void *algctx;
     EVP_CIPHER *fetched_cipher;
-} /* EVP_CIPHER_CTX */ ;
+} /* EVP_CIPHER_CTX */;
 
 struct evp_mac_ctx_st {
-    EVP_MAC *meth;               /* Method structure */
+    EVP_MAC *meth; /* Method structure */
     /*
      * Opaque ctx returned from a providers MAC algorithm implementation
      * OSSL_FUNC_mac_newctx()
@@ -71,30 +70,32 @@ struct evp_mac_ctx_st {
 } /* EVP_MAC_CTX */;
 
 struct evp_kdf_ctx_st {
-    EVP_KDF *meth;              /* Method structure */
+    EVP_KDF *meth; /* Method structure */
     /*
      * Opaque ctx returned from a providers KDF algorithm implementation
      * OSSL_FUNC_kdf_newctx()
      */
     void *algctx;
-} /* EVP_KDF_CTX */ ;
+} /* EVP_KDF_CTX */;
 
 struct evp_rand_ctx_st {
-    EVP_RAND *meth;             /* Method structure */
+    EVP_RAND *meth; /* Method structure */
     /*
      * Opaque ctx returned from a providers rand algorithm implementation
      * OSSL_FUNC_rand_newctx()
      */
     void *algctx;
-    EVP_RAND_CTX *parent;       /* Parent EVP_RAND or NULL if none */
-    CRYPTO_REF_COUNT refcnt;    /* Context reference count */
+    EVP_RAND_CTX *parent; /* Parent EVP_RAND or NULL if none */
+    CRYPTO_REF_COUNT refcnt; /* Context reference count */
     CRYPTO_RWLOCK *refcnt_lock;
-} /* EVP_RAND_CTX */ ;
+} /* EVP_RAND_CTX */;
 
 struct evp_keymgmt_st {
-    int id;                      /* libcrypto internal */
+    int id; /* libcrypto internal */
 
     int name_id;
+    /* NID for the legacy alg if there is one */
+    int legacy_alg;
     char *type_name;
     const char *description;
     OSSL_PROVIDER *prov;
@@ -132,7 +133,7 @@ struct evp_keymgmt_st {
     OSSL_FUNC_keymgmt_export_types_fn *export_types;
     OSSL_FUNC_keymgmt_export_types_ex_fn *export_types_ex;
     OSSL_FUNC_keymgmt_dup_fn *dup;
-} /* EVP_KEYMGMT */ ;
+} /* EVP_KEYMGMT */;
 
 struct evp_keyexch_st {
     int name_id;
@@ -230,13 +231,13 @@ struct evp_kem_st {
 } /* EVP_KEM */;
 
 int PKCS5_v2_PBKDF2_keyivgen(EVP_CIPHER_CTX *ctx, const char *pass,
-                             int passlen, ASN1_TYPE *param,
-                             const EVP_CIPHER *c, const EVP_MD *md,
-                             int en_de);
+    int passlen, ASN1_TYPE *param,
+    const EVP_CIPHER *c, const EVP_MD *md,
+    int en_de);
 int PKCS5_v2_PBKDF2_keyivgen_ex(EVP_CIPHER_CTX *ctx, const char *pass,
-                                int passlen, ASN1_TYPE *param,
-                                const EVP_CIPHER *c, const EVP_MD *md,
-                                int en_de, OSSL_LIB_CTX *libctx, const char *propq);
+    int passlen, ASN1_TYPE *param,
+    const EVP_CIPHER *c, const EVP_MD *md,
+    int en_de, OSSL_LIB_CTX *libctx, const char *propq);
 
 struct evp_Encode_Ctx_st {
     /* number saved in a partial encode/decode */
@@ -263,55 +264,55 @@ int ossl_is_partially_overlapping(const void *ptr1, const void *ptr2, int len);
 #include <openssl/core.h>
 
 void *evp_generic_fetch(OSSL_LIB_CTX *ctx, int operation_id,
-                        const char *name, const char *properties,
-                        void *(*new_method)(int name_id,
-                                            const OSSL_ALGORITHM *algodef,
-                                            OSSL_PROVIDER *prov),
-                        int (*up_ref_method)(void *),
-                        void (*free_method)(void *));
+    const char *name, const char *properties,
+    void *(*new_method)(int name_id,
+        const OSSL_ALGORITHM *algodef,
+        OSSL_PROVIDER *prov),
+    int (*up_ref_method)(void *),
+    void (*free_method)(void *));
 void *evp_generic_fetch_from_prov(OSSL_PROVIDER *prov, int operation_id,
-                                  const char *name, const char *properties,
-                                  void *(*new_method)(int name_id,
-                                                      const OSSL_ALGORITHM *algodef,
-                                                      OSSL_PROVIDER *prov),
-                                  int (*up_ref_method)(void *),
-                                  void (*free_method)(void *));
+    const char *name, const char *properties,
+    void *(*new_method)(int name_id,
+        const OSSL_ALGORITHM *algodef,
+        OSSL_PROVIDER *prov),
+    int (*up_ref_method)(void *),
+    void (*free_method)(void *));
 void evp_generic_do_all_prefetched(OSSL_LIB_CTX *libctx, int operation_id,
-                                   void (*user_fn)(void *method, void *arg),
-                                   void *user_arg);
+    void (*user_fn)(void *method, void *arg),
+    void *user_arg);
 void evp_generic_do_all(OSSL_LIB_CTX *libctx, int operation_id,
-                        void (*user_fn)(void *method, void *arg),
-                        void *user_arg,
-                        void *(*new_method)(int name_id,
-                                            const OSSL_ALGORITHM *algodef,
-                                            OSSL_PROVIDER *prov),
-                        int (*up_ref_method)(void *),
-                        void (*free_method)(void *));
+    void (*user_fn)(void *method, void *arg),
+    void *user_arg,
+    void *(*new_method)(int name_id,
+        const OSSL_ALGORITHM *algodef,
+        OSSL_PROVIDER *prov),
+    int (*up_ref_method)(void *),
+    void (*free_method)(void *));
 
 /* Internal fetchers for method types that are to be combined with others */
 EVP_KEYMGMT *evp_keymgmt_fetch_by_number(OSSL_LIB_CTX *ctx, int name_id,
-                                         const char *properties);
+    const char *properties);
 EVP_SIGNATURE *evp_signature_fetch_from_prov(OSSL_PROVIDER *prov,
-                                             const char *name,
-                                             const char *properties);
+    const char *name,
+    const char *properties);
 EVP_ASYM_CIPHER *evp_asym_cipher_fetch_from_prov(OSSL_PROVIDER *prov,
-                                                 const char *name,
-                                                 const char *properties);
+    const char *name,
+    const char *properties);
 EVP_KEYEXCH *evp_keyexch_fetch_from_prov(OSSL_PROVIDER *prov,
-                                         const char *name,
-                                         const char *properties);
+    const char *name,
+    const char *properties);
 EVP_KEM *evp_kem_fetch_from_prov(OSSL_PROVIDER *prov,
-                                 const char *name,
-                                 const char *properties);
+    const char *name,
+    const char *properties);
 
 /* Internal structure constructors for fetched methods */
 EVP_MD *evp_md_new(void);
 EVP_CIPHER *evp_cipher_new(void);
 
 int evp_cipher_get_asn1_aead_params(EVP_CIPHER_CTX *c, ASN1_TYPE *type,
-                                    evp_cipher_aead_asn1_params *asn1_params);
+    evp_cipher_aead_asn1_params *asn1_params);
 int evp_cipher_set_asn1_aead_params(EVP_CIPHER_CTX *c, ASN1_TYPE *type,
-                                    evp_cipher_aead_asn1_params *asn1_params);
+    evp_cipher_aead_asn1_params *asn1_params);
 
 /* Helper functions to avoid duplicating code */
 
@@ -328,33 +329,33 @@ int evp_cipher_set_asn1_aead_params(EVP_CIPHER_CTX *c, ASN1_TYPE *type,
  */
 int evp_do_ciph_getparams(const EVP_CIPHER *ciph, OSSL_PARAM params[]);
 int evp_do_ciph_ctx_getparams(const EVP_CIPHER *ciph, void *provctx,
-                              OSSL_PARAM params[]);
+    OSSL_PARAM params[]);
 int evp_do_ciph_ctx_setparams(const EVP_CIPHER *ciph, void *provctx,
-                              OSSL_PARAM params[]);
+    OSSL_PARAM params[]);
 int evp_do_md_getparams(const EVP_MD *md, OSSL_PARAM params[]);
 int evp_do_md_ctx_getparams(const EVP_MD *md, void *provctx,
-                            OSSL_PARAM params[]);
+    OSSL_PARAM params[]);
 int evp_do_md_ctx_setparams(const EVP_MD *md, void *provctx,
-                            OSSL_PARAM params[]);
+    OSSL_PARAM params[]);
 
 OSSL_PARAM *evp_pkey_to_param(EVP_PKEY *pkey, size_t *sz);
 
-#define M_check_autoarg(ctx, arg, arglen, err) \
-    if (ctx->pmeth->flags & EVP_PKEY_FLAG_AUTOARGLEN) {           \
-        size_t pksize = (size_t)EVP_PKEY_get_size(ctx->pkey);         \
-                                                                  \
-        if (pksize == 0) {                                        \
-            ERR_raise(ERR_LIB_EVP, EVP_R_INVALID_KEY); /*ckerr_ignore*/ \
-            return 0;                                             \
-        }                                                         \
-        if (arg == NULL) {                                        \
-            *arglen = pksize;                                     \
-            return 1;                                             \
-        }                                                         \
-        if (*arglen < pksize) {                                   \
+#define M_check_autoarg(ctx, arg, arglen, err)                               \
+    if (ctx->pmeth->flags & EVP_PKEY_FLAG_AUTOARGLEN) {                      \
+        size_t pksize = (size_t)EVP_PKEY_get_size(ctx->pkey);                \
+                                                                             \
+        if (pksize == 0) {                                                   \
+            ERR_raise(ERR_LIB_EVP, EVP_R_INVALID_KEY); /*ckerr_ignore*/      \
+            return 0;                                                        \
+        }                                                                    \
+        if (arg == NULL) {                                                   \
+            *arglen = pksize;                                                \
+            return 1;                                                        \
+        }                                                                    \
+        if (*arglen < pksize) {                                              \
             ERR_raise(ERR_LIB_EVP, EVP_R_BUFFER_TOO_SMALL); /*ckerr_ignore*/ \
-            return 0;                                             \
-        }                                                         \
+            return 0;                                                        \
+        }                                                                    \
     }
 
 void evp_pkey_ctx_free_old_ops(EVP_PKEY_CTX *ctx);
@@ -363,8 +364,8 @@ void evp_md_free_int(EVP_MD *md);
 
 /* OSSL_PROVIDER * is only used to get the library context */
 int evp_is_a(OSSL_PROVIDER *prov, int number,
-             const char *legacy_name, const char *name);
+    const char *legacy_name, const char *name);
 int evp_names_do_all(OSSL_PROVIDER *prov, int number,
-                     void (*fn)(const char *name, void *data),
-                     void *data);
+    void (*fn)(const char *name, void *data),
+    void *data);
 int evp_cipher_cache_constants(EVP_CIPHER *cipher);
