@@ -1,5 +1,5 @@
 /*
- * Copyright 2019-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2019-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -21,27 +21,45 @@ static void *keymgmt_new(void)
 {
     EVP_KEYMGMT *keymgmt = NULL;
 
-    if ((keymgmt = OPENSSL_zalloc(sizeof(*keymgmt))) == NULL
-        || (keymgmt->lock = CRYPTO_THREAD_lock_new()) == NULL) {
+    if ((keymgmt = OPENSSL_zalloc(sizeof(*keymgmt))) == NULL)
+        return NULL;
+    if (!CRYPTO_NEW_REF(&keymgmt->refcnt, 1)) {
         EVP_KEYMGMT_free(keymgmt);
-        ERR_raise(ERR_LIB_EVP, ERR_R_MALLOC_FAILURE);
         return NULL;
     }
-
-    keymgmt->refcnt = 1;
-
     return keymgmt;
 }
 
+#ifndef FIPS_MODULE
+static void help_get_legacy_alg_type_from_keymgmt(const char *keytype,
+    void *arg)
+{
+    int *type = arg;
+
+    if (*type == NID_undef)
+        *type = evp_pkey_name2type(keytype);
+}
+
+static int get_legacy_alg_type_from_keymgmt(const EVP_KEYMGMT *keymgmt)
+{
+    int type = NID_undef;
+
+    EVP_KEYMGMT_names_do_all(keymgmt, help_get_legacy_alg_type_from_keymgmt,
+        &type);
+    return type;
+}
+#endif
+
 static void *keymgmt_from_algorithm(int name_id,
-                                    const OSSL_ALGORITHM *algodef,
-                                    OSSL_PROVIDER *prov)
+    const OSSL_ALGORITHM *algodef,
+    OSSL_PROVIDER *prov)
 {
     const OSSL_DISPATCH *fns = algodef->implementation;
     EVP_KEYMGMT *keymgmt = NULL;
     int setparamfncnt = 0, getparamfncnt = 0;
     int setgenparamfncnt = 0;
     int importfncnt = 0, exportfncnt = 0;
+    int importtypesfncnt = 0, exporttypesfncnt = 0;
 
     if ((keymgmt = keymgmt_new()) == NULL)
         return NULL;
@@ -65,21 +83,18 @@ static void *keymgmt_from_algorithm(int name_id,
             break;
         case OSSL_FUNC_KEYMGMT_GEN_SET_TEMPLATE:
             if (keymgmt->gen_set_template == NULL)
-                keymgmt->gen_set_template =
-                    OSSL_FUNC_keymgmt_gen_set_template(fns);
+                keymgmt->gen_set_template = OSSL_FUNC_keymgmt_gen_set_template(fns);
             break;
         case OSSL_FUNC_KEYMGMT_GEN_SET_PARAMS:
             if (keymgmt->gen_set_params == NULL) {
                 setgenparamfncnt++;
-                keymgmt->gen_set_params =
-                    OSSL_FUNC_keymgmt_gen_set_params(fns);
+                keymgmt->gen_set_params = OSSL_FUNC_keymgmt_gen_set_params(fns);
             }
             break;
         case OSSL_FUNC_KEYMGMT_GEN_SETTABLE_PARAMS:
             if (keymgmt->gen_settable_params == NULL) {
                 setgenparamfncnt++;
-                keymgmt->gen_settable_params =
-                    OSSL_FUNC_keymgmt_gen_settable_params(fns);
+                keymgmt->gen_settable_params = OSSL_FUNC_keymgmt_gen_settable_params(fns);
             }
             break;
         case OSSL_FUNC_KEYMGMT_GEN:
@@ -107,11 +122,10 @@ static void *keymgmt_from_algorithm(int name_id,
         case OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS:
             if (keymgmt->gettable_params == NULL) {
                 getparamfncnt++;
-                keymgmt->gettable_params =
-                    OSSL_FUNC_keymgmt_gettable_params(fns);
+                keymgmt->gettable_params = OSSL_FUNC_keymgmt_gettable_params(fns);
             }
             break;
-         case OSSL_FUNC_KEYMGMT_SET_PARAMS:
+        case OSSL_FUNC_KEYMGMT_SET_PARAMS:
             if (keymgmt->set_params == NULL) {
                 setparamfncnt++;
                 keymgmt->set_params = OSSL_FUNC_keymgmt_set_params(fns);
@@ -120,14 +134,12 @@ static void *keymgmt_from_algorithm(int name_id,
         case OSSL_FUNC_KEYMGMT_SETTABLE_PARAMS:
             if (keymgmt->settable_params == NULL) {
                 setparamfncnt++;
-                keymgmt->settable_params =
-                    OSSL_FUNC_keymgmt_settable_params(fns);
+                keymgmt->settable_params = OSSL_FUNC_keymgmt_settable_params(fns);
             }
             break;
         case OSSL_FUNC_KEYMGMT_QUERY_OPERATION_NAME:
             if (keymgmt->query_operation_name == NULL)
-                keymgmt->query_operation_name =
-                    OSSL_FUNC_keymgmt_query_operation_name(fns);
+                keymgmt->query_operation_name = OSSL_FUNC_keymgmt_query_operation_name(fns);
             break;
         case OSSL_FUNC_KEYMGMT_HAS:
             if (keymgmt->has == NULL)
@@ -153,10 +165,20 @@ static void *keymgmt_from_algorithm(int name_id,
             break;
         case OSSL_FUNC_KEYMGMT_IMPORT_TYPES:
             if (keymgmt->import_types == NULL) {
-                importfncnt++;
+                if (importtypesfncnt == 0)
+                    importfncnt++;
+                importtypesfncnt++;
                 keymgmt->import_types = OSSL_FUNC_keymgmt_import_types(fns);
             }
             break;
+        case OSSL_FUNC_KEYMGMT_IMPORT_TYPES_EX:
+            if (keymgmt->import_types_ex == NULL) {
+                if (importtypesfncnt == 0)
+                    importfncnt++;
+                importtypesfncnt++;
+                keymgmt->import_types_ex = OSSL_FUNC_keymgmt_import_types_ex(fns);
+            }
+            break;
         case OSSL_FUNC_KEYMGMT_EXPORT:
             if (keymgmt->export == NULL) {
                 exportfncnt++;
@@ -165,10 +187,20 @@ static void *keymgmt_from_algorithm(int name_id,
             break;
         case OSSL_FUNC_KEYMGMT_EXPORT_TYPES:
             if (keymgmt->export_types == NULL) {
-                exportfncnt++;
+                if (exporttypesfncnt == 0)
+                    exportfncnt++;
+                exporttypesfncnt++;
                 keymgmt->export_types = OSSL_FUNC_keymgmt_export_types(fns);
             }
             break;
+        case OSSL_FUNC_KEYMGMT_EXPORT_TYPES_EX:
+            if (keymgmt->export_types_ex == NULL) {
+                if (exporttypesfncnt == 0)
+                    exportfncnt++;
+                exporttypesfncnt++;
+                keymgmt->export_types_ex = OSSL_FUNC_keymgmt_export_types_ex(fns);
+            }
+            break;
         }
     }
     /*
@@ -200,34 +232,38 @@ static void *keymgmt_from_algorithm(int name_id,
     if (prov != NULL)
         ossl_provider_up_ref(prov);
 
+#ifndef FIPS_MODULE
+    keymgmt->legacy_alg = get_legacy_alg_type_from_keymgmt(keymgmt);
+#endif
+
     return keymgmt;
 }
 
 EVP_KEYMGMT *evp_keymgmt_fetch_from_prov(OSSL_PROVIDER *prov,
-                                         const char *name,
-                                         const char *properties)
+    const char *name,
+    const char *properties)
 {
     return evp_generic_fetch_from_prov(prov, OSSL_OP_KEYMGMT,
-                                       name, properties,
-                                       keymgmt_from_algorithm,
-                                       (int (*)(void *))EVP_KEYMGMT_up_ref,
-                                       (void (*)(void *))EVP_KEYMGMT_free);
+        name, properties,
+        keymgmt_from_algorithm,
+        (int (*)(void *))EVP_KEYMGMT_up_ref,
+        (void (*)(void *))EVP_KEYMGMT_free);
 }
 
 EVP_KEYMGMT *EVP_KEYMGMT_fetch(OSSL_LIB_CTX *ctx, const char *algorithm,
-                               const char *properties)
+    const char *properties)
 {
     return evp_generic_fetch(ctx, OSSL_OP_KEYMGMT, algorithm, properties,
-                             keymgmt_from_algorithm,
-                             (int (*)(void *))EVP_KEYMGMT_up_ref,
-                             (void (*)(void *))EVP_KEYMGMT_free);
+        keymgmt_from_algorithm,
+        (int (*)(void *))EVP_KEYMGMT_up_ref,
+        (void (*)(void *))EVP_KEYMGMT_free);
 }
 
 int EVP_KEYMGMT_up_ref(EVP_KEYMGMT *keymgmt)
 {
     int ref = 0;
 
-    CRYPTO_UP_REF(&keymgmt->refcnt, &ref, keymgmt->lock);
+    CRYPTO_UP_REF(&keymgmt->refcnt, &ref);
     return 1;
 }
 
@@ -238,12 +274,12 @@ void EVP_KEYMGMT_free(EVP_KEYMGMT *keymgmt)
     if (keymgmt == NULL)
         return;
 
-    CRYPTO_DOWN_REF(&keymgmt->refcnt, &ref, keymgmt->lock);
+    CRYPTO_DOWN_REF(&keymgmt->refcnt, &ref);
     if (ref > 0)
         return;
     OPENSSL_free(keymgmt->type_name);
     ossl_provider_free(keymgmt->prov);
-    CRYPTO_THREAD_lock_free(keymgmt->lock);
+    CRYPTO_FREE_REF(&keymgmt->refcnt);
     OPENSSL_free(keymgmt);
 }
 
@@ -257,6 +293,11 @@ int evp_keymgmt_get_number(const EVP_KEYMGMT *keymgmt)
     return keymgmt->name_id;
 }
 
+int evp_keymgmt_get_legacy_alg(const EVP_KEYMGMT *keymgmt)
+{
+    return keymgmt->legacy_alg;
+}
+
 const char *EVP_KEYMGMT_get0_description(const EVP_KEYMGMT *keymgmt)
 {
     return keymgmt->description;
@@ -270,23 +311,23 @@ const char *EVP_KEYMGMT_get0_name(const EVP_KEYMGMT *keymgmt)
 int EVP_KEYMGMT_is_a(const EVP_KEYMGMT *keymgmt, const char *name)
 {
     return keymgmt != NULL
-           && evp_is_a(keymgmt->prov, keymgmt->name_id, NULL, name);
+        && evp_is_a(keymgmt->prov, keymgmt->name_id, NULL, name);
 }
 
 void EVP_KEYMGMT_do_all_provided(OSSL_LIB_CTX *libctx,
-                                 void (*fn)(EVP_KEYMGMT *keymgmt, void *arg),
-                                 void *arg)
+    void (*fn)(EVP_KEYMGMT *keymgmt, void *arg),
+    void *arg)
 {
     evp_generic_do_all(libctx, OSSL_OP_KEYMGMT,
-                       (void (*)(void *, void *))fn, arg,
-                       keymgmt_from_algorithm,
-                       (int (*)(void *))EVP_KEYMGMT_up_ref,
-                       (void (*)(void *))EVP_KEYMGMT_free);
+        (void (*)(void *, void *))fn, arg,
+        keymgmt_from_algorithm,
+        (int (*)(void *))EVP_KEYMGMT_up_ref,
+        (void (*)(void *))EVP_KEYMGMT_free);
 }
 
 int EVP_KEYMGMT_names_do_all(const EVP_KEYMGMT *keymgmt,
-                             void (*fn)(const char *name, void *data),
-                             void *data)
+    void (*fn)(const char *name, void *data),
+    void *data)
 {
     if (keymgmt->prov != NULL)
         return evp_names_do_all(keymgmt->prov, keymgmt->name_id, fn, data);
@@ -318,7 +359,7 @@ void evp_keymgmt_freedata(const EVP_KEYMGMT *keymgmt, void *keydata)
 }
 
 void *evp_keymgmt_gen_init(const EVP_KEYMGMT *keymgmt, int selection,
-                           const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     void *provctx = ossl_provider_ctx(EVP_KEYMGMT_get0_provider(keymgmt));
 
@@ -328,7 +369,7 @@ void *evp_keymgmt_gen_init(const EVP_KEYMGMT *keymgmt, int selection,
 }
 
 int evp_keymgmt_gen_set_template(const EVP_KEYMGMT *keymgmt, void *genctx,
-                                 void *template)
+    void *templ)
 {
     /*
      * It's arguable if we actually should return success in this case, as
@@ -338,11 +379,11 @@ int evp_keymgmt_gen_set_template(const EVP_KEYMGMT *keymgmt, void *genctx,
      */
     if (keymgmt->gen_set_template == NULL)
         return 1;
-    return keymgmt->gen_set_template(genctx, template);
+    return keymgmt->gen_set_template(genctx, templ);
 }
 
 int evp_keymgmt_gen_set_params(const EVP_KEYMGMT *keymgmt, void *genctx,
-                               const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     if (keymgmt->gen_set_params == NULL)
         return 0;
@@ -359,7 +400,7 @@ const OSSL_PARAM *EVP_KEYMGMT_gen_settable_params(const EVP_KEYMGMT *keymgmt)
 }
 
 void *evp_keymgmt_gen(const EVP_KEYMGMT *keymgmt, void *genctx,
-                      OSSL_CALLBACK *cb, void *cbarg)
+    OSSL_CALLBACK *cb, void *cbarg)
 {
     if (keymgmt->gen == NULL)
         return NULL;
@@ -378,7 +419,7 @@ int evp_keymgmt_has_load(const EVP_KEYMGMT *keymgmt)
 }
 
 void *evp_keymgmt_load(const EVP_KEYMGMT *keymgmt,
-                       const void *objref, size_t objref_sz)
+    const void *objref, size_t objref_sz)
 {
     if (evp_keymgmt_has_load(keymgmt))
         return keymgmt->load(objref, objref_sz);
@@ -386,7 +427,7 @@ void *evp_keymgmt_load(const EVP_KEYMGMT *keymgmt,
 }
 
 int evp_keymgmt_get_params(const EVP_KEYMGMT *keymgmt, void *keydata,
-                           OSSL_PARAM params[])
+    OSSL_PARAM params[])
 {
     if (keymgmt->get_params == NULL)
         return 1;
@@ -403,7 +444,7 @@ const OSSL_PARAM *EVP_KEYMGMT_gettable_params(const EVP_KEYMGMT *keymgmt)
 }
 
 int evp_keymgmt_set_params(const EVP_KEYMGMT *keymgmt, void *keydata,
-                           const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     if (keymgmt->set_params == NULL)
         return 1;
@@ -426,7 +467,7 @@ int evp_keymgmt_has(const EVP_KEYMGMT *keymgmt, void *keydata, int selection)
 }
 
 int evp_keymgmt_validate(const EVP_KEYMGMT *keymgmt, void *keydata,
-                         int selection, int checktype)
+    int selection, int checktype)
 {
     /* We assume valid if the implementation doesn't have a function */
     if (keymgmt->validate == NULL)
@@ -435,8 +476,8 @@ int evp_keymgmt_validate(const EVP_KEYMGMT *keymgmt, void *keydata,
 }
 
 int evp_keymgmt_match(const EVP_KEYMGMT *keymgmt,
-                      const void *keydata1, const void *keydata2,
-                      int selection)
+    const void *keydata1, const void *keydata2,
+    int selection)
 {
     /* We assume no match if the implementation doesn't have a function */
     if (keymgmt->match == NULL)
@@ -445,7 +486,7 @@ int evp_keymgmt_match(const EVP_KEYMGMT *keymgmt,
 }
 
 int evp_keymgmt_import(const EVP_KEYMGMT *keymgmt, void *keydata,
-                       int selection, const OSSL_PARAM params[])
+    int selection, const OSSL_PARAM params[])
 {
     if (keymgmt->import == NULL)
         return 0;
@@ -453,15 +494,19 @@ int evp_keymgmt_import(const EVP_KEYMGMT *keymgmt, void *keydata,
 }
 
 const OSSL_PARAM *evp_keymgmt_import_types(const EVP_KEYMGMT *keymgmt,
-                                           int selection)
+    int selection)
 {
+    void *provctx = ossl_provider_ctx(EVP_KEYMGMT_get0_provider(keymgmt));
+
+    if (keymgmt->import_types_ex != NULL)
+        return keymgmt->import_types_ex(provctx, selection);
     if (keymgmt->import_types == NULL)
         return NULL;
     return keymgmt->import_types(selection);
 }
 
 int evp_keymgmt_export(const EVP_KEYMGMT *keymgmt, void *keydata,
-                       int selection, OSSL_CALLBACK *param_cb, void *cbarg)
+    int selection, OSSL_CALLBACK *param_cb, void *cbarg)
 {
     if (keymgmt->export == NULL)
         return 0;
@@ -469,15 +514,19 @@ int evp_keymgmt_export(const EVP_KEYMGMT *keymgmt, void *keydata,
 }
 
 const OSSL_PARAM *evp_keymgmt_export_types(const EVP_KEYMGMT *keymgmt,
-                                           int selection)
+    int selection)
 {
+    void *provctx = ossl_provider_ctx(EVP_KEYMGMT_get0_provider(keymgmt));
+
+    if (keymgmt->export_types_ex != NULL)
+        return keymgmt->export_types_ex(provctx, selection);
     if (keymgmt->export_types == NULL)
         return NULL;
     return keymgmt->export_types(selection);
 }
 
 void *evp_keymgmt_dup(const EVP_KEYMGMT *keymgmt, const void *keydata_from,
-                      int selection)
+    int selection)
 {
     /* We assume no dup if the implementation doesn't have a function */
     if (keymgmt->dup == NULL)
