@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2001-2024 The OpenSSL Project Authors. All Rights Reserved.
  * Copyright Siemens AG 2018-2020
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
@@ -27,66 +27,67 @@
 #define HTTP_PREFIX "HTTP/"
 #define HTTP_VERSION_PATT "1." /* allow 1.x */
 #define HTTP_VERSION_STR_LEN sizeof(HTTP_VERSION_PATT) /* == strlen("1.0") */
-#define HTTP_PREFIX_VERSION HTTP_PREFIX""HTTP_VERSION_PATT
-#define HTTP_1_0 HTTP_PREFIX_VERSION"0" /* "HTTP/1.0" */
+#define HTTP_PREFIX_VERSION HTTP_PREFIX "" HTTP_VERSION_PATT
+#define HTTP_1_0 HTTP_PREFIX_VERSION "0" /* "HTTP/1.0" */
 #define HTTP_LINE1_MINLEN (sizeof(HTTP_PREFIX_VERSION "x 200\n") - 1)
 #define HTTP_VERSION_MAX_REDIRECTIONS 50
 
-#define HTTP_STATUS_CODE_OK                200
+#define HTTP_STATUS_CODE_OK 200
 #define HTTP_STATUS_CODE_MOVED_PERMANENTLY 301
-#define HTTP_STATUS_CODE_FOUND             302
+#define HTTP_STATUS_CODE_FOUND 302
 
 /* Stateful HTTP request code, supporting blocking and non-blocking I/O */
 
 /* Opaque HTTP request status structure */
 
 struct ossl_http_req_ctx_st {
-    int state;                  /* Current I/O state */
-    unsigned char *buf;         /* Buffer to write request or read response */
-    int buf_size;               /* Buffer size */
-    int free_wbio;              /* wbio allocated internally, free with ctx */
-    BIO *wbio;                  /* BIO to write/send request to */
-    BIO *rbio;                  /* BIO to read/receive response from */
-    OSSL_HTTP_bio_cb_t upd_fn;  /* Optional BIO update callback used for TLS */
-    void *upd_arg;              /* Optional arg for update callback function */
-    int use_ssl;                /* Use HTTPS */
-    char *proxy;                /* Optional proxy name or URI */
-    char *server;               /* Optional server hostname */
-    char *port;                 /* Optional server port */
-    BIO *mem;                   /* Mem BIO holding request header or response */
-    BIO *req;                   /* BIO holding the request provided by caller */
-    int method_POST;            /* HTTP method is POST (else GET) */
-    int text;                   /* Request content type is (likely) text */
-    char *expected_ct;          /* Optional expected Content-Type */
-    int expect_asn1;            /* Response must be ASN.1-encoded */
-    unsigned char *pos;         /* Current position sending data */
-    long len_to_send;           /* Number of bytes still to send */
-    size_t resp_len;            /* Length of response */
-    size_t max_resp_len;        /* Maximum length of response, or 0 */
-    int keep_alive;             /* Persistent conn. 0=no, 1=prefer, 2=require */
-    time_t max_time;            /* Maximum end time of current transfer, or 0 */
-    time_t max_total_time;      /* Maximum end time of total transfer, or 0 */
-    char *redirection_url;      /* Location obtained from HTTP status 301/302 */
+    int state; /* Current I/O state */
+    unsigned char *buf; /* Buffer to write request or read response */
+    int buf_size; /* Buffer size */
+    int free_wbio; /* wbio allocated internally, free with ctx */
+    BIO *wbio; /* BIO to write/send request to */
+    BIO *rbio; /* BIO to read/receive response from */
+    OSSL_HTTP_bio_cb_t upd_fn; /* Optional BIO update callback used for TLS */
+    void *upd_arg; /* Optional arg for update callback function */
+    int use_ssl; /* Use HTTPS */
+    char *proxy; /* Optional proxy name or URI */
+    char *server; /* Optional server hostname */
+    char *port; /* Optional server port */
+    BIO *mem; /* Mem BIO holding request header or response */
+    BIO *req; /* BIO holding the request provided by caller */
+    int method_POST; /* HTTP method is POST (else GET) */
+    int text; /* Request content type is (likely) text */
+    char *expected_ct; /* Optional expected Content-Type */
+    int expect_asn1; /* Response must be ASN.1-encoded */
+    unsigned char *pos; /* Current position sending data */
+    long len_to_send; /* Number of bytes still to send */
+    size_t resp_len; /* Length of response */
+    size_t max_resp_len; /* Maximum length of response, or 0 */
+    int keep_alive; /* Persistent conn. 0=no, 1=prefer, 2=require */
+    time_t max_time; /* Maximum end time of current transfer, or 0 */
+    time_t max_total_time; /* Maximum end time of total transfer, or 0 */
+    char *redirection_url; /* Location obtained from HTTP status 301/302 */
+    size_t max_hdr_lines; /* Max. number of http hdr lines, or 0 */
 };
 
 /* HTTP states */
 
-#define OHS_NOREAD         0x1000 /* If set no reading should be performed */
-#define OHS_ERROR          (0 | OHS_NOREAD) /* Error condition */
-#define OHS_ADD_HEADERS    (1 | OHS_NOREAD) /* Adding header lines to request */
-#define OHS_WRITE_INIT     (2 | OHS_NOREAD) /* 1st call: ready to start send */
-#define OHS_WRITE_HDR1     (3 | OHS_NOREAD) /* Request header to be sent */
-#define OHS_WRITE_HDR      (4 | OHS_NOREAD) /* Request header being sent */
-#define OHS_WRITE_REQ      (5 | OHS_NOREAD) /* Request content being sent */
-#define OHS_FLUSH          (6 | OHS_NOREAD) /* Request being flushed */
-#define OHS_FIRSTLINE       1 /* First line of response being read */
-#define OHS_HEADERS         2 /* MIME headers of response being read */
-#define OHS_HEADERS_ERROR   3 /* MIME headers of resp. being read after error */
-#define OHS_REDIRECT        4 /* MIME headers being read, expecting Location */
-#define OHS_ASN1_HEADER     5 /* ASN1 sequence header (tag+length) being read */
-#define OHS_ASN1_CONTENT    6 /* ASN1 content octets being read */
-#define OHS_ASN1_DONE      (7 | OHS_NOREAD) /* ASN1 content read completed */
-#define OHS_STREAM         (8 | OHS_NOREAD) /* HTTP content stream to be read */
+#define OHS_NOREAD 0x1000 /* If set no reading should be performed */
+#define OHS_ERROR (0 | OHS_NOREAD) /* Error condition */
+#define OHS_ADD_HEADERS (1 | OHS_NOREAD) /* Adding header lines to request */
+#define OHS_WRITE_INIT (2 | OHS_NOREAD) /* 1st call: ready to start send */
+#define OHS_WRITE_HDR1 (3 | OHS_NOREAD) /* Request header to be sent */
+#define OHS_WRITE_HDR (4 | OHS_NOREAD) /* Request header being sent */
+#define OHS_WRITE_REQ (5 | OHS_NOREAD) /* Request content being sent */
+#define OHS_FLUSH (6 | OHS_NOREAD) /* Request being flushed */
+#define OHS_FIRSTLINE 1 /* First line of response being read */
+#define OHS_HEADERS 2 /* MIME headers of response being read */
+#define OHS_HEADERS_ERROR 3 /* MIME headers of resp. being read after error */
+#define OHS_REDIRECT 4 /* MIME headers being read, expecting Location */
+#define OHS_ASN1_HEADER 5 /* ASN1 sequence header (tag+length) being read */
+#define OHS_ASN1_CONTENT 6 /* ASN1 content octets being read */
+#define OHS_ASN1_DONE (7 | OHS_NOREAD) /* ASN1 content read completed */
+#define OHS_STREAM (8 | OHS_NOREAD) /* HTTP content stream to be read */
 
 /* Low-level HTTP API implementation */
 
@@ -106,6 +107,7 @@ OSSL_HTTP_REQ_CTX *OSSL_HTTP_REQ_CTX_new(BIO *wbio, BIO *rbio, int buf_size)
     rctx->buf = OPENSSL_malloc(rctx->buf_size);
     rctx->wbio = wbio;
     rctx->rbio = rbio;
+    rctx->max_hdr_lines = OSSL_HTTP_DEFAULT_MAX_RESP_HDR_LINES;
     if (rctx->buf == NULL) {
         OPENSSL_free(rctx);
         return NULL;
@@ -156,7 +158,7 @@ size_t OSSL_HTTP_REQ_CTX_get_resp_len(const OSSL_HTTP_REQ_CTX *rctx)
 }
 
 void OSSL_HTTP_REQ_CTX_set_max_response_length(OSSL_HTTP_REQ_CTX *rctx,
-                                               unsigned long len)
+    unsigned long len)
 {
     if (rctx == NULL) {
         ERR_raise(ERR_LIB_HTTP, ERR_R_PASSED_NULL_PARAMETER);
@@ -171,8 +173,8 @@ void OSSL_HTTP_REQ_CTX_set_max_response_length(OSSL_HTTP_REQ_CTX *rctx,
  * a plain HTTP proxy is used and |path| does not begin with 'http://'.
  */
 int OSSL_HTTP_REQ_CTX_set_request_line(OSSL_HTTP_REQ_CTX *rctx, int method_POST,
-                                       const char *server, const char *port,
-                                       const char *path)
+    const char *server, const char *port,
+    const char *path)
 {
     if (rctx == NULL) {
         ERR_raise(ERR_LIB_HTTP, ERR_R_PASSED_NULL_PARAMETER);
@@ -191,14 +193,14 @@ int OSSL_HTTP_REQ_CTX_set_request_line(OSSL_HTTP_REQ_CTX *rctx, int method_POST,
          * Section 5.1.2 of RFC 1945 states that the absoluteURI form is only
          * allowed when using a proxy
          */
-        if (BIO_printf(rctx->mem, OSSL_HTTP_PREFIX"%s", server) <= 0)
+        if (BIO_printf(rctx->mem, OSSL_HTTP_PREFIX "%s", server) <= 0)
             return 0;
         if (port != NULL && BIO_printf(rctx->mem, ":%s", port) <= 0)
             return 0;
     }
 
     /* Make sure path includes a forward slash (abs_path) */
-    if (path == NULL)  {
+    if (path == NULL) {
         path = "/";
     } else if (HAS_PREFIX(path, "http://")) { /* absoluteURI for proxy use */
         if (server != NULL) {
@@ -212,7 +214,7 @@ int OSSL_HTTP_REQ_CTX_set_request_line(OSSL_HTTP_REQ_CTX *rctx, int method_POST,
      * Add (the rest of) the path and the HTTP version,
      * which is fixed to 1.0 for straightforward implementation of keep-alive
      */
-    if (BIO_printf(rctx->mem, "%s "HTTP_1_0"\r\n", path) <= 0)
+    if (BIO_printf(rctx->mem, "%s " HTTP_1_0 "\r\n", path) <= 0)
         return 0;
 
     rctx->resp_len = 0;
@@ -221,7 +223,7 @@ int OSSL_HTTP_REQ_CTX_set_request_line(OSSL_HTTP_REQ_CTX *rctx, int method_POST,
 }
 
 int OSSL_HTTP_REQ_CTX_add1_header(OSSL_HTTP_REQ_CTX *rctx,
-                                  const char *name, const char *value)
+    const char *name, const char *value)
 {
     if (rctx == NULL || name == NULL) {
         ERR_raise(ERR_LIB_HTTP, ERR_R_PASSED_NULL_PARAMETER);
@@ -244,15 +246,15 @@ int OSSL_HTTP_REQ_CTX_add1_header(OSSL_HTTP_REQ_CTX *rctx,
 }
 
 int OSSL_HTTP_REQ_CTX_set_expected(OSSL_HTTP_REQ_CTX *rctx,
-                                   const char *content_type, int asn1,
-                                   int timeout, int keep_alive)
+    const char *content_type, int asn1,
+    int timeout, int keep_alive)
 {
     if (rctx == NULL) {
         ERR_raise(ERR_LIB_HTTP, ERR_R_PASSED_NULL_PARAMETER);
         return 0;
     }
     if (keep_alive != 0
-            && rctx->state != OHS_ERROR && rctx->state != OHS_ADD_HEADERS) {
+        && rctx->state != OHS_ERROR && rctx->state != OHS_ADD_HEADERS) {
         /* Cannot anymore set keep-alive in request header */
         ERR_raise(ERR_LIB_HTTP, ERR_R_SHOULD_NOT_HAVE_BEEN_CALLED);
         return 0;
@@ -261,7 +263,7 @@ int OSSL_HTTP_REQ_CTX_set_expected(OSSL_HTTP_REQ_CTX *rctx,
     OPENSSL_free(rctx->expected_ct);
     rctx->expected_ct = NULL;
     if (content_type != NULL
-            && (rctx->expected_ct = OPENSSL_strdup(content_type)) == NULL)
+        && (rctx->expected_ct = OPENSSL_strdup(content_type)) == NULL)
         return 0;
 
     rctx->expect_asn1 = asn1;
@@ -274,7 +276,7 @@ int OSSL_HTTP_REQ_CTX_set_expected(OSSL_HTTP_REQ_CTX *rctx,
 }
 
 static int set1_content(OSSL_HTTP_REQ_CTX *rctx,
-                        const char *content_type, BIO *req)
+    const char *content_type, BIO *req)
 {
     long req_len = 0;
 #ifndef OPENSSL_NO_STDIO
@@ -287,7 +289,7 @@ static int set1_content(OSSL_HTTP_REQ_CTX *rctx,
     }
 
     if (rctx->keep_alive != 0
-            && !OSSL_HTTP_REQ_CTX_add1_header(rctx, "Connection", "keep-alive"))
+        && !OSSL_HTTP_REQ_CTX_add1_header(rctx, "Connection", "keep-alive"))
         return 0;
 
     BIO_free(rctx->req);
@@ -330,10 +332,10 @@ static int set1_content(OSSL_HTTP_REQ_CTX *rctx,
     }
     if ((
 #ifndef OPENSSL_NO_STDIO
-         fp != NULL /* definitely correct req_len */ ||
+            fp != NULL /* definitely correct req_len */ ||
 #endif
-         req_len > 0)
-            && BIO_printf(rctx->mem, "Content-Length: %ld\r\n", req_len) < 0)
+            req_len > 0)
+        && BIO_printf(rctx->mem, "Content-Length: %ld\r\n", req_len) < 0)
         return 0;
 
     if (!BIO_up_ref(req))
@@ -343,7 +345,7 @@ static int set1_content(OSSL_HTTP_REQ_CTX *rctx,
 }
 
 int OSSL_HTTP_REQ_CTX_set1_req(OSSL_HTTP_REQ_CTX *rctx, const char *content_type,
-                               const ASN1_ITEM *it, const ASN1_VALUE *req)
+    const ASN1_ITEM *it, const ASN1_VALUE *req)
 {
     BIO *mem = NULL;
     int res = 1;
@@ -355,8 +357,18 @@ int OSSL_HTTP_REQ_CTX_set1_req(OSSL_HTTP_REQ_CTX *rctx, const char *content_type
     return res;
 }
 
+void OSSL_HTTP_REQ_CTX_set_max_response_hdr_lines(OSSL_HTTP_REQ_CTX *rctx,
+    size_t count)
+{
+    if (rctx == NULL) {
+        ERR_raise(ERR_LIB_HTTP, ERR_R_PASSED_NULL_PARAMETER);
+        return;
+    }
+    rctx->max_hdr_lines = count;
+}
+
 static int add1_headers(OSSL_HTTP_REQ_CTX *rctx,
-                        const STACK_OF(CONF_VALUE) *headers, const char *host)
+    const STACK_OF(CONF_VALUE) *headers, const char *host)
 {
     int i;
     int add_host = host != NULL && *host != '\0';
@@ -377,11 +389,11 @@ static int add1_headers(OSSL_HTTP_REQ_CTX *rctx,
 
 /* Create OSSL_HTTP_REQ_CTX structure using the values provided. */
 static OSSL_HTTP_REQ_CTX *http_req_ctx_new(int free_wbio, BIO *wbio, BIO *rbio,
-                                           OSSL_HTTP_bio_cb_t bio_update_fn,
-                                           void *arg, int use_ssl,
-                                           const char *proxy,
-                                           const char *server, const char *port,
-                                           int buf_size, int overall_timeout)
+    OSSL_HTTP_bio_cb_t bio_update_fn,
+    void *arg, int use_ssl,
+    const char *proxy,
+    const char *server, const char *port,
+    int buf_size, int overall_timeout)
 {
     OSSL_HTTP_REQ_CTX *rctx = OSSL_HTTP_REQ_CTX_new(wbio, rbio, buf_size);
 
@@ -392,19 +404,18 @@ static OSSL_HTTP_REQ_CTX *http_req_ctx_new(int free_wbio, BIO *wbio, BIO *rbio,
     rctx->upd_arg = arg;
     rctx->use_ssl = use_ssl;
     if (proxy != NULL
-            && (rctx->proxy = OPENSSL_strdup(proxy)) == NULL)
+        && (rctx->proxy = OPENSSL_strdup(proxy)) == NULL)
         goto err;
     if (server != NULL
-            && (rctx->server = OPENSSL_strdup(server)) == NULL)
+        && (rctx->server = OPENSSL_strdup(server)) == NULL)
         goto err;
     if (port != NULL
-            && (rctx->port = OPENSSL_strdup(port)) == NULL)
+        && (rctx->port = OPENSSL_strdup(port)) == NULL)
         goto err;
-    rctx->max_total_time =
-        overall_timeout > 0 ? time(NULL) + overall_timeout : 0;
+    rctx->max_total_time = overall_timeout > 0 ? time(NULL) + overall_timeout : 0;
     return rctx;
 
- err:
+err:
     OSSL_HTTP_REQ_CTX_free(rctx);
     return NULL;
 }
@@ -480,11 +491,11 @@ static int parse_http_line1(char *line, int *found_keep_alive)
             ERR_raise_data(ERR_LIB_HTTP, err, "code=%s", code);
         else
             ERR_raise_data(ERR_LIB_HTTP, err, "code=%s, reason=%s", code,
-                           reason);
+                reason);
         return retcode;
     }
 
- err:
+err:
     for (i = 0; i < 60 && line[i] != '\0'; i++)
         if (!ossl_isprint(line[i]))
             line[i] = ' ';
@@ -497,13 +508,13 @@ static int check_set_resp_len(OSSL_HTTP_REQ_CTX *rctx, size_t len)
 {
     if (rctx->max_resp_len != 0 && len > rctx->max_resp_len) {
         ERR_raise_data(ERR_LIB_HTTP, HTTP_R_MAX_RESP_LEN_EXCEEDED,
-                       "length=%zu, max=%zu", len, rctx->max_resp_len);
+            "length=%zu, max=%zu", len, rctx->max_resp_len);
         return 0;
     }
     if (rctx->resp_len != 0 && rctx->resp_len != len) {
         ERR_raise_data(ERR_LIB_HTTP, HTTP_R_INCONSISTENT_CONTENT_LENGTH,
-                       "ASN.1 length=%zu, Content-Length=%zu",
-                       len, rctx->resp_len);
+            "ASN.1 length=%zu, Content-Length=%zu",
+            len, rctx->resp_len);
         return 0;
     }
     rctx->resp_len = len;
@@ -537,6 +548,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
     size_t resp_len;
     const unsigned char *p;
     char *buf, *key, *value, *line_end = NULL;
+    size_t resp_hdr_lines = 0;
 
     if (rctx == NULL) {
         ERR_raise(ERR_LIB_HTTP, ERR_R_PASSED_NULL_PARAMETER);
@@ -548,7 +560,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
     }
 
     rctx->redirection_url = NULL;
- next_io:
+next_io:
     buf = (char *)rctx->buf;
     if ((rctx->state & OHS_NOREAD) == 0) {
         if (rctx->expect_asn1) {
@@ -608,7 +620,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
             if (OSSL_TRACE_ENABLED(HTTP) && rctx->state == OHS_WRITE_HDR1)
                 OSSL_TRACE(HTTP, "Sending request: [\n");
             OSSL_TRACE_STRING(HTTP, rctx->state != OHS_WRITE_REQ || rctx->text,
-                              rctx->state != OHS_WRITE_REQ, rctx->pos, sz);
+                rctx->state != OHS_WRITE_REQ, rctx->pos, sz);
             if (rctx->state == OHS_WRITE_HDR1)
                 rctx->state = OHS_WRITE_HDR;
             rctx->pos += sz;
@@ -659,7 +671,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
     case OHS_REDIRECT:
 
         /* Attempt to read a line in */
- next_line:
+    next_line:
         /*
          * Due to strange memory BIO behavior with BIO_gets we have to check
          * there's a complete line in there before calling BIO_gets or we'll
@@ -682,6 +694,14 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
             return 0;
         }
 
+        resp_hdr_lines++;
+        if (rctx->max_hdr_lines != 0 && rctx->max_hdr_lines < resp_hdr_lines) {
+            ERR_raise(ERR_LIB_HTTP, HTTP_R_RESPONSE_TOO_MANY_HDRLINES);
+            OSSL_TRACE(HTTP, "Received too many headers\n");
+            rctx->state = OHS_ERROR;
+            return 0;
+        }
+
         /* Don't allow excessive lines */
         if (n == rctx->buf_size) {
             ERR_raise(ERR_LIB_HTTP, HTTP_R_RESPONSE_LINE_TOO_LONG);
@@ -730,7 +750,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
         }
         if (value != NULL && line_end != NULL) {
             if (rctx->state == OHS_REDIRECT
-                    && OPENSSL_strcasecmp(key, "Location") == 0) {
+                && OPENSSL_strcasecmp(key, "Location") == 0) {
                 rctx->redirection_url = value;
                 return 0;
             }
@@ -746,11 +766,12 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
                             || (semicolon = strchr(value, ';')) == NULL
                             || (size_t)(semicolon - value) != strlen(rctx->expected_ct)
                             || OPENSSL_strncasecmp(rctx->expected_ct, value,
-                                                   semicolon - value) != 0)) {
+                                   semicolon - value)
+                                != 0)) {
                         ERR_raise_data(ERR_LIB_HTTP,
-                                       HTTP_R_UNEXPECTED_CONTENT_TYPE,
-                                       "expected=%s, actual=%s",
-                                       rctx->expected_ct, value);
+                            HTTP_R_UNEXPECTED_CONTENT_TYPE,
+                            "expected=%s, actual=%s",
+                            rctx->expected_ct, value);
                         return 0;
                     }
                     found_expected_ct = 1;
@@ -767,8 +788,8 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
                 resp_len = (size_t)strtoul(value, &line_end, 10);
                 if (line_end == value || *line_end != '\0') {
                     ERR_raise_data(ERR_LIB_HTTP,
-                                   HTTP_R_ERROR_PARSING_CONTENT_LENGTH,
-                                   "input=%s", value);
+                        HTTP_R_ERROR_PARSING_CONTENT_LENGTH,
+                        "input=%s", value);
                     return 0;
                 }
                 if (!check_set_resp_len(rctx, resp_len))
@@ -786,8 +807,10 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
         if (OSSL_TRACE_ENABLED(HTTP))
             OSSL_TRACE(HTTP, "]\n");
 
+        resp_hdr_lines = 0;
+
         if (rctx->keep_alive != 0 /* do not let server initiate keep_alive */
-                && !found_keep_alive /* otherwise there is no change */) {
+            && !found_keep_alive /* otherwise there is no change */) {
             if (rctx->keep_alive == 2) {
                 rctx->keep_alive = 0;
                 ERR_raise(ERR_LIB_HTTP, HTTP_R_SERVER_CANCELED_CONNECTION);
@@ -802,7 +825,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
 
                 OSSL_TRACE(HTTP, "Received error response body: [\n");
                 while ((n = BIO_read(rctx->rbio, rctx->buf, rctx->buf_size)) > 0
-                       || (OSSL_sleep(100), BIO_should_retry(rctx->rbio))) {
+                    || (OSSL_sleep(100), BIO_should_retry(rctx->rbio))) {
                     OSSL_TRACE_STRING(HTTP, got_text, 1, rctx->buf, n);
                     if (n > 0)
                         printed_final_nl = rctx->buf[n - 1] == '\n';
@@ -815,7 +838,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
 
         if (rctx->expected_ct != NULL && !found_expected_ct) {
             ERR_raise_data(ERR_LIB_HTTP, HTTP_R_MISSING_CONTENT_TYPE,
-                           "expected=%s", rctx->expected_ct);
+                "expected=%s", rctx->expected_ct);
             return 0;
         }
         if (rctx->state == OHS_REDIRECT) {
@@ -890,7 +913,7 @@ int OSSL_HTTP_REQ_CTX_nbio(OSSL_HTTP_REQ_CTX *rctx)
 }
 
 int OSSL_HTTP_REQ_CTX_nbio_d2i(OSSL_HTTP_REQ_CTX *rctx,
-                               ASN1_VALUE **pval, const ASN1_ITEM *it)
+    ASN1_VALUE **pval, const ASN1_ITEM *it)
 {
     const unsigned char *p;
     int rv;
@@ -900,7 +923,6 @@ int OSSL_HTTP_REQ_CTX_nbio_d2i(OSSL_HTTP_REQ_CTX *rctx,
         return rv;
     *pval = ASN1_item_d2i(NULL, &p, BIO_get_mem_data(rctx->mem, &p), it);
     return *pval != NULL;
-
 }
 
 #ifndef OPENSSL_NO_SOCK
@@ -921,10 +943,10 @@ static const char *explict_or_default_port(const char *hostserv, const char *por
 
 /* set up a new connection BIO, to HTTP server or to HTTP(S) proxy if given */
 static BIO *http_new_bio(const char *server /* optionally includes ":port" */,
-                         const char *server_port /* explicit server port */,
-                         int use_ssl,
-                         const char *proxy /* optionally includes ":port" */,
-                         const char *proxy_port /* explicit proxy port */)
+    const char *server_port /* explicit server port */,
+    int use_ssl,
+    const char *proxy /* optionally includes ":port" */,
+    const char *proxy_port /* explicit proxy port */)
 {
     const char *host = server;
     const char *port = server_port;
@@ -946,7 +968,7 @@ static BIO *http_new_bio(const char *server /* optionally includes ":port" */,
     if (port != NULL)
         (void)BIO_set_conn_port(cbio, port);
 
- end:
+end:
     return cbio;
 }
 #endif /* OPENSSL_NO_SOCK */
@@ -992,10 +1014,10 @@ int OSSL_HTTP_is_alive(const OSSL_HTTP_REQ_CTX *rctx)
 
 /* Initiate an HTTP session using bio, else use given server, proxy, etc. */
 OSSL_HTTP_REQ_CTX *OSSL_HTTP_open(const char *server, const char *port,
-                                  const char *proxy, const char *no_proxy,
-                                  int use_ssl, BIO *bio, BIO *rbio,
-                                  OSSL_HTTP_bio_cb_t bio_update_fn, void *arg,
-                                  int buf_size, int overall_timeout)
+    const char *proxy, const char *no_proxy,
+    int use_ssl, BIO *bio, BIO *rbio,
+    OSSL_HTTP_bio_cb_t bio_update_fn, void *arg,
+    int buf_size, int overall_timeout)
 {
     BIO *cbio; /* == bio if supplied, used as connection BIO if rbio is NULL */
     OSSL_HTTP_REQ_CTX *rctx = NULL;
@@ -1028,8 +1050,8 @@ OSSL_HTTP_REQ_CTX *OSSL_HTTP_open(const char *server, const char *port,
         proxy = OSSL_HTTP_adapt_proxy(proxy, no_proxy, server, use_ssl);
         if (proxy != NULL
             && !OSSL_HTTP_parse_url(proxy, NULL /* use_ssl */, NULL /* user */,
-                                    &proxy_host, &proxy_port, NULL /* num */,
-                                    NULL /* path */, NULL, NULL))
+                &proxy_host, &proxy_port, NULL /* num */,
+                NULL /* path */, NULL, NULL))
             return NULL;
         cbio = http_new_bio(server, port, use_ssl, proxy_host, proxy_port);
         OPENSSL_free(proxy_host);
@@ -1064,10 +1086,10 @@ OSSL_HTTP_REQ_CTX *OSSL_HTTP_open(const char *server, const char *port,
     }
 
     rctx = http_req_ctx_new(bio == NULL, cbio, rbio != NULL ? rbio : cbio,
-                            bio_update_fn, arg, use_ssl, proxy, server, port,
-                            buf_size, overall_timeout);
+        bio_update_fn, arg, use_ssl, proxy, server, port,
+        buf_size, overall_timeout);
 
- end:
+end:
     if (rctx != NULL)
         /* remove any spurious error queue entries by ssl_add_cert_chain() */
         (void)ERR_pop_to_mark();
@@ -1078,10 +1100,10 @@ OSSL_HTTP_REQ_CTX *OSSL_HTTP_open(const char *server, const char *port,
 }
 
 int OSSL_HTTP_set1_request(OSSL_HTTP_REQ_CTX *rctx, const char *path,
-                           const STACK_OF(CONF_VALUE) *headers,
-                           const char *content_type, BIO *req,
-                           const char *expected_content_type, int expect_asn1,
-                           size_t max_resp_len, int timeout, int keep_alive)
+    const STACK_OF(CONF_VALUE) *headers,
+    const char *content_type, BIO *req,
+    const char *expected_content_type, int expect_asn1,
+    size_t max_resp_len, int timeout, int keep_alive)
 {
     int use_http_proxy;
 
@@ -1097,11 +1119,12 @@ int OSSL_HTTP_set1_request(OSSL_HTTP_REQ_CTX *rctx, const char *path,
     rctx->max_resp_len = max_resp_len; /* allows for 0: indefinite */
 
     return OSSL_HTTP_REQ_CTX_set_request_line(rctx, req != NULL,
-                                              use_http_proxy ? rctx->server
-                                              : NULL, rctx->port, path)
+               use_http_proxy ? rctx->server
+                              : NULL,
+               rctx->port, path)
         && add1_headers(rctx, headers, rctx->server)
         && OSSL_HTTP_REQ_CTX_set_expected(rctx, expected_content_type,
-                                          expect_asn1, timeout, keep_alive)
+            expect_asn1, timeout, keep_alive)
         && set1_content(rctx, content_type, req);
 }
 
@@ -1137,26 +1160,25 @@ BIO *OSSL_HTTP_exchange(OSSL_HTTP_REQ_CTX *rctx, char **redirection_url)
             int reason = ERR_GET_REASON(err);
 
             if (lib == ERR_LIB_SSL || lib == ERR_LIB_HTTP
-                    || (lib == ERR_LIB_BIO && reason == BIO_R_CONNECT_TIMEOUT)
-                    || (lib == ERR_LIB_BIO && reason == BIO_R_CONNECT_ERROR)
+                || (lib == ERR_LIB_BIO && reason == BIO_R_CONNECT_TIMEOUT)
+                || (lib == ERR_LIB_BIO && reason == BIO_R_CONNECT_ERROR)
 #ifndef OPENSSL_NO_CMP
-                    || (lib == ERR_LIB_CMP
-                        && reason == CMP_R_POTENTIALLY_INVALID_CERTIFICATE)
+                || (lib == ERR_LIB_CMP
+                    && reason == CMP_R_POTENTIALLY_INVALID_CERTIFICATE)
 #endif
-                ) {
+            ) {
                 if (rctx->server != NULL) {
                     BIO_snprintf(buf, sizeof(buf), "server=http%s://%s%s%s",
-                                 rctx->use_ssl ? "s" : "", rctx->server,
-                                 rctx->port != NULL ? ":" : "",
-                                 rctx->port != NULL ? rctx->port : "");
+                        rctx->use_ssl ? "s" : "", rctx->server,
+                        rctx->port != NULL ? ":" : "",
+                        rctx->port != NULL ? rctx->port : "");
                     ERR_add_error_data(1, buf);
                 }
                 if (rctx->proxy != NULL)
                     ERR_add_error_data(2, " proxy=", rctx->proxy);
                 if (err == 0) {
                     BIO_snprintf(buf, sizeof(buf), " peer has disconnected%s",
-                                 rctx->use_ssl ? " violating the protocol" :
-                                 ", likely because it requires the use of TLS");
+                        rctx->use_ssl ? " violating the protocol" : ", likely because it requires the use of TLS");
                     ERR_add_error_data(1, buf);
                 }
             }
@@ -1176,8 +1198,7 @@ static int redirection_ok(int n_redir, const char *old_url, const char *new_url)
     }
     if (*new_url == '/') /* redirection to same server => same protocol */
         return 1;
-    if (HAS_PREFIX(old_url, OSSL_HTTPS_NAME":") &&
-        !HAS_PREFIX(new_url, OSSL_HTTPS_NAME":")) {
+    if (HAS_PREFIX(old_url, OSSL_HTTPS_NAME ":") && !HAS_PREFIX(new_url, OSSL_HTTPS_NAME ":")) {
         ERR_raise(ERR_LIB_HTTP, HTTP_R_REDIRECTION_FROM_HTTPS_TO_HTTP);
         return 0;
     }
@@ -1186,11 +1207,11 @@ static int redirection_ok(int n_redir, const char *old_url, const char *new_url)
 
 /* Get data via HTTP from server at given URL, potentially with redirection */
 BIO *OSSL_HTTP_get(const char *url, const char *proxy, const char *no_proxy,
-                   BIO *bio, BIO *rbio,
-                   OSSL_HTTP_bio_cb_t bio_update_fn, void *arg,
-                   int buf_size, const STACK_OF(CONF_VALUE) *headers,
-                   const char *expected_ct, int expect_asn1,
-                   size_t max_resp_len, int timeout)
+    BIO *bio, BIO *rbio,
+    OSSL_HTTP_bio_cb_t bio_update_fn, void *arg,
+    int buf_size, const STACK_OF(CONF_VALUE) *headers,
+    const char *expected_ct, int expect_asn1,
+    size_t max_resp_len, int timeout)
 {
     char *current_url;
     int n_redirs = 0;
@@ -1213,21 +1234,21 @@ BIO *OSSL_HTTP_get(const char *url, const char *proxy, const char *no_proxy,
         char *redirection_url;
 
         if (!OSSL_HTTP_parse_url(current_url, &use_ssl, NULL /* user */, &host,
-                                 &port, NULL /* port_num */, &path, NULL, NULL))
+                &port, NULL /* port_num */, &path, NULL, NULL))
             break;
 
         rctx = OSSL_HTTP_open(host, port, proxy, no_proxy,
-                              use_ssl, bio, rbio, bio_update_fn, arg,
-                              buf_size, timeout);
+            use_ssl, bio, rbio, bio_update_fn, arg,
+            buf_size, timeout);
     new_rpath:
         redirection_url = NULL;
         if (rctx != NULL) {
             if (!OSSL_HTTP_set1_request(rctx, path, headers,
-                                        NULL /* content_type */,
-                                        NULL /* req */,
-                                        expected_ct, expect_asn1, max_resp_len,
-                                        -1 /* use same max time (timeout) */,
-                                        0 /* no keep_alive */)) {
+                    NULL /* content_type */,
+                    NULL /* req */,
+                    expected_ct, expect_asn1, max_resp_len,
+                    -1 /* use same max time (timeout) */,
+                    0 /* no keep_alive */)) {
                 OSSL_HTTP_REQ_CTX_free(rctx);
                 rctx = NULL;
             } else {
@@ -1237,7 +1258,7 @@ BIO *OSSL_HTTP_get(const char *url, const char *proxy, const char *no_proxy,
         OPENSSL_free(path);
         if (resp == NULL && redirection_url != NULL) {
             if (redirection_ok(++n_redirs, current_url, redirection_url)
-                    && may_still_retry(max_time, &timeout)) {
+                && may_still_retry(max_time, &timeout)) {
                 (void)BIO_reset(bio);
                 OPENSSL_free(current_url);
                 current_url = redirection_url;
@@ -1275,29 +1296,29 @@ BIO *OSSL_HTTP_get(const char *url, const char *proxy, const char *no_proxy,
 
 /* Exchange request and response over a connection managed via |prctx| */
 BIO *OSSL_HTTP_transfer(OSSL_HTTP_REQ_CTX **prctx,
-                        const char *server, const char *port,
-                        const char *path, int use_ssl,
-                        const char *proxy, const char *no_proxy,
-                        BIO *bio, BIO *rbio,
-                        OSSL_HTTP_bio_cb_t bio_update_fn, void *arg,
-                        int buf_size, const STACK_OF(CONF_VALUE) *headers,
-                        const char *content_type, BIO *req,
-                        const char *expected_ct, int expect_asn1,
-                        size_t max_resp_len, int timeout, int keep_alive)
+    const char *server, const char *port,
+    const char *path, int use_ssl,
+    const char *proxy, const char *no_proxy,
+    BIO *bio, BIO *rbio,
+    OSSL_HTTP_bio_cb_t bio_update_fn, void *arg,
+    int buf_size, const STACK_OF(CONF_VALUE) *headers,
+    const char *content_type, BIO *req,
+    const char *expected_ct, int expect_asn1,
+    size_t max_resp_len, int timeout, int keep_alive)
 {
     OSSL_HTTP_REQ_CTX *rctx = prctx == NULL ? NULL : *prctx;
     BIO *resp = NULL;
 
     if (rctx == NULL) {
         rctx = OSSL_HTTP_open(server, port, proxy, no_proxy,
-                              use_ssl, bio, rbio, bio_update_fn, arg,
-                              buf_size, timeout);
+            use_ssl, bio, rbio, bio_update_fn, arg,
+            buf_size, timeout);
         timeout = -1; /* Already set during opening the connection */
     }
     if (rctx != NULL) {
         if (OSSL_HTTP_set1_request(rctx, path, headers, content_type, req,
-                                   expected_ct, expect_asn1,
-                                   max_resp_len, timeout, keep_alive))
+                expected_ct, expect_asn1,
+                max_resp_len, timeout, keep_alive))
             resp = OSSL_HTTP_exchange(rctx, NULL);
         if (resp == NULL || !OSSL_HTTP_is_alive(rctx)) {
             if (!OSSL_HTTP_close(rctx, resp != NULL)) {
@@ -1320,7 +1341,7 @@ int OSSL_HTTP_close(OSSL_HTTP_REQ_CTX *rctx, int ok)
     /* callback can be used to finish TLS session and free its BIO */
     if (rctx != NULL && rctx->upd_fn != NULL) {
         wbio = (*rctx->upd_fn)(rctx->wbio, rctx->upd_arg,
-                               0 /* disconnect */, ok);
+            0 /* disconnect */, ok);
         ret = wbio != NULL;
         if (ret)
             rctx->wbio = wbio;
@@ -1359,8 +1380,8 @@ static char *base64encode(const void *buf, size_t len)
  * to print additional diagnostic information in a user-oriented way.
  */
 int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
-                            const char *proxyuser, const char *proxypass,
-                            int timeout, BIO *bio_err, const char *prog)
+    const char *proxyuser, const char *proxypass,
+    int timeout, BIO *bio_err, const char *prog)
 {
 #undef BUF_SIZE
 #define BUF_SIZE (8 * 1024)
@@ -1373,7 +1394,7 @@ int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
     time_t max_time = timeout > 0 ? time(NULL) + timeout : 0;
 
     if (bio == NULL || server == NULL
-            || (bio_err != NULL && prog == NULL)) {
+        || (bio_err != NULL && prog == NULL)) {
         ERR_raise(ERR_LIB_HTTP, ERR_R_PASSED_NULL_PARAMETER);
         goto end;
     }
@@ -1386,7 +1407,7 @@ int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
     }
     BIO_push(fbio, bio);
 
-    BIO_printf(fbio, "CONNECT %s:%s "HTTP_1_0"\r\n", server, port);
+    BIO_printf(fbio, "CONNECT %s:%s " HTTP_1_0 "\r\n", server, port);
 
     /*
      * Workaround for broken proxies which would otherwise close
@@ -1405,7 +1426,8 @@ int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
         if (proxyauth == NULL)
             goto end;
         if (BIO_snprintf(proxyauth, len + 1, "%s:%s", proxyuser,
-                         proxypass != NULL ? proxypass : "") != (int)len)
+                proxypass != NULL ? proxypass : "")
+            != (int)len)
             goto proxy_end;
         proxyauthenc = base64encode(proxyauth, len);
         if (proxyauthenc != NULL) {
@@ -1434,7 +1456,7 @@ int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
         rv = BIO_wait(fbio, max_time, 100 /* milliseconds */);
         if (rv <= 0) {
             BIO_printf(bio_err, "%s: HTTP CONNECT %s\n", prog,
-                       rv == 0 ? "timed out" : "failed waiting for data");
+                rv == 0 ? "timed out" : "failed waiting for data");
             goto end;
         }
 
@@ -1453,15 +1475,15 @@ int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
         if (!CHECK_AND_SKIP_PREFIX(mbufp, HTTP_PREFIX)) {
             ERR_raise(ERR_LIB_HTTP, HTTP_R_HEADER_PARSE_ERROR);
             BIO_printf(bio_err, "%s: HTTP CONNECT failed, non-HTTP response\n",
-                       prog);
+                prog);
             /* Wrong protocol, not even HTTP, so stop reading headers */
             goto end;
         }
         if (!HAS_PREFIX(mbufp, HTTP_VERSION_PATT)) {
             ERR_raise(ERR_LIB_HTTP, HTTP_R_RECEIVED_WRONG_HTTP_VERSION);
             BIO_printf(bio_err,
-                       "%s: HTTP CONNECT failed, bad HTTP version %.*s\n",
-                       prog, (int)HTTP_VERSION_STR_LEN, mbufp);
+                "%s: HTTP CONNECT failed, bad HTTP version %.*s\n",
+                prog, (int)HTTP_VERSION_STR_LEN, mbufp);
             goto end;
         }
         mbufp += HTTP_VERSION_STR_LEN;
@@ -1475,9 +1497,9 @@ int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
                 read_len--;
             mbuf[read_len] = '\0';
             ERR_raise_data(ERR_LIB_HTTP, HTTP_R_CONNECT_FAILURE,
-                           "reason=%s", mbufp);
+                "reason=%s", mbufp);
             BIO_printf(bio_err, "%s: HTTP CONNECT failed, reason=%s\n",
-                       prog, mbufp);
+                prog, mbufp);
             goto end;
         }
         ret = 1;
@@ -1493,7 +1515,7 @@ int OSSL_HTTP_proxy_connect(BIO *bio, const char *server, const char *port,
         read_len = BIO_gets(fbio, mbuf, BUF_SIZE);
     } while (read_len > 2);
 
- end:
+end:
     if (fbio != NULL) {
         (void)BIO_flush(fbio);
         BIO_pop(fbio);
