@@ -24,19 +24,19 @@ static CRYPTO_realloc_fn realloc_impl = CRYPTO_realloc;
 static CRYPTO_free_fn free_impl = CRYPTO_free;
 
 #if !defined(OPENSSL_NO_CRYPTO_MDEBUG) && !defined(FIPS_MODULE)
-# include "internal/tsan_assist.h"
+#include "internal/tsan_assist.h"
 
-# ifdef TSAN_REQUIRES_LOCKING
-#  define INCREMENT(x) /* empty */
-#  define LOAD(x) 0
-# else  /* TSAN_REQUIRES_LOCKING */
+#ifdef TSAN_REQUIRES_LOCKING
+#define INCREMENT(x) /* empty */
+#define LOAD(x) 0
+#else /* TSAN_REQUIRES_LOCKING */
 static TSAN_QUALIFIER int malloc_count;
 static TSAN_QUALIFIER int realloc_count;
 static TSAN_QUALIFIER int free_count;
 
-#  define INCREMENT(x) tsan_counter(&(x))
-#  define LOAD(x)      tsan_load(&x)
-# endif /* TSAN_REQUIRES_LOCKING */
+#define INCREMENT(x) tsan_counter(&(x))
+#define LOAD(x) tsan_load(&x)
+#endif /* TSAN_REQUIRES_LOCKING */
 
 static char *md_failstring;
 static long md_count;
@@ -46,17 +46,19 @@ static int md_tracefd = -1;
 static void parseit(void);
 static int shouldfail(void);
 
-# define FAILTEST() if (shouldfail()) return NULL
+#define FAILTEST()    \
+    if (shouldfail()) \
+    return NULL
 
 #else
 
-# define INCREMENT(x) /* empty */
-# define FAILTEST() /* empty */
+#define INCREMENT(x) /* empty */
+#define FAILTEST() /* empty */
 #endif
 
 int CRYPTO_set_mem_functions(CRYPTO_malloc_fn malloc_fn,
-                             CRYPTO_realloc_fn realloc_fn,
-                             CRYPTO_free_fn free_fn)
+    CRYPTO_realloc_fn realloc_fn,
+    CRYPTO_free_fn free_fn)
 {
     if (!allow_customize)
         return 0;
@@ -70,8 +72,8 @@ int CRYPTO_set_mem_functions(CRYPTO_malloc_fn malloc_fn,
 }
 
 void CRYPTO_get_mem_functions(CRYPTO_malloc_fn *malloc_fn,
-                              CRYPTO_realloc_fn *realloc_fn,
-                              CRYPTO_free_fn *free_fn)
+    CRYPTO_realloc_fn *realloc_fn,
+    CRYPTO_free_fn *free_fn)
 {
     if (malloc_fn != NULL)
         *malloc_fn = malloc_impl;
@@ -126,10 +128,10 @@ static void parseit(void)
  * Some rand() implementations aren't good, but we're not
  * dealing with secure randomness here.
  */
-# ifdef _WIN32
-#  define random() rand()
-#  define srandom(seed) srand(seed)
-# endif
+#ifdef _WIN32
+#define random() rand()
+#define srandom(seed) srand(seed)
+#endif
 /*
  * See if the current malloc should fail.
  */
@@ -137,20 +139,20 @@ static int shouldfail(void)
 {
     int roll = (int)(random() % 10000);
     int shoulditfail = roll < md_fail_percent;
-# ifndef _WIN32
-/* suppressed on Windows as POSIX-like file descriptors are non-inheritable */
+#ifndef _WIN32
+    /* suppressed on Windows as POSIX-like file descriptors are non-inheritable */
     int len;
     char buff[80];
 
     if (md_tracefd > 0) {
         BIO_snprintf(buff, sizeof(buff),
-                     "%c C%ld %%%d R%d\n",
-                     shoulditfail ? '-' : '+', md_count, md_fail_percent, roll);
+            "%c C%ld %%%d R%d\n",
+            shoulditfail ? '-' : '+', md_count, md_fail_percent, roll);
         len = strlen(buff);
         if (write(md_tracefd, buff, len) != len)
             perror("shouldfail write failed");
     }
-# endif
+#endif
 
     if (md_count) {
         /* If we used up this one, go to the next. */
@@ -202,7 +204,7 @@ void *CRYPTO_malloc(size_t num, const char *file, int line)
     ptr = malloc(num);
     if (ptr != NULL)
         return ptr;
- err:
+err:
     /*
      * ossl_err_get_state_int() in err.c uses CRYPTO_zalloc(num, NULL, 0) for
      * ERR_STATE allocation. Prevent mem alloc error loop while reporting error.
@@ -245,7 +247,7 @@ void *CRYPTO_realloc(void *str, size_t num, const char *file, int line)
 }
 
 void *CRYPTO_clear_realloc(void *str, size_t old_len, size_t num,
-                           const char *file, int line)
+    const char *file, int line)
 {
     void *ret = NULL;
 
@@ -259,7 +261,7 @@ void *CRYPTO_clear_realloc(void *str, size_t old_len, size_t num,
 
     /* Can't shrink the buffer since memcpy below copies |old_len| bytes. */
     if (num < old_len) {
-        OPENSSL_cleanse((char*)str + num, old_len - num);
+        OPENSSL_cleanse((char *)str + num, old_len - num);
         return str;
     }
 
@@ -293,7 +295,7 @@ void CRYPTO_clear_free(void *str, size_t num, const char *file, int line)
 
 #if !defined(OPENSSL_NO_CRYPTO_MDEBUG)
 
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
 int CRYPTO_mem_ctrl(int mode)
 {
     (void)mode;
@@ -308,7 +310,9 @@ int CRYPTO_set_mem_debug(int flag)
 
 int CRYPTO_mem_debug_push(const char *info, const char *file, int line)
 {
-    (void)info; (void)file; (void)line;
+    (void)info;
+    (void)file;
+    (void)line;
     return 0;
 }
 
@@ -318,21 +322,33 @@ int CRYPTO_mem_debug_pop(void)
 }
 
 void CRYPTO_mem_debug_malloc(void *addr, size_t num, int flag,
-                             const char *file, int line)
+    const char *file, int line)
 {
-    (void)addr; (void)num; (void)flag; (void)file; (void)line;
+    (void)addr;
+    (void)num;
+    (void)flag;
+    (void)file;
+    (void)line;
 }
 
 void CRYPTO_mem_debug_realloc(void *addr1, void *addr2, size_t num, int flag,
-                              const char *file, int line)
+    const char *file, int line)
 {
-    (void)addr1; (void)addr2; (void)num; (void)flag; (void)file; (void)line;
+    (void)addr1;
+    (void)addr2;
+    (void)num;
+    (void)flag;
+    (void)file;
+    (void)line;
 }
 
 void CRYPTO_mem_debug_free(void *addr, int flag,
-                           const char *file, int line)
+    const char *file, int line)
 {
-    (void)addr; (void)flag; (void)file; (void)line;
+    (void)addr;
+    (void)flag;
+    (void)file;
+    (void)line;
 }
 
 int CRYPTO_mem_leaks(BIO *b)
@@ -341,21 +357,22 @@ int CRYPTO_mem_leaks(BIO *b)
     return -1;
 }
 
-#  ifndef OPENSSL_NO_STDIO
+#ifndef OPENSSL_NO_STDIO
 int CRYPTO_mem_leaks_fp(FILE *fp)
 {
     (void)fp;
     return -1;
 }
-#  endif
+#endif
 
 int CRYPTO_mem_leaks_cb(int (*cb)(const char *str, size_t len, void *u),
-                        void *u)
+    void *u)
 {
-    (void)cb; (void)u;
+    (void)cb;
+    (void)u;
     return -1;
 }
 
-# endif
+#endif
 
 #endif
