@@ -49,8 +49,8 @@ struct ossl_param_bld_st {
 };
 
 static OSSL_PARAM_BLD_DEF *param_push(OSSL_PARAM_BLD *bld, const char *key,
-                                      int size, size_t alloc, int type,
-                                      int secure)
+    size_t size, size_t alloc, int type,
+    int secure)
 {
     OSSL_PARAM_BLD_DEF *pd = OPENSSL_zalloc(sizeof(*pd));
 
@@ -72,7 +72,7 @@ static OSSL_PARAM_BLD_DEF *param_push(OSSL_PARAM_BLD *bld, const char *key,
 }
 
 static int param_push_num(OSSL_PARAM_BLD *bld, const char *key,
-                          void *num, size_t size, int type)
+    void *num, size_t size, int type)
 {
     OSSL_PARAM_BLD_DEF *pd = param_push(bld, key, size, size, type, 0);
 
@@ -125,85 +125,85 @@ int OSSL_PARAM_BLD_push_int(OSSL_PARAM_BLD *bld, const char *key, int num)
 }
 
 int OSSL_PARAM_BLD_push_uint(OSSL_PARAM_BLD *bld, const char *key,
-                             unsigned int num)
+    unsigned int num)
 {
     return param_push_num(bld, key, &num, sizeof(num),
-                          OSSL_PARAM_UNSIGNED_INTEGER);
+        OSSL_PARAM_UNSIGNED_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_long(OSSL_PARAM_BLD *bld, const char *key,
-                             long int num)
+    long int num)
 {
     return param_push_num(bld, key, &num, sizeof(num), OSSL_PARAM_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_ulong(OSSL_PARAM_BLD *bld, const char *key,
-                              unsigned long int num)
+    unsigned long int num)
 {
     return param_push_num(bld, key, &num, sizeof(num),
-                          OSSL_PARAM_UNSIGNED_INTEGER);
+        OSSL_PARAM_UNSIGNED_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_int32(OSSL_PARAM_BLD *bld, const char *key,
-                              int32_t num)
+    int32_t num)
 {
     return param_push_num(bld, key, &num, sizeof(num), OSSL_PARAM_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_uint32(OSSL_PARAM_BLD *bld, const char *key,
-                               uint32_t num)
+    uint32_t num)
 {
     return param_push_num(bld, key, &num, sizeof(num),
-                          OSSL_PARAM_UNSIGNED_INTEGER);
+        OSSL_PARAM_UNSIGNED_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_int64(OSSL_PARAM_BLD *bld, const char *key,
-                              int64_t num)
+    int64_t num)
 {
     return param_push_num(bld, key, &num, sizeof(num), OSSL_PARAM_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_uint64(OSSL_PARAM_BLD *bld, const char *key,
-                               uint64_t num)
+    uint64_t num)
 {
     return param_push_num(bld, key, &num, sizeof(num),
-                          OSSL_PARAM_UNSIGNED_INTEGER);
+        OSSL_PARAM_UNSIGNED_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_size_t(OSSL_PARAM_BLD *bld, const char *key,
-                               size_t num)
+    size_t num)
 {
     return param_push_num(bld, key, &num, sizeof(num),
-                          OSSL_PARAM_UNSIGNED_INTEGER);
+        OSSL_PARAM_UNSIGNED_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_time_t(OSSL_PARAM_BLD *bld, const char *key,
-                               time_t num)
+    time_t num)
 {
     return param_push_num(bld, key, &num, sizeof(num),
-                          OSSL_PARAM_INTEGER);
+        OSSL_PARAM_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_double(OSSL_PARAM_BLD *bld, const char *key,
-                               double num)
+    double num)
 {
     return param_push_num(bld, key, &num, sizeof(num), OSSL_PARAM_REAL);
 }
 
 static int push_BN(OSSL_PARAM_BLD *bld, const char *key,
-                   const BIGNUM *bn, size_t sz, int type)
+    const BIGNUM *bn, size_t sz, int type)
 {
     int n, secure = 0;
     OSSL_PARAM_BLD_DEF *pd;
 
     if (!ossl_assert(type == OSSL_PARAM_UNSIGNED_INTEGER
-                     || type == OSSL_PARAM_INTEGER))
+            || type == OSSL_PARAM_INTEGER))
         return 0;
 
     if (bn != NULL) {
         if (type == OSSL_PARAM_UNSIGNED_INTEGER && BN_is_negative(bn)) {
             ERR_raise_data(ERR_LIB_CRYPTO, ERR_R_UNSUPPORTED,
-                           "Negative big numbers are unsupported for OSSL_PARAM_UNSIGNED_INTEGER");
+                "Negative big numbers are unsupported for OSSL_PARAM_UNSIGNED_INTEGER");
             return 0;
         }
 
@@ -231,36 +231,32 @@ static int push_BN(OSSL_PARAM_BLD *bld, const char *key,
 }
 
 int OSSL_PARAM_BLD_push_BN(OSSL_PARAM_BLD *bld, const char *key,
-                           const BIGNUM *bn)
+    const BIGNUM *bn)
 {
     if (bn != NULL && BN_is_negative(bn))
         return push_BN(bld, key, bn, BN_num_bytes(bn) + 1,
-                       OSSL_PARAM_INTEGER);
+            OSSL_PARAM_INTEGER);
     return push_BN(bld, key, bn, bn == NULL ? 0 : BN_num_bytes(bn),
-                   OSSL_PARAM_UNSIGNED_INTEGER);
+        OSSL_PARAM_UNSIGNED_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_BN_pad(OSSL_PARAM_BLD *bld, const char *key,
-                               const BIGNUM *bn, size_t sz)
+    const BIGNUM *bn, size_t sz)
 {
     if (bn != NULL && BN_is_negative(bn))
         return push_BN(bld, key, bn, BN_num_bytes(bn),
-                       OSSL_PARAM_INTEGER);
+            OSSL_PARAM_INTEGER);
     return push_BN(bld, key, bn, sz, OSSL_PARAM_UNSIGNED_INTEGER);
 }
 
 int OSSL_PARAM_BLD_push_utf8_string(OSSL_PARAM_BLD *bld, const char *key,
-                                    const char *buf, size_t bsize)
+    const char *buf, size_t bsize)
 {
     OSSL_PARAM_BLD_DEF *pd;
     int secure;
 
     if (bsize == 0)
         bsize = strlen(buf);
-    if (bsize > INT_MAX) {
-        ERR_raise(ERR_LIB_CRYPTO, CRYPTO_R_STRING_TOO_LONG);
-        return 0;
-    }
     secure = CRYPTO_secure_allocated(buf);
     pd = param_push(bld, key, bsize, bsize + 1, OSSL_PARAM_UTF8_STRING, secure);
     if (pd == NULL)
@@ -270,16 +266,12 @@ int OSSL_PARAM_BLD_push_utf8_string(OSSL_PARAM_BLD *bld, const char *key,
 }
 
 int OSSL_PARAM_BLD_push_utf8_ptr(OSSL_PARAM_BLD *bld, const char *key,
-                                 char *buf, size_t bsize)
+    char *buf, size_t bsize)
 {
     OSSL_PARAM_BLD_DEF *pd;
 
     if (bsize == 0)
         bsize = strlen(buf);
-    if (bsize > INT_MAX) {
-        ERR_raise(ERR_LIB_CRYPTO, CRYPTO_R_STRING_TOO_LONG);
-        return 0;
-    }
     pd = param_push(bld, key, bsize, sizeof(buf), OSSL_PARAM_UTF8_PTR, 0);
     if (pd == NULL)
         return 0;
@@ -288,15 +280,11 @@ int OSSL_PARAM_BLD_push_utf8_ptr(OSSL_PARAM_BLD *bld, const char *key,
 }
 
 int OSSL_PARAM_BLD_push_octet_string(OSSL_PARAM_BLD *bld, const char *key,
-                                     const void *buf, size_t bsize)
+    const void *buf, size_t bsize)
 {
     OSSL_PARAM_BLD_DEF *pd;
     int secure;
 
-    if (bsize > INT_MAX) {
-        ERR_raise(ERR_LIB_CRYPTO, CRYPTO_R_STRING_TOO_LONG);
-        return 0;
-    }
     secure = CRYPTO_secure_allocated(buf);
     pd = param_push(bld, key, bsize, bsize, OSSL_PARAM_OCTET_STRING, secure);
     if (pd == NULL)
@@ -306,14 +294,10 @@ int OSSL_PARAM_BLD_push_octet_string(OSSL_PARAM_BLD *bld, const char *key,
 }
 
 int OSSL_PARAM_BLD_push_octet_ptr(OSSL_PARAM_BLD *bld, const char *key,
-                                  void *buf, size_t bsize)
+    void *buf, size_t bsize)
 {
     OSSL_PARAM_BLD_DEF *pd;
 
-    if (bsize > INT_MAX) {
-        ERR_raise(ERR_LIB_CRYPTO, CRYPTO_R_STRING_TOO_LONG);
-        return 0;
-    }
     pd = param_push(bld, key, bsize, sizeof(buf), OSSL_PARAM_OCTET_PTR, 0);
     if (pd == NULL)
         return 0;
@@ -322,8 +306,8 @@ int OSSL_PARAM_BLD_push_octet_ptr(OSSL_PARAM_BLD *bld, const char *key,
 }
 
 static OSSL_PARAM *param_bld_convert(OSSL_PARAM_BLD *bld, OSSL_PARAM *param,
-                                     OSSL_PARAM_ALIGNED_BLOCK *blk,
-                                     OSSL_PARAM_ALIGNED_BLOCK *secure)
+    OSSL_PARAM_ALIGNED_BLOCK *blk,
+    OSSL_PARAM_ALIGNED_BLOCK *secure)
 {
     int i, num = sk_OSSL_PARAM_BLD_DEF_num(bld->params);
     OSSL_PARAM_BLD_DEF *pd;
@@ -351,11 +335,11 @@ static OSSL_PARAM *param_bld_convert(OSSL_PARAM_BLD *bld, OSSL_PARAM *param,
             else
                 BN_signed_bn2native(pd->bn, (unsigned char *)p, pd->size);
         } else if (pd->type == OSSL_PARAM_OCTET_PTR
-                   || pd->type == OSSL_PARAM_UTF8_PTR) {
+            || pd->type == OSSL_PARAM_UTF8_PTR) {
             /* PTR */
             *(const void **)p = pd->string;
         } else if (pd->type == OSSL_PARAM_OCTET_STRING
-                   || pd->type == OSSL_PARAM_UTF8_STRING) {
+            || pd->type == OSSL_PARAM_UTF8_STRING) {
             if (pd->string != NULL)
                 memcpy(p, pd->string, pd->size);
             else
