@@ -1,5 +1,5 @@
 /*
- * Copyright 1995-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 1995-2023 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -31,10 +31,10 @@
 int ossl_pem_check_suffix(const char *pem_str, const char *suffix);
 
 static EVP_PKEY *pem_read_bio_key_decoder(BIO *bp, EVP_PKEY **x,
-                                          pem_password_cb *cb, void *u,
-                                          OSSL_LIB_CTX *libctx,
-                                          const char *propq,
-                                          int selection)
+    pem_password_cb *cb, void *u,
+    OSSL_LIB_CTX *libctx,
+    const char *propq,
+    int selection)
 {
     EVP_PKEY *pkey = NULL;
     OSSL_DECODER_CTX *dctx = NULL;
@@ -45,7 +45,7 @@ static EVP_PKEY *pem_read_bio_key_decoder(BIO *bp, EVP_PKEY **x,
         return NULL;
 
     dctx = OSSL_DECODER_CTX_new_for_pkey(&pkey, "PEM", NULL, NULL,
-                                         selection, libctx, propq);
+        selection, libctx, propq);
 
     if (dctx == NULL)
         return NULL;
@@ -75,6 +75,10 @@ static EVP_PKEY *pem_read_bio_key_decoder(BIO *bp, EVP_PKEY **x,
         }
     ERR_pop_to_mark();
 
+    /* if we were asked for private key, the public key is optional */
+    if ((selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) != 0)
+        selection = selection & ~OSSL_KEYMGMT_SELECT_PUBLIC_KEY;
+
     if (!evp_keymgmt_util_has(pkey, selection)) {
         EVP_PKEY_free(pkey);
         pkey = NULL;
@@ -87,16 +91,16 @@ static EVP_PKEY *pem_read_bio_key_decoder(BIO *bp, EVP_PKEY **x,
         *x = pkey;
     }
 
- err:
+err:
     OSSL_DECODER_CTX_free(dctx);
     return pkey;
 }
 
 static EVP_PKEY *pem_read_bio_key_legacy(BIO *bp, EVP_PKEY **x,
-                                         pem_password_cb *cb, void *u,
-                                         OSSL_LIB_CTX *libctx,
-                                         const char *propq,
-                                         int selection)
+    pem_password_cb *cb, void *u,
+    OSSL_LIB_CTX *libctx,
+    const char *propq,
+    int selection)
 {
     char *nm = NULL;
     const unsigned char *p = NULL;
@@ -105,22 +109,22 @@ static EVP_PKEY *pem_read_bio_key_legacy(BIO *bp, EVP_PKEY **x,
     int slen;
     EVP_PKEY *ret = NULL;
 
-    ERR_set_mark();  /* not interested in PEM read errors */
-    if (selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) {
+    ERR_set_mark(); /* not interested in PEM read errors */
+    if ((selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) != 0) {
         if (!PEM_bytes_read_bio_secmem(&data, &len, &nm,
-                                       PEM_STRING_EVP_PKEY,
-                                       bp, cb, u)) {
+                PEM_STRING_EVP_PKEY,
+                bp, cb, u)) {
             ERR_pop_to_mark();
             return NULL;
-         }
+        }
     } else {
         const char *pem_string = PEM_STRING_PARAMETERS;
 
-        if (selection & OSSL_KEYMGMT_SELECT_PUBLIC_KEY)
+        if ((selection & OSSL_KEYMGMT_SELECT_PUBLIC_KEY) != 0)
             pem_string = PEM_STRING_PUBLIC;
         if (!PEM_bytes_read_bio(&data, &len, &nm,
-                                pem_string,
-                                bp, cb, u)) {
+                pem_string,
+                bp, cb, u)) {
             ERR_pop_to_mark();
             return NULL;
         }
@@ -173,10 +177,14 @@ static EVP_PKEY *pem_read_bio_key_legacy(BIO *bp, EVP_PKEY **x,
         if (ameth == NULL || ameth->old_priv_decode == NULL)
             goto p8err;
         ret = ossl_d2i_PrivateKey_legacy(ameth->pkey_id, x, &p, len, libctx,
-                                         propq);
-    } else if (selection & OSSL_KEYMGMT_SELECT_PUBLIC_KEY) {
+            propq);
+    } else if ((selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY) == 0
+        && (selection & OSSL_KEYMGMT_SELECT_PUBLIC_KEY) != 0) {
+        /* Trying legacy PUBKEY decoding only if we do not want private key. */
         ret = ossl_d2i_PUBKEY_legacy(x, &p, len);
-    } else if ((slen = ossl_pem_check_suffix(nm, "PARAMETERS")) > 0) {
+    } else if ((selection & EVP_PKEY_KEYPAIR) == 0
+        && (slen = ossl_pem_check_suffix(nm, "PARAMETERS")) > 0) {
+        /* Trying legacy params decoding only if we do not want a key. */
         ret = EVP_PKEY_new();
         if (ret == NULL)
             goto err;
@@ -193,21 +201,21 @@ static EVP_PKEY *pem_read_bio_key_legacy(BIO *bp, EVP_PKEY **x,
         }
     }
 
- p8err:
+p8err:
     if (ret == NULL && ERR_peek_last_error() == 0)
         /* ensure some error is reported but do not hide the real one */
         ERR_raise(ERR_LIB_PEM, ERR_R_ASN1_LIB);
- err:
+err:
     OPENSSL_secure_free(nm);
     OPENSSL_secure_clear_free(data, len);
     return ret;
 }
 
 static EVP_PKEY *pem_read_bio_key(BIO *bp, EVP_PKEY **x,
-                                  pem_password_cb *cb, void *u,
-                                  OSSL_LIB_CTX *libctx,
-                                  const char *propq,
-                                  int selection)
+    pem_password_cb *cb, void *u,
+    OSSL_LIB_CTX *libctx,
+    const char *propq,
+    int selection)
 {
     EVP_PKEY *ret = NULL;
     BIO *new_bio = NULL;
@@ -231,18 +239,19 @@ static EVP_PKEY *pem_read_bio_key(BIO *bp, EVP_PKEY **x,
 
     ERR_set_mark();
     ret = pem_read_bio_key_decoder(bp, x, ossl_pw_pem_password, &pwdata,
-                                   libctx, propq, selection);
+        libctx, propq, selection);
     if (ret == NULL
         && (BIO_seek(bp, pos) < 0
             || (ret = pem_read_bio_key_legacy(bp, x,
-                                              ossl_pw_pem_password, &pwdata,
-                                              libctx, propq,
-                                              selection)) == NULL))
+                    ossl_pw_pem_password, &pwdata,
+                    libctx, propq,
+                    selection))
+                == NULL))
         ERR_clear_last_mark();
     else
         ERR_pop_to_mark();
 
- err:
+err:
     ossl_pw_clear_passphrase_data(&pwdata);
     if (new_bio != NULL) {
         BIO_pop(new_bio);
@@ -252,23 +261,23 @@ static EVP_PKEY *pem_read_bio_key(BIO *bp, EVP_PKEY **x,
 }
 
 EVP_PKEY *PEM_read_bio_PUBKEY_ex(BIO *bp, EVP_PKEY **x,
-                                 pem_password_cb *cb, void *u,
-                                 OSSL_LIB_CTX *libctx, const char *propq)
+    pem_password_cb *cb, void *u,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     return pem_read_bio_key(bp, x, cb, u, libctx, propq,
-                            EVP_PKEY_PUBLIC_KEY);
+        EVP_PKEY_PUBLIC_KEY);
 }
 
 EVP_PKEY *PEM_read_bio_PUBKEY(BIO *bp, EVP_PKEY **x, pem_password_cb *cb,
-                              void *u)
+    void *u)
 {
     return PEM_read_bio_PUBKEY_ex(bp, x, cb, u, NULL, NULL);
 }
 
 #ifndef OPENSSL_NO_STDIO
 EVP_PKEY *PEM_read_PUBKEY_ex(FILE *fp, EVP_PKEY **x,
-                             pem_password_cb *cb, void *u,
-                             OSSL_LIB_CTX *libctx, const char *propq)
+    pem_password_cb *cb, void *u,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     BIO *b;
     EVP_PKEY *ret;
@@ -290,15 +299,16 @@ EVP_PKEY *PEM_read_PUBKEY(FILE *fp, EVP_PKEY **x, pem_password_cb *cb, void *u)
 #endif
 
 EVP_PKEY *PEM_read_bio_PrivateKey_ex(BIO *bp, EVP_PKEY **x,
-                                     pem_password_cb *cb, void *u,
-                                     OSSL_LIB_CTX *libctx, const char *propq)
+    pem_password_cb *cb, void *u,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     return pem_read_bio_key(bp, x, cb, u, libctx, propq,
-                            EVP_PKEY_KEYPAIR);
+        /* we also want the public key, if available */
+        EVP_PKEY_KEYPAIR);
 }
 
 EVP_PKEY *PEM_read_bio_PrivateKey(BIO *bp, EVP_PKEY **x, pem_password_cb *cb,
-                                  void *u)
+    void *u)
 {
     return PEM_read_bio_PrivateKey_ex(bp, x, cb, u, NULL, NULL);
 }
@@ -310,32 +320,35 @@ PEM_write_cb_ex_fnsig(PrivateKey, EVP_PKEY, BIO, write_bio)
     IMPLEMENT_PEM_provided_write_body_pass();
     IMPLEMENT_PEM_provided_write_body_main(pkey, bio);
 
- legacy:
-    if (x->ameth == NULL || x->ameth->priv_encode != NULL)
+legacy:
+    if (x != NULL && (x->ameth == NULL || x->ameth->priv_encode != NULL))
         return PEM_write_bio_PKCS8PrivateKey(out, x, enc,
-                                             (const char *)kstr, klen, cb, u);
+            (const char *)kstr, klen, cb, u);
     return PEM_write_bio_PrivateKey_traditional(out, x, enc, kstr, klen, cb, u);
 }
 
 PEM_write_cb_fnsig(PrivateKey, EVP_PKEY, BIO, write_bio)
 {
     return PEM_write_bio_PrivateKey_ex(out, x, enc, kstr, klen, cb, u,
-                                       NULL, NULL);
+        NULL, NULL);
 }
 
 /*
  * Note: there is no way to tell a provided pkey encoder to use "traditional"
- * encoding.  Therefore, if the pkey is provided, we try to take a copy 
+ * encoding.  Therefore, if the pkey is provided, we try to take a copy
  */
 int PEM_write_bio_PrivateKey_traditional(BIO *bp, const EVP_PKEY *x,
-                                         const EVP_CIPHER *enc,
-                                         const unsigned char *kstr, int klen,
-                                         pem_password_cb *cb, void *u)
+    const EVP_CIPHER *enc,
+    const unsigned char *kstr, int klen,
+    pem_password_cb *cb, void *u)
 {
     char pem_str[80];
     EVP_PKEY *copy = NULL;
     int ret;
 
+    if (x == NULL)
+        return 0;
+
     if (evp_pkey_is_assigned(x)
         && evp_pkey_is_provided(x)
         && evp_pkey_copy_downgraded(&copy, x))
@@ -343,21 +356,31 @@ int PEM_write_bio_PrivateKey_traditional(BIO *bp, const EVP_PKEY *x,
 
     if (x->ameth == NULL || x->ameth->old_priv_encode == NULL) {
         ERR_raise(ERR_LIB_PEM, PEM_R_UNSUPPORTED_PUBLIC_KEY_TYPE);
+        EVP_PKEY_free(copy);
         return 0;
     }
     BIO_snprintf(pem_str, 80, "%s PRIVATE KEY", x->ameth->pem_str);
     ret = PEM_ASN1_write_bio((i2d_of_void *)i2d_PrivateKey,
-                             pem_str, bp, x, enc, kstr, klen, cb, u);
+        pem_str, bp, x, enc, kstr, klen, cb, u);
 
     EVP_PKEY_free(copy);
     return ret;
 }
 
-EVP_PKEY *PEM_read_bio_Parameters_ex(BIO *bp, EVP_PKEY **x,
-                                     OSSL_LIB_CTX *libctx, const char *propq)
+static int no_password_cb(char *buf, int num, int rwflag, void *userdata)
 {
-    return pem_read_bio_key(bp, x, NULL, NULL, libctx, propq,
-                            EVP_PKEY_KEY_PARAMETERS);
+    return -1;
+}
+
+EVP_PKEY *PEM_read_bio_Parameters_ex(BIO *bp, EVP_PKEY **x,
+    OSSL_LIB_CTX *libctx, const char *propq)
+{
+    /*
+     * PEM_read_bio_Parameters(_ex) should never ask for a password. Any attempt
+     * to get a password just fails.
+     */
+    return pem_read_bio_key(bp, x, no_password_cb, NULL, libctx, propq,
+        EVP_PKEY_KEY_PARAMETERS);
 }
 
 EVP_PKEY *PEM_read_bio_Parameters(BIO *bp, EVP_PKEY **x)
@@ -372,19 +395,19 @@ PEM_write_fnsig(Parameters, EVP_PKEY, BIO, write_bio)
 
     IMPLEMENT_PEM_provided_write_body_main(pkey, bio);
 
- legacy:
+legacy:
     if (!x->ameth || !x->ameth->param_encode)
         return 0;
 
     BIO_snprintf(pem_str, 80, "%s PARAMETERS", x->ameth->pem_str);
     return PEM_ASN1_write_bio((i2d_of_void *)x->ameth->param_encode,
-                              pem_str, out, x, NULL, NULL, 0, 0, NULL);
+        pem_str, out, x, NULL, NULL, 0, 0, NULL);
 }
 
 #ifndef OPENSSL_NO_STDIO
 EVP_PKEY *PEM_read_PrivateKey_ex(FILE *fp, EVP_PKEY **x, pem_password_cb *cb,
-                                 void *u, OSSL_LIB_CTX *libctx,
-                                 const char *propq)
+    void *u, OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     BIO *b;
     EVP_PKEY *ret;
@@ -400,7 +423,7 @@ EVP_PKEY *PEM_read_PrivateKey_ex(FILE *fp, EVP_PKEY **x, pem_password_cb *cb,
 }
 
 EVP_PKEY *PEM_read_PrivateKey(FILE *fp, EVP_PKEY **x, pem_password_cb *cb,
-                              void *u)
+    void *u)
 {
     return PEM_read_PrivateKey_ex(fp, x, cb, u, NULL, NULL);
 }
@@ -415,7 +438,7 @@ PEM_write_cb_ex_fnsig(PrivateKey, EVP_PKEY, FILE, write)
         return 0;
     }
     ret = PEM_write_bio_PrivateKey_ex(b, x, enc, kstr, klen, cb, u,
-                                      libctx, propq);
+        libctx, propq);
     BIO_free(b);
     return ret;
 }
