@@ -17,12 +17,11 @@
 
 #define BUFFERSIZE 4096
 
-
 static int pkcs7_copy_existing_digest(PKCS7 *p7, PKCS7_SIGNER_INFO *si);
 
 PKCS7 *PKCS7_sign_ex(X509 *signcert, EVP_PKEY *pkey, STACK_OF(X509) *certs,
-                     BIO *data, int flags, OSSL_LIB_CTX *libctx,
-                     const char *propq)
+    BIO *data, int flags, OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     PKCS7 *p7;
     int i;
@@ -59,18 +58,17 @@ PKCS7 *PKCS7_sign_ex(X509 *signcert, EVP_PKEY *pkey, STACK_OF(X509) *certs,
     if (PKCS7_final(p7, data, flags))
         return p7;
 
- err:
+err:
     PKCS7_free(p7);
     return NULL;
 }
 
 PKCS7 *PKCS7_sign(X509 *signcert, EVP_PKEY *pkey, STACK_OF(X509) *certs,
-                  BIO *data, int flags)
+    BIO *data, int flags)
 {
     return PKCS7_sign_ex(signcert, pkey, certs, data, flags, NULL, NULL);
 }
 
-
 int PKCS7_final(PKCS7 *p7, BIO *data, int flags)
 {
     BIO *p7bio;
@@ -95,7 +93,6 @@ err:
     BIO_free_all(p7bio);
 
     return ret;
-
 }
 
 /* Check to see if a cipher exists and if so add S/MIME capabilities */
@@ -115,15 +112,15 @@ static int add_digest_smcap(STACK_OF(X509_ALGOR) *sk, int nid, int arg)
 }
 
 PKCS7_SIGNER_INFO *PKCS7_sign_add_signer(PKCS7 *p7, X509 *signcert,
-                                         EVP_PKEY *pkey, const EVP_MD *md,
-                                         int flags)
+    EVP_PKEY *pkey, const EVP_MD *md,
+    int flags)
 {
     PKCS7_SIGNER_INFO *si = NULL;
     STACK_OF(X509_ALGOR) *smcap = NULL;
 
     if (!X509_check_private_key(signcert, pkey)) {
         ERR_raise(ERR_LIB_PKCS7,
-                  PKCS7_R_PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE);
+            PKCS7_R_PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE);
         return NULL;
     }
 
@@ -173,7 +170,7 @@ PKCS7_SIGNER_INFO *PKCS7_sign_add_signer(PKCS7 *p7, X509 *signcert,
         }
     }
     return si;
- err:
+err:
     sk_X509_ALGOR_pop_free(smcap, X509_ALGOR_free);
     return NULL;
 }
@@ -200,7 +197,6 @@ static int pkcs7_copy_existing_digest(PKCS7 *p7, PKCS7_SIGNER_INFO *si)
             osdig = PKCS7_digest_from_attributes(sitmp->auth_attr);
             break;
         }
-
     }
 
     if (osdig != NULL)
@@ -212,7 +208,7 @@ static int pkcs7_copy_existing_digest(PKCS7 *p7, PKCS7_SIGNER_INFO *si)
 
 /* This strongly overlaps with CMS_verify(), partly with PKCS7_dataVerify() */
 int PKCS7_verify(PKCS7 *p7, STACK_OF(X509) *certs, X509_STORE *store,
-                 BIO *indata, BIO *out, int flags)
+    BIO *indata, BIO *out, int flags)
 {
     STACK_OF(X509) *signers;
     X509 *signer;
@@ -269,7 +265,7 @@ int PKCS7_verify(PKCS7 *p7, STACK_OF(X509) *certs, X509_STORE *store,
     /* Now verify the certificates */
     p7_ctx = ossl_pkcs7_get0_ctx(p7);
     cert_ctx = X509_STORE_CTX_new_ex(ossl_pkcs7_ctx_get0_libctx(p7_ctx),
-                                     ossl_pkcs7_ctx_get0_propq(p7_ctx));
+        ossl_pkcs7_ctx_get0_propq(p7_ctx));
     if (cert_ctx == NULL)
         goto err;
     if (!(flags & PKCS7_NOVERIFY))
@@ -277,7 +273,7 @@ int PKCS7_verify(PKCS7 *p7, STACK_OF(X509) *certs, X509_STORE *store,
             signer = sk_X509_value(signers, k);
             if (!(flags & PKCS7_NOCHAIN)) {
                 if (!X509_STORE_CTX_init(cert_ctx, store, signer,
-                                         p7->d.sign->cert)) {
+                        p7->d.sign->cert)) {
                     ERR_raise(ERR_LIB_PKCS7, ERR_R_X509_LIB);
                     goto err;
                 }
@@ -293,8 +289,8 @@ int PKCS7_verify(PKCS7 *p7, STACK_OF(X509) *certs, X509_STORE *store,
             if (i <= 0) {
                 j = X509_STORE_CTX_get_error(cert_ctx);
                 ERR_raise_data(ERR_LIB_PKCS7, PKCS7_R_CERTIFICATE_VERIFY_ERROR,
-                               "Verify error: %s",
-                               X509_verify_cert_error_string(j));
+                    "Verify error: %s",
+                    X509_verify_cert_error_string(j));
                 goto err;
             }
             /* Check for revocation status here */
@@ -344,7 +340,7 @@ int PKCS7_verify(PKCS7 *p7, STACK_OF(X509) *certs, X509_STORE *store,
 
     ret = 1;
 
- err:
+err:
     if (flags & PKCS7_TEXT)
         BIO_free(tmpout);
     X509_STORE_CTX_free(cert_ctx);
@@ -357,7 +353,7 @@ int PKCS7_verify(PKCS7 *p7, STACK_OF(X509) *certs, X509_STORE *store,
 }
 
 STACK_OF(X509) *PKCS7_get0_signers(PKCS7 *p7, STACK_OF(X509) *certs,
-                                   int flags)
+    int flags)
 {
     STACK_OF(X509) *signers;
     STACK_OF(PKCS7_SIGNER_INFO) *sinfos;
@@ -397,12 +393,11 @@ STACK_OF(X509) *PKCS7_get0_signers(PKCS7 *p7, STACK_OF(X509) *certs,
         /* If any certificates passed they take priority */
         if (certs != NULL)
             signer = X509_find_by_issuer_and_serial(certs,
-                                                    ias->issuer, ias->serial);
+                ias->issuer, ias->serial);
         if (signer == NULL && !(flags & PKCS7_NOINTERN)
             && p7->d.sign->cert)
-            signer =
-                X509_find_by_issuer_and_serial(p7->d.sign->cert,
-                                               ias->issuer, ias->serial);
+            signer = X509_find_by_issuer_and_serial(p7->d.sign->cert,
+                ias->issuer, ias->serial);
         if (signer == NULL) {
             ERR_raise(ERR_LIB_PKCS7, PKCS7_R_SIGNER_CERTIFICATE_NOT_FOUND);
             sk_X509_free(signers);
@@ -420,8 +415,8 @@ STACK_OF(X509) *PKCS7_get0_signers(PKCS7 *p7, STACK_OF(X509) *certs,
 /* Build a complete PKCS#7 enveloped data */
 
 PKCS7 *PKCS7_encrypt_ex(STACK_OF(X509) *certs, BIO *in,
-                        const EVP_CIPHER *cipher, int flags,
-                        OSSL_LIB_CTX *libctx, const char *propq)
+    const EVP_CIPHER *cipher, int flags,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     PKCS7 *p7;
     BIO *p7bio = NULL;
@@ -454,21 +449,19 @@ PKCS7 *PKCS7_encrypt_ex(STACK_OF(X509) *certs, BIO *in,
     if (PKCS7_final(p7, in, flags))
         return p7;
 
- err:
+err:
 
     BIO_free_all(p7bio);
     PKCS7_free(p7);
     return NULL;
-
 }
 
 PKCS7 *PKCS7_encrypt(STACK_OF(X509) *certs, BIO *in, const EVP_CIPHER *cipher,
-                     int flags)
+    int flags)
 {
     return PKCS7_encrypt_ex(certs, in, cipher, flags, NULL, NULL);
 }
 
-
 int PKCS7_decrypt(PKCS7 *p7, EVP_PKEY *pkey, X509 *cert, BIO *data, int flags)
 {
     BIO *tmpmem;
@@ -488,7 +481,7 @@ int PKCS7_decrypt(PKCS7 *p7, EVP_PKEY *pkey, X509 *cert, BIO *data, int flags)
 
     if (cert && !X509_check_private_key(cert, pkey)) {
         ERR_raise(ERR_LIB_PKCS7,
-                  PKCS7_R_PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE);
+            PKCS7_R_PRIVATE_KEY_DOES_NOT_MATCH_CERTIFICATE);
         return 0;
     }
 
