@@ -14,7 +14,9 @@
 typedef int OSSL_PROPERTY_IDX;
 
 typedef enum {
-    OSSL_PROPERTY_OPER_EQ, OSSL_PROPERTY_OPER_NE, OSSL_PROPERTY_OVERRIDE
+    OSSL_PROPERTY_OPER_EQ,
+    OSSL_PROPERTY_OPER_NE,
+    OSSL_PROPERTY_OVERRIDE
 } OSSL_PROPERTY_OPER;
 
 struct ossl_property_definition_st {
@@ -23,8 +25,8 @@ struct ossl_property_definition_st {
     OSSL_PROPERTY_OPER oper;
     unsigned int optional : 1;
     union {
-        int64_t             int_val;     /* Signed integer */
-        OSSL_PROPERTY_IDX   str_val;     /* String */
+        int64_t int_val; /* Signed integer */
+        OSSL_PROPERTY_IDX str_val; /* String */
     } v;
 };
 
@@ -34,15 +36,15 @@ struct ossl_property_list_st {
     OSSL_PROPERTY_DEFINITION properties[1];
 };
 
-#define OSSL_PROPERTY_TRUE      1
-#define OSSL_PROPERTY_FALSE     2
+#define OSSL_PROPERTY_TRUE 1
+#define OSSL_PROPERTY_FALSE 2
 
 /* Property string functions */
 OSSL_PROPERTY_IDX ossl_property_name(OSSL_LIB_CTX *ctx, const char *s,
-                                     int create);
+    int create);
 const char *ossl_property_name_str(OSSL_LIB_CTX *ctx, OSSL_PROPERTY_IDX idx);
 OSSL_PROPERTY_IDX ossl_property_value(OSSL_LIB_CTX *ctx, const char *s,
-                                      int create);
+    int create);
 const char *ossl_property_value_str(OSSL_LIB_CTX *ctx, OSSL_PROPERTY_IDX idx);
 
 /* Property list functions */
@@ -52,4 +54,4 @@ int ossl_property_has_optional(const OSSL_PROPERTY_LIST *query);
 /* Property definition cache functions */
 OSSL_PROPERTY_LIST *ossl_prop_defn_get(OSSL_LIB_CTX *ctx, const char *prop);
 int ossl_prop_defn_set(OSSL_LIB_CTX *ctx, const char *prop,
-                       OSSL_PROPERTY_LIST *pl);
+    OSSL_PROPERTY_LIST **pl);
