@@ -1,5 +1,5 @@
 /*
- * Copyright 1995-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 1995-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -21,43 +21,43 @@
 #include "crypto/context.h"
 
 #ifndef FIPS_MODULE
-# include <stdio.h>
-# include <time.h>
-# include <limits.h>
-# include <openssl/conf.h>
-# include <openssl/trace.h>
-# include <openssl/engine.h>
-# include "crypto/rand_pool.h"
-# include "prov/seeding.h"
-# include "internal/e_os.h"
-# include "internal/property.h"
+#include <stdio.h>
+#include <time.h>
+#include <limits.h>
+#include <openssl/conf.h>
+#include <openssl/trace.h>
+#include <openssl/engine.h>
+#include "crypto/rand_pool.h"
+#include "prov/seeding.h"
+#include "internal/e_os.h"
+#include "internal/property.h"
 
-# ifndef OPENSSL_NO_ENGINE
+#ifndef OPENSSL_NO_ENGINE
 /* non-NULL if default_RAND_meth is ENGINE-provided */
 static ENGINE *funct_ref;
 static CRYPTO_RWLOCK *rand_engine_lock;
-# endif
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#endif
+#ifndef OPENSSL_NO_DEPRECATED_3_0
 static CRYPTO_RWLOCK *rand_meth_lock;
 static const RAND_METHOD *default_RAND_meth;
-# endif
+#endif
 static CRYPTO_ONCE rand_init = CRYPTO_ONCE_STATIC_INIT;
 
 static int rand_inited = 0;
 
 DEFINE_RUN_ONCE_STATIC(do_rand_init)
 {
-# ifndef OPENSSL_NO_ENGINE
+#ifndef OPENSSL_NO_ENGINE
     rand_engine_lock = CRYPTO_THREAD_lock_new();
     if (rand_engine_lock == NULL)
         return 0;
-# endif
+#endif
 
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     rand_meth_lock = CRYPTO_THREAD_lock_new();
     if (rand_meth_lock == NULL)
         goto err;
-# endif
+#endif
 
     if (!ossl_rand_pool_init())
         goto err;
@@ -65,21 +65,21 @@ DEFINE_RUN_ONCE_STATIC(do_rand_init)
     rand_inited = 1;
     return 1;
 
- err:
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+err:
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     CRYPTO_THREAD_lock_free(rand_meth_lock);
     rand_meth_lock = NULL;
-# endif
-# ifndef OPENSSL_NO_ENGINE
+#endif
+#ifndef OPENSSL_NO_ENGINE
     CRYPTO_THREAD_lock_free(rand_engine_lock);
     rand_engine_lock = NULL;
-# endif
+#endif
     return 0;
 }
 
 void ossl_rand_cleanup_int(void)
 {
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     const RAND_METHOD *meth = default_RAND_meth;
 
     if (!rand_inited)
@@ -88,16 +88,16 @@ void ossl_rand_cleanup_int(void)
     if (meth != NULL && meth->cleanup != NULL)
         meth->cleanup();
     RAND_set_rand_method(NULL);
-# endif
+#endif
     ossl_rand_pool_cleanup();
-# ifndef OPENSSL_NO_ENGINE
+#ifndef OPENSSL_NO_ENGINE
     CRYPTO_THREAD_lock_free(rand_engine_lock);
     rand_engine_lock = NULL;
-# endif
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#endif
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     CRYPTO_THREAD_lock_free(rand_meth_lock);
     rand_meth_lock = NULL;
-# endif
+#endif
     ossl_release_default_drbg_ctx();
     rand_inited = 0;
 }
@@ -124,7 +124,7 @@ int RAND_poll(void)
 {
     static const char salt[] = "polling";
 
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     const RAND_METHOD *meth = RAND_get_rand_method();
     int ret = meth == RAND_OpenSSL();
 
@@ -134,8 +134,8 @@ int RAND_poll(void)
     if (!ret) {
         /* fill random pool and seed the current legacy RNG */
         RAND_POOL *pool = ossl_rand_pool_new(RAND_DRBG_STRENGTH, 1,
-                                             (RAND_DRBG_STRENGTH + 7) / 8,
-                                             RAND_POOL_MAX_LENGTH);
+            (RAND_DRBG_STRENGTH + 7) / 8,
+            RAND_POOL_MAX_LENGTH);
 
         if (pool == NULL)
             return 0;
@@ -145,34 +145,35 @@ int RAND_poll(void)
 
         if (meth->add == NULL
             || meth->add(ossl_rand_pool_buffer(pool),
-                         ossl_rand_pool_length(pool),
-                         (ossl_rand_pool_entropy(pool) / 8.0)) == 0)
+                   ossl_rand_pool_length(pool),
+                   (ossl_rand_pool_entropy(pool) / 8.0))
+                == 0)
             goto err;
 
         ret = 1;
-     err:
+    err:
         ossl_rand_pool_free(pool);
         return ret;
     }
-# endif
+#endif
 
     RAND_seed(salt, sizeof(salt));
     return 1;
 }
 
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
 static int rand_set_rand_method_internal(const RAND_METHOD *meth,
-                                         ossl_unused ENGINE *e)
+    ossl_unused ENGINE *e)
 {
     if (!RUN_ONCE(&rand_init, do_rand_init))
         return 0;
 
     if (!CRYPTO_THREAD_write_lock(rand_meth_lock))
         return 0;
-#  ifndef OPENSSL_NO_ENGINE
+#ifndef OPENSSL_NO_ENGINE
     ENGINE_finish(funct_ref);
     funct_ref = e;
-#  endif
+#endif
     default_RAND_meth = meth;
     CRYPTO_THREAD_unlock(rand_meth_lock);
     return 1;
@@ -200,28 +201,28 @@ const RAND_METHOD *RAND_get_rand_method(void)
     if (!CRYPTO_THREAD_write_lock(rand_meth_lock))
         return NULL;
     if (default_RAND_meth == NULL) {
-#  ifndef OPENSSL_NO_ENGINE
+#ifndef OPENSSL_NO_ENGINE
         ENGINE *e;
 
         /* If we have an engine that can do RAND, use it. */
         if ((e = ENGINE_get_default_RAND()) != NULL
-                && (tmp_meth = ENGINE_get_RAND(e)) != NULL) {
+            && (tmp_meth = ENGINE_get_RAND(e)) != NULL) {
             funct_ref = e;
             default_RAND_meth = tmp_meth;
         } else {
             ENGINE_finish(e);
             default_RAND_meth = &ossl_rand_meth;
         }
-#  else
+#else
         default_RAND_meth = &ossl_rand_meth;
-#  endif
+#endif
     }
     tmp_meth = default_RAND_meth;
     CRYPTO_THREAD_unlock(rand_meth_lock);
     return tmp_meth;
 }
 
-#  if !defined(OPENSSL_NO_ENGINE)
+#if !defined(OPENSSL_NO_ENGINE)
 int RAND_set_rand_engine(ENGINE *engine)
 {
     const RAND_METHOD *tmp_meth = NULL;
@@ -248,20 +249,20 @@ int RAND_set_rand_engine(ENGINE *engine)
     CRYPTO_THREAD_unlock(rand_engine_lock);
     return 1;
 }
-#  endif
-# endif /* OPENSSL_NO_DEPRECATED_3_0 */
+#endif
+#endif /* OPENSSL_NO_DEPRECATED_3_0 */
 
 void RAND_seed(const void *buf, int num)
 {
     EVP_RAND_CTX *drbg;
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     const RAND_METHOD *meth = RAND_get_rand_method();
 
     if (meth != NULL && meth->seed != NULL) {
         meth->seed(buf, num);
         return;
     }
-# endif
+#endif
 
     drbg = RAND_get0_primary(NULL);
     if (drbg != NULL && num > 0)
@@ -271,26 +272,26 @@ void RAND_seed(const void *buf, int num)
 void RAND_add(const void *buf, int num, double randomness)
 {
     EVP_RAND_CTX *drbg;
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     const RAND_METHOD *meth = RAND_get_rand_method();
 
     if (meth != NULL && meth->add != NULL) {
         meth->add(buf, num, randomness);
         return;
     }
-# endif
+#endif
     drbg = RAND_get0_primary(NULL);
     if (drbg != NULL && num > 0)
-# ifdef OPENSSL_RAND_SEED_NONE
+#ifdef OPENSSL_RAND_SEED_NONE
         /* Without an entropy source, we have to rely on the user */
         EVP_RAND_reseed(drbg, 0, buf, num, NULL, 0);
-# else
+#else
         /* With an entropy source, we downgrade this to additional input */
         EVP_RAND_reseed(drbg, 0, NULL, 0, buf, num);
-# endif
+#endif
 }
 
-# if !defined(OPENSSL_NO_DEPRECATED_1_1_0)
+#if !defined(OPENSSL_NO_DEPRECATED_1_1_0)
 int RAND_pseudo_bytes(unsigned char *buf, int num)
 {
     const RAND_METHOD *meth = RAND_get_rand_method();
@@ -300,30 +301,30 @@ int RAND_pseudo_bytes(unsigned char *buf, int num)
     ERR_raise(ERR_LIB_RAND, RAND_R_FUNC_NOT_IMPLEMENTED);
     return -1;
 }
-# endif
+#endif
 
 int RAND_status(void)
 {
     EVP_RAND_CTX *rand;
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     const RAND_METHOD *meth = RAND_get_rand_method();
 
     if (meth != NULL && meth != RAND_OpenSSL())
         return meth->status != NULL ? meth->status() : 0;
-# endif
+#endif
 
     if ((rand = RAND_get0_primary(NULL)) == NULL)
         return 0;
     return EVP_RAND_get_state(rand) == EVP_RAND_STATE_READY;
 }
-# else  /* !FIPS_MODULE */
+#else /* !FIPS_MODULE */
 
-# ifndef OPENSSL_NO_DEPRECATED_3_0
+#ifndef OPENSSL_NO_DEPRECATED_3_0
 const RAND_METHOD *RAND_get_rand_method(void)
 {
     return NULL;
 }
-# endif
+#endif
 #endif /* !FIPS_MODULE */
 
 /*
@@ -332,7 +333,7 @@ const RAND_METHOD *RAND_get_rand_method(void)
  * sure we're instantiated and use the private DRBG.
  */
 int RAND_priv_bytes_ex(OSSL_LIB_CTX *ctx, unsigned char *buf, size_t num,
-                       unsigned int strength)
+    unsigned int strength)
 {
     EVP_RAND_CTX *rand;
 #if !defined(OPENSSL_NO_DEPRECATED_3_0) && !defined(FIPS_MODULE)
@@ -361,7 +362,7 @@ int RAND_priv_bytes(unsigned char *buf, int num)
 }
 
 int RAND_bytes_ex(OSSL_LIB_CTX *ctx, unsigned char *buf, size_t num,
-                  unsigned int strength)
+    unsigned int strength)
 {
     EVP_RAND_CTX *rand;
 #if !defined(OPENSSL_NO_DEPRECATED_3_0) && !defined(FIPS_MODULE)
@@ -462,7 +463,7 @@ void *ossl_rand_ctx_new(OSSL_LIB_CTX *libctx)
      * We need to ensure that base libcrypto thread handling has been
      * initialised.
      */
-     OPENSSL_init_crypto(OPENSSL_INIT_BASE_ONLY, NULL);
+    OPENSSL_init_crypto(OPENSSL_INIT_BASE_ONLY, NULL);
 #endif
 
     dgbl->lock = CRYPTO_THREAD_lock_new();
@@ -477,9 +478,9 @@ void *ossl_rand_ctx_new(OSSL_LIB_CTX *libctx)
 
     return dgbl;
 
- err2:
+err2:
     CRYPTO_THREAD_cleanup_local(&dgbl->private);
- err1:
+err1:
     CRYPTO_THREAD_lock_free(dgbl->lock);
     OPENSSL_free(dgbl);
     return NULL;
@@ -584,7 +585,8 @@ static EVP_RAND_CTX *rand_new_seed(OSSL_LIB_CTX *libctx)
                     goto err;
                 }
                 if (ossl_property_list_to_string(libctx, pl3,
-                                                 props, props_len) == 0) {
+                        props, props_len)
+                    == 0) {
                     ERR_raise(ERR_LIB_RAND, ERR_R_INTERNAL_ERROR);
                     goto err;
                 }
@@ -613,7 +615,7 @@ static EVP_RAND_CTX *rand_new_seed(OSSL_LIB_CTX *libctx)
     }
     OPENSSL_free(props);
     return ctx;
- err:
+err:
     EVP_RAND_CTX_free(ctx);
     ossl_property_free(pl3);
     OPENSSL_free(props);
@@ -637,8 +639,8 @@ EVP_RAND_CTX *ossl_rand_get0_seed_noncreating(OSSL_LIB_CTX *ctx)
 #endif
 
 static EVP_RAND_CTX *rand_new_drbg(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent,
-                                   unsigned int reseed_interval,
-                                   time_t reseed_time_interval, int use_df)
+    unsigned int reseed_interval,
+    time_t reseed_time_interval, int use_df)
 {
     EVP_RAND *rand;
     RAND_GLOBAL *dgbl = rand_get_global(libctx);
@@ -666,23 +668,23 @@ static EVP_RAND_CTX *rand_new_drbg(OSSL_LIB_CTX *libctx, EVP_RAND_CTX *parent,
     if (OSSL_PARAM_locate_const(settables, OSSL_DRBG_PARAM_CIPHER)) {
         cipher = dgbl->rng_cipher != NULL ? dgbl->rng_cipher : "AES-256-CTR";
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_DRBG_PARAM_CIPHER,
-                                                cipher, 0);
+            cipher, 0);
     }
     if (dgbl->rng_digest != NULL
-            && OSSL_PARAM_locate_const(settables, OSSL_DRBG_PARAM_DIGEST))
+        && OSSL_PARAM_locate_const(settables, OSSL_DRBG_PARAM_DIGEST))
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_DRBG_PARAM_DIGEST,
-                                                dgbl->rng_digest, 0);
+            dgbl->rng_digest, 0);
     if (dgbl->rng_propq != NULL)
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_DRBG_PARAM_PROPERTIES,
-                                                dgbl->rng_propq, 0);
+            dgbl->rng_propq, 0);
     if (OSSL_PARAM_locate_const(settables, OSSL_ALG_PARAM_MAC))
         *p++ = OSSL_PARAM_construct_utf8_string(OSSL_ALG_PARAM_MAC, "HMAC", 0);
     if (OSSL_PARAM_locate_const(settables, OSSL_DRBG_PARAM_USE_DF))
         *p++ = OSSL_PARAM_construct_int(OSSL_DRBG_PARAM_USE_DF, &use_df);
     *p++ = OSSL_PARAM_construct_uint(OSSL_DRBG_PARAM_RESEED_REQUESTS,
-                                     &reseed_interval);
+        &reseed_interval);
     *p++ = OSSL_PARAM_construct_time_t(OSSL_DRBG_PARAM_RESEED_TIME_INTERVAL,
-                                       &reseed_time_interval);
+        &reseed_time_interval);
     *p = OSSL_PARAM_construct_end();
     if (!EVP_RAND_instantiate(ctx, 0, 0, NULL, 0, params)) {
         ERR_raise(ERR_LIB_RAND, RAND_R_ERROR_INSTANTIATING_DRBG);
@@ -732,12 +734,12 @@ EVP_RAND_CTX *RAND_get0_primary(OSSL_LIB_CTX *ctx)
 #endif
 
     ret = dgbl->primary = rand_new_drbg(ctx, dgbl->seed,
-                                        PRIMARY_RESEED_INTERVAL,
-                                        PRIMARY_RESEED_TIME_INTERVAL, 1);
+        PRIMARY_RESEED_INTERVAL,
+        PRIMARY_RESEED_TIME_INTERVAL, 1);
     /*
-    * The primary DRBG may be shared between multiple threads so we must
-    * enable locking.
-    */
+     * The primary DRBG may be shared between multiple threads so we must
+     * enable locking.
+     */
     if (ret != NULL && !EVP_RAND_enable_locking(ret)) {
         ERR_raise(ERR_LIB_EVP, EVP_R_UNABLE_TO_ENABLE_LOCKING);
         EVP_RAND_CTX_free(ret);
@@ -767,15 +769,18 @@ EVP_RAND_CTX *RAND_get0_public(OSSL_LIB_CTX *ctx)
             return NULL;
 
         ctx = ossl_lib_ctx_get_concrete(ctx);
+
+        if (ctx == NULL)
+            return NULL;
         /*
          * If the private is also NULL then this is the first time we've
          * used this thread.
          */
         if (CRYPTO_THREAD_get_local(&dgbl->private) == NULL
-                && !ossl_init_thread_start(NULL, ctx, rand_delete_thread_state))
+            && !ossl_init_thread_start(NULL, ctx, rand_delete_thread_state))
             return NULL;
         rand = rand_new_drbg(ctx, primary, SECONDARY_RESEED_INTERVAL,
-                             SECONDARY_RESEED_TIME_INTERVAL, 0);
+            SECONDARY_RESEED_TIME_INTERVAL, 0);
         CRYPTO_THREAD_set_local(&dgbl->public, rand);
     }
     return rand;
@@ -800,15 +805,18 @@ EVP_RAND_CTX *RAND_get0_private(OSSL_LIB_CTX *ctx)
             return NULL;
 
         ctx = ossl_lib_ctx_get_concrete(ctx);
+
+        if (ctx == NULL)
+            return NULL;
         /*
          * If the public is also NULL then this is the first time we've
          * used this thread.
          */
         if (CRYPTO_THREAD_get_local(&dgbl->public) == NULL
-                && !ossl_init_thread_start(NULL, ctx, rand_delete_thread_state))
+            && !ossl_init_thread_start(NULL, ctx, rand_delete_thread_state))
             return NULL;
         rand = rand_new_drbg(ctx, primary, SECONDARY_RESEED_INTERVAL,
-                             SECONDARY_RESEED_TIME_INTERVAL, 0);
+            SECONDARY_RESEED_TIME_INTERVAL, 0);
         CRYPTO_THREAD_set_local(&dgbl->private, rand);
     }
     return rand;
@@ -880,7 +888,7 @@ static int random_conf_init(CONF_IMODULE *md, const CONF *cnf)
     int i, r = 1;
 
     OSSL_TRACE1(CONF, "Loading random module: section %s\n",
-                CONF_imodule_get_value(md));
+        CONF_imodule_get_value(md));
 
     /* Value is a section containing RANDOM configuration */
     elist = NCONF_get_section(cnf, CONF_imodule_get_value(md));
@@ -914,15 +922,14 @@ static int random_conf_init(CONF_IMODULE *md, const CONF *cnf)
                 return 0;
         } else {
             ERR_raise_data(ERR_LIB_CRYPTO,
-                           CRYPTO_R_UNKNOWN_NAME_IN_RANDOM_SECTION,
-                           "name=%s, value=%s", cval->name, cval->value);
+                CRYPTO_R_UNKNOWN_NAME_IN_RANDOM_SECTION,
+                "name=%s, value=%s", cval->name, cval->value);
             r = 0;
         }
     }
     return r;
 }
 
-
 static void random_conf_deinit(CONF_IMODULE *md)
 {
     OSSL_TRACE(CONF, "Cleaned up random\n");
@@ -935,14 +942,14 @@ void ossl_random_add_conf_module(void)
 }
 
 int RAND_set_DRBG_type(OSSL_LIB_CTX *ctx, const char *drbg, const char *propq,
-                       const char *cipher, const char *digest)
+    const char *cipher, const char *digest)
 {
     RAND_GLOBAL *dgbl = rand_get_global(ctx);
 
     if (dgbl == NULL)
         return 0;
     if (dgbl->primary != NULL) {
-        ERR_raise(ERR_LIB_CRYPTO, RAND_R_ALREADY_INSTANTIATED);
+        ERR_raise(ERR_LIB_RAND, RAND_R_ALREADY_INSTANTIATED);
         return 0;
     }
     return random_set_string(&dgbl->rng_name, drbg)
@@ -952,14 +959,14 @@ int RAND_set_DRBG_type(OSSL_LIB_CTX *ctx, const char *drbg, const char *propq,
 }
 
 int RAND_set_seed_source_type(OSSL_LIB_CTX *ctx, const char *seed,
-                              const char *propq)
+    const char *propq)
 {
     RAND_GLOBAL *dgbl = rand_get_global(ctx);
 
     if (dgbl == NULL)
         return 0;
     if (dgbl->seed != NULL) {
-        ERR_raise(ERR_LIB_CRYPTO, RAND_R_ALREADY_INSTANTIATED);
+        ERR_raise(ERR_LIB_RAND, RAND_R_ALREADY_INSTANTIATED);
         return 0;
     }
     return random_set_string(&dgbl->seed_name, seed)
