@@ -1,5 +1,5 @@
 /*
- * Copyright 1995-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 1995-2021 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -20,19 +20,16 @@
  * Allocate memory and initialize a new random pool
  */
 RAND_POOL *ossl_rand_pool_new(int entropy_requested, int secure,
-                              size_t min_len, size_t max_len)
+    size_t min_len, size_t max_len)
 {
     RAND_POOL *pool = OPENSSL_zalloc(sizeof(*pool));
     size_t min_alloc_size = RAND_POOL_MIN_ALLOCATION(secure);
 
-    if (pool == NULL) {
-        ERR_raise(ERR_LIB_RAND, ERR_R_MALLOC_FAILURE);
+    if (pool == NULL)
         return NULL;
-    }
 
     pool->min_len = min_len;
-    pool->max_len = (max_len > RAND_POOL_MAX_LENGTH) ?
-        RAND_POOL_MAX_LENGTH : max_len;
+    pool->max_len = (max_len > RAND_POOL_MAX_LENGTH) ? RAND_POOL_MAX_LENGTH : max_len;
     pool->alloc_len = min_len < min_alloc_size ? min_alloc_size : min_len;
     if (pool->alloc_len > pool->max_len)
         pool->alloc_len = pool->max_len;
@@ -42,10 +39,8 @@ RAND_POOL *ossl_rand_pool_new(int entropy_requested, int secure,
     else
         pool->buffer = OPENSSL_zalloc(pool->alloc_len);
 
-    if (pool->buffer == NULL) {
-        ERR_raise(ERR_LIB_RAND, ERR_R_MALLOC_FAILURE);
+    if (pool->buffer == NULL)
         goto err;
-    }
 
     pool->entropy_requested = entropy_requested;
     pool->secure = secure;
@@ -63,21 +58,19 @@ err:
  * provided by RAND_add() and RAND_seed() into the <master> DRBG.
  */
 RAND_POOL *ossl_rand_pool_attach(const unsigned char *buffer, size_t len,
-                                 size_t entropy)
+    size_t entropy)
 {
     RAND_POOL *pool = OPENSSL_zalloc(sizeof(*pool));
 
-    if (pool == NULL) {
-        ERR_raise(ERR_LIB_RAND, ERR_R_MALLOC_FAILURE);
+    if (pool == NULL)
         return NULL;
-    }
 
     /*
      * The const needs to be cast away, but attached buffers will not be
      * modified (in contrary to allocated buffers which are zeroed and
      * freed in the end).
      */
-    pool->buffer = (unsigned char *) buffer;
+    pool->buffer = (unsigned char *)buffer;
     pool->len = len;
 
     pool->attached = 1;
@@ -168,7 +161,6 @@ void ossl_rand_pool_reattach(RAND_POOL *pool, unsigned char *buffer)
 #define ENTROPY_TO_BYTES(bits, entropy_factor) \
     (((bits) * (entropy_factor) + 7) / 8)
 
-
 /*
  * Checks whether the |pool|'s entropy is available to the caller.
  * This is the case when entropy count and buffer length are high enough.
@@ -222,10 +214,8 @@ static int rand_pool_grow(RAND_POOL *pool, size_t len)
             p = OPENSSL_secure_zalloc(newlen);
         else
             p = OPENSSL_zalloc(newlen);
-        if (p == NULL) {
-            ERR_raise(ERR_LIB_RAND, ERR_R_MALLOC_FAILURE);
+        if (p == NULL)
             return 0;
-        }
         memcpy(p, pool->buffer, pool->len);
         if (pool->secure)
             OPENSSL_secure_clear_free(pool->buffer, pool->alloc_len);
@@ -258,15 +248,14 @@ size_t ossl_rand_pool_bytes_needed(RAND_POOL *pool, unsigned int entropy_factor)
     if (bytes_needed > pool->max_len - pool->len) {
         /* not enough space left */
         ERR_raise_data(ERR_LIB_RAND, RAND_R_RANDOM_POOL_OVERFLOW,
-                       "entropy_factor=%u, entropy_needed=%zu, bytes_needed=%zu,"
-                       "pool->max_len=%zu, pool->len=%zu",
-                       entropy_factor, entropy_needed, bytes_needed,
-                       pool->max_len, pool->len);
+            "entropy_factor=%u, entropy_needed=%zu, bytes_needed=%zu,"
+            "pool->max_len=%zu, pool->len=%zu",
+            entropy_factor, entropy_needed, bytes_needed,
+            pool->max_len, pool->len);
         return 0;
     }
 
-    if (pool->len < pool->min_len &&
-        bytes_needed < pool->min_len - pool->len)
+    if (pool->len < pool->min_len && bytes_needed < pool->min_len - pool->len)
         /* to meet the min_len requirement */
         bytes_needed = pool->min_len - pool->len;
 
@@ -307,7 +296,7 @@ size_t ossl_rand_pool_bytes_remaining(RAND_POOL *pool)
  * Returns 1 if the added amount is adequate, otherwise 0
  */
 int ossl_rand_pool_add(RAND_POOL *pool,
-                  const unsigned char *buffer, size_t len, size_t entropy)
+    const unsigned char *buffer, size_t len, size_t entropy)
 {
     if (len > pool->max_len - pool->len) {
         ERR_raise(ERR_LIB_RAND, RAND_R_ENTROPY_INPUT_TOO_LONG);
