@@ -27,7 +27,7 @@
 
 /* Set any parameters associated with pkey */
 static int rsa_param_encode(const EVP_PKEY *pkey,
-                            ASN1_STRING **pstr, int *pstrtype)
+    ASN1_STRING **pstr, int *pstrtype)
 {
     const RSA *rsa = pkey->pkey.rsa;
 
@@ -65,7 +65,7 @@ static int rsa_pub_encode(X509_PUBKEY *pk, const EVP_PKEY *pkey)
         return 0;
     }
     if (X509_PUBKEY_set0_param(pk, OBJ_nid2obj(pkey->ameth->pkey_id),
-                               strtype, str, penc, penclen))
+            strtype, str, penc, penclen))
         return 1;
 
     OPENSSL_free(penc);
@@ -116,7 +116,7 @@ static int rsa_pub_cmp(const EVP_PKEY *a, const EVP_PKEY *b)
      * cards.
      */
     if (((RSA_flags(a->pkey.rsa) & RSA_METHOD_FLAG_NO_CHECK))
-            || (RSA_flags(b->pkey.rsa) & RSA_METHOD_FLAG_NO_CHECK)) {
+        || (RSA_flags(b->pkey.rsa) & RSA_METHOD_FLAG_NO_CHECK)) {
         return 1;
     }
 
@@ -127,7 +127,7 @@ static int rsa_pub_cmp(const EVP_PKEY *a, const EVP_PKEY *b)
 }
 
 static int old_rsa_priv_decode(EVP_PKEY *pkey,
-                               const unsigned char **pder, int derlen)
+    const unsigned char **pder, int derlen)
 {
     RSA *rsa;
 
@@ -160,7 +160,7 @@ static int rsa_priv_encode(PKCS8_PRIV_KEY_INFO *p8, const EVP_PKEY *pkey)
     }
 
     if (!PKCS8_pkey_set0(p8, OBJ_nid2obj(pkey->ameth->pkey_id), 0,
-                         strtype, str, rk, rklen)) {
+            strtype, str, rk, rklen)) {
         ERR_raise(ERR_LIB_RSA, ERR_R_ASN1_LIB);
         ASN1_STRING_free(str);
         OPENSSL_clear_free(rk, rklen);
@@ -203,7 +203,7 @@ static void int_rsa_free(EVP_PKEY *pkey)
 }
 
 static int rsa_pss_param_print(BIO *bp, int pss_key, RSA_PSS_PARAMS *pss,
-                               int indent)
+    int indent)
 {
     int rv = 0;
     X509_ALGOR *maskHash = NULL;
@@ -291,10 +291,9 @@ static int rsa_pss_param_print(BIO *bp, int pss_key, RSA_PSS_PARAMS *pss,
 
     rv = 1;
 
- err:
+err:
     X509_ALGOR_free(maskHash);
     return rv;
-
 }
 
 static int pkey_rsa_print(BIO *bp, const EVP_PKEY *pkey, int off, int priv)
@@ -311,12 +310,13 @@ static int pkey_rsa_print(BIO *bp, const EVP_PKEY *pkey, int off, int priv)
     if (!BIO_indent(bp, off, 128))
         goto err;
 
-    if (BIO_printf(bp, "%s ", pkey_is_pss(pkey) ?  "RSA-PSS" : "RSA") <= 0)
+    if (BIO_printf(bp, "%s ", pkey_is_pss(pkey) ? "RSA-PSS" : "RSA") <= 0)
         goto err;
 
     if (priv && x->d) {
         if (BIO_printf(bp, "Private-Key: (%d bit, %d primes)\n",
-                       mod_len, ex_primes <= 0 ? 2 : ex_primes + 2) <= 0)
+                mod_len, ex_primes <= 0 ? 2 : ex_primes + 2)
+            <= 0)
             goto err;
         str = "modulus:";
         s = "publicExponent:";
@@ -382,24 +382,24 @@ static int pkey_rsa_print(BIO *bp, const EVP_PKEY *pkey, int off, int priv)
     if (pkey_is_pss(pkey) && !rsa_pss_param_print(bp, 1, x->pss, off))
         goto err;
     ret = 1;
- err:
+err:
     return ret;
 }
 
 static int rsa_pub_print(BIO *bp, const EVP_PKEY *pkey, int indent,
-                         ASN1_PCTX *ctx)
+    ASN1_PCTX *ctx)
 {
     return pkey_rsa_print(bp, pkey, indent, 0);
 }
 
 static int rsa_priv_print(BIO *bp, const EVP_PKEY *pkey, int indent,
-                          ASN1_PCTX *ctx)
+    ASN1_PCTX *ctx)
 {
     return pkey_rsa_print(bp, pkey, indent, 1);
 }
 
 static int rsa_sig_print(BIO *bp, const X509_ALGOR *sigalg,
-                         const ASN1_STRING *sig, int indent, ASN1_PCTX *pctx)
+    const ASN1_STRING *sig, int indent, ASN1_PCTX *pctx)
 {
     if (OBJ_obj2nid(sigalg->algorithm) == EVP_PKEY_RSA_PSS) {
         int rv;
@@ -427,7 +427,7 @@ static int rsa_pkey_ctrl(EVP_PKEY *pkey, int op, long arg1, void *arg2)
     case ASN1_PKEY_CTRL_DEFAULT_MD_NID:
         if (pkey->pkey.rsa->pss != NULL) {
             if (!ossl_rsa_pss_get_param(pkey->pkey.rsa->pss, &md, &mgf1md,
-                                        &min_saltlen)) {
+                    &min_saltlen)) {
                 ERR_raise(ERR_LIB_RSA, ERR_R_INTERNAL_ERROR);
                 return 0;
             }
@@ -488,7 +488,7 @@ static RSA_PSS_PARAMS *rsa_ctx_to_pss(EVP_PKEY_CTX *pkctx)
 }
 
 RSA_PSS_PARAMS *ossl_rsa_pss_params_create(const EVP_MD *sigmd,
-                                           const EVP_MD *mgf1md, int saltlen)
+    const EVP_MD *mgf1md, int saltlen)
 {
     RSA_PSS_PARAMS *pss = RSA_PSS_PARAMS_new();
 
@@ -510,7 +510,7 @@ RSA_PSS_PARAMS *ossl_rsa_pss_params_create(const EVP_MD *sigmd,
     if (!ossl_x509_algor_new_from_md(&pss->maskHash, mgf1md))
         goto err;
     return pss;
- err:
+err:
     RSA_PSS_PARAMS_free(pss);
     return NULL;
 }
@@ -535,7 +535,7 @@ ASN1_STRING *ossl_rsa_ctx_to_pss_string(EVP_PKEY_CTX *pkctx)
  */
 
 int ossl_rsa_pss_to_ctx(EVP_MD_CTX *ctx, EVP_PKEY_CTX *pkctx,
-                        const X509_ALGOR *sigalg, EVP_PKEY *pkey)
+    const X509_ALGOR *sigalg, EVP_PKEY *pkey)
 {
     int rv = -1;
     int saltlen;
@@ -580,13 +580,13 @@ int ossl_rsa_pss_to_ctx(EVP_MD_CTX *ctx, EVP_PKEY_CTX *pkctx,
     /* Carry on */
     rv = 1;
 
- err:
+err:
     RSA_PSS_PARAMS_free(pss);
     return rv;
 }
 
 static int rsa_pss_verify_param(const EVP_MD **pmd, const EVP_MD **pmgf1md,
-                                int *psaltlen, int *ptrailerField)
+    int *psaltlen, int *ptrailerField)
 {
     if (psaltlen != NULL && *psaltlen < 0) {
         ERR_raise(ERR_LIB_RSA, RSA_R_INVALID_SALT_LENGTH);
@@ -604,7 +604,7 @@ static int rsa_pss_verify_param(const EVP_MD **pmd, const EVP_MD **pmgf1md,
 }
 
 int ossl_rsa_pss_get_param(const RSA_PSS_PARAMS *pss, const EVP_MD **pmd,
-                           const EVP_MD **pmgf1md, int *psaltlen)
+    const EVP_MD **pmgf1md, int *psaltlen)
 {
     /*
      * Callers do not care about the trailer field, and yet, we must
@@ -617,7 +617,7 @@ int ossl_rsa_pss_get_param(const RSA_PSS_PARAMS *pss, const EVP_MD **pmd,
     int trailerField = 0;
 
     return ossl_rsa_pss_get_param_unverified(pss, pmd, pmgf1md, psaltlen,
-                                             &trailerField)
+               &trailerField)
         && rsa_pss_verify_param(pmd, pmgf1md, psaltlen, &trailerField);
 }
 
@@ -627,8 +627,8 @@ int ossl_rsa_pss_get_param(const RSA_PSS_PARAMS *pss, const EVP_MD **pmd,
  */
 
 static int rsa_item_verify(EVP_MD_CTX *ctx, const ASN1_ITEM *it,
-                           const void *asn, const X509_ALGOR *sigalg,
-                           const ASN1_BIT_STRING *sig, EVP_PKEY *pkey)
+    const void *asn, const X509_ALGOR *sigalg,
+    const ASN1_BIT_STRING *sig, EVP_PKEY *pkey)
 {
     /* Sanity check: make sure it is PSS */
     if (OBJ_obj2nid(sigalg->algorithm) != EVP_PKEY_RSA_PSS) {
@@ -643,8 +643,8 @@ static int rsa_item_verify(EVP_MD_CTX *ctx, const ASN1_ITEM *it,
 }
 
 static int rsa_item_sign(EVP_MD_CTX *ctx, const ASN1_ITEM *it, const void *asn,
-                         X509_ALGOR *alg1, X509_ALGOR *alg2,
-                         ASN1_BIT_STRING *sig)
+    X509_ALGOR *alg1, X509_ALGOR *alg2,
+    ASN1_BIT_STRING *sig)
 {
     int pad_mode;
     EVP_PKEY_CTX *pkctx = EVP_MD_CTX_get_pkey_ctx(ctx);
@@ -674,16 +674,16 @@ static int rsa_item_sign(EVP_MD_CTX *ctx, const ASN1_ITEM *it, const void *asn,
                     return 0;
                 }
                 if (!X509_ALGOR_set0(alg2, OBJ_nid2obj(EVP_PKEY_RSA_PSS),
-                                     V_ASN1_SEQUENCE, os2)) {
+                        V_ASN1_SEQUENCE, os2)) {
                     ASN1_STRING_free(os1);
                     ASN1_STRING_free(os2);
                     return 0;
                 }
             }
             if (!X509_ALGOR_set0(alg1, OBJ_nid2obj(EVP_PKEY_RSA_PSS),
-                                 V_ASN1_SEQUENCE, os1)) {
-                    ASN1_STRING_free(os1);
-                    return 0;
+                    V_ASN1_SEQUENCE, os1)) {
+                ASN1_STRING_free(os1);
+                return 0;
             }
             return 3;
         }
@@ -716,7 +716,7 @@ static int rsa_item_sign(EVP_MD_CTX *ctx, const ASN1_ITEM *it, const void *asn,
 }
 
 static int rsa_sig_info_set(X509_SIG_INFO *siginf, const X509_ALGOR *sigalg,
-                            const ASN1_STRING *sig)
+    const ASN1_STRING *sig)
 {
     int rv = 0;
     int mdnid, saltlen;
@@ -738,8 +738,8 @@ static int rsa_sig_info_set(X509_SIG_INFO *siginf, const X509_ALGOR *sigalg,
      * match and salt length must equal digest size
      */
     if ((mdnid == NID_sha256 || mdnid == NID_sha384 || mdnid == NID_sha512)
-            && mdnid == EVP_MD_get_type(mgf1md)
-            && saltlen == EVP_MD_get_size(md))
+        && mdnid == EVP_MD_get_type(mgf1md)
+        && saltlen == EVP_MD_get_size(md))
         flags = X509_SIG_INFO_TLS;
     else
         flags = 0;
@@ -762,9 +762,9 @@ static int rsa_sig_info_set(X509_SIG_INFO *siginf, const X509_ALGOR *sigalg,
     else if (mdnid == NID_md5)
         secbits = 39;
     X509_SIG_INFO_set(siginf, mdnid, EVP_PKEY_RSA_PSS, secbits,
-                      flags);
+        flags);
     rv = 1;
-    err:
+err:
     RSA_PSS_PARAMS_free(pss);
     return rv;
 }
@@ -784,9 +784,9 @@ static size_t rsa_pkey_dirty_cnt(const EVP_PKEY *pkey)
  * checks in this method since the caller tests EVP_KEYMGMT_is_a() first.
  */
 static int rsa_int_export_to(const EVP_PKEY *from, int rsa_type,
-                             void *to_keydata,
-                             OSSL_FUNC_keymgmt_import_fn *importer,
-                             OSSL_LIB_CTX *libctx, const char *propq)
+    void *to_keydata,
+    OSSL_FUNC_keymgmt_import_fn *importer,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     RSA *rsa = from->pkey.rsa;
     OSSL_PARAM_BLD *tmpl = OSSL_PARAM_BLD_new();
@@ -813,14 +813,14 @@ static int rsa_int_export_to(const EVP_PKEY *from, int rsa_type,
         RSA_PSS_PARAMS_30 pss_params;
 
         if (!ossl_rsa_pss_get_param_unverified(rsa->pss, &md, &mgf1md,
-                                               &saltlen, &trailerfield))
+                &saltlen, &trailerfield))
             goto err;
         md_nid = EVP_MD_get_type(md);
         mgf1md_nid = EVP_MD_get_type(mgf1md);
         if (!ossl_rsa_pss_params_30_set_defaults(&pss_params)
             || !ossl_rsa_pss_params_30_set_hashalg(&pss_params, md_nid)
             || !ossl_rsa_pss_params_30_set_maskgenhashalg(&pss_params,
-                                                          mgf1md_nid)
+                mgf1md_nid)
             || !ossl_rsa_pss_params_30_set_saltlen(&pss_params, saltlen)
             || !ossl_rsa_pss_params_30_todata(&pss_params, tmpl, NULL))
             goto err;
@@ -833,19 +833,21 @@ static int rsa_int_export_to(const EVP_PKEY *from, int rsa_type,
     /* We export, the provider imports */
     rv = importer(to_keydata, selection, params);
 
- err:
+err:
     OSSL_PARAM_free(params);
     OSSL_PARAM_BLD_free(tmpl);
     return rv;
 }
 
 static int rsa_int_import_from(const OSSL_PARAM params[], void *vpctx,
-                               int rsa_type)
+    int rsa_type)
 {
     EVP_PKEY_CTX *pctx = vpctx;
     EVP_PKEY *pkey = EVP_PKEY_CTX_get0_pkey(pctx);
     RSA *rsa = ossl_rsa_new_with_ctx(pctx->libctx);
-    RSA_PSS_PARAMS_30 rsa_pss_params = { 0, };
+    RSA_PSS_PARAMS_30 rsa_pss_params = {
+        0,
+    };
     int pss_defaults_set = 0;
     int ok = 0;
 
@@ -858,7 +860,7 @@ static int rsa_int_import_from(const OSSL_PARAM params[], void *vpctx,
     RSA_set_flags(rsa, rsa_type);
 
     if (!ossl_rsa_pss_params_30_fromdata(&rsa_pss_params, &pss_defaults_set,
-                                         params, pctx->libctx))
+            params, pctx->libctx))
         goto err;
 
     switch (rsa_type) {
@@ -884,7 +886,8 @@ static int rsa_int_import_from(const OSSL_PARAM params[], void *vpctx,
             const EVP_MD *mgf1md = EVP_get_digestbynid(mgf1mdnid);
 
             if ((rsa->pss = ossl_rsa_pss_params_create(md, mgf1md,
-                                                       saltlen)) == NULL)
+                     saltlen))
+                == NULL)
                 goto err;
         }
         break;
@@ -905,26 +908,26 @@ static int rsa_int_import_from(const OSSL_PARAM params[], void *vpctx,
         break;
     }
 
- err:
+err:
     if (!ok)
         RSA_free(rsa);
     return ok;
 }
 
 static int rsa_pkey_export_to(const EVP_PKEY *from, void *to_keydata,
-                              OSSL_FUNC_keymgmt_import_fn *importer,
-                              OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_FUNC_keymgmt_import_fn *importer,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     return rsa_int_export_to(from, RSA_FLAG_TYPE_RSA, to_keydata,
-                             importer, libctx, propq);
+        importer, libctx, propq);
 }
 
 static int rsa_pss_pkey_export_to(const EVP_PKEY *from, void *to_keydata,
-                                  OSSL_FUNC_keymgmt_import_fn *importer,
-                                  OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_FUNC_keymgmt_import_fn *importer,
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     return rsa_int_export_to(from, RSA_FLAG_TYPE_RSASSAPSS, to_keydata,
-                             importer, libctx, propq);
+        importer, libctx, propq);
 }
 
 static int rsa_pkey_import_from(const OSSL_PARAM params[], void *vpctx)
@@ -956,91 +959,88 @@ static int rsa_pkey_copy(EVP_PKEY *to, EVP_PKEY *from)
 }
 
 const EVP_PKEY_ASN1_METHOD ossl_rsa_asn1_meths[2] = {
-    {
-     EVP_PKEY_RSA,
-     EVP_PKEY_RSA,
-     ASN1_PKEY_SIGPARAM_NULL,
+    { EVP_PKEY_RSA,
+        EVP_PKEY_RSA,
+        ASN1_PKEY_SIGPARAM_NULL,
 
-     "RSA",
-     "OpenSSL RSA method",
+        "RSA",
+        "OpenSSL RSA method",
 
-     rsa_pub_decode,
-     rsa_pub_encode,
-     rsa_pub_cmp,
-     rsa_pub_print,
+        rsa_pub_decode,
+        rsa_pub_encode,
+        rsa_pub_cmp,
+        rsa_pub_print,
 
-     rsa_priv_decode,
-     rsa_priv_encode,
-     rsa_priv_print,
+        rsa_priv_decode,
+        rsa_priv_encode,
+        rsa_priv_print,
 
-     int_rsa_size,
-     rsa_bits,
-     rsa_security_bits,
+        int_rsa_size,
+        rsa_bits,
+        rsa_security_bits,
 
-     0, 0, 0, 0, 0, 0,
+        0, 0, 0, 0, 0, 0,
 
-     rsa_sig_print,
-     int_rsa_free,
-     rsa_pkey_ctrl,
-     old_rsa_priv_decode,
-     old_rsa_priv_encode,
-     rsa_item_verify,
-     rsa_item_sign,
-     rsa_sig_info_set,
-     rsa_pkey_check,
+        rsa_sig_print,
+        int_rsa_free,
+        rsa_pkey_ctrl,
+        old_rsa_priv_decode,
+        old_rsa_priv_encode,
+        rsa_item_verify,
+        rsa_item_sign,
+        rsa_sig_info_set,
+        rsa_pkey_check,
 
-     0, 0,
-     0, 0, 0, 0,
+        0, 0,
+        0, 0, 0, 0,
 
-     rsa_pkey_dirty_cnt,
-     rsa_pkey_export_to,
-     rsa_pkey_import_from,
-     rsa_pkey_copy
-    },
+        rsa_pkey_dirty_cnt,
+        rsa_pkey_export_to,
+        rsa_pkey_import_from,
+        rsa_pkey_copy },
 
-    {
-     EVP_PKEY_RSA2,
-     EVP_PKEY_RSA,
-     ASN1_PKEY_ALIAS}
+    { EVP_PKEY_RSA2,
+        EVP_PKEY_RSA,
+        ASN1_PKEY_ALIAS }
 };
 
 const EVP_PKEY_ASN1_METHOD ossl_rsa_pss_asn1_meth = {
-     EVP_PKEY_RSA_PSS,
-     EVP_PKEY_RSA_PSS,
-     ASN1_PKEY_SIGPARAM_NULL,
+    EVP_PKEY_RSA_PSS,
+    EVP_PKEY_RSA_PSS,
+    ASN1_PKEY_SIGPARAM_NULL,
 
-     "RSA-PSS",
-     "OpenSSL RSA-PSS method",
+    "RSA-PSS",
+    "OpenSSL RSA-PSS method",
 
-     rsa_pub_decode,
-     rsa_pub_encode,
-     rsa_pub_cmp,
-     rsa_pub_print,
+    rsa_pub_decode,
+    rsa_pub_encode,
+    rsa_pub_cmp,
+    rsa_pub_print,
 
-     rsa_priv_decode,
-     rsa_priv_encode,
-     rsa_priv_print,
+    rsa_priv_decode,
+    rsa_priv_encode,
+    rsa_priv_print,
 
-     int_rsa_size,
-     rsa_bits,
-     rsa_security_bits,
+    int_rsa_size,
+    rsa_bits,
+    rsa_security_bits,
 
-     0, 0, 0, 0, 0, 0,
+    0, 0, 0, 0, 0, 0,
 
-     rsa_sig_print,
-     int_rsa_free,
-     rsa_pkey_ctrl,
-     0, 0,
-     rsa_item_verify,
-     rsa_item_sign,
-     rsa_sig_info_set,
-     rsa_pkey_check,
+    rsa_sig_print,
+    int_rsa_free,
+    rsa_pkey_ctrl,
+    0, 0,
+    rsa_item_verify,
+    rsa_item_sign,
+    rsa_sig_info_set,
+    rsa_pkey_check,
 
-     0, 0,
-     0, 0, 0, 0,
+    0, 0,
+    0, 0, 0, 0,
 
-     rsa_pkey_dirty_cnt,
-     rsa_pss_pkey_export_to,
-     rsa_pss_pkey_import_from,
-     rsa_pkey_copy
+    rsa_pkey_dirty_cnt,
+    rsa_pss_pkey_export_to,
+    rsa_pss_pkey_import_from,
+    rsa_pkey_copy
 };
