@@ -1,5 +1,5 @@
 /*
- * Copyright 2020-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2020-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -19,8 +19,8 @@
 #include <openssl/err.h>
 #include <openssl/evp.h>
 #ifndef FIPS_MODULE
-# include <openssl/x509.h>
-# include "crypto/asn1.h"
+#include <openssl/x509.h>
+#include "crypto/asn1.h"
 #endif
 #include "internal/sizes.h"
 #include "internal/param_build_set.h"
@@ -36,7 +36,7 @@
 DEFINE_STACK_OF(BIGNUM)
 
 static int collect_numbers(STACK_OF(BIGNUM) *numbers,
-                           const OSSL_PARAM params[], const char *names[])
+    const OSSL_PARAM params[], const char *names[])
 {
     const OSSL_PARAM *p = NULL;
     int i;
@@ -44,14 +44,17 @@ static int collect_numbers(STACK_OF(BIGNUM) *numbers,
     if (numbers == NULL)
         return 0;
 
-    for (i = 0; names[i] != NULL; i++){
+    for (i = 0; names[i] != NULL; i++) {
         p = OSSL_PARAM_locate_const(params, names[i]);
         if (p != NULL) {
             BIGNUM *tmp = NULL;
 
-            if (!OSSL_PARAM_get_BN(p, &tmp)
-                || sk_BIGNUM_push(numbers, tmp) == 0)
+            if (!OSSL_PARAM_get_BN(p, &tmp))
                 return 0;
+            if (sk_BIGNUM_push(numbers, tmp) == 0) {
+                BN_clear_free(tmp);
+                return 0;
+            }
         }
     }
 
@@ -60,23 +63,56 @@ static int collect_numbers(STACK_OF(BIGNUM) *numbers,
 
 int ossl_rsa_fromdata(RSA *rsa, const OSSL_PARAM params[], int include_private)
 {
-    const OSSL_PARAM *param_n, *param_e,  *param_d = NULL;
-    BIGNUM *n = NULL, *e = NULL, *d = NULL;
+    const OSSL_PARAM *param_n, *param_e, *param_d = NULL;
+    const OSSL_PARAM *param_p, *param_q = NULL;
+    const OSSL_PARAM *param_derive = NULL;
+    BIGNUM *p = NULL, *q = NULL, *n = NULL, *e = NULL, *d = NULL;
     STACK_OF(BIGNUM) *factors = NULL, *exps = NULL, *coeffs = NULL;
     int is_private = 0;
+    int derive_from_pq = 0;
+    BN_CTX *ctx = NULL;
 
     if (rsa == NULL)
         return 0;
 
     param_n = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_N);
     param_e = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_E);
-    if (include_private)
-        param_d = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_D);
 
-    if ((param_n != NULL && !OSSL_PARAM_get_BN(param_n, &n))
-        || (param_e != NULL && !OSSL_PARAM_get_BN(param_e, &e))
-        || (param_d != NULL && !OSSL_PARAM_get_BN(param_d, &d)))
+    if ((param_n == NULL || !OSSL_PARAM_get_BN(param_n, &n))
+        || (param_e == NULL || !OSSL_PARAM_get_BN(param_e, &e))) {
+        ERR_raise(ERR_LIB_RSA, ERR_R_PASSED_NULL_PARAMETER);
         goto err;
+    }
+
+    if (include_private) {
+
+        param_derive = OSSL_PARAM_locate_const(params,
+            OSSL_PKEY_PARAM_RSA_DERIVE_FROM_PQ);
+        if ((param_derive != NULL)
+            && !OSSL_PARAM_get_int(param_derive, &derive_from_pq))
+            goto err;
+
+        param_d = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_D);
+        if (param_d != NULL && !OSSL_PARAM_get_BN(param_d, &d)) {
+            ERR_raise(ERR_LIB_RSA, ERR_R_PASSED_NULL_PARAMETER);
+            goto err;
+        }
+
+        if (derive_from_pq) {
+            ctx = BN_CTX_new_ex(rsa->libctx);
+            if (ctx == NULL)
+                goto err;
+
+            /* we need at minimum p, q */
+            param_p = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_FACTOR1);
+            param_q = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_FACTOR2);
+            if ((param_p == NULL || !OSSL_PARAM_get_BN(param_p, &p))
+                || (param_q == NULL || !OSSL_PARAM_get_BN(param_q, &q))) {
+                ERR_raise(ERR_LIB_RSA, ERR_R_PASSED_NULL_PARAMETER);
+                goto err;
+            }
+        }
+    }
 
     is_private = (d != NULL);
 
@@ -86,39 +122,135 @@ int ossl_rsa_fromdata(RSA *rsa, const OSSL_PARAM params[], int include_private)
 
     if (is_private) {
         if (!collect_numbers(factors = sk_BIGNUM_new_null(), params,
-                             ossl_rsa_mp_factor_names)
+                ossl_rsa_mp_factor_names)
             || !collect_numbers(exps = sk_BIGNUM_new_null(), params,
-                                ossl_rsa_mp_exp_names)
+                ossl_rsa_mp_exp_names)
             || !collect_numbers(coeffs = sk_BIGNUM_new_null(), params,
-                                ossl_rsa_mp_coeff_names))
+                ossl_rsa_mp_coeff_names))
             goto err;
 
-        /* It's ok if this private key just has n, e and d */
+        if (derive_from_pq && sk_BIGNUM_num(exps) == 0
+            && sk_BIGNUM_num(coeffs) == 0) {
+            /*
+             * If we want to use crt to derive our exponents/coefficients, we
+             * need to have at least 2 factors
+             */
+            if (sk_BIGNUM_num(factors) < 2) {
+                ERR_raise(ERR_LIB_RSA, ERR_R_PASSED_NULL_PARAMETER);
+                goto err;
+            }
+
+            /*
+             * if we have more than two factors, n and d must also have
+             * been provided
+             */
+            if (sk_BIGNUM_num(factors) > 2
+                && (param_n == NULL || param_d == NULL)) {
+                ERR_raise(ERR_LIB_RSA, ERR_R_PASSED_NULL_PARAMETER);
+                goto err;
+            }
+
+            /* build our exponents and coefficients here */
+            if (sk_BIGNUM_num(factors) == 2) {
+                /* for 2 factors we can use the sp800 functions to do this */
+                if (!RSA_set0_factors(rsa, sk_BIGNUM_value(factors, 0),
+                        sk_BIGNUM_value(factors, 1))) {
+                    ERR_raise(ERR_LIB_RSA, ERR_R_INTERNAL_ERROR);
+                    goto err;
+                }
+                /*
+                 * once consumed by RSA_set0_factors, pop those off the stack
+                 * so we don't free them below
+                 */
+                sk_BIGNUM_pop(factors);
+                sk_BIGNUM_pop(factors);
+
+                /*
+                 * Note: Because we only have 2 factors here, there will be no
+                 * additional pinfo fields to hold additional factors, and
+                 * since we set our key and 2 factors above we can skip
+                 * the call to ossl_rsa_set0_all_params
+                 */
+                if (!ossl_rsa_sp800_56b_derive_params_from_pq(rsa,
+                        RSA_bits(rsa),
+                        NULL, ctx)) {
+                    ERR_raise(ERR_LIB_RSA, ERR_R_INTERNAL_ERROR);
+                    goto err;
+                }
+            } else {
+#ifndef FIPS_MODULE
+                /*
+                 * in the multiprime case we have to generate exps/coeffs here
+                 * for each additional prime
+                 */
+                if (!ossl_rsa_multiprime_derive(rsa, RSA_bits(rsa),
+                        sk_BIGNUM_num(factors),
+                        rsa->e, factors, exps,
+                        coeffs)) {
+                    ERR_raise(ERR_LIB_RSA, ERR_R_INTERNAL_ERROR);
+                    goto err;
+                }
+
+                /*
+                 * Now we should have all our factors, exponents and
+                 * coefficients
+                 */
+                if (!ossl_rsa_set0_all_params(rsa, factors, exps, coeffs)) {
+                    ERR_raise(ERR_LIB_RSA, ERR_R_INTERNAL_ERROR);
+                    goto err;
+                }
+
+#else
+                /* multiprime case is disallowed in FIPS mode, raise an error */
+                ERR_raise(ERR_LIB_RSA, ERR_R_UNSUPPORTED);
+                goto err;
+#endif
+            }
+
+        } else {
+            /*
+             * It's ok if this private key just has n, e and d
+             * but only if we're not using derive_from_pq
+             */
+            if (sk_BIGNUM_num(factors) != 0
+                && !ossl_rsa_set0_all_params(rsa, factors, exps, coeffs))
+                goto err;
+        }
+        /* sanity check to ensure we used everything in our stacks */
         if (sk_BIGNUM_num(factors) != 0
-            && !ossl_rsa_set0_all_params(rsa, factors, exps, coeffs))
+            || sk_BIGNUM_num(exps) != 0
+            || sk_BIGNUM_num(coeffs) != 0) {
+            ERR_raise_data(ERR_LIB_RSA, ERR_R_INTERNAL_ERROR,
+                "There are %d, %d, %d elements left on our factors, exps, coeffs stacks\n",
+                sk_BIGNUM_num(factors), sk_BIGNUM_num(exps),
+                sk_BIGNUM_num(coeffs));
             goto err;
+        }
     }
 
-
+    BN_clear_free(p);
+    BN_clear_free(q);
     sk_BIGNUM_free(factors);
     sk_BIGNUM_free(exps);
     sk_BIGNUM_free(coeffs);
+    BN_CTX_free(ctx);
     return 1;
 
- err:
+err:
     BN_free(n);
     BN_free(e);
     BN_free(d);
-    sk_BIGNUM_pop_free(factors, BN_free);
-    sk_BIGNUM_pop_free(exps, BN_free);
-    sk_BIGNUM_pop_free(coeffs, BN_free);
+    sk_BIGNUM_pop_free(factors, BN_clear_free);
+    sk_BIGNUM_pop_free(exps, BN_clear_free);
+    sk_BIGNUM_pop_free(coeffs, BN_clear_free);
+    BN_CTX_free(ctx);
     return 0;
 }
 
 DEFINE_SPECIAL_STACK_OF_CONST(BIGNUM_const, BIGNUM)
 
 int ossl_rsa_todata(RSA *rsa, OSSL_PARAM_BLD *bld, OSSL_PARAM params[],
-                    int include_private)
+    int include_private)
 {
     int ret = 0;
     const BIGNUM *rsa_d = NULL, *rsa_n = NULL, *rsa_e = NULL;
@@ -138,30 +270,18 @@ int ossl_rsa_todata(RSA *rsa, OSSL_PARAM_BLD *bld, OSSL_PARAM params[],
 
     /* Check private key data integrity */
     if (include_private && rsa_d != NULL) {
-        int numprimes = sk_BIGNUM_const_num(factors);
-        int numexps = sk_BIGNUM_const_num(exps);
-        int numcoeffs = sk_BIGNUM_const_num(coeffs);
-
-        /*
-         * It's permissible to have zero primes, i.e. no CRT params.
-         * Otherwise, there must be at least two, as many exponents,
-         * and one coefficient less.
-         */
-        if (numprimes != 0
-            && (numprimes < 2 || numexps < 2 || numcoeffs < 1))
-            goto err;
 
         if (!ossl_param_build_set_bn(bld, params, OSSL_PKEY_PARAM_RSA_D,
-                                     rsa_d)
+                rsa_d)
             || !ossl_param_build_set_multi_key_bn(bld, params,
-                                                  ossl_rsa_mp_factor_names,
-                                                  factors)
+                ossl_rsa_mp_factor_names,
+                factors)
             || !ossl_param_build_set_multi_key_bn(bld, params,
-                                                  ossl_rsa_mp_exp_names, exps)
+                ossl_rsa_mp_exp_names, exps)
             || !ossl_param_build_set_multi_key_bn(bld, params,
-                                                  ossl_rsa_mp_coeff_names,
-                                                  coeffs))
-        goto err;
+                ossl_rsa_mp_coeff_names,
+                coeffs))
+            goto err;
     }
 
 #if defined(FIPS_MODULE) && !defined(OPENSSL_NO_ACVP_TESTS)
@@ -170,7 +290,7 @@ int ossl_rsa_todata(RSA *rsa, OSSL_PARAM_BLD *bld, OSSL_PARAM params[],
         ossl_rsa_acvp_test_get_params(rsa, params);
 #endif
     ret = 1;
- err:
+err:
     sk_BIGNUM_const_free(factors);
     sk_BIGNUM_const_free(exps);
     sk_BIGNUM_const_free(coeffs);
@@ -178,7 +298,7 @@ int ossl_rsa_todata(RSA *rsa, OSSL_PARAM_BLD *bld, OSSL_PARAM params[],
 }
 
 int ossl_rsa_pss_params_30_todata(const RSA_PSS_PARAMS_30 *pss,
-                                  OSSL_PARAM_BLD *bld, OSSL_PARAM params[])
+    OSSL_PARAM_BLD *bld, OSSL_PARAM params[])
 {
     if (!ossl_rsa_pss_params_30_is_unrestricted(pss)) {
         int hashalg_nid = ossl_rsa_pss_params_30_hashalg(pss);
@@ -187,17 +307,16 @@ int ossl_rsa_pss_params_30_todata(const RSA_PSS_PARAMS_30 *pss,
         int saltlen = ossl_rsa_pss_params_30_saltlen(pss);
         int default_hashalg_nid = ossl_rsa_pss_params_30_hashalg(NULL);
         int default_maskgenalg_nid = ossl_rsa_pss_params_30_maskgenalg(NULL);
-        int default_maskgenhashalg_nid =
-                ossl_rsa_pss_params_30_maskgenhashalg(NULL);
-        const char *mdname =
-            (hashalg_nid == default_hashalg_nid
-             ? NULL : ossl_rsa_oaeppss_nid2name(hashalg_nid));
-        const char *mgfname =
-            (maskgenalg_nid == default_maskgenalg_nid
-             ? NULL : ossl_rsa_oaeppss_nid2name(maskgenalg_nid));
-        const char *mgf1mdname =
-            (maskgenhashalg_nid == default_maskgenhashalg_nid
-             ? NULL : ossl_rsa_oaeppss_nid2name(maskgenhashalg_nid));
+        int default_maskgenhashalg_nid = ossl_rsa_pss_params_30_maskgenhashalg(NULL);
+        const char *mdname = (hashalg_nid == default_hashalg_nid
+                ? NULL
+                : ossl_rsa_oaeppss_nid2name(hashalg_nid));
+        const char *mgfname = (maskgenalg_nid == default_maskgenalg_nid
+                ? NULL
+                : ossl_rsa_oaeppss_nid2name(maskgenalg_nid));
+        const char *mgf1mdname = (maskgenhashalg_nid == default_maskgenhashalg_nid
+                ? NULL
+                : ossl_rsa_oaeppss_nid2name(maskgenhashalg_nid));
         const char *key_md = OSSL_PKEY_PARAM_RSA_DIGEST;
         const char *key_mgf = OSSL_PKEY_PARAM_RSA_MASKGENFUNC;
         const char *key_mgf1_md = OSSL_PKEY_PARAM_RSA_MGF1_DIGEST;
@@ -209,13 +328,13 @@ int ossl_rsa_pss_params_30_todata(const RSA_PSS_PARAMS_30 *pss,
          * if it has a default value; saltlen.
          */
         if ((mdname != NULL
-             && !ossl_param_build_set_utf8_string(bld, params, key_md, mdname))
+                && !ossl_param_build_set_utf8_string(bld, params, key_md, mdname))
             || (mgfname != NULL
                 && !ossl_param_build_set_utf8_string(bld, params,
-                                                     key_mgf, mgfname))
+                    key_mgf, mgfname))
             || (mgf1mdname != NULL
                 && !ossl_param_build_set_utf8_string(bld, params,
-                                                     key_mgf1_md, mgf1mdname))
+                    key_mgf1_md, mgf1mdname))
             || (!ossl_param_build_set_int(bld, params, key_saltlen, saltlen)))
             return 0;
     }
@@ -223,11 +342,11 @@ int ossl_rsa_pss_params_30_todata(const RSA_PSS_PARAMS_30 *pss,
 }
 
 int ossl_rsa_pss_params_30_fromdata(RSA_PSS_PARAMS_30 *pss_params,
-                                    int *defaults_set,
-                                    const OSSL_PARAM params[],
-                                    OSSL_LIB_CTX *libctx)
+    int *defaults_set,
+    const OSSL_PARAM params[],
+    OSSL_LIB_CTX *libctx)
 {
-    const OSSL_PARAM *param_md, *param_mgf, *param_mgf1md,  *param_saltlen;
+    const OSSL_PARAM *param_md, *param_mgf, *param_mgf1md, *param_saltlen;
     const OSSL_PARAM *param_propq;
     const char *propq = NULL;
     EVP_MD *md = NULL, *mgf1md = NULL;
@@ -236,16 +355,11 @@ int ossl_rsa_pss_params_30_fromdata(RSA_PSS_PARAMS_30 *pss_params,
 
     if (pss_params == NULL)
         return 0;
-    param_propq =
-        OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_DIGEST_PROPS);
-    param_md =
-        OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_DIGEST);
-    param_mgf =
-        OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_MASKGENFUNC);
-    param_mgf1md =
-        OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_MGF1_DIGEST);
-    param_saltlen =
-        OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_PSS_SALTLEN);
+    param_propq = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_DIGEST_PROPS);
+    param_md = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_DIGEST);
+    param_mgf = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_MASKGENFUNC);
+    param_mgf1md = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_MGF1_DIGEST);
+    param_saltlen = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_RSA_PSS_SALTLEN);
 
     if (param_propq != NULL) {
         if (param_propq->data_type == OSSL_PARAM_UTF8_STRING)
@@ -274,7 +388,8 @@ int ossl_rsa_pss_params_30_fromdata(RSA_PSS_PARAMS_30 *pss_params,
             return 0;
 
         if (OPENSSL_strcasecmp(param_mgf->data,
-                               ossl_rsa_mgf_nid2name(default_maskgenalg_nid)) != 0)
+                ossl_rsa_mgf_nid2name(default_maskgenalg_nid))
+            != 0)
             return 0;
     }
 
@@ -293,7 +408,7 @@ int ossl_rsa_pss_params_30_fromdata(RSA_PSS_PARAMS_30 *pss_params,
 
         if ((md = EVP_MD_fetch(libctx, mdname, propq)) == NULL
             || !ossl_rsa_pss_params_30_set_hashalg(pss_params,
-                                                   ossl_rsa_oaeppss_md2nid(md)))
+                ossl_rsa_oaeppss_md2nid(md)))
             goto err;
     }
 
@@ -307,7 +422,7 @@ int ossl_rsa_pss_params_30_fromdata(RSA_PSS_PARAMS_30 *pss_params,
 
         if ((mgf1md = EVP_MD_fetch(libctx, mgf1mdname, propq)) == NULL
             || !ossl_rsa_pss_params_30_set_maskgenhashalg(
-                    pss_params, ossl_rsa_oaeppss_md2nid(mgf1md)))
+                pss_params, ossl_rsa_oaeppss_md2nid(mgf1md)))
             goto err;
     }
 
@@ -319,7 +434,7 @@ int ossl_rsa_pss_params_30_fromdata(RSA_PSS_PARAMS_30 *pss_params,
 
     ret = 1;
 
- err:
+err:
     EVP_MD_free(md);
     EVP_MD_free(mgf1md);
     return ret;
@@ -398,10 +513,8 @@ RSA *ossl_rsa_dup(const RSA *rsa, int selection)
             const RSA_PRIME_INFO *pinfo = NULL;
             RSA_PRIME_INFO *duppinfo = NULL;
 
-            if ((duppinfo = OPENSSL_zalloc(sizeof(*duppinfo))) == NULL) {
-                ERR_raise(ERR_LIB_RSA, ERR_R_MALLOC_FAILURE);
+            if ((duppinfo = OPENSSL_zalloc(sizeof(*duppinfo))) == NULL)
                 goto err;
-            }
             /* push first so cleanup in error case works */
             (void)sk_RSA_PRIME_INFO_push(dupkey->prime_infos, duppinfo);
 
@@ -427,13 +540,13 @@ RSA *ossl_rsa_dup(const RSA *rsa, int selection)
         }
     }
     if (!CRYPTO_dup_ex_data(CRYPTO_EX_INDEX_RSA,
-                            &dupkey->ex_data, &rsa->ex_data))
+            &dupkey->ex_data, &rsa->ex_data))
         goto err;
 #endif
 
     return dupkey;
 
- err:
+err:
     RSA_free(dupkey);
     return NULL;
 }
@@ -444,7 +557,7 @@ RSA_PSS_PARAMS *ossl_rsa_pss_decode(const X509_ALGOR *alg)
     RSA_PSS_PARAMS *pss;
 
     pss = ASN1_TYPE_unpack_sequence(ASN1_ITEM_rptr(RSA_PSS_PARAMS),
-                                    alg->parameter);
+        alg->parameter);
 
     if (pss == NULL)
         return NULL;
@@ -482,17 +595,17 @@ static int ossl_rsa_sync_to_pss_params_30(RSA *rsa)
          * be checked, eventually.
          */
         if (!ossl_rsa_pss_get_param_unverified(legacy_pss, &md, &mgf1md,
-                                               &saltlen, &trailerField))
+                &saltlen, &trailerField))
             return 0;
         md_nid = EVP_MD_get_type(md);
         mgf1md_nid = EVP_MD_get_type(mgf1md);
         if (!ossl_rsa_pss_params_30_set_defaults(&pss_params)
             || !ossl_rsa_pss_params_30_set_hashalg(&pss_params, md_nid)
             || !ossl_rsa_pss_params_30_set_maskgenhashalg(&pss_params,
-                                                          mgf1md_nid)
+                mgf1md_nid)
             || !ossl_rsa_pss_params_30_set_saltlen(&pss_params, saltlen)
             || !ossl_rsa_pss_params_30_set_trailerfield(&pss_params,
-                                                        trailerField))
+                trailerField))
             return 0;
         *pss = pss_params;
     }
@@ -500,8 +613,8 @@ static int ossl_rsa_sync_to_pss_params_30(RSA *rsa)
 }
 
 int ossl_rsa_pss_get_param_unverified(const RSA_PSS_PARAMS *pss,
-                                      const EVP_MD **pmd, const EVP_MD **pmgf1md,
-                                      int *psaltlen, int *ptrailerField)
+    const EVP_MD **pmd, const EVP_MD **pmgf1md,
+    int *psaltlen, int *ptrailerField)
 {
     RSA_PSS_PARAMS_30 pss_params;
 
@@ -523,7 +636,7 @@ int ossl_rsa_pss_get_param_unverified(const RSA_PSS_PARAMS *pss,
     if (pss->trailerField)
         *ptrailerField = ASN1_INTEGER_get(pss->trailerField);
     else
-        *ptrailerField = ossl_rsa_pss_params_30_trailerfield(&pss_params);;
+        *ptrailerField = ossl_rsa_pss_params_30_trailerfield(&pss_params);
 
     return 1;
 }
@@ -555,7 +668,7 @@ int ossl_rsa_param_decode(RSA *rsa, const X509_ALGOR *alg)
 }
 
 RSA *ossl_rsa_key_from_pkcs8(const PKCS8_PRIV_KEY_INFO *p8inf,
-                             OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     const unsigned char *p;
     RSA *rsa;
