@@ -1,5 +1,5 @@
 /*
- * Copyright 2017-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2017-2021 The OpenSSL Project Authors. All Rights Reserved.
  * Copyright 2017 BaishanCloud. All rights reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
@@ -33,10 +33,8 @@ RSA_PRIME_INFO *ossl_rsa_multip_info_new(void)
     RSA_PRIME_INFO *pinfo;
 
     /* create an RSA_PRIME_INFO structure */
-    if ((pinfo = OPENSSL_zalloc(sizeof(RSA_PRIME_INFO))) == NULL) {
-        ERR_raise(ERR_LIB_RSA, ERR_R_MALLOC_FAILURE);
+    if ((pinfo = OPENSSL_zalloc(sizeof(RSA_PRIME_INFO))) == NULL)
         return NULL;
-    }
     if ((pinfo->r = BN_secure_new()) == NULL)
         goto err;
     if ((pinfo->d = BN_secure_new()) == NULL)
@@ -48,7 +46,7 @@ RSA_PRIME_INFO *ossl_rsa_multip_info_new(void)
 
     return pinfo;
 
- err:
+err:
     BN_free(pinfo->r);
     BN_free(pinfo->d);
     BN_free(pinfo->t);
@@ -92,7 +90,7 @@ int ossl_rsa_multip_calc_product(RSA *rsa)
     }
 
     rv = 1;
- err:
+err:
     BN_CTX_free(ctx);
     return rv;
 }
