@@ -115,8 +115,7 @@ static int setup_tbuf(RSA_PKEY_CTX *ctx, EVP_PKEY_CTX *pk)
 {
     if (ctx->tbuf != NULL)
         return 1;
-    if ((ctx->tbuf =
-            OPENSSL_malloc(RSA_size(EVP_PKEY_get0_RSA(pk->pkey)))) == NULL)
+    if ((ctx->tbuf = OPENSSL_malloc(RSA_size(EVP_PKEY_get0_RSA(pk->pkey)))) == NULL)
         return 0;
     return 1;
 }
@@ -133,8 +132,8 @@ static void pkey_rsa_cleanup(EVP_PKEY_CTX *ctx)
 }
 
 static int pkey_rsa_sign(EVP_PKEY_CTX *ctx, unsigned char *sig,
-                         size_t *siglen, const unsigned char *tbs,
-                         size_t tbslen)
+    size_t *siglen, const unsigned char *tbs,
+    size_t tbslen)
 {
     int ret;
     RSA_PKEY_CTX *rctx = ctx->data;
@@ -172,11 +171,11 @@ static int pkey_rsa_sign(EVP_PKEY_CTX *ctx, unsigned char *sig,
             memcpy(rctx->tbuf, tbs, tbslen);
             rctx->tbuf[tbslen] = RSA_X931_hash_id(EVP_MD_get_type(rctx->md));
             ret = RSA_private_encrypt(tbslen + 1, rctx->tbuf,
-                                      sig, rsa, RSA_X931_PADDING);
+                sig, rsa, RSA_X931_PADDING);
         } else if (rctx->pad_mode == RSA_PKCS1_PADDING) {
             unsigned int sltmp;
             ret = RSA_sign(EVP_MD_get_type(rctx->md),
-                           tbs, tbslen, sig, &sltmp, rsa);
+                tbs, tbslen, sig, &sltmp, rsa);
             if (ret <= 0)
                 return ret;
             ret = sltmp;
@@ -184,12 +183,12 @@ static int pkey_rsa_sign(EVP_PKEY_CTX *ctx, unsigned char *sig,
             if (!setup_tbuf(rctx, ctx))
                 return -1;
             if (!RSA_padding_add_PKCS1_PSS_mgf1(rsa,
-                                                rctx->tbuf, tbs,
-                                                rctx->md, rctx->mgf1md,
-                                                rctx->saltlen))
+                    rctx->tbuf, tbs,
+                    rctx->md, rctx->mgf1md,
+                    rctx->saltlen))
                 return -1;
             ret = RSA_private_encrypt(RSA_size(rsa), rctx->tbuf,
-                                      sig, rsa, RSA_NO_PADDING);
+                sig, rsa, RSA_NO_PADDING);
         } else {
             return -1;
         }
@@ -203,8 +202,8 @@ static int pkey_rsa_sign(EVP_PKEY_CTX *ctx, unsigned char *sig,
 }
 
 static int pkey_rsa_verifyrecover(EVP_PKEY_CTX *ctx,
-                                  unsigned char *rout, size_t *routlen,
-                                  const unsigned char *sig, size_t siglen)
+    unsigned char *rout, size_t *routlen,
+    const unsigned char *sig, size_t siglen)
 {
     int ret;
     RSA_PKEY_CTX *rctx = ctx->data;
@@ -220,7 +219,7 @@ static int pkey_rsa_verifyrecover(EVP_PKEY_CTX *ctx,
             if (!setup_tbuf(rctx, ctx))
                 return -1;
             ret = RSA_public_decrypt(siglen, sig, rctx->tbuf, rsa,
-                                     RSA_X931_PADDING);
+                RSA_X931_PADDING);
             if (ret <= 0)
                 return 0;
             ret--;
@@ -237,8 +236,8 @@ static int pkey_rsa_verifyrecover(EVP_PKEY_CTX *ctx,
         } else if (rctx->pad_mode == RSA_PKCS1_PADDING) {
             size_t sltmp;
             ret = ossl_rsa_verify(EVP_MD_get_type(rctx->md),
-                                  NULL, 0, rout, &sltmp,
-                                  sig, siglen, rsa);
+                NULL, 0, rout, &sltmp,
+                sig, siglen, rsa);
             if (ret <= 0)
                 return 0;
             ret = sltmp;
@@ -255,8 +254,8 @@ static int pkey_rsa_verifyrecover(EVP_PKEY_CTX *ctx,
 }
 
 static int pkey_rsa_verify(EVP_PKEY_CTX *ctx,
-                           const unsigned char *sig, size_t siglen,
-                           const unsigned char *tbs, size_t tbslen)
+    const unsigned char *sig, size_t siglen,
+    const unsigned char *tbs, size_t tbslen)
 {
     RSA_PKEY_CTX *rctx = ctx->data;
     /*
@@ -270,7 +269,7 @@ static int pkey_rsa_verify(EVP_PKEY_CTX *ctx,
     if (rctx->md) {
         if (rctx->pad_mode == RSA_PKCS1_PADDING)
             return RSA_verify(EVP_MD_get_type(rctx->md), tbs, tbslen,
-                              sig, siglen, rsa);
+                sig, siglen, rsa);
         if (tbslen != (size_t)EVP_MD_get_size(rctx->md)) {
             ERR_raise(ERR_LIB_RSA, RSA_R_INVALID_DIGEST_LENGTH);
             return -1;
@@ -283,12 +282,12 @@ static int pkey_rsa_verify(EVP_PKEY_CTX *ctx,
             if (!setup_tbuf(rctx, ctx))
                 return -1;
             ret = RSA_public_decrypt(siglen, sig, rctx->tbuf,
-                                     rsa, RSA_NO_PADDING);
+                rsa, RSA_NO_PADDING);
             if (ret <= 0)
                 return 0;
             ret = RSA_verify_PKCS1_PSS_mgf1(rsa, tbs,
-                                            rctx->md, rctx->mgf1md,
-                                            rctx->tbuf, rctx->saltlen);
+                rctx->md, rctx->mgf1md,
+                rctx->tbuf, rctx->saltlen);
             if (ret <= 0)
                 return 0;
             return 1;
@@ -299,7 +298,7 @@ static int pkey_rsa_verify(EVP_PKEY_CTX *ctx,
         if (!setup_tbuf(rctx, ctx))
             return -1;
         rslen = RSA_public_decrypt(siglen, sig, rctx->tbuf,
-                                   rsa, rctx->pad_mode);
+            rsa, rctx->pad_mode);
         if (rslen <= 0)
             return 0;
     }
@@ -308,12 +307,11 @@ static int pkey_rsa_verify(EVP_PKEY_CTX *ctx,
         return 0;
 
     return 1;
-
 }
 
 static int pkey_rsa_encrypt(EVP_PKEY_CTX *ctx,
-                            unsigned char *out, size_t *outlen,
-                            const unsigned char *in, size_t inlen)
+    unsigned char *out, size_t *outlen,
+    const unsigned char *in, size_t inlen)
 {
     int ret;
     RSA_PKEY_CTX *rctx = ctx->data;
@@ -329,10 +327,10 @@ static int pkey_rsa_encrypt(EVP_PKEY_CTX *ctx,
         if (!setup_tbuf(rctx, ctx))
             return -1;
         if (!RSA_padding_add_PKCS1_OAEP_mgf1(rctx->tbuf, klen,
-                                             in, inlen,
-                                             rctx->oaep_label,
-                                             rctx->oaep_labellen,
-                                             rctx->md, rctx->mgf1md))
+                in, inlen,
+                rctx->oaep_label,
+                rctx->oaep_labellen,
+                rctx->md, rctx->mgf1md))
             return -1;
         ret = RSA_public_encrypt(klen, rctx->tbuf, out, rsa, RSA_NO_PADDING);
     } else {
@@ -345,8 +343,8 @@ static int pkey_rsa_encrypt(EVP_PKEY_CTX *ctx,
 }
 
 static int pkey_rsa_decrypt(EVP_PKEY_CTX *ctx,
-                            unsigned char *out, size_t *outlen,
-                            const unsigned char *in, size_t inlen)
+    unsigned char *out, size_t *outlen,
+    const unsigned char *in, size_t inlen)
 {
     int ret;
     int pad_mode;
@@ -365,13 +363,12 @@ static int pkey_rsa_decrypt(EVP_PKEY_CTX *ctx,
         if (ret <= 0)
             return ret;
         ret = RSA_padding_check_PKCS1_OAEP_mgf1(out, ret, rctx->tbuf,
-                                                ret, ret,
-                                                rctx->oaep_label,
-                                                rctx->oaep_labellen,
-                                                rctx->md, rctx->mgf1md);
+            ret, ret,
+            rctx->oaep_label,
+            rctx->oaep_labellen,
+            rctx->md, rctx->mgf1md);
     } else {
-        if (rctx->pad_mode == RSA_PKCS1_PADDING &&
-              rctx->implicit_rejection == 0)
+        if (rctx->pad_mode == RSA_PKCS1_PADDING && rctx->implicit_rejection == 0)
             pad_mode = RSA_PKCS1_NO_IMPLICIT_REJECT_PADDING;
         else
             pad_mode = rctx->pad_mode;
@@ -426,7 +423,6 @@ static int check_padding_md(const EVP_MD *md, int padding)
         default:
             ERR_raise(ERR_LIB_RSA, RSA_R_INVALID_DIGEST);
             return 0;
-
         }
     }
 
@@ -443,8 +439,7 @@ static int pkey_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
             if (!check_padding_md(rctx->md, p1))
                 return 0;
             if (p1 == RSA_PKCS1_PSS_PADDING) {
-                if (!(ctx->operation &
-                      (EVP_PKEY_OP_SIGN | EVP_PKEY_OP_VERIFY)))
+                if (!(ctx->operation & (EVP_PKEY_OP_SIGN | EVP_PKEY_OP_VERIFY)))
                     goto bad_pad;
                 if (!rctx->md)
                     rctx->md = EVP_sha1();
@@ -460,7 +455,7 @@ static int pkey_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
             rctx->pad_mode = p1;
             return 1;
         }
- bad_pad:
+    bad_pad:
         ERR_raise(ERR_LIB_RSA, RSA_R_ILLEGAL_OR_UNSUPPORTED_PADDING_MODE);
         return -2;
 
@@ -486,7 +481,7 @@ static int pkey_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
                     return -2;
                 }
                 if ((p1 == RSA_PSS_SALTLEN_DIGEST
-                     && rctx->min_saltlen > EVP_MD_get_size(rctx->md))
+                        && rctx->min_saltlen > EVP_MD_get_size(rctx->md))
                     || (p1 >= 0 && p1 < rctx->min_saltlen)) {
                     ERR_raise(ERR_LIB_RSA, RSA_R_PSS_SALTLEN_TOO_SMALL);
                     return 0;
@@ -612,7 +607,7 @@ static int pkey_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
 #ifndef OPENSSL_NO_CMS
     case EVP_PKEY_CTRL_CMS_SIGN:
 #endif
-    return 1;
+        return 1;
 
     case EVP_PKEY_CTRL_PKCS7_ENCRYPT:
     case EVP_PKEY_CTRL_PKCS7_DECRYPT:
@@ -620,8 +615,8 @@ static int pkey_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
     case EVP_PKEY_CTRL_CMS_DECRYPT:
     case EVP_PKEY_CTRL_CMS_ENCRYPT:
 #endif
-    if (!pkey_ctx_is_pss(ctx))
-        return 1;
+        if (!pkey_ctx_is_pss(ctx))
+            return 1;
     /* fall through */
     case EVP_PKEY_CTRL_PEER_KEY:
         ERR_raise(ERR_LIB_RSA, RSA_R_OPERATION_NOT_SUPPORTED_FOR_THIS_KEYTYPE);
@@ -629,12 +624,11 @@ static int pkey_rsa_ctrl(EVP_PKEY_CTX *ctx, int type, int p1, void *p2)
 
     default:
         return -2;
-
     }
 }
 
 static int pkey_rsa_ctrl_str(EVP_PKEY_CTX *ctx,
-                             const char *type, const char *value)
+    const char *type, const char *value)
 {
     if (value == NULL) {
         ERR_raise(ERR_LIB_RSA, RSA_R_VALUE_MISSING);
@@ -701,18 +695,18 @@ static int pkey_rsa_ctrl_str(EVP_PKEY_CTX *ctx,
 
     if (strcmp(type, "rsa_mgf1_md") == 0)
         return EVP_PKEY_CTX_md(ctx,
-                               EVP_PKEY_OP_TYPE_SIG | EVP_PKEY_OP_TYPE_CRYPT,
-                               EVP_PKEY_CTRL_RSA_MGF1_MD, value);
+            EVP_PKEY_OP_TYPE_SIG | EVP_PKEY_OP_TYPE_CRYPT,
+            EVP_PKEY_CTRL_RSA_MGF1_MD, value);
 
     if (pkey_ctx_is_pss(ctx)) {
 
         if (strcmp(type, "rsa_pss_keygen_mgf1_md") == 0)
             return EVP_PKEY_CTX_md(ctx, EVP_PKEY_OP_KEYGEN,
-                                   EVP_PKEY_CTRL_RSA_MGF1_MD, value);
+                EVP_PKEY_CTRL_RSA_MGF1_MD, value);
 
         if (strcmp(type, "rsa_pss_keygen_md") == 0)
             return EVP_PKEY_CTX_md(ctx, EVP_PKEY_OP_KEYGEN,
-                                   EVP_PKEY_CTRL_MD, value);
+                EVP_PKEY_CTRL_MD, value);
 
         if (strcmp(type, "rsa_pss_keygen_saltlen") == 0) {
             int saltlen = atoi(value);
@@ -723,7 +717,7 @@ static int pkey_rsa_ctrl_str(EVP_PKEY_CTX *ctx,
 
     if (strcmp(type, "rsa_oaep_md") == 0)
         return EVP_PKEY_CTX_md(ctx, EVP_PKEY_OP_TYPE_CRYPT,
-                               EVP_PKEY_CTRL_RSA_OAEP_MD, value);
+            EVP_PKEY_CTRL_RSA_OAEP_MD, value);
 
     if (strcmp(type, "rsa_oaep_label") == 0) {
         unsigned char *lab;
@@ -753,8 +747,9 @@ static int rsa_set_pss_param(RSA *rsa, EVP_PKEY_CTX *ctx)
     if (rctx->md == NULL && rctx->mgf1md == NULL && rctx->saltlen == -2)
         return 1;
     rsa->pss = ossl_rsa_pss_params_create(rctx->md, rctx->mgf1md,
-                                          rctx->saltlen == -2
-                                          ? 0 : rctx->saltlen);
+        rctx->saltlen == -2
+            ? 0
+            : rctx->saltlen);
     if (rsa->pss == NULL)
         return 0;
     return 1;
@@ -786,7 +781,7 @@ static int pkey_rsa_keygen(EVP_PKEY_CTX *ctx, EVP_PKEY *pkey)
         pcb = NULL;
     }
     ret = RSA_generate_multi_prime_key(rsa, rctx->nbits, rctx->primes,
-                                       rctx->pub_exp, pcb);
+        rctx->pub_exp, pcb);
     BN_GENCB_free(pcb);
     if (ret > 0 && !rsa_set_pss_param(rsa, ctx)) {
         RSA_free(rsa);
