@@ -25,19 +25,19 @@
 static const unsigned char zeroes[] = { 0, 0, 0, 0, 0, 0, 0, 0 };
 
 #if defined(_MSC_VER) && defined(_ARM_)
-# pragma optimize("g", off)
+#pragma optimize("g", off)
 #endif
 
 int RSA_verify_PKCS1_PSS(RSA *rsa, const unsigned char *mHash,
-                         const EVP_MD *Hash, const unsigned char *EM,
-                         int sLen)
+    const EVP_MD *Hash, const unsigned char *EM,
+    int sLen)
 {
     return RSA_verify_PKCS1_PSS_mgf1(rsa, mHash, Hash, NULL, EM, sLen);
 }
 
 int RSA_verify_PKCS1_PSS_mgf1(RSA *rsa, const unsigned char *mHash,
-                              const EVP_MD *Hash, const EVP_MD *mgf1Hash,
-                              const unsigned char *EM, int sLen)
+    const EVP_MD *Hash, const EVP_MD *mgf1Hash,
+    const unsigned char *EM, int sLen)
 {
     int i;
     int ret = 0;
@@ -106,17 +106,18 @@ int RSA_verify_PKCS1_PSS_mgf1(RSA *rsa, const unsigned char *mHash,
         DB[i] ^= EM[i];
     if (MSBits)
         DB[0] &= 0xFF >> (8 - MSBits);
-    for (i = 0; DB[i] == 0 && i < (maskedDBLen - 1); i++) ;
+    for (i = 0; DB[i] == 0 && i < (maskedDBLen - 1); i++)
+        ;
     if (DB[i++] != 0x1) {
         ERR_raise(ERR_LIB_RSA, RSA_R_SLEN_RECOVERY_FAILED);
         goto err;
     }
     if (sLen != RSA_PSS_SALTLEN_AUTO
-            && sLen != RSA_PSS_SALTLEN_AUTO_DIGEST_MAX
-            && (maskedDBLen - i) != sLen) {
+        && sLen != RSA_PSS_SALTLEN_AUTO_DIGEST_MAX
+        && (maskedDBLen - i) != sLen) {
         ERR_raise_data(ERR_LIB_RSA, RSA_R_SLEN_CHECK_FAILED,
-                       "expected: %d retrieved: %d", sLen,
-                       maskedDBLen - i);
+            "expected: %d retrieved: %d", sLen,
+            maskedDBLen - i);
         goto err;
     }
     if (!EVP_DigestInit_ex(ctx, Hash, NULL)
@@ -136,25 +137,24 @@ int RSA_verify_PKCS1_PSS_mgf1(RSA *rsa, const unsigned char *mHash,
         ret = 1;
     }
 
- err:
+err:
     OPENSSL_free(DB);
     EVP_MD_CTX_free(ctx);
 
     return ret;
-
 }
 
 int RSA_padding_add_PKCS1_PSS(RSA *rsa, unsigned char *EM,
-                              const unsigned char *mHash,
-                              const EVP_MD *Hash, int sLen)
+    const unsigned char *mHash,
+    const EVP_MD *Hash, int sLen)
 {
     return RSA_padding_add_PKCS1_PSS_mgf1(rsa, EM, mHash, Hash, NULL, sLen);
 }
 
 int RSA_padding_add_PKCS1_PSS_mgf1(RSA *rsa, unsigned char *EM,
-                                   const unsigned char *mHash,
-                                   const EVP_MD *Hash, const EVP_MD *mgf1Hash,
-                                   int sLen)
+    const unsigned char *mHash,
+    const EVP_MD *Hash, const EVP_MD *mgf1Hash,
+    int sLen)
 {
     int i;
     int ret = 0;
@@ -187,7 +187,7 @@ int RSA_padding_add_PKCS1_PSS_mgf1(RSA *rsa, unsigned char *EM,
     if (sLen == RSA_PSS_SALTLEN_DIGEST) {
         sLen = hLen;
     } else if (sLen == RSA_PSS_SALTLEN_MAX_SIGN
-            || sLen == RSA_PSS_SALTLEN_AUTO) {
+        || sLen == RSA_PSS_SALTLEN_AUTO) {
         sLen = RSA_PSS_SALTLEN_MAX;
     } else if (sLen == RSA_PSS_SALTLEN_AUTO_DIGEST_MAX) {
         sLen = RSA_PSS_SALTLEN_MAX;
@@ -261,12 +261,11 @@ int RSA_padding_add_PKCS1_PSS_mgf1(RSA *rsa, unsigned char *EM,
 
     ret = 1;
 
- err:
+err:
     EVP_MD_CTX_free(ctx);
     OPENSSL_clear_free(salt, (size_t)sLen); /* salt != NULL implies sLen > 0 */
 
     return ret;
-
 }
 
 /*
@@ -292,13 +291,13 @@ int RSA_padding_add_PKCS1_PSS_mgf1(RSA *rsa, unsigned char *EM,
  *     }
  */
 static const RSA_PSS_PARAMS_30 default_RSASSA_PSS_params = {
-    NID_sha1,                    /* default hashAlgorithm */
+    NID_sha1, /* default hashAlgorithm */
     {
-        NID_mgf1,                /* default maskGenAlgorithm */
-        NID_sha1                 /* default MGF1 hash */
+        NID_mgf1, /* default maskGenAlgorithm */
+        NID_sha1 /* default MGF1 hash */
     },
-    20,                          /* default saltLength */
-    1                            /* default trailerField (0xBC) */
+    20, /* default saltLength */
+    1 /* default trailerField (0xBC) */
 };
 
 int ossl_rsa_pss_params_30_set_defaults(RSA_PSS_PARAMS_30 *rsa_pss_params)
@@ -311,22 +310,25 @@ int ossl_rsa_pss_params_30_set_defaults(RSA_PSS_PARAMS_30 *rsa_pss_params)
 
 int ossl_rsa_pss_params_30_is_unrestricted(const RSA_PSS_PARAMS_30 *rsa_pss_params)
 {
-    static RSA_PSS_PARAMS_30 pss_params_cmp = { 0, };
+    static RSA_PSS_PARAMS_30 pss_params_cmp = {
+        0,
+    };
 
     return rsa_pss_params == NULL
         || memcmp(rsa_pss_params, &pss_params_cmp,
-                  sizeof(*rsa_pss_params)) == 0;
+               sizeof(*rsa_pss_params))
+        == 0;
 }
 
 int ossl_rsa_pss_params_30_copy(RSA_PSS_PARAMS_30 *to,
-                                const RSA_PSS_PARAMS_30 *from)
+    const RSA_PSS_PARAMS_30 *from)
 {
     memcpy(to, from, sizeof(*to));
     return 1;
 }
 
 int ossl_rsa_pss_params_30_set_hashalg(RSA_PSS_PARAMS_30 *rsa_pss_params,
-                                       int hashalg_nid)
+    int hashalg_nid)
 {
     if (rsa_pss_params == NULL)
         return 0;
@@ -335,7 +337,7 @@ int ossl_rsa_pss_params_30_set_hashalg(RSA_PSS_PARAMS_30 *rsa_pss_params,
 }
 
 int ossl_rsa_pss_params_30_set_maskgenhashalg(RSA_PSS_PARAMS_30 *rsa_pss_params,
-                                              int maskgenhashalg_nid)
+    int maskgenhashalg_nid)
 {
     if (rsa_pss_params == NULL)
         return 0;
@@ -344,7 +346,7 @@ int ossl_rsa_pss_params_30_set_maskgenhashalg(RSA_PSS_PARAMS_30 *rsa_pss_params,
 }
 
 int ossl_rsa_pss_params_30_set_saltlen(RSA_PSS_PARAMS_30 *rsa_pss_params,
-                                       int saltlen)
+    int saltlen)
 {
     if (rsa_pss_params == NULL)
         return 0;
@@ -353,7 +355,7 @@ int ossl_rsa_pss_params_30_set_saltlen(RSA_PSS_PARAMS_30 *rsa_pss_params,
 }
 
 int ossl_rsa_pss_params_30_set_trailerfield(RSA_PSS_PARAMS_30 *rsa_pss_params,
-                                            int trailerfield)
+    int trailerfield)
 {
     if (rsa_pss_params == NULL)
         return 0;
@@ -397,5 +399,5 @@ int ossl_rsa_pss_params_30_trailerfield(const RSA_PSS_PARAMS_30 *rsa_pss_params)
 }
 
 #if defined(_MSC_VER)
-# pragma optimize("",on)
+#pragma optimize("", on)
 #endif
