@@ -13,14 +13,12 @@
 #include "internal/cryptlib.h"
 #include "crypto/context.h"
 
-typedef struct self_test_cb_st
-{
+typedef struct self_test_cb_st {
     OSSL_CALLBACK *cb;
     void *cbarg;
 } SELF_TEST_CB;
 
-struct ossl_self_test_st
-{
+struct ossl_self_test_st {
     /* local state variables */
     const char *phase;
     const char *type;
@@ -52,7 +50,7 @@ static SELF_TEST_CB *get_self_test_callback(OSSL_LIB_CTX *libctx)
 }
 
 void OSSL_SELF_TEST_set_callback(OSSL_LIB_CTX *libctx, OSSL_CALLBACK *cb,
-                                 void *cbarg)
+    void *cbarg)
 {
     SELF_TEST_CB *stcb = get_self_test_callback(libctx);
 
@@ -63,7 +61,7 @@ void OSSL_SELF_TEST_set_callback(OSSL_LIB_CTX *libctx, OSSL_CALLBACK *cb,
 }
 
 void OSSL_SELF_TEST_get_callback(OSSL_LIB_CTX *libctx, OSSL_CALLBACK **cb,
-                                 void **cbarg)
+    void **cbarg)
 {
     SELF_TEST_CB *stcb = get_self_test_callback(libctx);
 
@@ -79,15 +77,12 @@ static void self_test_setparams(OSSL_SELF_TEST *st)
     size_t n = 0;
 
     if (st->cb != NULL) {
-        st->params[n++] =
-            OSSL_PARAM_construct_utf8_string(OSSL_PROV_PARAM_SELF_TEST_PHASE,
-                                             (char *)st->phase, 0);
-        st->params[n++] =
-            OSSL_PARAM_construct_utf8_string(OSSL_PROV_PARAM_SELF_TEST_TYPE,
-                                             (char *)st->type, 0);
-        st->params[n++] =
-            OSSL_PARAM_construct_utf8_string(OSSL_PROV_PARAM_SELF_TEST_DESC,
-                                             (char *)st->desc, 0);
+        st->params[n++] = OSSL_PARAM_construct_utf8_string(OSSL_PROV_PARAM_SELF_TEST_PHASE,
+            (char *)st->phase, 0);
+        st->params[n++] = OSSL_PARAM_construct_utf8_string(OSSL_PROV_PARAM_SELF_TEST_TYPE,
+            (char *)st->type, 0);
+        st->params[n++] = OSSL_PARAM_construct_utf8_string(OSSL_PROV_PARAM_SELF_TEST_DESC,
+            (char *)st->desc, 0);
     }
     st->params[n++] = OSSL_PARAM_construct_end();
 }
@@ -115,7 +110,7 @@ void OSSL_SELF_TEST_free(OSSL_SELF_TEST *st)
 
 /* Can be used during application testing to log that a test has started. */
 void OSSL_SELF_TEST_onbegin(OSSL_SELF_TEST *st, const char *type,
-                            const char *desc)
+    const char *desc)
 {
     if (st != NULL && st->cb != NULL) {
         st->phase = OSSL_SELF_TEST_PHASE_START;
@@ -133,8 +128,7 @@ void OSSL_SELF_TEST_onbegin(OSSL_SELF_TEST *st, const char *type,
 void OSSL_SELF_TEST_onend(OSSL_SELF_TEST *st, int ret)
 {
     if (st != NULL && st->cb != NULL) {
-        st->phase =
-            (ret == 1 ? OSSL_SELF_TEST_PHASE_PASS : OSSL_SELF_TEST_PHASE_FAIL);
+        st->phase = (ret == 1 ? OSSL_SELF_TEST_PHASE_PASS : OSSL_SELF_TEST_PHASE_FAIL);
         self_test_setparams(st);
         (void)st->cb(st->params, st->cb_arg);
 
