@@ -12,41 +12,35 @@
 #include <assert.h>
 
 size_t SHA3_absorb(uint64_t A[5][5], const unsigned char *inp, size_t len,
-                   size_t r);
-void SHA3_squeeze(uint64_t A[5][5], unsigned char *out, size_t len, size_t r);
+    size_t r);
+void SHA3_squeeze(uint64_t A[5][5], unsigned char *out, size_t len, size_t r, int next);
 
 #if !defined(KECCAK1600_ASM) || !defined(SELFTEST)
 
 /*
  * Choose some sensible defaults
  */
-#if !defined(KECCAK_REF) && !defined(KECCAK_1X) && !defined(KECCAK_1X_ALT) && \
-    !defined(KECCAK_2X) && !defined(KECCAK_INPLACE)
-# define KECCAK_2X      /* default to KECCAK_2X variant */
+#if !defined(KECCAK_REF) && !defined(KECCAK_1X) && !defined(KECCAK_1X_ALT) && !defined(KECCAK_2X) && !defined(KECCAK_INPLACE)
+#define KECCAK_2X /* default to KECCAK_2X variant */
 #endif
 
-#if defined(__i386) || defined(__i386__) || defined(_M_IX86) || \
-    (defined(__x86_64) && !defined(__BMI__)) || defined(_M_X64) || \
-    defined(__mips) || defined(__riscv) || defined(__s390__) || \
-    defined(__EMSCRIPTEN__)
+#if defined(__i386) || defined(__i386__) || defined(_M_IX86) || (defined(__x86_64) && !defined(__BMI__)) || defined(_M_X64) || defined(__mips) || defined(__riscv) || defined(__s390__) || defined(__EMSCRIPTEN__)
 /*
  * These don't have "and with complement" instruction, so minimize amount
  * of "not"-s. Implemented only in the [default] KECCAK_2X variant.
  */
-# define KECCAK_COMPLEMENTING_TRANSFORM
+#define KECCAK_COMPLEMENTING_TRANSFORM
 #endif
 
-#if defined(__x86_64__) || defined(__aarch64__) || \
-    defined(__mips64) || defined(__ia64) || \
-    (defined(__VMS) && !defined(__vax))
+#if defined(__x86_64__) || defined(__aarch64__) || defined(__mips64) || defined(__ia64) || (defined(__VMS) && !defined(__vax))
 /*
  * These are available even in ILP32 flavours, but even then they are
  * capable of performing 64-bit operations as efficiently as in *P64.
  * Since it's not given that we can use sizeof(void *), just shunt it.
  */
-# define BIT_INTERLEAVE (0)
+#define BIT_INTERLEAVE (0)
 #else
-# define BIT_INTERLEAVE (sizeof(void *) < 8)
+#define BIT_INTERLEAVE (sizeof(void *) < 8)
 #endif
 
 #define ROL32(a, offset) (((a) << (offset)) | ((a) >> ((32 - (offset)) & 31)))
@@ -56,7 +50,7 @@ static uint64_t ROL64(uint64_t val, int offset)
     if (offset == 0) {
         return val;
     } else if (!BIT_INTERLEAVE) {
-        return (val << offset) | (val >> (64-offset));
+        return (val << offset) | (val >> (64 - offset));
     } else {
         uint32_t hi = (uint32_t)(val >> 32), lo = (uint32_t)val;
 
@@ -77,11 +71,11 @@ static uint64_t ROL64(uint64_t val, int offset)
 }
 
 static const unsigned char rhotates[5][5] = {
-    {  0,  1, 62, 28, 27 },
-    { 36, 44,  6, 55, 20 },
-    {  3, 10, 43, 25, 39 },
-    { 41, 45, 15, 21,  8 },
-    { 18,  2, 61, 56, 14 }
+    { 0, 1, 62, 28, 27 },
+    { 36, 44, 6, 55, 20 },
+    { 3, 10, 43, 25, 39 },
+    { 41, 45, 15, 21, 8 },
+    { 18, 2, 61, 56, 14 }
 };
 
 static const uint64_t iotas[] = {
@@ -261,8 +255,8 @@ static void KeccakF1600(uint64_t A[5][5])
  */
 static void Round(uint64_t A[5][5], size_t i)
 {
-    uint64_t C[5], E[2];        /* registers */
-    uint64_t D[5], T[2][5];     /* memory    */
+    uint64_t C[5], E[2]; /* registers */
+    uint64_t D[5], T[2][5]; /* memory    */
 
     assert(i < (sizeof(iotas) / sizeof(iotas[0])));
 
@@ -285,11 +279,11 @@ static void Round(uint64_t A[5][5], size_t i)
     T[0][3] = A[0][3] ^ C[2]; /* D[3] */
     T[0][4] = A[0][4] ^ E[1]; /* D[4] */
 
-    C[3] = ROL64(A[3][3] ^ C[2], rhotates[3][3]);   /* D[3] */
-    C[4] = ROL64(A[4][4] ^ E[1], rhotates[4][4]);   /* D[4] */
-    C[0] =       A[0][0] ^ C[0]; /* rotate by 0 */  /* D[0] */
-    C[2] = ROL64(A[2][2] ^ C[1], rhotates[2][2]);   /* D[2] */
-    C[1] = ROL64(A[1][1] ^ E[0], rhotates[1][1]);   /* D[1] */
+    C[3] = ROL64(A[3][3] ^ C[2], rhotates[3][3]); /* D[3] */
+    C[4] = ROL64(A[4][4] ^ E[1], rhotates[4][4]); /* D[4] */
+    C[0] = A[0][0] ^ C[0]; /* rotate by 0 */ /* D[0] */
+    C[2] = ROL64(A[2][2] ^ C[1], rhotates[2][2]); /* D[2] */
+    C[1] = ROL64(A[1][1] ^ E[0], rhotates[1][1]); /* D[1] */
 #else
     D[0] = ROL64(C[1], 1) ^ C[4];
     D[1] = ROL64(C[2], 1) ^ C[0];
@@ -303,7 +297,7 @@ static void Round(uint64_t A[5][5], size_t i)
     T[0][3] = A[0][3] ^ D[3];
     T[0][4] = A[0][4] ^ D[4];
 
-    C[0] =       A[0][0] ^ D[0]; /* rotate by 0 */
+    C[0] = A[0][0] ^ D[0]; /* rotate by 0 */
     C[1] = ROL64(A[1][1] ^ D[1], rhotates[1][1]);
     C[2] = ROL64(A[2][2] ^ D[2], rhotates[2][2]);
     C[3] = ROL64(A[3][3] ^ D[3], rhotates[3][3]);
@@ -321,11 +315,11 @@ static void Round(uint64_t A[5][5], size_t i)
     T[1][3] = A[1][3] ^ (E[1] = D[3]);
     T[1][4] = A[2][4] ^ (C[2] = D[4]); /* borrow T[1][4] */
 
-    C[0] = ROL64(T[0][3],        rhotates[0][3]);
-    C[1] = ROL64(A[1][4] ^ C[2], rhotates[1][4]);   /* D[4] */
-    C[2] = ROL64(A[2][0] ^ C[3], rhotates[2][0]);   /* D[0] */
-    C[3] = ROL64(A[3][1] ^ C[4], rhotates[3][1]);   /* D[1] */
-    C[4] = ROL64(A[4][2] ^ E[0], rhotates[4][2]);   /* D[2] */
+    C[0] = ROL64(T[0][3], rhotates[0][3]);
+    C[1] = ROL64(A[1][4] ^ C[2], rhotates[1][4]); /* D[4] */
+    C[2] = ROL64(A[2][0] ^ C[3], rhotates[2][0]); /* D[0] */
+    C[3] = ROL64(A[3][1] ^ C[4], rhotates[3][1]); /* D[1] */
+    C[4] = ROL64(A[4][2] ^ E[0], rhotates[4][2]); /* D[2] */
 
     A[1][0] = C[0] ^ (~C[1] & C[2]);
     A[1][1] = C[1] ^ (~C[2] & C[3]);
@@ -333,8 +327,8 @@ static void Round(uint64_t A[5][5], size_t i)
     A[1][3] = C[3] ^ (~C[4] & C[0]);
     A[1][4] = C[4] ^ (~C[0] & C[1]);
 
-    C[0] = ROL64(T[0][1],        rhotates[0][1]);
-    C[1] = ROL64(T[1][2],        rhotates[1][2]);
+    C[0] = ROL64(T[0][1], rhotates[0][1]);
+    C[1] = ROL64(T[1][2], rhotates[1][2]);
     C[2] = ROL64(A[2][3] ^ D[3], rhotates[2][3]);
     C[3] = ROL64(A[3][4] ^ D[4], rhotates[3][4]);
     C[4] = ROL64(A[4][0] ^ D[0], rhotates[4][0]);
@@ -345,9 +339,9 @@ static void Round(uint64_t A[5][5], size_t i)
     A[2][3] = C[3] ^ (~C[4] & C[0]);
     A[2][4] = C[4] ^ (~C[0] & C[1]);
 
-    C[0] = ROL64(T[0][4],        rhotates[0][4]);
-    C[1] = ROL64(T[1][0],        rhotates[1][0]);
-    C[2] = ROL64(T[1][1],        rhotates[2][1]); /* originally A[2][1] */
+    C[0] = ROL64(T[0][4], rhotates[0][4]);
+    C[1] = ROL64(T[1][0], rhotates[1][0]);
+    C[2] = ROL64(T[1][1], rhotates[2][1]); /* originally A[2][1] */
     C[3] = ROL64(A[3][2] ^ D[2], rhotates[3][2]);
     C[4] = ROL64(A[4][3] ^ D[3], rhotates[4][3]);
 
@@ -357,10 +351,10 @@ static void Round(uint64_t A[5][5], size_t i)
     A[3][3] = C[3] ^ (~C[4] & C[0]);
     A[3][4] = C[4] ^ (~C[0] & C[1]);
 
-    C[0] = ROL64(T[0][2],        rhotates[0][2]);
-    C[1] = ROL64(T[1][3],        rhotates[1][3]);
-    C[2] = ROL64(T[1][4],        rhotates[2][4]); /* originally A[2][4] */
-    C[3] = ROL64(T[0][0],        rhotates[3][0]); /* originally A[3][0] */
+    C[0] = ROL64(T[0][2], rhotates[0][2]);
+    C[1] = ROL64(T[1][3], rhotates[1][3]);
+    C[2] = ROL64(T[1][4], rhotates[2][4]); /* originally A[2][4] */
+    C[3] = ROL64(T[0][0], rhotates[3][0]); /* originally A[3][0] */
     C[4] = ROL64(A[4][1] ^ D[1], rhotates[4][1]);
 
     A[4][0] = C[0] ^ (~C[1] & C[2]);
@@ -399,8 +393,8 @@ static void Round(uint64_t A[5][5], size_t i)
     C[3] = A[0][3] ^ A[1][3] ^ A[2][3] ^ A[3][3] ^ A[4][3];
     C[4] = A[0][4] ^ A[1][4] ^ A[2][4] ^ A[3][4] ^ A[4][4];
 
-    D[1] = C[0] ^  ROL64(C[2], 1);
-    D[2] = C[1] ^  ROL64(C[3], 1);
+    D[1] = C[0] ^ ROL64(C[2], 1);
+    D[2] = C[1] ^ ROL64(C[3], 1);
     D[3] = C[2] ^= ROL64(C[4], 1);
     D[4] = C[3] ^= ROL64(C[0], 1);
     D[0] = C[4] ^= ROL64(C[1], 1);
@@ -465,10 +459,10 @@ static void Round(uint64_t A[5][5], size_t i)
     A[1][2] = ROL64(A[2][0], rhotates[2][0]);
     A[3][1] = ROL64(A[1][0], rhotates[1][0]);
 
-    A[1][0] = ROL64(C[3],    rhotates[0][3]);
-    A[2][0] = ROL64(C[1],    rhotates[0][1]);
-    A[3][0] = ROL64(C[4],    rhotates[0][4]);
-    A[4][0] = ROL64(C[2],    rhotates[0][2]);
+    A[1][0] = ROL64(C[3], rhotates[0][3]);
+    A[2][0] = ROL64(C[1], rhotates[0][1]);
+    A[3][0] = ROL64(C[4], rhotates[0][4]);
+    A[4][0] = ROL64(C[2], rhotates[0][2]);
 
     C[0] = A[0][0];
     C[1] = A[1][0];
@@ -483,8 +477,8 @@ static void Round(uint64_t A[5][5], size_t i)
     A[1][2] ^= (~A[1][3] & A[1][4]);
     A[0][3] ^= (~A[0][4] & C[0]);
     A[1][3] ^= (~A[1][4] & C[1]);
-    A[0][4] ^= (~C[0]    & D[0]);
-    A[1][4] ^= (~C[1]    & D[1]);
+    A[0][4] ^= (~C[0] & D[0]);
+    A[1][4] ^= (~C[1] & D[1]);
 
     C[2] = A[2][0];
     C[3] = A[3][0];
@@ -499,8 +493,8 @@ static void Round(uint64_t A[5][5], size_t i)
     A[3][2] ^= (~A[3][3] & A[3][4]);
     A[2][3] ^= (~A[2][4] & C[2]);
     A[3][3] ^= (~A[3][4] & C[3]);
-    A[2][4] ^= (~C[2]    & D[2]);
-    A[3][4] ^= (~C[3]    & D[3]);
+    A[2][4] ^= (~C[2] & D[2]);
+    A[3][4] ^= (~C[3] & D[3]);
 
     C[4] = A[4][0];
     D[4] = A[4][1];
@@ -509,7 +503,7 @@ static void Round(uint64_t A[5][5], size_t i)
     A[4][1] ^= (~A[4][2] & A[4][3]);
     A[4][2] ^= (~A[4][3] & A[4][4]);
     A[4][3] ^= (~A[4][4] & C[4]);
-    A[4][4] ^= (~C[4]    & D[4]);
+    A[4][4] ^= (~C[4] & D[4]);
     A[0][0] ^= iotas[i];
 }
 
@@ -550,18 +544,18 @@ static void Round(uint64_t R[5][5], uint64_t A[5][5], size_t i)
     D[3] = ROL64(C[4], 1) ^ C[2];
     D[4] = ROL64(C[0], 1) ^ C[3];
 
-    C[0] =       A[0][0] ^ D[0]; /* rotate by 0 */
+    C[0] = A[0][0] ^ D[0]; /* rotate by 0 */
     C[1] = ROL64(A[1][1] ^ D[1], rhotates[1][1]);
     C[2] = ROL64(A[2][2] ^ D[2], rhotates[2][2]);
     C[3] = ROL64(A[3][3] ^ D[3], rhotates[3][3]);
     C[4] = ROL64(A[4][4] ^ D[4], rhotates[4][4]);
 
 #ifdef KECCAK_COMPLEMENTING_TRANSFORM
-    R[0][0] = C[0] ^ ( C[1] | C[2]) ^ iotas[i];
+    R[0][0] = C[0] ^ (C[1] | C[2]) ^ iotas[i];
     R[0][1] = C[1] ^ (~C[2] | C[3]);
-    R[0][2] = C[2] ^ ( C[3] & C[4]);
-    R[0][3] = C[3] ^ ( C[4] | C[0]);
-    R[0][4] = C[4] ^ ( C[0] & C[1]);
+    R[0][2] = C[2] ^ (C[3] & C[4]);
+    R[0][3] = C[3] ^ (C[4] | C[0]);
+    R[0][4] = C[4] ^ (C[0] & C[1]);
 #else
     R[0][0] = C[0] ^ (~C[1] & C[2]) ^ iotas[i];
     R[0][1] = C[1] ^ (~C[2] & C[3]);
@@ -577,11 +571,11 @@ static void Round(uint64_t R[5][5], uint64_t A[5][5], size_t i)
     C[4] = ROL64(A[4][2] ^ D[2], rhotates[4][2]);
 
 #ifdef KECCAK_COMPLEMENTING_TRANSFORM
-    R[1][0] = C[0] ^ (C[1] |  C[2]);
-    R[1][1] = C[1] ^ (C[2] &  C[3]);
+    R[1][0] = C[0] ^ (C[1] | C[2]);
+    R[1][1] = C[1] ^ (C[2] & C[3]);
     R[1][2] = C[2] ^ (C[3] | ~C[4]);
-    R[1][3] = C[3] ^ (C[4] |  C[0]);
-    R[1][4] = C[4] ^ (C[0] &  C[1]);
+    R[1][3] = C[3] ^ (C[4] | C[0]);
+    R[1][4] = C[4] ^ (C[0] & C[1]);
 #else
     R[1][0] = C[0] ^ (~C[1] & C[2]);
     R[1][1] = C[1] ^ (~C[2] & C[3]);
@@ -597,11 +591,11 @@ static void Round(uint64_t R[5][5], uint64_t A[5][5], size_t i)
     C[4] = ROL64(A[4][0] ^ D[0], rhotates[4][0]);
 
 #ifdef KECCAK_COMPLEMENTING_TRANSFORM
-    R[2][0] =  C[0] ^ ( C[1] | C[2]);
-    R[2][1] =  C[1] ^ ( C[2] & C[3]);
-    R[2][2] =  C[2] ^ (~C[3] & C[4]);
-    R[2][3] = ~C[3] ^ ( C[4] | C[0]);
-    R[2][4] =  C[4] ^ ( C[0] & C[1]);
+    R[2][0] = C[0] ^ (C[1] | C[2]);
+    R[2][1] = C[1] ^ (C[2] & C[3]);
+    R[2][2] = C[2] ^ (~C[3] & C[4]);
+    R[2][3] = ~C[3] ^ (C[4] | C[0]);
+    R[2][4] = C[4] ^ (C[0] & C[1]);
 #else
     R[2][0] = C[0] ^ (~C[1] & C[2]);
     R[2][1] = C[1] ^ (~C[2] & C[3]);
@@ -617,11 +611,11 @@ static void Round(uint64_t R[5][5], uint64_t A[5][5], size_t i)
     C[4] = ROL64(A[4][3] ^ D[3], rhotates[4][3]);
 
 #ifdef KECCAK_COMPLEMENTING_TRANSFORM
-    R[3][0] =  C[0] ^ ( C[1] & C[2]);
-    R[3][1] =  C[1] ^ ( C[2] | C[3]);
-    R[3][2] =  C[2] ^ (~C[3] | C[4]);
-    R[3][3] = ~C[3] ^ ( C[4] & C[0]);
-    R[3][4] =  C[4] ^ ( C[0] | C[1]);
+    R[3][0] = C[0] ^ (C[1] & C[2]);
+    R[3][1] = C[1] ^ (C[2] | C[3]);
+    R[3][2] = C[2] ^ (~C[3] | C[4]);
+    R[3][3] = ~C[3] ^ (C[4] & C[0]);
+    R[3][4] = C[4] ^ (C[0] | C[1]);
 #else
     R[3][0] = C[0] ^ (~C[1] & C[2]);
     R[3][1] = C[1] ^ (~C[2] & C[3]);
@@ -637,11 +631,11 @@ static void Round(uint64_t R[5][5], uint64_t A[5][5], size_t i)
     C[4] = ROL64(A[4][1] ^ D[1], rhotates[4][1]);
 
 #ifdef KECCAK_COMPLEMENTING_TRANSFORM
-    R[4][0] =  C[0] ^ (~C[1] & C[2]);
-    R[4][1] = ~C[1] ^ ( C[2] | C[3]);
-    R[4][2] =  C[2] ^ ( C[3] & C[4]);
-    R[4][3] =  C[3] ^ ( C[4] | C[0]);
-    R[4][4] =  C[4] ^ ( C[0] & C[1]);
+    R[4][0] = C[0] ^ (~C[1] & C[2]);
+    R[4][1] = ~C[1] ^ (C[2] | C[3]);
+    R[4][2] = C[2] ^ (C[3] & C[4]);
+    R[4][3] = C[3] ^ (C[4] | C[0]);
+    R[4][4] = C[4] ^ (C[0] & C[1]);
 #else
     R[4][0] = C[0] ^ (~C[1] & C[2]);
     R[4][1] = C[1] ^ (~C[2] & C[3]);
@@ -680,7 +674,7 @@ static void KeccakF1600(uint64_t A[5][5])
 #endif
 }
 
-#else   /* define KECCAK_INPLACE to compile this code path */
+#else /* define KECCAK_INPLACE to compile this code path */
 /*
  * This implementation is KECCAK_1X from above combined 4 times with
  * a twist that allows to omit temporary storage and perform in-place
@@ -709,7 +703,7 @@ static void FourRounds(uint64_t A[5][5], size_t i)
     D[3] = ROL64(C[4], 1) ^ C[2];
     D[4] = ROL64(C[0], 1) ^ C[3];
 
-    B[0] =       A[0][0] ^ D[0]; /* rotate by 0 */
+    B[0] = A[0][0] ^ D[0]; /* rotate by 0 */
     B[1] = ROL64(A[1][1] ^ D[1], rhotates[1][1]);
     B[2] = ROL64(A[2][2] ^ D[2], rhotates[2][2]);
     B[3] = ROL64(A[3][3] ^ D[3], rhotates[3][3]);
@@ -776,7 +770,7 @@ static void FourRounds(uint64_t A[5][5], size_t i)
     D[3] = ROL64(C[4], 1) ^ C[2];
     D[4] = ROL64(C[0], 1) ^ C[3];
 
-    B[0] =       A[0][0] ^ D[0]; /* rotate by 0 */
+    B[0] = A[0][0] ^ D[0]; /* rotate by 0 */
     B[1] = ROL64(A[3][1] ^ D[1], rhotates[1][1]);
     B[2] = ROL64(A[1][2] ^ D[2], rhotates[2][2]);
     B[3] = ROL64(A[4][3] ^ D[3], rhotates[3][3]);
@@ -843,7 +837,7 @@ static void FourRounds(uint64_t A[5][5], size_t i)
     D[3] = ROL64(C[4], 1) ^ C[2];
     D[4] = ROL64(C[0], 1) ^ C[3];
 
-    B[0] =       A[0][0] ^ D[0]; /* rotate by 0 */
+    B[0] = A[0][0] ^ D[0]; /* rotate by 0 */
     B[1] = ROL64(A[2][1] ^ D[1], rhotates[1][1]);
     B[2] = ROL64(A[4][2] ^ D[2], rhotates[2][2]);
     B[3] = ROL64(A[1][3] ^ D[3], rhotates[3][3]);
@@ -910,7 +904,7 @@ static void FourRounds(uint64_t A[5][5], size_t i)
     D[3] = ROL64(C[4], 1) ^ C[2];
     D[4] = ROL64(C[0], 1) ^ C[3];
 
-    B[0] =       A[0][0] ^ D[0]; /* rotate by 0 */
+    B[0] = A[0][0] ^ D[0]; /* rotate by 0 */
     B[1] = ROL64(A[0][1] ^ D[1], rhotates[1][1]);
     B[2] = ROL64(A[0][2] ^ D[2], rhotates[2][2]);
     B[3] = ROL64(A[0][3] ^ D[3], rhotates[3][3]);
@@ -989,28 +983,44 @@ static uint64_t BitInterleave(uint64_t Ai)
         uint32_t t0, t1;
 
         t0 = lo & 0x55555555;
-        t0 |= t0 >> 1;  t0 &= 0x33333333;
-        t0 |= t0 >> 2;  t0 &= 0x0f0f0f0f;
-        t0 |= t0 >> 4;  t0 &= 0x00ff00ff;
-        t0 |= t0 >> 8;  t0 &= 0x0000ffff;
+        t0 |= t0 >> 1;
+        t0 &= 0x33333333;
+        t0 |= t0 >> 2;
+        t0 &= 0x0f0f0f0f;
+        t0 |= t0 >> 4;
+        t0 &= 0x00ff00ff;
+        t0 |= t0 >> 8;
+        t0 &= 0x0000ffff;
 
         t1 = hi & 0x55555555;
-        t1 |= t1 >> 1;  t1 &= 0x33333333;
-        t1 |= t1 >> 2;  t1 &= 0x0f0f0f0f;
-        t1 |= t1 >> 4;  t1 &= 0x00ff00ff;
-        t1 |= t1 >> 8;  t1 <<= 16;
+        t1 |= t1 >> 1;
+        t1 &= 0x33333333;
+        t1 |= t1 >> 2;
+        t1 &= 0x0f0f0f0f;
+        t1 |= t1 >> 4;
+        t1 &= 0x00ff00ff;
+        t1 |= t1 >> 8;
+        t1 <<= 16;
 
         lo &= 0xaaaaaaaa;
-        lo |= lo << 1;  lo &= 0xcccccccc;
-        lo |= lo << 2;  lo &= 0xf0f0f0f0;
-        lo |= lo << 4;  lo &= 0xff00ff00;
-        lo |= lo << 8;  lo >>= 16;
+        lo |= lo << 1;
+        lo &= 0xcccccccc;
+        lo |= lo << 2;
+        lo &= 0xf0f0f0f0;
+        lo |= lo << 4;
+        lo &= 0xff00ff00;
+        lo |= lo << 8;
+        lo >>= 16;
 
         hi &= 0xaaaaaaaa;
-        hi |= hi << 1;  hi &= 0xcccccccc;
-        hi |= hi << 2;  hi &= 0xf0f0f0f0;
-        hi |= hi << 4;  hi &= 0xff00ff00;
-        hi |= hi << 8;  hi &= 0xffff0000;
+        hi |= hi << 1;
+        hi &= 0xcccccccc;
+        hi |= hi << 2;
+        hi &= 0xf0f0f0f0;
+        hi |= hi << 4;
+        hi &= 0xff00ff00;
+        hi |= hi << 8;
+        hi &= 0xffff0000;
 
         Ai = ((uint64_t)(hi | lo) << 32) | (t1 | t0);
     }
@@ -1025,28 +1035,44 @@ static uint64_t BitDeinterleave(uint64_t Ai)
         uint32_t t0, t1;
 
         t0 = lo & 0x0000ffff;
-        t0 |= t0 << 8;  t0 &= 0x00ff00ff;
-        t0 |= t0 << 4;  t0 &= 0x0f0f0f0f;
-        t0 |= t0 << 2;  t0 &= 0x33333333;
-        t0 |= t0 << 1;  t0 &= 0x55555555;
+        t0 |= t0 << 8;
+        t0 &= 0x00ff00ff;
+        t0 |= t0 << 4;
+        t0 &= 0x0f0f0f0f;
+        t0 |= t0 << 2;
+        t0 &= 0x33333333;
+        t0 |= t0 << 1;
+        t0 &= 0x55555555;
 
         t1 = hi << 16;
-        t1 |= t1 >> 8;  t1 &= 0xff00ff00;
-        t1 |= t1 >> 4;  t1 &= 0xf0f0f0f0;
-        t1 |= t1 >> 2;  t1 &= 0xcccccccc;
-        t1 |= t1 >> 1;  t1 &= 0xaaaaaaaa;
+        t1 |= t1 >> 8;
+        t1 &= 0xff00ff00;
+        t1 |= t1 >> 4;
+        t1 &= 0xf0f0f0f0;
+        t1 |= t1 >> 2;
+        t1 &= 0xcccccccc;
+        t1 |= t1 >> 1;
+        t1 &= 0xaaaaaaaa;
 
         lo >>= 16;
-        lo |= lo << 8;  lo &= 0x00ff00ff;
-        lo |= lo << 4;  lo &= 0x0f0f0f0f;
-        lo |= lo << 2;  lo &= 0x33333333;
-        lo |= lo << 1;  lo &= 0x55555555;
+        lo |= lo << 8;
+        lo &= 0x00ff00ff;
+        lo |= lo << 4;
+        lo &= 0x0f0f0f0f;
+        lo |= lo << 2;
+        lo &= 0x33333333;
+        lo |= lo << 1;
+        lo &= 0x55555555;
 
         hi &= 0xffff0000;
-        hi |= hi >> 8;  hi &= 0xff00ff00;
-        hi |= hi >> 4;  hi &= 0xf0f0f0f0;
-        hi |= hi >> 2;  hi &= 0xcccccccc;
-        hi |= hi >> 1;  hi &= 0xaaaaaaaa;
+        hi |= hi >> 8;
+        hi &= 0xff00ff00;
+        hi |= hi >> 4;
+        hi &= 0xf0f0f0f0;
+        hi |= hi >> 2;
+        hi &= 0xcccccccc;
+        hi |= hi >> 1;
+        hi &= 0xaaaaaaaa;
 
         Ai = ((uint64_t)(hi | lo) << 32) | (t1 | t0);
     }
@@ -1065,7 +1091,7 @@ static uint64_t BitDeinterleave(uint64_t Ai)
  * caller's responsibility.
  */
 size_t SHA3_absorb(uint64_t A[5][5], const unsigned char *inp, size_t len,
-                   size_t r)
+    size_t r)
 {
     uint64_t *A_flat = (uint64_t *)A;
     size_t i, w = r / 8;
@@ -1074,10 +1100,7 @@ size_t SHA3_absorb(uint64_t A[5][5], const unsigned char *inp, size_t len,
 
     while (len >= r) {
         for (i = 0; i < w; i++) {
-            uint64_t Ai = (uint64_t)inp[0]       | (uint64_t)inp[1] << 8  |
-                          (uint64_t)inp[2] << 16 | (uint64_t)inp[3] << 24 |
-                          (uint64_t)inp[4] << 32 | (uint64_t)inp[5] << 40 |
-                          (uint64_t)inp[6] << 48 | (uint64_t)inp[7] << 56;
+            uint64_t Ai = (uint64_t)inp[0] | (uint64_t)inp[1] << 8 | (uint64_t)inp[2] << 16 | (uint64_t)inp[3] << 24 | (uint64_t)inp[4] << 32 | (uint64_t)inp[5] << 40 | (uint64_t)inp[6] << 48 | (uint64_t)inp[7] << 56;
             inp += 8;
 
             A_flat[i] ^= BitInterleave(Ai);
@@ -1090,10 +1113,16 @@ size_t SHA3_absorb(uint64_t A[5][5], const unsigned char *inp, size_t len,
 }
 
 /*
- * sha3_squeeze is called once at the end to generate |out| hash value
- * of |len| bytes.
+ * SHA3_squeeze may be called after SHA3_absorb to generate |out| hash value of
+ * |len| bytes.
+ * If multiple SHA3_squeeze calls are required the output length |len| must be a
+ * multiple of the blocksize, with |next| being 0 on the first call and 1 on
+ * subsequent calls. It is the callers responsibility to buffer the results.
+ * When only a single call to SHA3_squeeze is required, |len| can be any size
+ * and |next| must be 0.
  */
-void SHA3_squeeze(uint64_t A[5][5], unsigned char *out, size_t len, size_t r)
+void SHA3_squeeze(uint64_t A[5][5], unsigned char *out, size_t len, size_t r,
+    int next)
 {
     uint64_t *A_flat = (uint64_t *)A;
     size_t i, w = r / 8;
@@ -1101,6 +1130,9 @@ void SHA3_squeeze(uint64_t A[5][5], unsigned char *out, size_t len, size_t r)
     assert(r < (25 * sizeof(A[0][0])) && (r % 8) == 0);
 
     while (len != 0) {
+        if (next)
+            KeccakF1600(A);
+        next = 1;
         for (i = 0; i < w && len != 0; i++) {
             uint64_t Ai = BitDeinterleave(A_flat[i]);
 
@@ -1123,8 +1155,6 @@ void SHA3_squeeze(uint64_t A[5][5], unsigned char *out, size_t len, size_t r)
             out += 8;
             len -= 8;
         }
-        if (len)
-            KeccakF1600(A);
     }
 }
 #endif
@@ -1142,7 +1172,7 @@ void SHA3_squeeze(uint64_t A[5][5], unsigned char *out, size_t len, size_t r)
  */
 
 void SHA3_sponge(const unsigned char *inp, size_t len,
-                 unsigned char *out, size_t d, size_t r)
+    unsigned char *out, size_t d, size_t r)
 {
     uint64_t A[5][5];
 
@@ -1151,7 +1181,7 @@ void SHA3_sponge(const unsigned char *inp, size_t len,
     SHA3_squeeze(A, out, d, r);
 }
 
-# include <stdio.h>
+#include <stdio.h>
 
 int main(void)
 {
