@@ -73,9 +73,9 @@ int SHA224_Final(unsigned char *md, SHA256_CTX *c)
 
 #define DATA_ORDER_IS_BIG_ENDIAN
 
-#define HASH_LONG               SHA_LONG
-#define HASH_CTX                SHA256_CTX
-#define HASH_CBLOCK             SHA_CBLOCK
+#define HASH_LONG SHA_LONG
+#define HASH_CTX SHA256_CTX
+#define HASH_CBLOCK SHA_CBLOCK
 
 /*
  * Note that FIPS180-2 discusses "Truncation of the Hash Function Output."
@@ -85,43 +85,56 @@ int SHA224_Final(unsigned char *md, SHA256_CTX *c)
  * Idea behind separate cases for pre-defined lengths is to let the
  * compiler decide if it's appropriate to unroll small loops.
  */
-#define HASH_MAKE_STRING(c,s)   do {    \
-        unsigned long ll;               \
-        unsigned int  nn;               \
-        switch ((c)->md_len)            \
-        {   case SHA256_192_DIGEST_LENGTH: \
-                for (nn=0;nn<SHA256_192_DIGEST_LENGTH/4;nn++)   \
-                {   ll=(c)->h[nn]; (void)HOST_l2c(ll,(s));   }  \
-                break;                  \
-            case SHA224_DIGEST_LENGTH:  \
-                for (nn=0;nn<SHA224_DIGEST_LENGTH/4;nn++)       \
-                {   ll=(c)->h[nn]; (void)HOST_l2c(ll,(s));   }  \
-                break;                  \
-            case SHA256_DIGEST_LENGTH:  \
-                for (nn=0;nn<SHA256_DIGEST_LENGTH/4;nn++)       \
-                {   ll=(c)->h[nn]; (void)HOST_l2c(ll,(s));   }  \
-                break;                  \
-            default:                    \
-                if ((c)->md_len > SHA256_DIGEST_LENGTH) \
-                    return 0;                           \
-                for (nn=0;nn<(c)->md_len/4;nn++)                \
-                {   ll=(c)->h[nn]; (void)HOST_l2c(ll,(s));   }  \
-                break;                  \
-        }                               \
-        } while (0)
+#define HASH_MAKE_STRING(c, s)                                      \
+    do {                                                            \
+        unsigned long ll;                                           \
+        unsigned int nn;                                            \
+        switch ((c)->md_len) {                                      \
+        case SHA256_192_DIGEST_LENGTH:                              \
+            for (nn = 0; nn < SHA256_192_DIGEST_LENGTH / 4; nn++) { \
+                ll = (c)->h[nn];                                    \
+                (void)HOST_l2c(ll, (s));                            \
+            }                                                       \
+            break;                                                  \
+        case SHA224_DIGEST_LENGTH:                                  \
+            for (nn = 0; nn < SHA224_DIGEST_LENGTH / 4; nn++) {     \
+                ll = (c)->h[nn];                                    \
+                (void)HOST_l2c(ll, (s));                            \
+            }                                                       \
+            break;                                                  \
+        case SHA256_DIGEST_LENGTH:                                  \
+            for (nn = 0; nn < SHA256_DIGEST_LENGTH / 4; nn++) {     \
+                ll = (c)->h[nn];                                    \
+                (void)HOST_l2c(ll, (s));                            \
+            }                                                       \
+            break;                                                  \
+        default:                                                    \
+            if ((c)->md_len > SHA256_DIGEST_LENGTH)                 \
+                return 0;                                           \
+            for (nn = 0; nn < (c)->md_len / 4; nn++) {              \
+                ll = (c)->h[nn];                                    \
+                (void)HOST_l2c(ll, (s));                            \
+            }                                                       \
+            break;                                                  \
+        }                                                           \
+    } while (0)
 
-#define HASH_UPDATE             SHA256_Update
-#define HASH_TRANSFORM          SHA256_Transform
-#define HASH_FINAL              SHA256_Final
-#define HASH_BLOCK_DATA_ORDER   sha256_block_data_order
+#define HASH_UPDATE SHA256_Update
+#define HASH_TRANSFORM SHA256_Transform
+#define HASH_FINAL SHA256_Final
+#define HASH_BLOCK_DATA_ORDER sha256_block_data_order
 #ifndef SHA256_ASM
 static
-#endif
-void sha256_block_data_order(SHA256_CTX *ctx, const void *in, size_t num);
+#else
+#ifdef INCLUDE_C_SHA256
+void sha256_block_data_order_c(SHA256_CTX *ctx, const void *in, size_t num);
+#endif /* INCLUDE_C_SHA256 */
+#endif /* SHA256_ASM */
+    void sha256_block_data_order(SHA256_CTX *ctx, const void *in, size_t num);
 
 #include "crypto/md32_common.h"
 
-#ifndef SHA256_ASM
+#if !defined(SHA256_ASM) || defined(INCLUDE_C_SHA256)
 static const SHA_LONG K256[64] = {
     0x428a2f98UL, 0x71374491UL, 0xb5c0fbcfUL, 0xe9b5dba5UL,
     0x3956c25bUL, 0x59f111f1UL, 0x923f82a4UL, 0xab1c5ed5UL,
@@ -141,68 +154,67 @@ static const SHA_LONG K256[64] = {
     0x90befffaUL, 0xa4506cebUL, 0xbef9a3f7UL, 0xc67178f2UL
 };
 
-# ifndef PEDANTIC
-#  if defined(__GNUC__) && __GNUC__>=2 && \
-      !defined(OPENSSL_NO_ASM) && !defined(OPENSSL_NO_INLINE_ASM)
-#   if defined(__riscv_zknh)
-#    define Sigma0(x) ({ MD32_REG_T ret;            \
+#ifndef PEDANTIC
+#if defined(__GNUC__) && __GNUC__ >= 2 && !defined(OPENSSL_NO_ASM) && !defined(OPENSSL_NO_INLINE_ASM)
+#if defined(__riscv_zknh)
+#define Sigma0(x) ({ MD32_REG_T ret;            \
                         asm ("sha256sum0 %0, %1"    \
                         : "=r"(ret)                 \
-                        : "r"(x)); ret;             })
-#    define Sigma1(x) ({ MD32_REG_T ret;            \
+                        : "r"(x)); ret; })
+#define Sigma1(x) ({ MD32_REG_T ret;            \
                         asm ("sha256sum1 %0, %1"    \
                         : "=r"(ret)                 \
-                        : "r"(x)); ret;             })
-#    define sigma0(x) ({ MD32_REG_T ret;            \
+                        : "r"(x)); ret; })
+#define sigma0(x) ({ MD32_REG_T ret;            \
                         asm ("sha256sig0 %0, %1"    \
                         : "=r"(ret)                 \
-                        : "r"(x)); ret;             })
-#    define sigma1(x) ({ MD32_REG_T ret;            \
+                        : "r"(x)); ret; })
+#define sigma1(x) ({ MD32_REG_T ret;            \
                         asm ("sha256sig1 %0, %1"    \
                         : "=r"(ret)                 \
-                        : "r"(x)); ret;             })
-#   endif
-#   if defined(__riscv_zbt) || defined(__riscv_zpn)
-#    define Ch(x,y,z) ({  MD32_REG_T ret;                           \
+                        : "r"(x)); ret; })
+#endif
+#if defined(__riscv_zbt) || defined(__riscv_zpn)
+#define Ch(x, y, z) ({  MD32_REG_T ret;                           \
                         asm (".insn r4 0x33, 1, 0x3, %0, %2, %1, %3"\
                         : "=r"(ret)                                 \
-                        : "r"(x), "r"(y), "r"(z)); ret;             })
-#    define Maj(x,y,z) ({ MD32_REG_T ret;                           \
+                        : "r"(x), "r"(y), "r"(z)); ret; })
+#define Maj(x, y, z) ({ MD32_REG_T ret;                           \
                         asm (".insn r4 0x33, 1, 0x3, %0, %2, %1, %3"\
                         : "=r"(ret)                                 \
-                        : "r"(x^z), "r"(y), "r"(x)); ret;           })
-#   endif
-#  endif
-# endif
+                        : "r"(x^z), "r"(y), "r"(x)); ret; })
+#endif
+#endif
+#endif
 
 /*
  * FIPS specification refers to right rotations, while our ROTATE macro
  * is left one. This is why you might notice that rotation coefficients
  * differ from those observed in FIPS document by 32-N...
  */
-# ifndef Sigma0
-#  define Sigma0(x)       (ROTATE((x),30) ^ ROTATE((x),19) ^ ROTATE((x),10))
-# endif
-# ifndef Sigma1
-#  define Sigma1(x)       (ROTATE((x),26) ^ ROTATE((x),21) ^ ROTATE((x),7))
-# endif
-# ifndef sigma0
-#  define sigma0(x)       (ROTATE((x),25) ^ ROTATE((x),14) ^ ((x)>>3))
-# endif
-# ifndef sigma1
-#  define sigma1(x)       (ROTATE((x),15) ^ ROTATE((x),13) ^ ((x)>>10))
-# endif
-# ifndef Ch
-#  define Ch(x,y,z)       (((x) & (y)) ^ ((~(x)) & (z)))
-# endif
-# ifndef Maj
-#  define Maj(x,y,z)      (((x) & (y)) ^ ((x) & (z)) ^ ((y) & (z)))
-# endif
+#ifndef Sigma0
+#define Sigma0(x) (ROTATE((x), 30) ^ ROTATE((x), 19) ^ ROTATE((x), 10))
+#endif
+#ifndef Sigma1
+#define Sigma1(x) (ROTATE((x), 26) ^ ROTATE((x), 21) ^ ROTATE((x), 7))
+#endif
+#ifndef sigma0
+#define sigma0(x) (ROTATE((x), 25) ^ ROTATE((x), 14) ^ ((x) >> 3))
+#endif
+#ifndef sigma1
+#define sigma1(x) (ROTATE((x), 15) ^ ROTATE((x), 13) ^ ((x) >> 10))
+#endif
+#ifndef Ch
+#define Ch(x, y, z) (((x) & (y)) ^ ((~(x)) & (z)))
+#endif
+#ifndef Maj
+#define Maj(x, y, z) (((x) & (y)) ^ ((x) & (z)) ^ ((y) & (z)))
+#endif
 
-# ifdef OPENSSL_SMALL_FOOTPRINT
+#ifdef OPENSSL_SMALL_FOOTPRINT
 
 static void sha256_block_data_order(SHA256_CTX *ctx, const void *in,
-                                    size_t num)
+    size_t num)
 {
     unsigned MD32_REG_T a, b, c, d, e, f, g, h, s0, s1, T1, T2;
     SHA_LONG X[16], l;
@@ -262,25 +274,35 @@ static void sha256_block_data_order(SHA256_CTX *ctx, const void *in,
         ctx->h[5] += f;
         ctx->h[6] += g;
         ctx->h[7] += h;
-
     }
 }
 
-# else
+#else
 
-#  define ROUND_00_15(i,a,b,c,d,e,f,g,h)          do {    \
-        T1 += h + Sigma1(e) + Ch(e,f,g) + K256[i];      \
-        h = Sigma0(a) + Maj(a,b,c);                     \
-        d += T1;        h += T1;                } while (0)
+#define ROUND_00_15(i, a, b, c, d, e, f, g, h)       \
+    do {                                             \
+        T1 += h + Sigma1(e) + Ch(e, f, g) + K256[i]; \
+        h = Sigma0(a) + Maj(a, b, c);                \
+        d += T1;                                     \
+        h += T1;                                     \
+    } while (0)
 
-#  define ROUND_16_63(i,a,b,c,d,e,f,g,h,X)        do {    \
-        s0 = X[(i+1)&0x0f];     s0 = sigma0(s0);        \
-        s1 = X[(i+14)&0x0f];    s1 = sigma1(s1);        \
-        T1 = X[(i)&0x0f] += s0 + s1 + X[(i+9)&0x0f];    \
-        ROUND_00_15(i,a,b,c,d,e,f,g,h);         } while (0)
+#define ROUND_16_63(i, a, b, c, d, e, f, g, h, X)          \
+    do {                                                   \
+        s0 = X[(i + 1) & 0x0f];                            \
+        s0 = sigma0(s0);                                   \
+        s1 = X[(i + 14) & 0x0f];                           \
+        s1 = sigma1(s1);                                   \
+        T1 = X[(i) & 0x0f] += s0 + s1 + X[(i + 9) & 0x0f]; \
+        ROUND_00_15(i, a, b, c, d, e, f, g, h);            \
+    } while (0)
 
+#ifdef INCLUDE_C_SHA256
+void sha256_block_data_order_c(SHA256_CTX *ctx, const void *in, size_t num)
+#else
 static void sha256_block_data_order(SHA256_CTX *ctx, const void *in,
-                                    size_t num)
+    size_t num)
+#endif
 {
     unsigned MD32_REG_T a, b, c, d, e, f, g, h, s0, s1, T1;
     SHA_LONG X[16];
@@ -409,9 +431,8 @@ static void sha256_block_data_order(SHA256_CTX *ctx, const void *in,
         ctx->h[5] += f;
         ctx->h[6] += g;
         ctx->h[7] += h;
-
     }
 }
 
-# endif
-#endif                         /* SHA256_ASM */
+#endif
+#endif /* SHA256_ASM */
