@@ -1,5 +1,5 @@
 /*
- * Copyright 2017-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2017-2025 The OpenSSL Project Authors. All Rights Reserved.
  * Copyright 2017 Ribose Inc. All Rights Reserved.
  * Ported from Ribose contributions from Botan.
  *
@@ -21,10 +21,10 @@
 #include <string.h>
 
 int ossl_sm2_compute_z_digest(uint8_t *out,
-                              const EVP_MD *digest,
-                              const uint8_t *id,
-                              const size_t id_len,
-                              const EC_KEY *key)
+    const EVP_MD *digest,
+    const uint8_t *id,
+    const size_t id_len,
+    const EC_KEY *key)
 {
     int rc = 0;
     const EC_GROUP *group = EC_KEY_get0_group(key);
@@ -115,31 +115,31 @@ int ossl_sm2_compute_z_digest(uint8_t *out,
         goto done;
 
     if (BN_bn2binpad(a, buf, p_bytes) < 0
-            || !EVP_DigestUpdate(hash, buf, p_bytes)
-            || BN_bn2binpad(b, buf, p_bytes) < 0
-            || !EVP_DigestUpdate(hash, buf, p_bytes)
-            || !EC_POINT_get_affine_coordinates(group,
-                                                EC_GROUP_get0_generator(group),
-                                                xG, yG, ctx)
-            || BN_bn2binpad(xG, buf, p_bytes) < 0
-            || !EVP_DigestUpdate(hash, buf, p_bytes)
-            || BN_bn2binpad(yG, buf, p_bytes) < 0
-            || !EVP_DigestUpdate(hash, buf, p_bytes)
-            || !EC_POINT_get_affine_coordinates(group,
-                                                pubkey,
-                                                xA, yA, ctx)
-            || BN_bn2binpad(xA, buf, p_bytes) < 0
-            || !EVP_DigestUpdate(hash, buf, p_bytes)
-            || BN_bn2binpad(yA, buf, p_bytes) < 0
-            || !EVP_DigestUpdate(hash, buf, p_bytes)
-            || !EVP_DigestFinal(hash, out, NULL)) {
+        || !EVP_DigestUpdate(hash, buf, p_bytes)
+        || BN_bn2binpad(b, buf, p_bytes) < 0
+        || !EVP_DigestUpdate(hash, buf, p_bytes)
+        || !EC_POINT_get_affine_coordinates(group,
+            EC_GROUP_get0_generator(group),
+            xG, yG, ctx)
+        || BN_bn2binpad(xG, buf, p_bytes) < 0
+        || !EVP_DigestUpdate(hash, buf, p_bytes)
+        || BN_bn2binpad(yG, buf, p_bytes) < 0
+        || !EVP_DigestUpdate(hash, buf, p_bytes)
+        || !EC_POINT_get_affine_coordinates(group,
+            pubkey,
+            xA, yA, ctx)
+        || BN_bn2binpad(xA, buf, p_bytes) < 0
+        || !EVP_DigestUpdate(hash, buf, p_bytes)
+        || BN_bn2binpad(yA, buf, p_bytes) < 0
+        || !EVP_DigestUpdate(hash, buf, p_bytes)
+        || !EVP_DigestFinal(hash, out, NULL)) {
         ERR_raise(ERR_LIB_SM2, ERR_R_INTERNAL_ERROR);
         goto done;
     }
 
     rc = 1;
 
- done:
+done:
     OPENSSL_free(buf);
     BN_CTX_free(ctx);
     EVP_MD_CTX_free(hash);
@@ -147,10 +147,10 @@ int ossl_sm2_compute_z_digest(uint8_t *out,
 }
 
 static BIGNUM *sm2_compute_msg_hash(const EVP_MD *digest,
-                                    const EC_KEY *key,
-                                    const uint8_t *id,
-                                    const size_t id_len,
-                                    const uint8_t *msg, size_t msg_len)
+    const EC_KEY *key,
+    const uint8_t *id,
+    const size_t id_len,
+    const uint8_t *msg, size_t msg_len)
 {
     EVP_MD_CTX *hash = EVP_MD_CTX_new();
     const int md_size = EVP_MD_get_size(digest);
@@ -185,10 +185,10 @@ static BIGNUM *sm2_compute_msg_hash(const EVP_MD *digest,
     }
 
     if (!EVP_DigestInit(hash, fetched_digest)
-            || !EVP_DigestUpdate(hash, z, md_size)
-            || !EVP_DigestUpdate(hash, msg, msg_len)
-               /* reuse z buffer to hold H(Z || M) */
-            || !EVP_DigestFinal(hash, z, NULL)) {
+        || !EVP_DigestUpdate(hash, z, md_size)
+        || !EVP_DigestUpdate(hash, msg, msg_len)
+        /* reuse z buffer to hold H(Z || M) */
+        || !EVP_DigestFinal(hash, z, NULL)) {
         ERR_raise(ERR_LIB_SM2, ERR_R_EVP_LIB);
         goto done;
     }
@@ -197,7 +197,7 @@ static BIGNUM *sm2_compute_msg_hash(const EVP_MD *digest,
     if (e == NULL)
         ERR_raise(ERR_LIB_SM2, ERR_R_INTERNAL_ERROR);
 
- done:
+done:
     EVP_MD_free(fetched_digest);
     OPENSSL_free(z);
     EVP_MD_CTX_free(hash);
@@ -220,6 +220,10 @@ static ECDSA_SIG *sm2_sig_gen(const EC_KEY *key, const BIGNUM *e)
     BIGNUM *tmp = NULL;
     OSSL_LIB_CTX *libctx = ossl_ec_key_get_libctx(key);
 
+    if (dA == NULL) {
+        ERR_raise(ERR_LIB_SM2, SM2_R_INVALID_PRIVATE_KEY);
+        goto done;
+    }
     kG = EC_POINT_new(group);
     if (kG == NULL) {
         ERR_raise(ERR_LIB_SM2, ERR_R_EC_LIB);
@@ -269,9 +273,9 @@ static ECDSA_SIG *sm2_sig_gen(const EC_KEY *key, const BIGNUM *e)
         }
 
         if (!EC_POINT_mul(group, kG, k, NULL, NULL, ctx)
-                || !EC_POINT_get_affine_coordinates(group, kG, x1, NULL,
-                                                    ctx)
-                || !BN_mod_add(r, e, x1, order, ctx)) {
+            || !EC_POINT_get_affine_coordinates(group, kG, x1, NULL,
+                ctx)
+            || !BN_mod_add(r, e, x1, order, ctx)) {
             ERR_raise(ERR_LIB_SM2, ERR_R_INTERNAL_ERROR);
             goto done;
         }
@@ -289,10 +293,10 @@ static ECDSA_SIG *sm2_sig_gen(const EC_KEY *key, const BIGNUM *e)
             continue;
 
         if (!BN_add(s, dA, BN_value_one())
-                || !ossl_ec_group_do_inverse_ord(group, s, s, ctx)
-                || !BN_mod_mul(tmp, dA, r, order, ctx)
-                || !BN_sub(tmp, k, tmp)
-                || !BN_mod_mul(s, s, tmp, order, ctx)) {
+            || !ossl_ec_group_do_inverse_ord(group, s, s, ctx)
+            || !BN_mod_mul(tmp, dA, r, order, ctx)
+            || !BN_sub(tmp, k, tmp)
+            || !BN_mod_mul(s, s, tmp, order, ctx)) {
             ERR_raise(ERR_LIB_SM2, ERR_R_BN_LIB);
             goto done;
         }
@@ -307,12 +311,12 @@ static ECDSA_SIG *sm2_sig_gen(const EC_KEY *key, const BIGNUM *e)
             goto done;
         }
 
-         /* takes ownership of r and s */
+        /* takes ownership of r and s */
         ECDSA_SIG_set0(sig, r, s);
         break;
     }
 
- done:
+done:
     if (sig == NULL) {
         BN_free(r);
         BN_free(s);
@@ -324,7 +328,7 @@ static ECDSA_SIG *sm2_sig_gen(const EC_KEY *key, const BIGNUM *e)
 }
 
 static int sm2_sig_verify(const EC_KEY *key, const ECDSA_SIG *sig,
-                          const BIGNUM *e)
+    const BIGNUM *e)
 {
     int ret = 0;
     const EC_GROUP *group = EC_KEY_get0_group(key);
@@ -369,9 +373,9 @@ static int sm2_sig_verify(const EC_KEY *key, const ECDSA_SIG *sig,
     ECDSA_SIG_get0(sig, &r, &s);
 
     if (BN_cmp(r, BN_value_one()) < 0
-            || BN_cmp(s, BN_value_one()) < 0
-            || BN_cmp(order, r) <= 0
-            || BN_cmp(order, s) <= 0) {
+        || BN_cmp(s, BN_value_one()) < 0
+        || BN_cmp(order, r) <= 0
+        || BN_cmp(order, s) <= 0) {
         ERR_raise(ERR_LIB_SM2, SM2_R_BAD_SIGNATURE);
         goto done;
     }
@@ -387,7 +391,7 @@ static int sm2_sig_verify(const EC_KEY *key, const ECDSA_SIG *sig,
     }
 
     if (!EC_POINT_mul(group, pt, s, EC_KEY_get0_public_key(key), t, ctx)
-            || !EC_POINT_get_affine_coordinates(group, pt, x1, NULL, ctx)) {
+        || !EC_POINT_get_affine_coordinates(group, pt, x1, NULL, ctx)) {
         ERR_raise(ERR_LIB_SM2, ERR_R_EC_LIB);
         goto done;
     }
@@ -400,7 +404,7 @@ static int sm2_sig_verify(const EC_KEY *key, const ECDSA_SIG *sig,
     if (BN_cmp(r, t) == 0)
         ret = 1;
 
- done:
+done:
     BN_CTX_end(ctx);
     EC_POINT_free(pt);
     BN_CTX_free(ctx);
@@ -408,10 +412,10 @@ static int sm2_sig_verify(const EC_KEY *key, const ECDSA_SIG *sig,
 }
 
 ECDSA_SIG *ossl_sm2_do_sign(const EC_KEY *key,
-                            const EVP_MD *digest,
-                            const uint8_t *id,
-                            const size_t id_len,
-                            const uint8_t *msg, size_t msg_len)
+    const EVP_MD *digest,
+    const uint8_t *id,
+    const size_t id_len,
+    const uint8_t *msg, size_t msg_len)
 {
     BIGNUM *e = NULL;
     ECDSA_SIG *sig = NULL;
@@ -424,17 +428,17 @@ ECDSA_SIG *ossl_sm2_do_sign(const EC_KEY *key,
 
     sig = sm2_sig_gen(key, e);
 
- done:
+done:
     BN_free(e);
     return sig;
 }
 
 int ossl_sm2_do_verify(const EC_KEY *key,
-                       const EVP_MD *digest,
-                       const ECDSA_SIG *sig,
-                       const uint8_t *id,
-                       const size_t id_len,
-                       const uint8_t *msg, size_t msg_len)
+    const EVP_MD *digest,
+    const ECDSA_SIG *sig,
+    const uint8_t *id,
+    const size_t id_len,
+    const uint8_t *msg, size_t msg_len)
 {
     BIGNUM *e = NULL;
     int ret = 0;
@@ -447,14 +451,14 @@ int ossl_sm2_do_verify(const EC_KEY *key,
 
     ret = sm2_sig_verify(key, sig, e);
 
- done:
+done:
     BN_free(e);
     return ret;
 }
 
 int ossl_sm2_internal_sign(const unsigned char *dgst, int dgstlen,
-                           unsigned char *sig, unsigned int *siglen,
-                           EC_KEY *eckey)
+    unsigned char *sig, unsigned int *siglen,
+    EC_KEY *eckey)
 {
     BIGNUM *e = NULL;
     ECDSA_SIG *s = NULL;
@@ -468,8 +472,8 @@ int ossl_sm2_internal_sign(const unsigned char *dgst, int dgstlen,
 
     e = BN_bin2bn(dgst, dgstlen, NULL);
     if (e == NULL) {
-       ERR_raise(ERR_LIB_SM2, ERR_R_BN_LIB);
-       goto done;
+        ERR_raise(ERR_LIB_SM2, ERR_R_BN_LIB);
+        goto done;
     }
 
     s = sm2_sig_gen(eckey, e);
@@ -480,22 +484,22 @@ int ossl_sm2_internal_sign(const unsigned char *dgst, int dgstlen,
 
     sigleni = i2d_ECDSA_SIG(s, &sig);
     if (sigleni < 0) {
-       ERR_raise(ERR_LIB_SM2, ERR_R_INTERNAL_ERROR);
-       goto done;
+        ERR_raise(ERR_LIB_SM2, ERR_R_INTERNAL_ERROR);
+        goto done;
     }
     *siglen = (unsigned int)sigleni;
 
     ret = 1;
 
- done:
+done:
     ECDSA_SIG_free(s);
     BN_free(e);
     return ret;
 }
 
 int ossl_sm2_internal_verify(const unsigned char *dgst, int dgstlen,
-                             const unsigned char *sig, int sig_len,
-                             EC_KEY *eckey)
+    const unsigned char *sig, int sig_len,
+    EC_KEY *eckey)
 {
     ECDSA_SIG *s = NULL;
     BIGNUM *e = NULL;
@@ -528,7 +532,7 @@ int ossl_sm2_internal_verify(const unsigned char *dgst, int dgstlen,
 
     ret = sm2_sig_verify(eckey, s, e);
 
- done:
+done:
     OPENSSL_free(der);
     BN_free(e);
     ECDSA_SIG_free(s);
