@@ -33,38 +33,39 @@
 static int ossl_store_close_it(OSSL_STORE_CTX *ctx);
 
 static int loader_set_params(OSSL_STORE_LOADER *loader,
-                             OSSL_STORE_LOADER_CTX *loader_ctx,
-                             const OSSL_PARAM params[], const char *propq)
+    OSSL_STORE_LOADER_CTX *loader_ctx,
+    const OSSL_PARAM params[], const char *propq)
 {
-   if (params != NULL) {
-       if (!loader->p_set_ctx_params(loader_ctx, params))
-           return 0;
-   }
+    if (params != NULL) {
+        if (!loader->p_set_ctx_params(loader_ctx, params))
+            return 0;
+    }
 
-   if (propq != NULL) {
-       OSSL_PARAM propp[2];
+    if (propq != NULL) {
+        OSSL_PARAM propp[2];
 
-       if (OSSL_PARAM_locate_const(params,
-                                   OSSL_STORE_PARAM_PROPERTIES) != NULL)
-           /* use the propq from params */
-           return 1;
+        if (OSSL_PARAM_locate_const(params,
+                OSSL_STORE_PARAM_PROPERTIES)
+            != NULL)
+            /* use the propq from params */
+            return 1;
 
-       propp[0] = OSSL_PARAM_construct_utf8_string(OSSL_STORE_PARAM_PROPERTIES,
-                                                   (char *)propq, 0);
-       propp[1] = OSSL_PARAM_construct_end();
+        propp[0] = OSSL_PARAM_construct_utf8_string(OSSL_STORE_PARAM_PROPERTIES,
+            (char *)propq, 0);
+        propp[1] = OSSL_PARAM_construct_end();
 
-       if (!loader->p_set_ctx_params(loader_ctx, propp))
-           return 0;
+        if (!loader->p_set_ctx_params(loader_ctx, propp))
+            return 0;
     }
     return 1;
 }
 
 OSSL_STORE_CTX *
 OSSL_STORE_open_ex(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
-                   const UI_METHOD *ui_method, void *ui_data,
-                   const OSSL_PARAM params[],
-                   OSSL_STORE_post_process_info_fn post_process,
-                   void *post_process_data)
+    const UI_METHOD *ui_method, void *ui_data,
+    const OSSL_PARAM params[],
+    OSSL_STORE_post_process_info_fn post_process,
+    void *post_process_data)
 {
     struct ossl_passphrase_data_st pwdata = { 0 };
     const OSSL_STORE_LOADER *loader = NULL;
@@ -77,6 +78,11 @@ OSSL_STORE_open_ex(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
     size_t schemes_n = 0;
     size_t i;
 
+    if (uri == NULL) {
+        ERR_raise(ERR_LIB_OSSL_STORE, ERR_R_PASSED_NULL_PARAMETER);
+        return 0;
+    }
+
     /*
      * Put the file scheme first.  If the uri does represent an existing file,
      * possible device name and all, then it should be loaded.  Only a failed
@@ -96,7 +102,7 @@ OSSL_STORE_open_ex(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
         *p++ = '\0';
         if (OPENSSL_strcasecmp(scheme_copy, "file") != 0) {
             if (HAS_PREFIX(p, "//"))
-                schemes_n--;         /* Invalidate the file scheme */
+                schemes_n--; /* Invalidate the file scheme */
             schemes[schemes_n++] = scheme_copy;
         }
     }
@@ -128,7 +134,7 @@ OSSL_STORE_open_ex(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
             no_loader_found = 0;
             if (loader->open_ex != NULL)
                 loader_ctx = loader->open_ex(loader, uri, libctx, propq,
-                                             ui_method, ui_data);
+                    ui_method, ui_data);
             else
                 loader_ctx = loader->open(loader, uri, ui_method, ui_data);
         } else {
@@ -136,23 +142,17 @@ OSSL_STORE_open_ex(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
         }
 #endif
         if (loader == NULL
-            && (fetched_loader =
-                OSSL_STORE_LOADER_fetch(libctx, scheme, propq)) != NULL) {
-            const OSSL_PROVIDER *provider =
-                OSSL_STORE_LOADER_get0_provider(fetched_loader);
+            && (fetched_loader = OSSL_STORE_LOADER_fetch(libctx, scheme, propq)) != NULL) {
+            const OSSL_PROVIDER *provider = OSSL_STORE_LOADER_get0_provider(fetched_loader);
             void *provctx = OSSL_PROVIDER_get0_provider_ctx(provider);
 
             no_loader_found = 0;
             if (fetched_loader->p_open_ex != NULL) {
-                loader_ctx =
-                    fetched_loader->p_open_ex(provctx, uri, params,
-                                              ossl_pw_passphrase_callback_dec,
-                                              &pwdata);
+                loader_ctx = fetched_loader->p_open_ex(provctx, uri, params,
+                    ossl_pw_passphrase_callback_dec,
+                    &pwdata);
             } else {
-                if (fetched_loader->p_open != NULL &&
-                    (loader_ctx = fetched_loader->p_open(provctx, uri)) != NULL &&
-                    !loader_set_params(fetched_loader, loader_ctx,
-                                       params, propq)) {
+                if (fetched_loader->p_open != NULL && (loader_ctx = fetched_loader->p_open(provctx, uri)) != NULL && !loader_set_params(fetched_loader, loader_ctx, params, propq)) {
                     (void)fetched_loader->p_close(loader_ctx);
                     loader_ctx = NULL;
                 }
@@ -207,14 +207,16 @@ OSSL_STORE_open_ex(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
 
     return ctx;
 
- err:
+err:
     ERR_clear_last_mark();
     if (loader_ctx != NULL) {
         /*
          * Temporary structure so OSSL_STORE_close() can work even when
          * |ctx| couldn't be allocated properly
          */
-        OSSL_STORE_CTX tmpctx = { NULL, };
+        OSSL_STORE_CTX tmpctx = {
+            NULL,
+        };
 
         tmpctx.fetched_loader = fetched_loader;
         tmpctx.loader = loader;
@@ -236,12 +238,12 @@ OSSL_STORE_open_ex(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
 }
 
 OSSL_STORE_CTX *OSSL_STORE_open(const char *uri,
-                                const UI_METHOD *ui_method, void *ui_data,
-                                OSSL_STORE_post_process_info_fn post_process,
-                                void *post_process_data)
+    const UI_METHOD *ui_method, void *ui_data,
+    OSSL_STORE_post_process_info_fn post_process,
+    void *post_process_data)
 {
     return OSSL_STORE_open_ex(uri, NULL, NULL, ui_method, ui_data, NULL,
-                              post_process, post_process_data);
+        post_process, post_process_data);
 }
 
 #ifndef OPENSSL_NO_DEPRECATED_3_0
@@ -264,19 +266,17 @@ int OSSL_STORE_vctrl(OSSL_STORE_CTX *ctx, int cmd, va_list args)
             OSSL_PARAM params[2] = { OSSL_PARAM_END, OSSL_PARAM_END };
 
             switch (cmd) {
-            case OSSL_STORE_C_USE_SECMEM:
-                {
-                    int on = *(va_arg(args, int *));
+            case OSSL_STORE_C_USE_SECMEM: {
+                int on = *(va_arg(args, int *));
 
-                    params[0] = OSSL_PARAM_construct_int("use_secmem", &on);
-                }
-                break;
+                params[0] = OSSL_PARAM_construct_int("use_secmem", &on);
+            } break;
             default:
                 break;
             }
 
             return ctx->fetched_loader->p_set_ctx_params(ctx->loader_ctx,
-                                                         params);
+                params);
         }
     } else if (ctx->loader->ctrl != NULL) {
         return ctx->loader->ctrl(ctx->loader_ctx, cmd, args);
@@ -295,7 +295,7 @@ int OSSL_STORE_expect(OSSL_STORE_CTX *ctx, int expected_type)
     int ret = 1;
 
     if (ctx == NULL
-            || expected_type < 0 || expected_type > OSSL_STORE_INFO_CRL) {
+        || expected_type < 0 || expected_type > OSSL_STORE_INFO_CRL) {
         ERR_raise(ERR_LIB_OSSL_STORE, ERR_R_PASSED_INVALID_ARGUMENT);
         return 0;
     }
@@ -309,8 +309,7 @@ int OSSL_STORE_expect(OSSL_STORE_CTX *ctx, int expected_type)
         && ctx->fetched_loader->p_set_ctx_params != NULL) {
         OSSL_PARAM params[2] = { OSSL_PARAM_END, OSSL_PARAM_END };
 
-        params[0] =
-            OSSL_PARAM_construct_int(OSSL_STORE_PARAM_EXPECT, &expected_type);
+        params[0] = OSSL_PARAM_construct_int(OSSL_STORE_PARAM_EXPECT, &expected_type);
         ret = ctx->fetched_loader->p_set_ctx_params(ctx->loader_ctx, params);
     }
 #ifndef OPENSSL_NO_DEPRECATED_3_0
@@ -354,49 +353,51 @@ int OSSL_STORE_find(OSSL_STORE_CTX *ctx, const OSSL_STORE_SEARCH *search)
             return 0;
         }
 
-        ret = 0;                 /* Assume the worst */
+        ret = 0; /* Assume the worst */
 
         switch (search->search_type) {
         case OSSL_STORE_SEARCH_BY_NAME:
             if ((name_der_sz = i2d_X509_NAME(search->name,
-                                             (unsigned char **)&name_der)) > 0
+                     (unsigned char **)&name_der))
+                    > 0
                 && OSSL_PARAM_BLD_push_octet_string(bld,
-                                                    OSSL_STORE_PARAM_SUBJECT,
-                                                    name_der, name_der_sz))
+                    OSSL_STORE_PARAM_SUBJECT,
+                    name_der, name_der_sz))
                 ret = 1;
             break;
         case OSSL_STORE_SEARCH_BY_ISSUER_SERIAL:
             if ((name_der_sz = i2d_X509_NAME(search->name,
-                                             (unsigned char **)&name_der)) > 0
+                     (unsigned char **)&name_der))
+                    > 0
                 && (number = ASN1_INTEGER_to_BN(search->serial, NULL)) != NULL
                 && OSSL_PARAM_BLD_push_octet_string(bld,
-                                                    OSSL_STORE_PARAM_ISSUER,
-                                                    name_der, name_der_sz)
+                    OSSL_STORE_PARAM_ISSUER,
+                    name_der, name_der_sz)
                 && OSSL_PARAM_BLD_push_BN(bld, OSSL_STORE_PARAM_SERIAL,
-                                          number))
+                    number))
                 ret = 1;
             break;
         case OSSL_STORE_SEARCH_BY_KEY_FINGERPRINT:
             if (OSSL_PARAM_BLD_push_utf8_string(bld, OSSL_STORE_PARAM_DIGEST,
-                                                EVP_MD_get0_name(search->digest),
-                                                0)
+                    EVP_MD_get0_name(search->digest),
+                    0)
                 && OSSL_PARAM_BLD_push_octet_string(bld,
-                                                    OSSL_STORE_PARAM_FINGERPRINT,
-                                                    search->string,
-                                                    search->stringlength))
+                    OSSL_STORE_PARAM_FINGERPRINT,
+                    search->string,
+                    search->stringlength))
                 ret = 1;
             break;
         case OSSL_STORE_SEARCH_BY_ALIAS:
             if (OSSL_PARAM_BLD_push_utf8_string(bld, OSSL_STORE_PARAM_ALIAS,
-                                                (char *)search->string,
-                                                search->stringlength))
+                    (char *)search->string,
+                    search->stringlength))
                 ret = 1;
             break;
         }
         if (ret) {
             params = OSSL_PARAM_BLD_to_param(bld);
             ret = ctx->fetched_loader->p_set_ctx_params(ctx->loader_ctx,
-                                                        params);
+                params);
             OSSL_PARAM_free(params);
         }
         OSSL_PARAM_BLD_free(bld);
@@ -421,7 +422,7 @@ OSSL_STORE_INFO *OSSL_STORE_load(OSSL_STORE_CTX *ctx)
     OSSL_STORE_INFO *v = NULL;
 
     ctx->loading = 1;
- again:
+again:
     if (OSSL_STORE_eof(ctx))
         return NULL;
 
@@ -439,10 +440,10 @@ OSSL_STORE_INFO *OSSL_STORE_load(OSSL_STORE_CTX *ctx)
             ctx->error_flag = 0;
 
             if (!ctx->fetched_loader->p_load(ctx->loader_ctx,
-                                             ossl_store_handle_load_result,
-                                             &load_data,
-                                             ossl_pw_passphrase_callback_dec,
-                                             &ctx->pwdata)) {
+                    ossl_store_handle_load_result,
+                    &load_data,
+                    ossl_pw_passphrase_callback_dec,
+                    &ctx->pwdata)) {
                 ctx->error_flag = 1;
                 return NULL;
             }
@@ -451,8 +452,8 @@ OSSL_STORE_INFO *OSSL_STORE_load(OSSL_STORE_CTX *ctx)
 #ifndef OPENSSL_NO_DEPRECATED_3_0
         if (ctx->fetched_loader == NULL)
             v = ctx->loader->load(ctx->loader_ctx,
-                                  ctx->pwdata._.ui_method.ui_method,
-                                  ctx->pwdata._.ui_method.ui_method_data);
+                ctx->pwdata._.ui_method.ui_method,
+                ctx->pwdata._.ui_method.ui_method_data);
 #endif
     }
 
@@ -483,19 +484,19 @@ OSSL_STORE_INFO *OSSL_STORE_load(OSSL_STORE_CTX *ctx)
 
     if (v != NULL)
         OSSL_TRACE1(STORE, "Got a %s\n",
-                    OSSL_STORE_INFO_type_string(OSSL_STORE_INFO_get_type(v)));
+            OSSL_STORE_INFO_type_string(OSSL_STORE_INFO_get_type(v)));
 
     return v;
 }
 
 int OSSL_STORE_delete(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
-                      const UI_METHOD *ui_method, void *ui_data,
-                      const OSSL_PARAM params[])
+    const UI_METHOD *ui_method, void *ui_data,
+    const OSSL_PARAM params[])
 {
     OSSL_STORE_LOADER *fetched_loader = NULL;
     char scheme[256], *p;
     int res = 0;
-    struct ossl_passphrase_data_st pwdata = {0};
+    struct ossl_passphrase_data_st pwdata = { 0 };
 
     OPENSSL_strlcpy(scheme, uri, sizeof(scheme));
     if ((p = strchr(scheme, ':')) != NULL)
@@ -514,8 +515,7 @@ int OSSL_STORE_delete(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
     fetched_loader = OSSL_STORE_LOADER_fetch(libctx, scheme, propq);
 
     if (fetched_loader != NULL && fetched_loader->p_delete != NULL) {
-        const OSSL_PROVIDER *provider =
-            OSSL_STORE_LOADER_get0_provider(fetched_loader);
+        const OSSL_PROVIDER *provider = OSSL_STORE_LOADER_get0_provider(fetched_loader);
         void *provctx = OSSL_PROVIDER_get0_provider_ctx(provider);
 
         /*
@@ -524,8 +524,8 @@ int OSSL_STORE_delete(const char *uri, OSSL_LIB_CTX *libctx, const char *propq,
          */
         OSSL_TRACE1(STORE, "Performing URI delete %s\n", uri);
         res = fetched_loader->p_delete(provctx, uri, params,
-                                       ossl_pw_passphrase_callback_dec,
-                                       &pwdata);
+            ossl_pw_passphrase_callback_dec,
+            &pwdata);
     }
     /* Clear any internally cached passphrase */
     (void)ossl_pw_clear_passphrase_cache(&pwdata);
@@ -856,8 +856,7 @@ int OSSL_STORE_supports_search(OSSL_STORE_CTX *ctx, int search_type)
     int ret = 0;
 
     if (ctx->fetched_loader != NULL) {
-        void *provctx =
-            ossl_provider_ctx(OSSL_STORE_LOADER_get0_provider(ctx->fetched_loader));
+        void *provctx = ossl_provider_ctx(OSSL_STORE_LOADER_get0_provider(ctx->fetched_loader));
         const OSSL_PARAM *params;
         const OSSL_PARAM *p_subject = NULL;
         const OSSL_PARAM *p_issuer = NULL;
@@ -872,8 +871,7 @@ int OSSL_STORE_supports_search(OSSL_STORE_CTX *ctx, int search_type)
         p_subject = OSSL_PARAM_locate_const(params, OSSL_STORE_PARAM_SUBJECT);
         p_issuer = OSSL_PARAM_locate_const(params, OSSL_STORE_PARAM_ISSUER);
         p_serial = OSSL_PARAM_locate_const(params, OSSL_STORE_PARAM_SERIAL);
-        p_fingerprint =
-            OSSL_PARAM_locate_const(params, OSSL_STORE_PARAM_FINGERPRINT);
+        p_fingerprint = OSSL_PARAM_locate_const(params, OSSL_STORE_PARAM_FINGERPRINT);
         p_alias = OSSL_PARAM_locate_const(params, OSSL_STORE_PARAM_ALIAS);
 
         switch (search_type) {
@@ -918,7 +916,7 @@ OSSL_STORE_SEARCH *OSSL_STORE_SEARCH_by_name(X509_NAME *name)
 }
 
 OSSL_STORE_SEARCH *OSSL_STORE_SEARCH_by_issuer_serial(X509_NAME *name,
-                                                      const ASN1_INTEGER *serial)
+    const ASN1_INTEGER *serial)
 {
     OSSL_STORE_SEARCH *search = OPENSSL_zalloc(sizeof(*search));
 
@@ -932,8 +930,9 @@ OSSL_STORE_SEARCH *OSSL_STORE_SEARCH_by_issuer_serial(X509_NAME *name,
 }
 
 OSSL_STORE_SEARCH *OSSL_STORE_SEARCH_by_key_fingerprint(const EVP_MD *digest,
-                                                        const unsigned char
-                                                        *bytes, size_t len)
+    const unsigned char
+        *bytes,
+    size_t len)
 {
     OSSL_STORE_SEARCH *search = OPENSSL_zalloc(sizeof(*search));
 
@@ -942,9 +941,9 @@ OSSL_STORE_SEARCH *OSSL_STORE_SEARCH_by_key_fingerprint(const EVP_MD *digest,
 
     if (digest != NULL && len != (size_t)EVP_MD_get_size(digest)) {
         ERR_raise_data(ERR_LIB_OSSL_STORE,
-                       OSSL_STORE_R_FINGERPRINT_SIZE_DOES_NOT_MATCH_DIGEST,
-                       "%s size is %d, fingerprint size is %zu",
-                       EVP_MD_get0_name(digest), EVP_MD_get_size(digest), len);
+            OSSL_STORE_R_FINGERPRINT_SIZE_DOES_NOT_MATCH_DIGEST,
+            "%s size is %d, fingerprint size is %zu",
+            EVP_MD_get0_name(digest), EVP_MD_get_size(digest), len);
         OPENSSL_free(search);
         return NULL;
     }
@@ -987,13 +986,14 @@ X509_NAME *OSSL_STORE_SEARCH_get0_name(const OSSL_STORE_SEARCH *criterion)
 }
 
 const ASN1_INTEGER *OSSL_STORE_SEARCH_get0_serial(const OSSL_STORE_SEARCH
-                                                  *criterion)
+        *criterion)
 {
     return criterion->serial;
 }
 
 const unsigned char *OSSL_STORE_SEARCH_get0_bytes(const OSSL_STORE_SEARCH
-                                                  *criterion, size_t *length)
+                                                      *criterion,
+    size_t *length)
 {
     *length = criterion->stringlength;
     return criterion->string;
@@ -1010,11 +1010,11 @@ const EVP_MD *OSSL_STORE_SEARCH_get0_digest(const OSSL_STORE_SEARCH *criterion)
 }
 
 OSSL_STORE_CTX *OSSL_STORE_attach(BIO *bp, const char *scheme,
-                                  OSSL_LIB_CTX *libctx, const char *propq,
-                                  const UI_METHOD *ui_method, void *ui_data,
-                                  const OSSL_PARAM params[],
-                                  OSSL_STORE_post_process_info_fn post_process,
-                                  void *post_process_data)
+    OSSL_LIB_CTX *libctx, const char *propq,
+    const UI_METHOD *ui_method, void *ui_data,
+    const OSSL_PARAM params[],
+    OSSL_STORE_post_process_info_fn post_process,
+    void *post_process_data)
 {
     const OSSL_STORE_LOADER *loader = NULL;
     OSSL_STORE_LOADER *fetched_loader = NULL;
@@ -1029,13 +1029,11 @@ OSSL_STORE_CTX *OSSL_STORE_attach(BIO *bp, const char *scheme,
 #ifndef OPENSSL_NO_DEPRECATED_3_0
     if ((loader = ossl_store_get0_loader_int(scheme)) != NULL)
         loader_ctx = loader->attach(loader, bp, libctx, propq,
-                                    ui_method, ui_data);
+            ui_method, ui_data);
 #endif
     if (loader == NULL
-        && (fetched_loader =
-            OSSL_STORE_LOADER_fetch(libctx, scheme, propq)) != NULL) {
-        const OSSL_PROVIDER *provider =
-            OSSL_STORE_LOADER_get0_provider(fetched_loader);
+        && (fetched_loader = OSSL_STORE_LOADER_fetch(libctx, scheme, propq)) != NULL) {
+        const OSSL_PROVIDER *provider = OSSL_STORE_LOADER_get0_provider(fetched_loader);
         void *provctx = OSSL_PROVIDER_get0_provider_ctx(provider);
         OSSL_CORE_BIO *cbio = ossl_core_bio_new_from_bio(bp);
 
@@ -1045,7 +1043,7 @@ OSSL_STORE_CTX *OSSL_STORE_attach(BIO *bp, const char *scheme,
             OSSL_STORE_LOADER_free(fetched_loader);
             fetched_loader = NULL;
         } else if (!loader_set_params(fetched_loader, loader_ctx,
-                                      params, propq)) {
+                       params, propq)) {
             (void)fetched_loader->p_close(loader_ctx);
             OSSL_STORE_LOADER_free(fetched_loader);
             fetched_loader = NULL;
