@@ -8,10 +8,10 @@
  */
 
 #if defined(_WIN32)
-# include <windows.h>
-# if defined(_WIN32_WINNT) && _WIN32_WINNT >= 0x600
-#  define USE_RWLOCK
-# endif
+#include <windows.h>
+#if defined(_WIN32_WINNT) && _WIN32_WINNT >= 0x600
+#define USE_RWLOCK
+#endif
 #endif
 #include <assert.h>
 
@@ -24,7 +24,7 @@
  */
 
 #if (defined(_MSC_VER) && defined(_M_IX86) && _MSC_VER <= 1600)
-# define NO_INTERLOCKEDOR64
+#define NO_INTERLOCKEDOR64
 #endif
 
 #include <openssl/crypto.h>
@@ -36,12 +36,12 @@
 
 #if defined(OPENSSL_THREADS) && !defined(CRYPTO_TDEBUG) && defined(OPENSSL_SYS_WINDOWS)
 
-# ifdef USE_RWLOCK
+#ifdef USE_RWLOCK
 typedef struct {
     SRWLOCK lock;
     int exclusive;
 } CRYPTO_win_rwlock;
-# endif
+#endif
 
 /*
  * This defines a quescent point (qp)
@@ -100,10 +100,9 @@ struct rcu_lock_st {
 };
 
 static struct rcu_qp *allocate_new_qp_group(struct rcu_lock_st *lock,
-                                            uint32_t count)
+    uint32_t count)
 {
-    struct rcu_qp *new =
-        OPENSSL_zalloc(sizeof(*new) * count);
+    struct rcu_qp *new = OPENSSL_zalloc(sizeof(*new) * count);
 
     lock->group_count = count;
     return new;
@@ -152,7 +151,6 @@ CRYPTO_RCU_LOCK *ossl_rcu_lock_new(int num_writers, OSSL_LIB_CTX *ctx)
     }
 
     return new;
-
 }
 
 void ossl_rcu_lock_free(CRYPTO_RCU_LOCK *lock)
@@ -281,8 +279,7 @@ static struct rcu_qp *update_qp(CRYPTO_RCU_LOCK *lock, uint32_t *curr_id)
     lock->writers_alloced++;
 
     /* increment the allocation index */
-    lock->current_alloc_idx =
-        (lock->current_alloc_idx + 1) % lock->group_count;
+    lock->current_alloc_idx = (lock->current_alloc_idx + 1) % lock->group_count;
 
     /* get and insert a new id */
     *curr_id = lock->id_ctr;
@@ -299,7 +296,7 @@ static struct rcu_qp *update_qp(CRYPTO_RCU_LOCK *lock, uint32_t *curr_id)
 }
 
 static void retire_qp(CRYPTO_RCU_LOCK *lock,
-                      struct rcu_qp *qp)
+    struct rcu_qp *qp)
 {
     ossl_crypto_mutex_lock(lock->alloc_lock);
     lock->writers_alloced--;
@@ -307,7 +304,6 @@ static void retire_qp(CRYPTO_RCU_LOCK *lock,
     ossl_crypto_mutex_unlock(lock->alloc_lock);
 }
 
-
 void ossl_synchronize_rcu(CRYPTO_RCU_LOCK *lock)
 {
     struct rcu_qp *qp;
@@ -349,7 +345,6 @@ void ossl_synchronize_rcu(CRYPTO_RCU_LOCK *lock)
 
     /* and we're done */
     return;
-
 }
 
 /*
@@ -378,14 +373,13 @@ void *ossl_rcu_uptr_deref(void **p)
 
 void ossl_rcu_assign_uptr(void **p, void **v)
 {
-    InterlockedExchangePointer((void * volatile *)p, (void *)*v);
+    InterlockedExchangePointer((void *volatile *)p, (void *)*v);
 }
 
-
 CRYPTO_RWLOCK *CRYPTO_THREAD_lock_new(void)
 {
     CRYPTO_RWLOCK *lock;
-# ifdef USE_RWLOCK
+#ifdef USE_RWLOCK
     CRYPTO_win_rwlock *rwlock;
 
     if ((lock = OPENSSL_zalloc(sizeof(CRYPTO_win_rwlock))) == NULL)
@@ -393,54 +387,54 @@ CRYPTO_RWLOCK *CRYPTO_THREAD_lock_new(void)
         return NULL;
     rwlock = lock;
     InitializeSRWLock(&rwlock->lock);
-# else
+#else
 
     if ((lock = OPENSSL_zalloc(sizeof(CRITICAL_SECTION))) == NULL)
         /* Don't set error, to avoid recursion blowup. */
         return NULL;
 
-#  if !defined(_WIN32_WCE)
+#if !defined(_WIN32_WCE)
     /* 0x400 is the spin count value suggested in the documentation */
     if (!InitializeCriticalSectionAndSpinCount(lock, 0x400)) {
         OPENSSL_free(lock);
         return NULL;
     }
-#  else
+#else
     InitializeCriticalSection(lock);
-#  endif
-# endif
+#endif
+#endif
 
     return lock;
 }
 
 __owur int CRYPTO_THREAD_read_lock(CRYPTO_RWLOCK *lock)
 {
-# ifdef USE_RWLOCK
+#ifdef USE_RWLOCK
     CRYPTO_win_rwlock *rwlock = lock;
 
     AcquireSRWLockShared(&rwlock->lock);
-# else
+#else
     EnterCriticalSection(lock);
-# endif
+#endif
     return 1;
 }
 
 __owur int CRYPTO_THREAD_write_lock(CRYPTO_RWLOCK *lock)
 {
-# ifdef USE_RWLOCK
+#ifdef USE_RWLOCK
     CRYPTO_win_rwlock *rwlock = lock;
 
     AcquireSRWLockExclusive(&rwlock->lock);
     rwlock->exclusive = 1;
-# else
+#else
     EnterCriticalSection(lock);
-# endif
+#endif
     return 1;
 }
 
 int CRYPTO_THREAD_unlock(CRYPTO_RWLOCK *lock)
 {
-# ifdef USE_RWLOCK
+#ifdef USE_RWLOCK
     CRYPTO_win_rwlock *rwlock = lock;
 
     if (rwlock->exclusive) {
@@ -449,9 +443,9 @@ int CRYPTO_THREAD_unlock(CRYPTO_RWLOCK *lock)
     } else {
         ReleaseSRWLockShared(&rwlock->lock);
     }
-# else
+#else
     LeaveCriticalSection(lock);
-# endif
+#endif
     return 1;
 }
 
@@ -460,17 +454,17 @@ void CRYPTO_THREAD_lock_free(CRYPTO_RWLOCK *lock)
     if (lock == NULL)
         return;
 
-# ifndef USE_RWLOCK
+#ifndef USE_RWLOCK
     DeleteCriticalSection(lock);
-# endif
+#endif
     OPENSSL_free(lock);
 
     return;
 }
 
-# define ONCE_UNINITED     0
-# define ONCE_ININIT       1
-# define ONCE_DONE         2
+#define ONCE_UNINITED 0
+#define ONCE_ININIT 1
+#define ONCE_DONE 2
 
 /*
  * We don't use InitOnceExecuteOnce because that isn't available in WinXP which
@@ -498,6 +492,12 @@ int CRYPTO_THREAD_run_once(CRYPTO_ONCE *once, void (*init)(void))
 
 int CRYPTO_THREAD_init_local(CRYPTO_THREAD_LOCAL *key, void (*cleanup)(void *))
 {
+
+#ifndef FIPS_MODULE
+    if (!ossl_init_thread())
+        return 0;
+#endif
+
     *key = TlsAlloc();
     if (*key == TLS_OUT_OF_INDEXES)
         return 0;
@@ -563,7 +563,7 @@ int CRYPTO_atomic_add(int *val, int amount, int *ret, CRYPTO_RWLOCK *lock)
 }
 
 int CRYPTO_atomic_or(uint64_t *val, uint64_t op, uint64_t *ret,
-                     CRYPTO_RWLOCK *lock)
+    CRYPTO_RWLOCK *lock)
 {
 #if (defined(NO_INTERLOCKEDOR64))
     if (lock == NULL || !CRYPTO_THREAD_write_lock(lock))
