@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2006-2026 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -17,32 +17,32 @@
 #include "ts_local.h"
 
 static int ts_verify_cert(X509_STORE *store, STACK_OF(X509) *untrusted,
-                          X509 *signer, STACK_OF(X509) **chain);
+    X509 *signer, STACK_OF(X509) **chain);
 static int ts_check_signing_certs(const PKCS7_SIGNER_INFO *si,
-                                  const STACK_OF(X509) *chain);
+    const STACK_OF(X509) *chain);
 
 static int int_ts_RESP_verify_token(TS_VERIFY_CTX *ctx,
-                                    PKCS7 *token, TS_TST_INFO *tst_info);
+    PKCS7 *token, TS_TST_INFO *tst_info);
 static int ts_check_status_info(TS_RESP *response);
 static char *ts_get_status_text(STACK_OF(ASN1_UTF8STRING) *text);
 static int ts_check_policy(const ASN1_OBJECT *req_oid,
-                           const TS_TST_INFO *tst_info);
+    const TS_TST_INFO *tst_info);
 static int ts_compute_imprint(BIO *data, TS_TST_INFO *tst_info,
-                              X509_ALGOR **md_alg,
-                              unsigned char **imprint, unsigned *imprint_len);
+    X509_ALGOR **md_alg,
+    unsigned char **imprint, unsigned *imprint_len);
 static int ts_check_imprints(X509_ALGOR *algor_a,
-                             const unsigned char *imprint_a, unsigned len_a,
-                             TS_TST_INFO *tst_info);
+    const unsigned char *imprint_a, unsigned len_a,
+    TS_TST_INFO *tst_info);
 static int ts_check_nonces(const ASN1_INTEGER *a, TS_TST_INFO *tst_info);
 static int ts_check_signer_name(GENERAL_NAME *tsa_name, X509 *signer);
 static int ts_find_name(STACK_OF(GENERAL_NAME) *gen_names,
-                        GENERAL_NAME *name);
+    GENERAL_NAME *name);
 
 /*
  * This must be large enough to hold all values in ts_status_text (with
  * comma separator) or all text fields in ts_failure_info (also with comma).
  */
-#define TS_STATUS_BUF_SIZE      256
+#define TS_STATUS_BUF_SIZE 256
 
 /*
  * Local mapping between response codes and descriptions.
@@ -56,23 +56,22 @@ static const char *ts_status_text[] = {
     "revocationNotification"
 };
 
-#define TS_STATUS_TEXT_SIZE     OSSL_NELEM(ts_status_text)
+#define TS_STATUS_TEXT_SIZE OSSL_NELEM(ts_status_text)
 
 static struct {
     int code;
     const char *text;
 } ts_failure_info[] = {
-    {TS_INFO_BAD_ALG, "badAlg"},
-    {TS_INFO_BAD_REQUEST, "badRequest"},
-    {TS_INFO_BAD_DATA_FORMAT, "badDataFormat"},
-    {TS_INFO_TIME_NOT_AVAILABLE, "timeNotAvailable"},
-    {TS_INFO_UNACCEPTED_POLICY, "unacceptedPolicy"},
-    {TS_INFO_UNACCEPTED_EXTENSION, "unacceptedExtension"},
-    {TS_INFO_ADD_INFO_NOT_AVAILABLE, "addInfoNotAvailable"},
-    {TS_INFO_SYSTEM_FAILURE, "systemFailure"}
+    { TS_INFO_BAD_ALG, "badAlg" },
+    { TS_INFO_BAD_REQUEST, "badRequest" },
+    { TS_INFO_BAD_DATA_FORMAT, "badDataFormat" },
+    { TS_INFO_TIME_NOT_AVAILABLE, "timeNotAvailable" },
+    { TS_INFO_UNACCEPTED_POLICY, "unacceptedPolicy" },
+    { TS_INFO_UNACCEPTED_EXTENSION, "unacceptedExtension" },
+    { TS_INFO_ADD_INFO_NOT_AVAILABLE, "addInfoNotAvailable" },
+    { TS_INFO_SYSTEM_FAILURE, "systemFailure" }
 };
 
-
 /*-
  * This function carries out the following tasks:
  *      - Checks if there is one and only one signer.
@@ -86,7 +85,7 @@ static struct {
  *      - Returns the signer certificate in 'signer', if 'signer' is not NULL.
  */
 int TS_RESP_verify_signature(PKCS7 *token, STACK_OF(X509) *certs,
-                             X509_STORE *store, X509 **signer_out)
+    X509_STORE *store, X509 **signer_out)
 {
     STACK_OF(PKCS7_SIGNER_INFO) *sinfos = NULL;
     PKCS7_SIGNER_INFO *si;
@@ -127,11 +126,10 @@ int TS_RESP_verify_signature(PKCS7 *token, STACK_OF(X509) *certs,
         goto err;
     signer = sk_X509_value(signers, 0);
 
-    untrusted = sk_X509_new_reserve(NULL, sk_X509_num(certs)
-                                    + sk_X509_num(token->d.sign->cert));
+    untrusted = sk_X509_new_reserve(NULL, sk_X509_num(certs) + sk_X509_num(token->d.sign->cert));
     if (untrusted == NULL
-            || !X509_add_certs(untrusted, certs, 0)
-            || !X509_add_certs(untrusted, token->d.sign->cert, 0))
+        || !X509_add_certs(untrusted, certs, 0)
+        || !X509_add_certs(untrusted, token->d.sign->cert, 0))
         goto err;
     if (!ts_verify_cert(store, untrusted, signer, &chain))
         goto err;
@@ -155,7 +153,7 @@ int TS_RESP_verify_signature(PKCS7 *token, STACK_OF(X509) *certs,
     }
     ret = 1;
 
- err:
+err:
     BIO_free_all(p7bio);
     sk_X509_free(untrusted);
     OSSL_STACK_OF_X509_free(chain);
@@ -169,7 +167,7 @@ int TS_RESP_verify_signature(PKCS7 *token, STACK_OF(X509) *certs,
  * freeing the vector.
  */
 static int ts_verify_cert(X509_STORE *store, STACK_OF(X509) *untrusted,
-                          X509 *signer, STACK_OF(X509) **chain)
+    X509 *signer, STACK_OF(X509) **chain)
 {
     X509_STORE_CTX *cert_ctx = NULL;
     int i;
@@ -188,7 +186,7 @@ static int ts_verify_cert(X509_STORE *store, STACK_OF(X509) *untrusted,
     if (i <= 0) {
         int j = X509_STORE_CTX_get_error(cert_ctx);
         ERR_raise_data(ERR_LIB_TS, TS_R_CERTIFICATE_VERIFY_ERROR,
-                       "Verify error:%s", X509_verify_cert_error_string(j));
+            "Verify error:%s", X509_verify_cert_error_string(j));
         goto err;
     }
     *chain = X509_STORE_CTX_get1_chain(cert_ctx);
@@ -209,27 +207,26 @@ static ESS_SIGNING_CERT *ossl_ess_get_signing_cert(const PKCS7_SIGNER_INFO *si)
     const unsigned char *p;
 
     attr = PKCS7_get_signed_attribute(si, NID_id_smime_aa_signingCertificate);
-    if (attr == NULL)
+    if (attr == NULL || attr->type != V_ASN1_SEQUENCE)
         return NULL;
     p = attr->value.sequence->data;
     return d2i_ESS_SIGNING_CERT(NULL, &p, attr->value.sequence->length);
 }
 
-static
-ESS_SIGNING_CERT_V2 *ossl_ess_get_signing_cert_v2(const PKCS7_SIGNER_INFO *si)
+static ESS_SIGNING_CERT_V2 *ossl_ess_get_signing_cert_v2(const PKCS7_SIGNER_INFO *si)
 {
     ASN1_TYPE *attr;
     const unsigned char *p;
 
     attr = PKCS7_get_signed_attribute(si, NID_id_smime_aa_signingCertificateV2);
-    if (attr == NULL)
+    if (attr == NULL || attr->type != V_ASN1_SEQUENCE)
         return NULL;
     p = attr->value.sequence->data;
     return d2i_ESS_SIGNING_CERT_V2(NULL, &p, attr->value.sequence->length);
 }
 
 static int ts_check_signing_certs(const PKCS7_SIGNER_INFO *si,
-                                  const STACK_OF(X509) *chain)
+    const STACK_OF(X509) *chain)
 {
     ESS_SIGNING_CERT *ss = ossl_ess_get_signing_cert(si);
     ESS_SIGNING_CERT_V2 *ssv2 = ossl_ess_get_signing_cert_v2(si);
@@ -258,7 +255,7 @@ int TS_RESP_verify_response(TS_VERIFY_CTX *ctx, TS_RESP *response)
         goto err;
     ret = 1;
 
- err:
+err:
     return ret;
 }
 
@@ -290,7 +287,7 @@ int TS_RESP_verify_token(TS_VERIFY_CTX *ctx, PKCS7 *token)
  *      - Check if the TSA name is the expected TSA.
  */
 static int int_ts_RESP_verify_token(TS_VERIFY_CTX *ctx,
-                                    PKCS7 *token, TS_TST_INFO *tst_info)
+    PKCS7 *token, TS_TST_INFO *tst_info)
 {
     X509 *signer = NULL;
     GENERAL_NAME *tsa_name = tst_info->tsa;
@@ -302,7 +299,7 @@ static int int_ts_RESP_verify_token(TS_VERIFY_CTX *ctx,
 
     /* Some options require us to also check the signature */
     if (((flags & TS_VFY_SIGNER) && tsa_name != NULL)
-            || (flags & TS_VFY_TSA_NAME)) {
+        || (flags & TS_VFY_TSA_NAME)) {
         flags |= TS_VFY_SIGNATURE;
     }
 
@@ -319,11 +316,11 @@ static int int_ts_RESP_verify_token(TS_VERIFY_CTX *ctx,
         goto err;
     if ((flags & TS_VFY_IMPRINT)
         && !ts_check_imprints(ctx->md_alg, ctx->imprint, ctx->imprint_len,
-                              tst_info))
+            tst_info))
         goto err;
     if ((flags & TS_VFY_DATA)
         && (!ts_compute_imprint(ctx->data, tst_info,
-                                &md_alg, &imprint, &imprint_len)
+                &md_alg, &imprint, &imprint_len)
             || !ts_check_imprints(md_alg, imprint, imprint_len, tst_info)))
         goto err;
     if ((flags & TS_VFY_NONCE)
@@ -341,7 +338,7 @@ static int int_ts_RESP_verify_token(TS_VERIFY_CTX *ctx,
     }
     ret = 1;
 
- err:
+err:
     X509_free(signer);
     X509_ALGOR_free(md_alg);
     OPENSSL_free(imprint);
@@ -360,7 +357,7 @@ static int ts_check_status_info(TS_RESP *response)
         return 1;
 
     /* There was an error, get the description in status_text. */
-    if (0 <= status && status < (long) OSSL_NELEM(ts_status_text))
+    if (0 <= status && status < (long)OSSL_NELEM(ts_status_text))
         status_text = ts_status_text[status];
     else
         status_text = "unknown code";
@@ -375,7 +372,7 @@ static int ts_check_status_info(TS_RESP *response)
         int first = 1;
         for (i = 0; i < (int)OSSL_NELEM(ts_failure_info); ++i) {
             if (ASN1_BIT_STRING_get_bit(info->failure_info,
-                                        ts_failure_info[i].code)) {
+                    ts_failure_info[i].code)) {
                 if (!first)
                     strcat(failure_text, ",");
                 else
@@ -388,10 +385,10 @@ static int ts_check_status_info(TS_RESP *response)
         strcpy(failure_text, "unspecified");
 
     ERR_raise_data(ERR_LIB_TS, TS_R_NO_TIME_STAMP_TOKEN,
-                   "status code: %s, status text: %s, failure codes: %s",
-                   status_text,
-                   embedded_status_text ? embedded_status_text : "unspecified",
-                   failure_text);
+        "status code: %s, status text: %s, failure codes: %s",
+        status_text,
+        embedded_status_text ? embedded_status_text : "unspecified",
+        failure_text);
     OPENSSL_free(embedded_status_text);
 
     return 0;
@@ -403,7 +400,7 @@ static char *ts_get_status_text(STACK_OF(ASN1_UTF8STRING) *text)
 }
 
 static int ts_check_policy(const ASN1_OBJECT *req_oid,
-                           const TS_TST_INFO *tst_info)
+    const TS_TST_INFO *tst_info)
 {
     const ASN1_OBJECT *resp_oid = tst_info->policy_id;
 
@@ -416,8 +413,8 @@ static int ts_check_policy(const ASN1_OBJECT *req_oid,
 }
 
 static int ts_compute_imprint(BIO *data, TS_TST_INFO *tst_info,
-                              X509_ALGOR **md_alg,
-                              unsigned char **imprint, unsigned *imprint_len)
+    X509_ALGOR **md_alg,
+    unsigned char **imprint, unsigned *imprint_len)
 {
     TS_MSG_IMPRINT *msg_imprint = tst_info->msg_imprint;
     X509_ALGOR *md_alg_resp = msg_imprint->hash_algo;
@@ -472,7 +469,7 @@ static int ts_compute_imprint(BIO *data, TS_TST_INFO *tst_info,
     EVP_MD_CTX_free(md_ctx);
 
     return 1;
- err:
+err:
     EVP_MD_CTX_free(md_ctx);
     EVP_MD_free(md);
     X509_ALGOR_free(*md_alg);
@@ -484,8 +481,8 @@ static int ts_compute_imprint(BIO *data, TS_TST_INFO *tst_info,
 }
 
 static int ts_check_imprints(X509_ALGOR *algor_a,
-                             const unsigned char *imprint_a, unsigned len_a,
-                             TS_TST_INFO *tst_info)
+    const unsigned char *imprint_a, unsigned len_a,
+    TS_TST_INFO *tst_info)
 {
     TS_MSG_IMPRINT *b = tst_info->msg_imprint;
     X509_ALGOR *algor_b = b->hash_algo;
@@ -497,15 +494,14 @@ static int ts_check_imprints(X509_ALGOR *algor_a,
 
         /* The parameter must be NULL in both. */
         if ((algor_a->parameter
-             && ASN1_TYPE_get(algor_a->parameter) != V_ASN1_NULL)
+                && ASN1_TYPE_get(algor_a->parameter) != V_ASN1_NULL)
             || (algor_b->parameter
                 && ASN1_TYPE_get(algor_b->parameter) != V_ASN1_NULL))
             goto err;
     }
 
-    ret = len_a == (unsigned)ASN1_STRING_length(b->hashed_msg) &&
-        memcmp(imprint_a, ASN1_STRING_get0_data(b->hashed_msg), len_a) == 0;
- err:
+    ret = len_a == (unsigned)ASN1_STRING_length(b->hashed_msg) && memcmp(imprint_a, ASN1_STRING_get0_data(b->hashed_msg), len_a) == 0;
+err:
     if (!ret)
         ERR_raise(ERR_LIB_TS, TS_R_MESSAGE_IMPRINT_MISMATCH);
     return ret;
