@@ -50,22 +50,29 @@
 #include "ext_dat.h"
 
 static int i2r_pci(X509V3_EXT_METHOD *method, PROXY_CERT_INFO_EXTENSION *ext,
-                   BIO *out, int indent);
+    BIO *out, int indent);
 static PROXY_CERT_INFO_EXTENSION *r2i_pci(X509V3_EXT_METHOD *method,
-                                          X509V3_CTX *ctx, char *str);
+    X509V3_CTX *ctx, char *str);
 
-const X509V3_EXT_METHOD ossl_v3_pci =
-    { NID_proxyCertInfo, 0, ASN1_ITEM_ref(PROXY_CERT_INFO_EXTENSION),
-    0, 0, 0, 0,
-    0, 0,
-    NULL, NULL,
+const X509V3_EXT_METHOD ossl_v3_pci = {
+    NID_proxyCertInfo,
+    0,
+    ASN1_ITEM_ref(PROXY_CERT_INFO_EXTENSION),
+    0,
+    0,
+    0,
+    0,
+    0,
+    0,
+    NULL,
+    NULL,
     (X509V3_EXT_I2R)i2r_pci,
     (X509V3_EXT_R2I)r2i_pci,
     NULL,
 };
 
 static int i2r_pci(X509V3_EXT_METHOD *method, PROXY_CERT_INFO_EXTENSION *pci,
-                   BIO *out, int indent)
+    BIO *out, int indent)
 {
     BIO_printf(out, "%*sPath Length Constraint: ", indent, "");
     if (pci->pcPathLengthConstraint)
@@ -77,14 +84,14 @@ static int i2r_pci(X509V3_EXT_METHOD *method, PROXY_CERT_INFO_EXTENSION *pci,
     i2a_ASN1_OBJECT(out, pci->proxyPolicy->policyLanguage);
     if (pci->proxyPolicy->policy && pci->proxyPolicy->policy->data)
         BIO_printf(out, "\n%*sPolicy Text: %.*s", indent, "",
-                   pci->proxyPolicy->policy->length,
-                   pci->proxyPolicy->policy->data);
+            pci->proxyPolicy->policy->length,
+            pci->proxyPolicy->policy->data);
     return 1;
 }
 
 static int process_pci_value(CONF_VALUE *val,
-                             ASN1_OBJECT **language, ASN1_INTEGER **pathlen,
-                             ASN1_OCTET_STRING **policy)
+    ASN1_OBJECT **language, ASN1_INTEGER **pathlen,
+    ASN1_OCTET_STRING **policy)
 {
     int free_policy = 0;
 
@@ -102,7 +109,7 @@ static int process_pci_value(CONF_VALUE *val,
     } else if (strcmp(val->name, "pathlen") == 0) {
         if (*pathlen) {
             ERR_raise(ERR_LIB_X509V3,
-                      X509V3_R_POLICY_PATH_LENGTH_ALREADY_DEFINED);
+                X509V3_R_POLICY_PATH_LENGTH_ALREADY_DEFINED);
             X509V3_conf_err(val);
             return 0;
         }
@@ -126,8 +133,7 @@ static int process_pci_value(CONF_VALUE *val,
             free_policy = 1;
         }
         if (CHECK_AND_SKIP_PREFIX(valp, "hex:")) {
-            unsigned char *tmp_data2 =
-                OPENSSL_hexstr2buf(valp, &val_len);
+            unsigned char *tmp_data2 = OPENSSL_hexstr2buf(valp, &val_len);
 
             if (!tmp_data2) {
                 X509V3_conf_err(val);
@@ -135,11 +141,11 @@ static int process_pci_value(CONF_VALUE *val,
             }
 
             tmp_data = OPENSSL_realloc((*policy)->data,
-                                       (*policy)->length + val_len + 1);
+                (*policy)->length + val_len + 1);
             if (tmp_data) {
                 (*policy)->data = tmp_data;
                 memcpy(&(*policy)->data[(*policy)->length],
-                       tmp_data2, val_len);
+                    tmp_data2, val_len);
                 (*policy)->length += val_len;
                 (*policy)->data[(*policy)->length] = '\0';
             } else {
@@ -165,12 +171,12 @@ static int process_pci_value(CONF_VALUE *val,
                 goto err;
             }
             while ((n = BIO_read(b, buf, sizeof(buf))) > 0
-                   || (n == 0 && BIO_should_retry(b))) {
+                || (n == 0 && BIO_should_retry(b))) {
                 if (!n)
                     continue;
 
                 tmp_data = OPENSSL_realloc((*policy)->data,
-                                           (*policy)->length + n + 1);
+                    (*policy)->length + n + 1);
 
                 if (!tmp_data) {
                     OPENSSL_free((*policy)->data);
@@ -196,11 +202,11 @@ static int process_pci_value(CONF_VALUE *val,
         } else if (CHECK_AND_SKIP_PREFIX(valp, "text:")) {
             val_len = strlen(valp);
             tmp_data = OPENSSL_realloc((*policy)->data,
-                                       (*policy)->length + val_len + 1);
+                (*policy)->length + val_len + 1);
             if (tmp_data) {
                 (*policy)->data = tmp_data;
                 memcpy(&(*policy)->data[(*policy)->length],
-                       val->value + 5, val_len);
+                    val->value + 5, val_len);
                 (*policy)->length += val_len;
                 (*policy)->data[(*policy)->length] = '\0';
             } else {
@@ -225,7 +231,7 @@ static int process_pci_value(CONF_VALUE *val,
         }
     }
     return 1;
- err:
+err:
     if (free_policy) {
         ASN1_OCTET_STRING_free(*policy);
         *policy = NULL;
@@ -234,7 +240,7 @@ static int process_pci_value(CONF_VALUE *val,
 }
 
 static PROXY_CERT_INFO_EXTENSION *r2i_pci(X509V3_EXT_METHOD *method,
-                                          X509V3_CTX *ctx, char *value)
+    X509V3_CTX *ctx, char *value)
 {
     PROXY_CERT_INFO_EXTENSION *pci = NULL;
     STACK_OF(CONF_VALUE) *vals;
@@ -263,9 +269,8 @@ static PROXY_CERT_INFO_EXTENSION *r2i_pci(X509V3_EXT_METHOD *method,
                 goto err;
             }
             for (j = 0; success_p && j < sk_CONF_VALUE_num(sect); j++) {
-                success_p =
-                    process_pci_value(sk_CONF_VALUE_value(sect, j),
-                                      &language, &pathlen, &policy);
+                success_p = process_pci_value(sk_CONF_VALUE_value(sect, j),
+                    &language, &pathlen, &policy);
             }
             X509V3_section_free(ctx, sect);
             if (!success_p)
@@ -281,13 +286,13 @@ static PROXY_CERT_INFO_EXTENSION *r2i_pci(X509V3_EXT_METHOD *method,
     /* Language is mandatory */
     if (!language) {
         ERR_raise(ERR_LIB_X509V3,
-                  X509V3_R_NO_PROXY_CERT_POLICY_LANGUAGE_DEFINED);
+            X509V3_R_NO_PROXY_CERT_POLICY_LANGUAGE_DEFINED);
         goto err;
     }
     i = OBJ_obj2nid(language);
     if ((i == NID_Independent || i == NID_id_ppl_inheritAll) && policy) {
         ERR_raise(ERR_LIB_X509V3,
-                  X509V3_R_POLICY_WHEN_PROXY_LANGUAGE_REQUIRES_NO_POLICY);
+            X509V3_R_POLICY_WHEN_PROXY_LANGUAGE_REQUIRES_NO_POLICY);
         goto err;
     }
 
@@ -304,7 +309,7 @@ static PROXY_CERT_INFO_EXTENSION *r2i_pci(X509V3_EXT_METHOD *method,
     pci->pcPathLengthConstraint = pathlen;
     pathlen = NULL;
     goto end;
- err:
+err:
     ASN1_OBJECT_free(language);
     ASN1_INTEGER_free(pathlen);
     pathlen = NULL;
@@ -312,7 +317,7 @@ static PROXY_CERT_INFO_EXTENSION *r2i_pci(X509V3_EXT_METHOD *method,
     policy = NULL;
     PROXY_CERT_INFO_EXTENSION_free(pci);
     pci = NULL;
- end:
+end:
     sk_CONF_VALUE_pop_free(vals, X509V3_conf_free);
     return pci;
 }
