@@ -16,41 +16,41 @@
 #include "ext_dat.h"
 
 static GENERAL_NAMES *v2i_subject_alt(X509V3_EXT_METHOD *method,
-                                      X509V3_CTX *ctx,
-                                      STACK_OF(CONF_VALUE) *nval);
+    X509V3_CTX *ctx,
+    STACK_OF(CONF_VALUE) *nval);
 static GENERAL_NAMES *v2i_issuer_alt(X509V3_EXT_METHOD *method,
-                                     X509V3_CTX *ctx,
-                                     STACK_OF(CONF_VALUE) *nval);
+    X509V3_CTX *ctx,
+    STACK_OF(CONF_VALUE) *nval);
 static int copy_email(X509V3_CTX *ctx, GENERAL_NAMES *gens, int move_p);
 static int copy_issuer(X509V3_CTX *ctx, GENERAL_NAMES *gens);
 static int do_othername(GENERAL_NAME *gen, const char *value, X509V3_CTX *ctx);
 static int do_dirname(GENERAL_NAME *gen, const char *value, X509V3_CTX *ctx);
 
 const X509V3_EXT_METHOD ossl_v3_alt[3] = {
-    {NID_subject_alt_name, 0, ASN1_ITEM_ref(GENERAL_NAMES),
-     0, 0, 0, 0,
-     0, 0,
-     (X509V3_EXT_I2V) i2v_GENERAL_NAMES,
-     (X509V3_EXT_V2I)v2i_subject_alt,
-     NULL, NULL, NULL},
+    { NID_subject_alt_name, 0, ASN1_ITEM_ref(GENERAL_NAMES),
+        0, 0, 0, 0,
+        0, 0,
+        (X509V3_EXT_I2V)i2v_GENERAL_NAMES,
+        (X509V3_EXT_V2I)v2i_subject_alt,
+        NULL, NULL, NULL },
 
-    {NID_issuer_alt_name, 0, ASN1_ITEM_ref(GENERAL_NAMES),
-     0, 0, 0, 0,
-     0, 0,
-     (X509V3_EXT_I2V) i2v_GENERAL_NAMES,
-     (X509V3_EXT_V2I)v2i_issuer_alt,
-     NULL, NULL, NULL},
+    { NID_issuer_alt_name, 0, ASN1_ITEM_ref(GENERAL_NAMES),
+        0, 0, 0, 0,
+        0, 0,
+        (X509V3_EXT_I2V)i2v_GENERAL_NAMES,
+        (X509V3_EXT_V2I)v2i_issuer_alt,
+        NULL, NULL, NULL },
 
-    {NID_certificate_issuer, 0, ASN1_ITEM_ref(GENERAL_NAMES),
-     0, 0, 0, 0,
-     0, 0,
-     (X509V3_EXT_I2V) i2v_GENERAL_NAMES,
-     NULL, NULL, NULL, NULL},
+    { NID_certificate_issuer, 0, ASN1_ITEM_ref(GENERAL_NAMES),
+        0, 0, 0, 0,
+        0, 0,
+        (X509V3_EXT_I2V)i2v_GENERAL_NAMES,
+        NULL, NULL, NULL, NULL },
 };
 
 STACK_OF(CONF_VALUE) *i2v_GENERAL_NAMES(X509V3_EXT_METHOD *method,
-                                        GENERAL_NAMES *gens,
-                                        STACK_OF(CONF_VALUE) *ret)
+    GENERAL_NAMES *gens,
+    STACK_OF(CONF_VALUE) *ret)
 {
     int i;
     GENERAL_NAME *gen;
@@ -77,8 +77,8 @@ STACK_OF(CONF_VALUE) *i2v_GENERAL_NAMES(X509V3_EXT_METHOD *method,
 }
 
 STACK_OF(CONF_VALUE) *i2v_GENERAL_NAME(X509V3_EXT_METHOD *method,
-                                       GENERAL_NAME *gen,
-                                       STACK_OF(CONF_VALUE) *ret)
+    GENERAL_NAME *gen,
+    STACK_OF(CONF_VALUE) *ret)
 {
     char othername[300];
     char oline[256], *tmp;
@@ -88,64 +88,64 @@ STACK_OF(CONF_VALUE) *i2v_GENERAL_NAME(X509V3_EXT_METHOD *method,
         switch (OBJ_obj2nid(gen->d.otherName->type_id)) {
         case NID_id_on_SmtpUTF8Mailbox:
             if (gen->d.otherName->value->type != V_ASN1_UTF8STRING
-                    || !x509v3_add_len_value_uchar("othername: SmtpUTF8Mailbox:",
-                            gen->d.otherName->value->value.utf8string->data,
-                            gen->d.otherName->value->value.utf8string->length,
-                            &ret))
+                || !x509v3_add_len_value_uchar("othername: SmtpUTF8Mailbox:",
+                    gen->d.otherName->value->value.utf8string->data,
+                    gen->d.otherName->value->value.utf8string->length,
+                    &ret))
                 return NULL;
             break;
         case NID_XmppAddr:
             if (gen->d.otherName->value->type != V_ASN1_UTF8STRING
-                    || !x509v3_add_len_value_uchar("othername: XmppAddr:",
-                            gen->d.otherName->value->value.utf8string->data,
-                            gen->d.otherName->value->value.utf8string->length,
-                            &ret))
+                || !x509v3_add_len_value_uchar("othername: XmppAddr:",
+                    gen->d.otherName->value->value.utf8string->data,
+                    gen->d.otherName->value->value.utf8string->length,
+                    &ret))
                 return NULL;
             break;
         case NID_SRVName:
             if (gen->d.otherName->value->type != V_ASN1_IA5STRING
-                    || !x509v3_add_len_value_uchar("othername: SRVName:",
-                            gen->d.otherName->value->value.ia5string->data,
-                            gen->d.otherName->value->value.ia5string->length,
-                            &ret))
+                || !x509v3_add_len_value_uchar("othername: SRVName:",
+                    gen->d.otherName->value->value.ia5string->data,
+                    gen->d.otherName->value->value.ia5string->length,
+                    &ret))
                 return NULL;
             break;
         case NID_ms_upn:
             if (gen->d.otherName->value->type != V_ASN1_UTF8STRING
-                    || !x509v3_add_len_value_uchar("othername: UPN:",
-                            gen->d.otherName->value->value.utf8string->data,
-                            gen->d.otherName->value->value.utf8string->length,
-                            &ret))
+                || !x509v3_add_len_value_uchar("othername: UPN:",
+                    gen->d.otherName->value->value.utf8string->data,
+                    gen->d.otherName->value->value.utf8string->length,
+                    &ret))
                 return NULL;
             break;
         case NID_NAIRealm:
             if (gen->d.otherName->value->type != V_ASN1_UTF8STRING
-                    || !x509v3_add_len_value_uchar("othername: NAIRealm:",
-                            gen->d.otherName->value->value.utf8string->data,
-                            gen->d.otherName->value->value.utf8string->length,
-                            &ret))
+                || !x509v3_add_len_value_uchar("othername: NAIRealm:",
+                    gen->d.otherName->value->value.utf8string->data,
+                    gen->d.otherName->value->value.utf8string->length,
+                    &ret))
                 return NULL;
             break;
         default:
-            if (OBJ_obj2txt(oline, sizeof(oline), gen->d.otherName->type_id, 0) > 0) 
+            if (OBJ_obj2txt(oline, sizeof(oline), gen->d.otherName->type_id, 0) > 0)
                 BIO_snprintf(othername, sizeof(othername), "othername: %s:",
-                             oline);
+                    oline);
             else
                 OPENSSL_strlcpy(othername, "othername:", sizeof(othername));
 
             /* check if the value is something printable */
             if (gen->d.otherName->value->type == V_ASN1_IA5STRING) {
                 if (x509v3_add_len_value_uchar(othername,
-                             gen->d.otherName->value->value.ia5string->data,
-                             gen->d.otherName->value->value.ia5string->length,
-                             &ret)) 
+                        gen->d.otherName->value->value.ia5string->data,
+                        gen->d.otherName->value->value.ia5string->length,
+                        &ret))
                     return ret;
             }
             if (gen->d.otherName->value->type == V_ASN1_UTF8STRING) {
                 if (x509v3_add_len_value_uchar(othername,
-                             gen->d.otherName->value->value.utf8string->data,
-                             gen->d.otherName->value->value.utf8string->length,
-                             &ret)) 
+                        gen->d.otherName->value->value.utf8string->data,
+                        gen->d.otherName->value->value.utf8string->length,
+                        &ret))
                     return ret;
             }
             if (!X509V3_add_value(othername, "<unsupported>", &ret))
@@ -166,25 +166,25 @@ STACK_OF(CONF_VALUE) *i2v_GENERAL_NAME(X509V3_EXT_METHOD *method,
 
     case GEN_EMAIL:
         if (!x509v3_add_len_value_uchar("email", gen->d.ia5->data,
-                                        gen->d.ia5->length, &ret))
+                gen->d.ia5->length, &ret))
             return NULL;
         break;
 
     case GEN_DNS:
         if (!x509v3_add_len_value_uchar("DNS", gen->d.ia5->data,
-                                        gen->d.ia5->length, &ret))
+                gen->d.ia5->length, &ret))
             return NULL;
         break;
 
     case GEN_URI:
         if (!x509v3_add_len_value_uchar("URI", gen->d.ia5->data,
-                                        gen->d.ia5->length, &ret))
+                gen->d.ia5->length, &ret))
             return NULL;
         break;
 
     case GEN_DIRNAME:
         if (X509_NAME_oneline(gen->d.dirn, oline, sizeof(oline)) == NULL
-                || !X509V3_add_value("DirName", oline, &ret))
+            || !X509V3_add_value("DirName", oline, &ret))
             return NULL;
         break;
 
@@ -214,9 +214,9 @@ int GENERAL_NAME_print(BIO *out, GENERAL_NAME *gen)
         nid = OBJ_obj2nid(gen->d.otherName->type_id);
         /* Validate the types are as we expect before we use them */
         if ((nid == NID_SRVName
-             && gen->d.otherName->value->type != V_ASN1_IA5STRING)
-                || (nid != NID_SRVName
-                    && gen->d.otherName->value->type != V_ASN1_UTF8STRING)) {
+                && gen->d.otherName->value->type != V_ASN1_IA5STRING)
+            || (nid != NID_SRVName
+                && gen->d.otherName->value->type != V_ASN1_UTF8STRING)) {
             BIO_printf(out, "othername:<unsupported>");
             break;
         }
@@ -224,28 +224,28 @@ int GENERAL_NAME_print(BIO *out, GENERAL_NAME *gen)
         switch (nid) {
         case NID_id_on_SmtpUTF8Mailbox:
             BIO_printf(out, "othername:SmtpUTF8Mailbox:%.*s",
-                       gen->d.otherName->value->value.utf8string->length,
-                       gen->d.otherName->value->value.utf8string->data);
+                gen->d.otherName->value->value.utf8string->length,
+                gen->d.otherName->value->value.utf8string->data);
             break;
         case NID_XmppAddr:
             BIO_printf(out, "othername:XmppAddr:%.*s",
-                       gen->d.otherName->value->value.utf8string->length,
-                       gen->d.otherName->value->value.utf8string->data);
+                gen->d.otherName->value->value.utf8string->length,
+                gen->d.otherName->value->value.utf8string->data);
             break;
         case NID_SRVName:
             BIO_printf(out, "othername:SRVName:%.*s",
-                       gen->d.otherName->value->value.ia5string->length,
-                       gen->d.otherName->value->value.ia5string->data);
+                gen->d.otherName->value->value.ia5string->length,
+                gen->d.otherName->value->value.ia5string->data);
             break;
         case NID_ms_upn:
             BIO_printf(out, "othername:UPN:%.*s",
-                       gen->d.otherName->value->value.utf8string->length,
-                       gen->d.otherName->value->value.utf8string->data);
+                gen->d.otherName->value->value.utf8string->length,
+                gen->d.otherName->value->value.utf8string->data);
             break;
         case NID_NAIRealm:
             BIO_printf(out, "othername:NAIRealm:%.*s",
-                       gen->d.otherName->value->value.utf8string->length,
-                       gen->d.otherName->value->value.utf8string->data);
+                gen->d.otherName->value->value.utf8string->length,
+                gen->d.otherName->value->value.utf8string->data);
             break;
         default:
             BIO_printf(out, "othername:<unsupported>");
@@ -299,8 +299,8 @@ int GENERAL_NAME_print(BIO *out, GENERAL_NAME *gen)
 }
 
 static GENERAL_NAMES *v2i_issuer_alt(X509V3_EXT_METHOD *method,
-                                     X509V3_CTX *ctx,
-                                     STACK_OF(CONF_VALUE) *nval)
+    X509V3_CTX *ctx,
+    STACK_OF(CONF_VALUE) *nval)
 {
     const int num = sk_CONF_VALUE_num(nval);
     GENERAL_NAMES *gens = sk_GENERAL_NAME_new_reserve(NULL, num);
@@ -327,7 +327,7 @@ static GENERAL_NAMES *v2i_issuer_alt(X509V3_EXT_METHOD *method,
         }
     }
     return gens;
- err:
+err:
     sk_GENERAL_NAME_pop_free(gens, GENERAL_NAME_free);
     return NULL;
 }
@@ -364,21 +364,20 @@ static int copy_issuer(X509V3_CTX *ctx, GENERAL_NAMES *gens)
 
     for (i = 0; i < num; i++) {
         gen = sk_GENERAL_NAME_value(ialt, i);
-        sk_GENERAL_NAME_push(gens, gen);     /* no failure as it was reserved */
+        sk_GENERAL_NAME_push(gens, gen); /* no failure as it was reserved */
     }
     sk_GENERAL_NAME_free(ialt);
 
     return 1;
 
- err:
+err:
     sk_GENERAL_NAME_free(ialt);
     return 0;
-
 }
 
 static GENERAL_NAMES *v2i_subject_alt(X509V3_EXT_METHOD *method,
-                                      X509V3_CTX *ctx,
-                                      STACK_OF(CONF_VALUE) *nval)
+    X509V3_CTX *ctx,
+    STACK_OF(CONF_VALUE) *nval)
 {
     GENERAL_NAMES *gens;
     CONF_VALUE *cnf;
@@ -399,7 +398,7 @@ static GENERAL_NAMES *v2i_subject_alt(X509V3_EXT_METHOD *method,
             if (!copy_email(ctx, gens, 0))
                 goto err;
         } else if (ossl_v3_name_cmp(cnf->name, "email") == 0
-                   && cnf->value && strcmp(cnf->value, "move") == 0) {
+            && cnf->value && strcmp(cnf->value, "move") == 0) {
             if (!copy_email(ctx, gens, 1))
                 goto err;
         } else {
@@ -410,7 +409,7 @@ static GENERAL_NAMES *v2i_subject_alt(X509V3_EXT_METHOD *method,
         }
     }
     return gens;
- err:
+err:
     sk_GENERAL_NAME_pop_free(gens, GENERAL_NAME_free);
     return NULL;
 }
@@ -435,13 +434,12 @@ static int copy_email(X509V3_CTX *ctx, GENERAL_NAMES *gens, int move_p)
         return 0;
     }
     /* Find the subject name */
-    nm = ctx->subject_cert != NULL ?
-        X509_get_subject_name(ctx->subject_cert) :
-        X509_REQ_get_subject_name(ctx->subject_req);
+    nm = ctx->subject_cert != NULL ? X509_get_subject_name(ctx->subject_cert) : X509_REQ_get_subject_name(ctx->subject_req);
 
     /* Now add any email address(es) to STACK */
     while ((i = X509_NAME_get_index_by_NID(nm,
-                                           NID_pkcs9_emailAddress, i)) >= 0) {
+                NID_pkcs9_emailAddress, i))
+        >= 0) {
         ne = X509_NAME_get_entry(nm, i);
         email = ASN1_STRING_dup(X509_NAME_ENTRY_get_data(ne));
         if (move_p) {
@@ -465,15 +463,14 @@ static int copy_email(X509V3_CTX *ctx, GENERAL_NAMES *gens, int move_p)
 
     return 1;
 
- err:
+err:
     GENERAL_NAME_free(gen);
     ASN1_IA5STRING_free(email);
     return 0;
-
 }
 
 GENERAL_NAMES *v2i_GENERAL_NAMES(const X509V3_EXT_METHOD *method,
-                                 X509V3_CTX *ctx, STACK_OF(CONF_VALUE) *nval)
+    X509V3_CTX *ctx, STACK_OF(CONF_VALUE) *nval)
 {
     GENERAL_NAME *gen;
     GENERAL_NAMES *gens;
@@ -492,24 +489,24 @@ GENERAL_NAMES *v2i_GENERAL_NAMES(const X509V3_EXT_METHOD *method,
         cnf = sk_CONF_VALUE_value(nval, i);
         if ((gen = v2i_GENERAL_NAME(method, ctx, cnf)) == NULL)
             goto err;
-        sk_GENERAL_NAME_push(gens, gen);    /* no failure as it was reserved */
+        sk_GENERAL_NAME_push(gens, gen); /* no failure as it was reserved */
     }
     return gens;
- err:
+err:
     sk_GENERAL_NAME_pop_free(gens, GENERAL_NAME_free);
     return NULL;
 }
 
 GENERAL_NAME *v2i_GENERAL_NAME(const X509V3_EXT_METHOD *method,
-                               X509V3_CTX *ctx, CONF_VALUE *cnf)
+    X509V3_CTX *ctx, CONF_VALUE *cnf)
 {
     return v2i_GENERAL_NAME_ex(NULL, method, ctx, cnf, 0);
 }
 
 GENERAL_NAME *a2i_GENERAL_NAME(GENERAL_NAME *out,
-                               const X509V3_EXT_METHOD *method,
-                               X509V3_CTX *ctx, int gen_type, const char *value,
-                               int is_nc)
+    const X509V3_EXT_METHOD *method,
+    X509V3_CTX *ctx, int gen_type, const char *value,
+    int is_nc)
 {
     char is_string = 0;
     GENERAL_NAME *gen = NULL;
@@ -536,17 +533,15 @@ GENERAL_NAME *a2i_GENERAL_NAME(GENERAL_NAME *out,
         is_string = 1;
         break;
 
-    case GEN_RID:
-        {
-            ASN1_OBJECT *obj;
-            if ((obj = OBJ_txt2obj(value, 0)) == NULL) {
-                ERR_raise_data(ERR_LIB_X509V3, X509V3_R_BAD_OBJECT,
-                               "value=%s", value);
-                goto err;
-            }
-            gen->d.rid = obj;
+    case GEN_RID: {
+        ASN1_OBJECT *obj;
+        if ((obj = OBJ_txt2obj(value, 0)) == NULL) {
+            ERR_raise_data(ERR_LIB_X509V3, X509V3_R_BAD_OBJECT,
+                "value=%s", value);
+            goto err;
         }
-        break;
+        gen->d.rid = obj;
+    } break;
 
     case GEN_IPADD:
         if (is_nc)
@@ -555,7 +550,7 @@ GENERAL_NAME *a2i_GENERAL_NAME(GENERAL_NAME *out,
             gen->d.ip = a2i_IPADDRESS(value);
         if (gen->d.ip == NULL) {
             ERR_raise_data(ERR_LIB_X509V3, X509V3_R_BAD_IP_ADDRESS,
-                           "value=%s", value);
+                "value=%s", value);
             goto err;
         }
         break;
@@ -579,9 +574,7 @@ GENERAL_NAME *a2i_GENERAL_NAME(GENERAL_NAME *out,
     }
 
     if (is_string) {
-        if ((gen->d.ia5 = ASN1_IA5STRING_new()) == NULL ||
-            !ASN1_STRING_set(gen->d.ia5, (unsigned char *)value,
-                             strlen(value))) {
+        if ((gen->d.ia5 = ASN1_IA5STRING_new()) == NULL || !ASN1_STRING_set(gen->d.ia5, (unsigned char *)value, strlen(value))) {
             ASN1_IA5STRING_free(gen->d.ia5);
             gen->d.ia5 = NULL;
             ERR_raise(ERR_LIB_X509V3, ERR_R_ASN1_LIB);
@@ -593,15 +586,15 @@ GENERAL_NAME *a2i_GENERAL_NAME(GENERAL_NAME *out,
 
     return gen;
 
- err:
+err:
     if (!out)
         GENERAL_NAME_free(gen);
     return NULL;
 }
 
 GENERAL_NAME *v2i_GENERAL_NAME_ex(GENERAL_NAME *out,
-                                  const X509V3_EXT_METHOD *method,
-                                  X509V3_CTX *ctx, CONF_VALUE *cnf, int is_nc)
+    const X509V3_EXT_METHOD *method,
+    X509V3_CTX *ctx, CONF_VALUE *cnf, int is_nc)
 {
     int type;
 
@@ -631,12 +624,11 @@ GENERAL_NAME *v2i_GENERAL_NAME_ex(GENERAL_NAME *out,
         type = GEN_OTHERNAME;
     else {
         ERR_raise_data(ERR_LIB_X509V3, X509V3_R_UNSUPPORTED_OPTION,
-                       "name=%s", name);
+            "name=%s", name);
         return NULL;
     }
 
     return a2i_GENERAL_NAME(out, method, ctx, type, value, is_nc);
-
 }
 
 static int do_othername(GENERAL_NAME *gen, const char *value, X509V3_CTX *ctx)
@@ -665,7 +657,7 @@ static int do_othername(GENERAL_NAME *gen, const char *value, X509V3_CTX *ctx)
         goto err;
     return 1;
 
- err:
+err:
     OTHERNAME_free(gen->d.otherName);
     gen->d.otherName = NULL;
     return 0;
@@ -682,7 +674,7 @@ static int do_dirname(GENERAL_NAME *gen, const char *value, X509V3_CTX *ctx)
     sk = X509V3_get_section(ctx, value);
     if (!sk) {
         ERR_raise_data(ERR_LIB_X509V3, X509V3_R_SECTION_NOT_FOUND,
-                       "section=%s", value);
+            "section=%s", value);
         goto err;
     }
     /* FIXME: should allow other character types... */
