@@ -45,7 +45,7 @@ struct X509_pubkey_st {
 static int x509_pubkey_decode(EVP_PKEY **pk, const X509_PUBKEY *key);
 
 static int x509_pubkey_set0_libctx(X509_PUBKEY *x, OSSL_LIB_CTX *libctx,
-                                   const char *propq)
+    const char *propq)
 {
     if (x != NULL) {
         x->libctx = libctx;
@@ -61,21 +61,20 @@ static int x509_pubkey_set0_libctx(X509_PUBKEY *x, OSSL_LIB_CTX *libctx,
 }
 
 ASN1_SEQUENCE(X509_PUBKEY_INTERNAL) = {
-        ASN1_SIMPLE(X509_PUBKEY, algor, X509_ALGOR),
-        ASN1_SIMPLE(X509_PUBKEY, public_key, ASN1_BIT_STRING)
+    ASN1_SIMPLE(X509_PUBKEY, algor, X509_ALGOR),
+    ASN1_SIMPLE(X509_PUBKEY, public_key, ASN1_BIT_STRING)
 } static_ASN1_SEQUENCE_END_name(X509_PUBKEY, X509_PUBKEY_INTERNAL)
 
-X509_PUBKEY *ossl_d2i_X509_PUBKEY_INTERNAL(const unsigned char **pp,
-                                           long len, OSSL_LIB_CTX *libctx,
-                                           const char *propq)
+                                          X509_PUBKEY
+    * ossl_d2i_X509_PUBKEY_INTERNAL(const unsigned char **pp, long len, OSSL_LIB_CTX *libctx, const char *propq)
 {
     X509_PUBKEY *xpub = OPENSSL_zalloc(sizeof(*xpub));
 
     if (xpub == NULL)
         return NULL;
     return (X509_PUBKEY *)ASN1_item_d2i_ex((ASN1_VALUE **)&xpub, pp, len,
-                                           ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL),
-                                           libctx, propq);
+        ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL),
+        libctx, propq);
 }
 
 void ossl_X509_PUBKEY_INTERNAL_free(X509_PUBKEY *xpub)
@@ -102,14 +101,13 @@ static int x509_pubkey_ex_populate(ASN1_VALUE **pval, const ASN1_ITEM *it)
     X509_PUBKEY *pubkey = (X509_PUBKEY *)*pval;
 
     return (pubkey->algor != NULL
-            || (pubkey->algor = X509_ALGOR_new()) != NULL)
+               || (pubkey->algor = X509_ALGOR_new()) != NULL)
         && (pubkey->public_key != NULL
             || (pubkey->public_key = ASN1_BIT_STRING_new()) != NULL);
 }
 
-
 static int x509_pubkey_ex_new_ex(ASN1_VALUE **pval, const ASN1_ITEM *it,
-                                 OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     X509_PUBKEY *ret;
 
@@ -128,10 +126,10 @@ static int x509_pubkey_ex_new_ex(ASN1_VALUE **pval, const ASN1_ITEM *it,
 }
 
 static int x509_pubkey_ex_d2i_ex(ASN1_VALUE **pval,
-                                 const unsigned char **in, long len,
-                                 const ASN1_ITEM *it, int tag, int aclass,
-                                 char opt, ASN1_TLC *ctx, OSSL_LIB_CTX *libctx,
-                                 const char *propq)
+    const unsigned char **in, long len,
+    const ASN1_ITEM *it, int tag, int aclass,
+    char opt, ASN1_TLC *ctx, OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     const unsigned char *in_saved = *in;
     size_t publen;
@@ -148,10 +146,14 @@ static int x509_pubkey_ex_d2i_ex(ASN1_VALUE **pval,
     }
 
     /* This ensures that |*in| advances properly no matter what */
-    if ((ret = ASN1_item_ex_d2i(pval, in, len,
-                                ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL),
-                                tag, aclass, opt, ctx)) <= 0)
+    if ((ret = asn1_item_embed_d2i(pval, in, len,
+             ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL),
+             tag, aclass, opt, ctx, 0,
+             NULL, NULL))
+        <= 0) {
+        x509_pubkey_ex_free(pval, it);
         return ret;
+    }
 
     publen = *in - in_saved;
     if (!ossl_assert(publen > 0)) {
@@ -187,9 +189,9 @@ static int x509_pubkey_ex_d2i_ex(ASN1_VALUE **pval,
         size_t slen = publen;
 
         /*
-        * The decoders don't know how to handle anything other than Universal
-        * class so we modify the data accordingly.
-        */
+         * The decoders don't know how to handle anything other than Universal
+         * class so we modify the data accordingly.
+         */
         if (aclass != V_ASN1_UNIVERSAL) {
             tmpbuf = OPENSSL_memdup(in_saved, publen);
             if (tmpbuf == NULL)
@@ -200,16 +202,17 @@ static int x509_pubkey_ex_d2i_ex(ASN1_VALUE **pval,
         p = in_saved;
 
         if (OBJ_obj2txt(txtoidname, sizeof(txtoidname),
-                        pubkey->algor->algorithm, 0) <= 0) {
+                pubkey->algor->algorithm, 0)
+            <= 0) {
             ERR_clear_last_mark();
             goto end;
         }
-        if ((dctx =
-             OSSL_DECODER_CTX_new_for_pkey(&pubkey->pkey,
-                                           "DER", "SubjectPublicKeyInfo",
-                                           txtoidname, EVP_PKEY_PUBLIC_KEY,
-                                           pubkey->libctx,
-                                           pubkey->propq)) != NULL)
+        if ((dctx = OSSL_DECODER_CTX_new_for_pkey(&pubkey->pkey,
+                 "DER", "SubjectPublicKeyInfo",
+                 txtoidname, EVP_PKEY_PUBLIC_KEY,
+                 pubkey->libctx,
+                 pubkey->propq))
+            != NULL)
             /*
              * As said higher up, we're being opportunistic.  In other words,
              * we don't care if we fail.
@@ -229,31 +232,31 @@ static int x509_pubkey_ex_d2i_ex(ASN1_VALUE **pval,
 
     ERR_pop_to_mark();
     ret = 1;
- end:
+end:
     OSSL_DECODER_CTX_free(dctx);
     OPENSSL_free(tmpbuf);
     return ret;
 }
 
 static int x509_pubkey_ex_i2d(const ASN1_VALUE **pval, unsigned char **out,
-                              const ASN1_ITEM *it, int tag, int aclass)
+    const ASN1_ITEM *it, int tag, int aclass)
 {
     return ASN1_item_ex_i2d(pval, out, ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL),
-                            tag, aclass);
+        tag, aclass);
 }
 
 static int x509_pubkey_ex_print(BIO *out, const ASN1_VALUE **pval, int indent,
-                                const char *fname, const ASN1_PCTX *pctx)
+    const char *fname, const ASN1_PCTX *pctx)
 {
     return ASN1_item_print(out, *pval, indent,
-                           ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL), pctx);
+        ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL), pctx);
 }
 
 static const ASN1_EXTERN_FUNCS x509_pubkey_ff = {
     NULL,
     NULL,
     x509_pubkey_ex_free,
-    0,                          /* Default clear behaviour is OK */
+    0, /* Default clear behaviour is OK */
     NULL,
     x509_pubkey_ex_i2d,
     x509_pubkey_ex_print,
@@ -289,16 +292,16 @@ X509_PUBKEY *X509_PUBKEY_dup(const X509_PUBKEY *a)
     if (!x509_pubkey_set0_libctx(pubkey, a->libctx, a->propq)) {
         ERR_raise(ERR_LIB_X509, ERR_R_X509_LIB);
         x509_pubkey_ex_free((ASN1_VALUE **)&pubkey,
-                            ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL));
+            ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL));
         return NULL;
     }
     if ((pubkey->algor = X509_ALGOR_dup(a->algor)) == NULL
         || (pubkey->public_key = ASN1_BIT_STRING_new()) == NULL
         || !ASN1_BIT_STRING_set(pubkey->public_key,
-                                a->public_key->data,
-                                a->public_key->length)) {
+            a->public_key->data,
+            a->public_key->length)) {
         x509_pubkey_ex_free((ASN1_VALUE **)&pubkey,
-                            ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL));
+            ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL));
         ERR_raise(ERR_LIB_X509, ERR_R_ASN1_LIB);
         return NULL;
     }
@@ -310,7 +313,7 @@ X509_PUBKEY *X509_PUBKEY_dup(const X509_PUBKEY *a)
             pubkey->flag_force_legacy = 1;
             if (x509_pubkey_decode(&pubkey->pkey, pubkey) <= 0) {
                 x509_pubkey_ex_free((ASN1_VALUE **)&pubkey,
-                                    ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL));
+                    ASN1_ITEM_rptr(X509_PUBKEY_INTERNAL));
                 ERR_clear_last_mark();
                 return NULL;
             }
@@ -346,10 +349,9 @@ int X509_PUBKEY_set(X509_PUBKEY **x, EVP_PKEY *pkey)
     } else if (evp_pkey_is_provided(pkey)) {
         unsigned char *der = NULL;
         size_t derlen = 0;
-        OSSL_ENCODER_CTX *ectx =
-            OSSL_ENCODER_CTX_new_for_pkey(pkey, EVP_PKEY_PUBLIC_KEY,
-                                          "DER", "SubjectPublicKeyInfo",
-                                          NULL);
+        OSSL_ENCODER_CTX *ectx = OSSL_ENCODER_CTX_new_for_pkey(pkey, EVP_PKEY_PUBLIC_KEY,
+            "DER", "SubjectPublicKeyInfo",
+            NULL);
 
         if (OSSL_ENCODER_to_data(ectx, &der, &derlen)) {
             const unsigned char *pder = der;
@@ -389,7 +391,7 @@ int X509_PUBKEY_set(X509_PUBKEY **x, EVP_PKEY *pkey)
     pk->pkey = pkey;
     return 1;
 
- error:
+error:
     X509_PUBKEY_free(pk);
     return 0;
 }
@@ -447,7 +449,7 @@ static int x509_pubkey_decode(EVP_PKEY **ppkey, const X509_PUBKEY *key)
     *ppkey = pkey;
     return 1;
 
- error:
+error:
     EVP_PKEY_free(pkey);
     return 0;
 }
@@ -484,13 +486,12 @@ EVP_PKEY *X509_PUBKEY_get(const X509_PUBKEY *key)
  * or decode as X509_PUBKEY
  */
 static EVP_PKEY *d2i_PUBKEY_int(EVP_PKEY **a,
-                                const unsigned char **pp, long length,
-                                OSSL_LIB_CTX *libctx, const char *propq,
-                                unsigned int force_legacy,
-                                X509_PUBKEY *
-                                (*d2i_x509_pubkey)(X509_PUBKEY **a,
-                                                   const unsigned char **in,
-                                                   long len))
+    const unsigned char **pp, long length,
+    OSSL_LIB_CTX *libctx, const char *propq,
+    unsigned int force_legacy,
+    X509_PUBKEY *(*d2i_x509_pubkey)(X509_PUBKEY **a,
+        const unsigned char **in,
+        long len))
 {
     X509_PUBKEY *xpk, *xpk2 = NULL, **pxpk = NULL;
     EVP_PKEY *pktmp = NULL;
@@ -517,7 +518,7 @@ static EVP_PKEY *d2i_PUBKEY_int(EVP_PKEY **a,
         goto end;
     pktmp = X509_PUBKEY_get(xpk);
     X509_PUBKEY_free(xpk);
-    xpk2 = NULL;                 /* We know that xpk == xpk2 */
+    xpk2 = NULL; /* We know that xpk == xpk2 */
     if (pktmp == NULL)
         goto end;
     *pp = q;
@@ -525,20 +526,20 @@ static EVP_PKEY *d2i_PUBKEY_int(EVP_PKEY **a,
         EVP_PKEY_free(*a);
         *a = pktmp;
     }
- end:
+end:
     X509_PUBKEY_free(xpk2);
     return pktmp;
 }
 
 /* For the algorithm specific d2i functions further down */
 EVP_PKEY *ossl_d2i_PUBKEY_legacy(EVP_PKEY **a, const unsigned char **pp,
-                                 long length)
+    long length)
 {
     return d2i_PUBKEY_int(a, pp, length, NULL, NULL, 1, d2i_X509_PUBKEY);
 }
 
 EVP_PKEY *d2i_PUBKEY_ex(EVP_PKEY **a, const unsigned char **pp, long length,
-                        OSSL_LIB_CTX *libctx, const char *propq)
+    OSSL_LIB_CTX *libctx, const char *propq)
 {
     return d2i_PUBKEY_int(a, pp, length, libctx, propq, 0, d2i_X509_PUBKEY);
 }
@@ -568,10 +569,9 @@ int i2d_PUBKEY(const EVP_PKEY *a, unsigned char **pp)
         }
         X509_PUBKEY_free(xpk);
     } else if (a->keymgmt != NULL) {
-        OSSL_ENCODER_CTX *ctx =
-            OSSL_ENCODER_CTX_new_for_pkey(a, EVP_PKEY_PUBLIC_KEY,
-                                          "DER", "SubjectPublicKeyInfo",
-                                          NULL);
+        OSSL_ENCODER_CTX *ctx = OSSL_ENCODER_CTX_new_for_pkey(a, EVP_PKEY_PUBLIC_KEY,
+            "DER", "SubjectPublicKeyInfo",
+            NULL);
         BIO *out = BIO_new(BIO_s_mem());
         BUF_MEM *buf = NULL;
 
@@ -836,9 +836,9 @@ int i2d_EC_PUBKEY(const EC_KEY *a, unsigned char **pp)
     return ret;
 }
 
-# ifndef OPENSSL_NO_ECX
+#ifndef OPENSSL_NO_ECX
 ECX_KEY *ossl_d2i_ED25519_PUBKEY(ECX_KEY **a,
-                                 const unsigned char **pp, long length)
+    const unsigned char **pp, long length)
 {
     EVP_PKEY *pkey;
     ECX_KEY *key = NULL;
@@ -879,7 +879,7 @@ int ossl_i2d_ED25519_PUBKEY(const ECX_KEY *a, unsigned char **pp)
 }
 
 ECX_KEY *ossl_d2i_ED448_PUBKEY(ECX_KEY **a,
-                               const unsigned char **pp, long length)
+    const unsigned char **pp, long length)
 {
     EVP_PKEY *pkey;
     ECX_KEY *key = NULL;
@@ -921,7 +921,7 @@ int ossl_i2d_ED448_PUBKEY(const ECX_KEY *a, unsigned char **pp)
 }
 
 ECX_KEY *ossl_d2i_X25519_PUBKEY(ECX_KEY **a,
-                                const unsigned char **pp, long length)
+    const unsigned char **pp, long length)
 {
     EVP_PKEY *pkey;
     ECX_KEY *key = NULL;
@@ -963,7 +963,7 @@ int ossl_i2d_X25519_PUBKEY(const ECX_KEY *a, unsigned char **pp)
 }
 
 ECX_KEY *ossl_d2i_X448_PUBKEY(ECX_KEY **a,
-                              const unsigned char **pp, long length)
+    const unsigned char **pp, long length)
 {
     EVP_PKEY *pkey;
     ECX_KEY *key = NULL;
@@ -1004,19 +1004,19 @@ int ossl_i2d_X448_PUBKEY(const ECX_KEY *a, unsigned char **pp)
     return ret;
 }
 
-# endif /* OPENSSL_NO_ECX */ 
+#endif /* OPENSSL_NO_ECX */
 #endif
 
 void X509_PUBKEY_set0_public_key(X509_PUBKEY *pub,
-                                 unsigned char *penc, int penclen)
+    unsigned char *penc, int penclen)
 {
     ASN1_STRING_set0(pub->public_key, penc, penclen);
     ossl_asn1_string_set_bits_left(pub->public_key, 0);
 }
 
 int X509_PUBKEY_set0_param(X509_PUBKEY *pub, ASN1_OBJECT *aobj,
-                           int ptype, void *pval,
-                           unsigned char *penc, int penclen)
+    int ptype, void *pval,
+    unsigned char *penc, int penclen)
 {
     if (!X509_ALGOR_set0(pub->algor, aobj, ptype, pval))
         return 0;
@@ -1026,8 +1026,8 @@ int X509_PUBKEY_set0_param(X509_PUBKEY *pub, ASN1_OBJECT *aobj,
 }
 
 int X509_PUBKEY_get0_param(ASN1_OBJECT **ppkalg,
-                           const unsigned char **pk, int *ppklen,
-                           X509_ALGOR **pa, const X509_PUBKEY *pub)
+    const unsigned char **pk, int *ppklen,
+    X509_ALGOR **pa, const X509_PUBKEY *pub)
 {
     if (ppkalg)
         *ppkalg = pub->algor->algorithm;
@@ -1069,7 +1069,7 @@ int X509_PUBKEY_eq(const X509_PUBKEY *a, const X509_PUBKEY *b)
 }
 
 int ossl_x509_PUBKEY_get0_libctx(OSSL_LIB_CTX **plibctx, const char **ppropq,
-                                 const X509_PUBKEY *key)
+    const X509_PUBKEY *key)
 {
     if (plibctx)
         *plibctx = key->libctx;
