@@ -34,7 +34,8 @@ int main(int argc, char **argv)
 
     rcert = PEM_read_bio_X509(tbio, NULL, 0, NULL);
 
-    BIO_reset(tbio);
+    if (BIO_reset(tbio) < 0)
+        goto err;
 
     rkey = PEM_read_bio_PrivateKey(tbio, NULL, 0, NULL);
 
@@ -70,7 +71,7 @@ int main(int argc, char **argv)
 
     ret = EXIT_SUCCESS;
 
- err:
+err:
 
     if (ret != EXIT_SUCCESS) {
         fprintf(stderr, "Error Decrypting Data\n");
