@@ -1,5 +1,5 @@
 /*-
- * Copyright 2021-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2021-2023 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -53,13 +53,13 @@ static EVP_PKEY *do_ec_keygen(void)
     }
 
     params[0] = OSSL_PARAM_construct_utf8_string(OSSL_PKEY_PARAM_GROUP_NAME,
-                                                 (char *)curvename, 0);
+        (char *)curvename, 0);
     /*
      * This is an optional parameter.
      * For many curves where the cofactor is 1, setting this has no effect.
      */
     params[1] = OSSL_PARAM_construct_int(OSSL_PKEY_PARAM_USE_COFACTOR_ECDH,
-                                         &use_cofactordh);
+        &use_cofactordh);
     params[2] = OSSL_PARAM_construct_end();
     if (!EVP_PKEY_CTX_set_params(genctx, params)) {
         fprintf(stderr, "EVP_PKEY_CTX_set_params() failed\n");
@@ -84,7 +84,7 @@ cleanup:
  */
 static int get_key_values(EVP_PKEY *pkey)
 {
-    int result = 0;
+    int ret = 0;
     char out_curvename[80];
     unsigned char out_pubkey[80];
     unsigned char out_privkey[80];
@@ -92,15 +92,15 @@ static int get_key_values(EVP_PKEY *pkey)
     size_t out_pubkey_len, out_privkey_len = 0;
 
     if (!EVP_PKEY_get_utf8_string_param(pkey, OSSL_PKEY_PARAM_GROUP_NAME,
-                                        out_curvename, sizeof(out_curvename),
-                                        NULL)) {
+            out_curvename, sizeof(out_curvename),
+            NULL)) {
         fprintf(stderr, "Failed to get curve name\n");
         goto cleanup;
     }
 
     if (!EVP_PKEY_get_octet_string_param(pkey, OSSL_PKEY_PARAM_PUB_KEY,
-                                        out_pubkey, sizeof(out_pubkey),
-                                        &out_pubkey_len)) {
+            out_pubkey, sizeof(out_pubkey),
+            &out_pubkey_len)) {
         fprintf(stderr, "Failed to get public key\n");
         goto cleanup;
     }
@@ -122,16 +122,16 @@ static int get_key_values(EVP_PKEY *pkey)
     fprintf(stdout, "Private Key:\n");
     BIO_dump_indent_fp(stdout, out_privkey, out_privkey_len, 2);
 
-    result = 1;
+    ret = 1;
 cleanup:
     /* Zeroize the private key data when we free it */
     BN_clear_free(out_priv);
-    return result;
+    return ret;
 }
 
 int main(void)
 {
-    int result = 0;
+    int ret = EXIT_FAILURE;
     EVP_PKEY *pkey;
 
     pkey = do_ec_keygen();
@@ -145,11 +145,11 @@ int main(void)
      * At this point we can write out the generated key using
      * i2d_PrivateKey() and i2d_PublicKey() if required.
      */
-    result = 1;
+    ret = EXIT_SUCCESS;
 cleanup:
-    if (result != 1)
+    if (ret != EXIT_SUCCESS)
         ERR_print_errors_fp(stderr);
 
     EVP_PKEY_free(pkey);
-    return result == 0;
+    return ret;
 }
