@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2018-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -40,6 +40,11 @@
 #define OPENSSL_KTLS_AES_GCM_128
 #define OPENSSL_KTLS_AES_GCM_256
 #define OPENSSL_KTLS_TLS13
+#ifdef TLS_CHACHA20_IV_LEN
+#ifndef OPENSSL_NO_CHACHA
+#define OPENSSL_KTLS_CHACHA20_POLY1305
+#endif
+#endif
 
 typedef struct tls_enable ktls_crypto_info_t;
 
@@ -79,6 +84,12 @@ static ossl_inline int ktls_start(int fd, ktls_crypto_info_t *tls_en, int is_tx)
 #endif
 }
 
+/* Not supported on FreeBSD */
+static ossl_inline int ktls_enable_tx_zerocopy_sendfile(int fd)
+{
+    return 0;
+}
+
 /*
  * Send a TLS record using the tls_en provided in ktls_start and use
  * record_type instead of the default SSL3_RT_APPLICATION_DATA.
@@ -214,6 +225,13 @@ static ossl_inline ossl_ssize_t ktls_sendfile(int s, int fd, off_t off,
 #warning "Skipping Compilation of KTLS receive data path"
 #endif
 #endif
+#if LINUX_VERSION_CODE < KERNEL_VERSION(5, 19, 0)
+#define OPENSSL_NO_KTLS_ZC_TX
+#ifndef PEDANTIC
+#warning "KTLS requires Kernel Headers >= 5.19.0 for zerocopy sendfile"
+#warning "Skipping Compilation of KTLS zerocopy sendfile"
+#endif
+#endif
 #define OPENSSL_KTLS_AES_GCM_128
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 1, 0)
 #define OPENSSL_KTLS_AES_GCM_256
@@ -301,6 +319,20 @@ static ossl_inline int ktls_start(int fd, ktls_crypto_info_t *crypto_info,
         : 1;
 }
 
+static ossl_inline int ktls_enable_tx_zerocopy_sendfile(int fd)
+{
+#ifndef OPENSSL_NO_KTLS_ZC_TX
+    int enable = 1;
+
+    return setsockopt(fd, SOL_TLS, TLS_TX_ZEROCOPY_RO,
+               &enable, sizeof(enable))
+        ? 0
+        : 1;
+#else
+    return 0;
+#endif
+}
+
 /*
  * Send a TLS record using the crypto_info provided in ktls_start and use
  * record_type instead of the default SSL3_RT_APPLICATION_DATA.
