@@ -65,10 +65,8 @@ static void *siv_dupctx(void *vctx)
         return NULL;
 
     ret = OPENSSL_malloc(sizeof(*ret));
-    if (ret == NULL) {
-        ERR_raise(ERR_LIB_PROV, ERR_R_MALLOC_FAILURE);
+    if (ret == NULL)
         return NULL;
-    }
     if (!in->hw->dupctx(in, ret)) {
         OPENSSL_free(ret);
         ret = NULL;
@@ -299,7 +297,7 @@ static const OSSL_PARAM *aes_siv_settable_ctx_params(ossl_unused void *cctx,
             (void (*)(void))alg##_##lc##_set_ctx_params },                       \
         { OSSL_FUNC_CIPHER_SETTABLE_CTX_PARAMS,                                  \
             (void (*)(void))alg##_##lc##_settable_ctx_params },                  \
-        { 0, NULL }                                                              \
+        OSSL_DISPATCH_END                                                        \
     };
 
 IMPLEMENT_cipher(aes, siv, SIV, SIV_FLAGS, 128, 8, 0)
