@@ -44,11 +44,10 @@ static sha3_squeeze_fn generic_sha3_squeeze;
 /*
  * IBM S390X support
  */
-# include "s390x_arch.h"
-# define S390_SHA3 1
-# define S390_SHA3_CAPABLE(name) \
-    ((OPENSSL_s390xcap_P.kimd[0] & S390X_CAPBIT(S390X_##name)) && \
-     (OPENSSL_s390xcap_P.klmd[0] & S390X_CAPBIT(S390X_##name)))
+#include "s390x_arch.h"
+#define S390_SHA3 1
+#define S390_SHA3_CAPABLE(name) \
+    ((OPENSSL_s390xcap_P.kimd[0] & S390X_CAPBIT(S390X_##name)) && (OPENSSL_s390xcap_P.klmd[0] & S390X_CAPBIT(S390X_##name)))
 
 #endif
 
@@ -64,7 +63,7 @@ static int keccak_init(void *vctx, ossl_unused const OSSL_PARAM params[])
 static int keccak_init_params(void *vctx, const OSSL_PARAM params[])
 {
     return keccak_init(vctx, NULL)
-            && shake_set_ctx_params(vctx, params);
+        && shake_set_ctx_params(vctx, params);
 }
 
 static int keccak_update(void *vctx, const unsigned char *inp, size_t len)
@@ -105,7 +104,7 @@ static int keccak_update(void *vctx, const unsigned char *inp, size_t len)
 }
 
 static int keccak_final(void *vctx, unsigned char *out, size_t *outl,
-                        size_t outlen)
+    size_t outlen)
 {
     int ret = 1;
     KECCAK1600_CTX *ctx = vctx;
@@ -120,7 +119,7 @@ static int keccak_final(void *vctx, unsigned char *out, size_t *outl,
 }
 
 static int shake_squeeze(void *vctx, unsigned char *out, size_t *outl,
-                         size_t outlen)
+    size_t outlen)
 {
     int ret = 1;
     KECCAK1600_CTX *ctx = vctx;
@@ -143,8 +142,7 @@ static size_t generic_sha3_absorb(void *vctx, const void *inp, size_t len)
 {
     KECCAK1600_CTX *ctx = vctx;
 
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     ctx->xof_state = XOF_STATE_ABSORB;
     return SHA3_absorb(ctx->A, inp, len, ctx->block_size);
@@ -160,15 +158,13 @@ static int generic_sha3_squeeze(void *vctx, unsigned char *out, size_t outlen)
     return ossl_sha3_squeeze((KECCAK1600_CTX *)vctx, out, outlen);
 }
 
-static PROV_SHA3_METHOD sha3_generic_md =
-{
+static PROV_SHA3_METHOD sha3_generic_md = {
     generic_sha3_absorb,
     generic_sha3_final,
     NULL
 };
 
-static PROV_SHA3_METHOD shake_generic_md =
-{
+static PROV_SHA3_METHOD shake_generic_md = {
     generic_sha3_absorb,
     generic_sha3_final,
     generic_sha3_squeeze
@@ -188,8 +184,7 @@ static size_t s390x_sha3_absorb(void *vctx, const void *inp, size_t len)
     KECCAK1600_CTX *ctx = vctx;
     size_t rem = len % ctx->block_size;
 
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     ctx->xof_state = XOF_STATE_ABSORB;
     s390x_kimd(inp, len - rem, ctx->pad, ctx->A);
@@ -202,8 +197,7 @@ static int s390x_sha3_final(void *vctx, unsigned char *out, size_t outlen)
 
     if (!ossl_prov_is_running())
         return 0;
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     ctx->xof_state = XOF_STATE_FINAL;
     s390x_klmd(ctx->buf, ctx->bufsz, NULL, 0, ctx->pad, ctx->A);
@@ -217,8 +211,7 @@ static int s390x_shake_final(void *vctx, unsigned char *out, size_t outlen)
 
     if (!ossl_prov_is_running())
         return 0;
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     ctx->xof_state = XOF_STATE_FINAL;
     s390x_klmd(ctx->buf, ctx->bufsz, out, outlen, ctx->pad, ctx->A);
@@ -265,7 +258,7 @@ static int s390x_shake_squeeze(void *vctx, unsigned char *out, size_t outlen)
 }
 
 static int s390x_keccakc_final(void *vctx, unsigned char *out, size_t outlen,
-                               int padding)
+    int padding)
 {
     KECCAK1600_CTX *ctx = vctx;
     size_t bsz = ctx->block_size;
@@ -274,8 +267,7 @@ static int s390x_keccakc_final(void *vctx, unsigned char *out, size_t outlen,
 
     if (!ossl_prov_is_running())
         return 0;
-    if (!(ctx->xof_state == XOF_STATE_INIT ||
-          ctx->xof_state == XOF_STATE_ABSORB))
+    if (!(ctx->xof_state == XOF_STATE_INIT || ctx->xof_state == XOF_STATE_ABSORB))
         return 0;
     ctx->xof_state = XOF_STATE_FINAL;
     if (outlen == 0)
@@ -304,7 +296,7 @@ static int s390x_kmac_final(void *vctx, unsigned char *out, size_t outlen)
 }
 
 static int s390x_keccakc_squeeze(void *vctx, unsigned char *out, size_t outlen,
-                                 int padding)
+    int padding)
 {
     KECCAK1600_CTX *ctx = vctx;
     size_t len;
@@ -349,71 +341,67 @@ static int s390x_keccakc_squeeze(void *vctx, unsigned char *out, size_t outlen,
 
 static int s390x_keccak_squeeze(void *vctx, unsigned char *out, size_t outlen)
 {
-     return s390x_keccakc_squeeze(vctx, out, outlen, 0x01);
+    return s390x_keccakc_squeeze(vctx, out, outlen, 0x01);
 }
 
 static int s390x_kmac_squeeze(void *vctx, unsigned char *out, size_t outlen)
 {
-     return s390x_keccakc_squeeze(vctx, out, outlen, 0x04);
+    return s390x_keccakc_squeeze(vctx, out, outlen, 0x04);
 }
 
-static PROV_SHA3_METHOD sha3_s390x_md =
-{
+static PROV_SHA3_METHOD sha3_s390x_md = {
     s390x_sha3_absorb,
     s390x_sha3_final,
     NULL,
 };
 
-static PROV_SHA3_METHOD keccak_s390x_md =
-{
+static PROV_SHA3_METHOD keccak_s390x_md = {
     s390x_sha3_absorb,
     s390x_keccak_final,
     s390x_keccak_squeeze,
 };
 
-static PROV_SHA3_METHOD shake_s390x_md =
-{
+static PROV_SHA3_METHOD shake_s390x_md = {
     s390x_sha3_absorb,
     s390x_shake_final,
     s390x_shake_squeeze,
 };
 
-static PROV_SHA3_METHOD kmac_s390x_md =
-{
+static PROV_SHA3_METHOD kmac_s390x_md = {
     s390x_sha3_absorb,
     s390x_kmac_final,
     s390x_kmac_squeeze,
 };
 
-# define SHAKE_SET_MD(uname, typ)                                              \
-    if (S390_SHA3_CAPABLE(uname)) {                                            \
-        ctx->pad = S390X_##uname;                                              \
-        ctx->meth = typ##_s390x_md;                                            \
-    } else {                                                                   \
-        ctx->meth = shake_generic_md;                                          \
+#define SHAKE_SET_MD(uname, typ)      \
+    if (S390_SHA3_CAPABLE(uname)) {   \
+        ctx->pad = S390X_##uname;     \
+        ctx->meth = typ##_s390x_md;   \
+    } else {                          \
+        ctx->meth = shake_generic_md; \
     }
 
-# define SHA3_SET_MD(uname, typ)                                               \
-    if (S390_SHA3_CAPABLE(uname)) {                                            \
-        ctx->pad = S390X_##uname;                                              \
-        ctx->meth = typ##_s390x_md;                                            \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define SHA3_SET_MD(uname, typ)      \
+    if (S390_SHA3_CAPABLE(uname)) {  \
+        ctx->pad = S390X_##uname;    \
+        ctx->meth = typ##_s390x_md;  \
+    } else {                         \
+        ctx->meth = sha3_generic_md; \
     }
-# define KMAC_SET_MD(bitlen)                                                   \
-    if (S390_SHA3_CAPABLE(SHAKE_##bitlen)) {                                   \
-        ctx->pad = S390X_SHAKE_##bitlen;                                       \
-        ctx->meth = kmac_s390x_md;                                             \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define KMAC_SET_MD(bitlen)                  \
+    if (S390_SHA3_CAPABLE(SHAKE_##bitlen)) { \
+        ctx->pad = S390X_SHAKE_##bitlen;     \
+        ctx->meth = kmac_s390x_md;           \
+    } else {                                 \
+        ctx->meth = sha3_generic_md;         \
     }
 #elif defined(__aarch64__) && defined(KECCAK1600_ASM)
-# include "arm_arch.h"
+#include "arm_arch.h"
 
 static sha3_absorb_fn armsha3_sha3_absorb;
 
 size_t SHA3_absorb_cext(uint64_t A[5][5], const unsigned char *inp, size_t len,
-                        size_t r);
+    size_t r);
 /*-
  * Hardware-assisted ARMv8.2 SHA3 extension version of the absorb()
  */
@@ -424,113 +412,111 @@ static size_t armsha3_sha3_absorb(void *vctx, const void *inp, size_t len)
     return SHA3_absorb_cext(ctx->A, inp, len, ctx->block_size);
 }
 
-static PROV_SHA3_METHOD sha3_ARMSHA3_md =
-{
+static PROV_SHA3_METHOD sha3_ARMSHA3_md = {
     armsha3_sha3_absorb,
     generic_sha3_final
 };
-static PROV_SHA3_METHOD shake_ARMSHA3_md =
-{
+static PROV_SHA3_METHOD shake_ARMSHA3_md = {
     armsha3_sha3_absorb,
     generic_sha3_final,
     generic_sha3_squeeze
 };
-# define SHAKE_SET_MD(uname, typ)                                              \
-    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) {                  \
-        ctx->meth = shake_ARMSHA3_md;                                          \
-    } else {                                                                   \
-        ctx->meth = shake_generic_md;                                          \
+#define SHAKE_SET_MD(uname, typ)                              \
+    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) { \
+        ctx->meth = shake_ARMSHA3_md;                         \
+    } else {                                                  \
+        ctx->meth = shake_generic_md;                         \
     }
 
-# define SHA3_SET_MD(uname, typ)                                               \
-    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) {                  \
-        ctx->meth = sha3_ARMSHA3_md;                                           \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define SHA3_SET_MD(uname, typ)                               \
+    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) { \
+        ctx->meth = sha3_ARMSHA3_md;                          \
+    } else {                                                  \
+        ctx->meth = sha3_generic_md;                          \
     }
-# define KMAC_SET_MD(bitlen)                                                   \
-    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) {                  \
-        ctx->meth = sha3_ARMSHA3_md;                                           \
-    } else {                                                                   \
-        ctx->meth = sha3_generic_md;                                           \
+#define KMAC_SET_MD(bitlen)                                   \
+    if (OPENSSL_armcap_P & ARMV8_HAVE_SHA3_AND_WORTH_USING) { \
+        ctx->meth = sha3_ARMSHA3_md;                          \
+    } else {                                                  \
+        ctx->meth = sha3_generic_md;                          \
     }
 #else
-# define SHA3_SET_MD(uname, typ) ctx->meth = sha3_generic_md;
-# define KMAC_SET_MD(bitlen) ctx->meth = sha3_generic_md;
-# define SHAKE_SET_MD(uname, typ) ctx->meth = shake_generic_md;
+#define SHA3_SET_MD(uname, typ) ctx->meth = sha3_generic_md;
+#define KMAC_SET_MD(bitlen) ctx->meth = sha3_generic_md;
+#define SHAKE_SET_MD(uname, typ) ctx->meth = shake_generic_md;
 #endif /* S390_SHA3 */
 
-#define SHA3_newctx(typ, uname, name, bitlen, pad)                             \
-static OSSL_FUNC_digest_newctx_fn name##_newctx;                               \
-static void *name##_newctx(void *provctx)                                      \
-{                                                                              \
-    KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
-                                                : NULL;                        \
-                                                                               \
-    if (ctx == NULL)                                                           \
-        return NULL;                                                           \
-    ossl_sha3_init(ctx, pad, bitlen);                                          \
-    SHA3_SET_MD(uname, typ)                                                    \
-    return ctx;                                                                \
-}
+#define SHA3_newctx(typ, uname, name, bitlen, pad)                                  \
+    static OSSL_FUNC_digest_newctx_fn name##_newctx;                                \
+    static void *name##_newctx(void *provctx)                                       \
+    {                                                                               \
+        KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
+                                                     : NULL;                        \
+                                                                                    \
+        if (ctx == NULL)                                                            \
+            return NULL;                                                            \
+        ossl_sha3_init(ctx, pad, bitlen);                                           \
+        SHA3_SET_MD(uname, typ)                                                     \
+        return ctx;                                                                 \
+    }
 
-#define SHAKE_newctx(typ, uname, name, bitlen, pad)                            \
-static OSSL_FUNC_digest_newctx_fn name##_newctx;                               \
-static void *name##_newctx(void *provctx)                                      \
-{                                                                              \
-    KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx))\
-                                                : NULL;                        \
-                                                                               \
-    if (ctx == NULL)                                                           \
-        return NULL;                                                           \
-    ossl_sha3_init(ctx, pad, bitlen);                                          \
-    SHAKE_SET_MD(uname, typ)                                                   \
-    return ctx;                                                                \
-}
+#define SHAKE_newctx(typ, uname, name, bitlen, pad)                                 \
+    static OSSL_FUNC_digest_newctx_fn name##_newctx;                                \
+    static void *name##_newctx(void *provctx)                                       \
+    {                                                                               \
+        KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
+                                                     : NULL;                        \
+                                                                                    \
+        if (ctx == NULL)                                                            \
+            return NULL;                                                            \
+        ossl_sha3_init(ctx, pad, bitlen);                                           \
+        SHAKE_SET_MD(uname, typ)                                                    \
+        return ctx;                                                                 \
+    }
 
-#define KMAC_newctx(uname, bitlen, pad)                                        \
-static OSSL_FUNC_digest_newctx_fn uname##_newctx;                              \
-static void *uname##_newctx(void *provctx)                                     \
-{                                                                              \
-    KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
-                                                : NULL;                        \
-                                                                               \
-    if (ctx == NULL)                                                           \
-        return NULL;                                                           \
-    ossl_keccak_kmac_init(ctx, pad, bitlen);                                   \
-    KMAC_SET_MD(bitlen)                                                        \
-    return ctx;                                                                \
-}
+#define KMAC_newctx(uname, bitlen, pad)                                             \
+    static OSSL_FUNC_digest_newctx_fn uname##_newctx;                               \
+    static void *uname##_newctx(void *provctx)                                      \
+    {                                                                               \
+        KECCAK1600_CTX *ctx = ossl_prov_is_running() ? OPENSSL_zalloc(sizeof(*ctx)) \
+                                                     : NULL;                        \
+                                                                                    \
+        if (ctx == NULL)                                                            \
+            return NULL;                                                            \
+        ossl_keccak_kmac_init(ctx, pad, bitlen);                                    \
+        KMAC_SET_MD(bitlen)                                                         \
+        return ctx;                                                                 \
+    }
 
-#define PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags)   \
-PROV_FUNC_DIGEST_GET_PARAM(name, blksize, dgstsize, flags)                     \
-const OSSL_DISPATCH ossl_##name##_functions[] = {                              \
-    { OSSL_FUNC_DIGEST_NEWCTX, (void (*)(void))name##_newctx },                \
-    { OSSL_FUNC_DIGEST_UPDATE, (void (*)(void))keccak_update },                \
-    { OSSL_FUNC_DIGEST_FINAL, (void (*)(void))keccak_final },                  \
-    { OSSL_FUNC_DIGEST_FREECTX, (void (*)(void))keccak_freectx },              \
-    { OSSL_FUNC_DIGEST_DUPCTX, (void (*)(void))keccak_dupctx },                \
-    PROV_DISPATCH_FUNC_DIGEST_GET_PARAMS(name)
+#define PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags) \
+    PROV_FUNC_DIGEST_GET_PARAM(name, blksize, dgstsize, flags)               \
+    const OSSL_DISPATCH ossl_##name##_functions[] = {                        \
+        { OSSL_FUNC_DIGEST_NEWCTX, (void (*)(void))name##_newctx },          \
+        { OSSL_FUNC_DIGEST_UPDATE, (void (*)(void))keccak_update },          \
+        { OSSL_FUNC_DIGEST_FINAL, (void (*)(void))keccak_final },            \
+        { OSSL_FUNC_DIGEST_FREECTX, (void (*)(void))keccak_freectx },        \
+        { OSSL_FUNC_DIGEST_DUPCTX, (void (*)(void))keccak_dupctx },          \
+        PROV_DISPATCH_FUNC_DIGEST_GET_PARAMS(name)
 
-#define PROV_FUNC_SHA3_DIGEST(name, bitlen, blksize, dgstsize, flags)          \
-    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags),      \
-    { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init },                    \
-    PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
+#define PROV_FUNC_SHA3_DIGEST(name, bitlen, blksize, dgstsize, flags)     \
+    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags), \
+        { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init },           \
+        PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
 
-#define PROV_FUNC_SHAKE_DIGEST(name, bitlen, blksize, dgstsize, flags)         \
-    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags),      \
-    { OSSL_FUNC_DIGEST_SQUEEZE, (void (*)(void))shake_squeeze },               \
-    { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init_params },             \
-    { OSSL_FUNC_DIGEST_SET_CTX_PARAMS, (void (*)(void))shake_set_ctx_params }, \
-    { OSSL_FUNC_DIGEST_SETTABLE_CTX_PARAMS,                                    \
-     (void (*)(void))shake_settable_ctx_params },                              \
-    PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
+#define PROV_FUNC_SHAKE_DIGEST(name, bitlen, blksize, dgstsize, flags)             \
+    PROV_FUNC_SHA3_DIGEST_COMMON(name, bitlen, blksize, dgstsize, flags),          \
+        { OSSL_FUNC_DIGEST_SQUEEZE, (void (*)(void))shake_squeeze },               \
+        { OSSL_FUNC_DIGEST_INIT, (void (*)(void))keccak_init_params },             \
+        { OSSL_FUNC_DIGEST_SET_CTX_PARAMS, (void (*)(void))shake_set_ctx_params }, \
+        { OSSL_FUNC_DIGEST_SETTABLE_CTX_PARAMS,                                    \
+            (void (*)(void))shake_settable_ctx_params },                           \
+        PROV_DISPATCH_FUNC_DIGEST_CONSTRUCT_END
 
 static void keccak_freectx(void *vctx)
 {
     KECCAK1600_CTX *ctx = (KECCAK1600_CTX *)vctx;
 
-    OPENSSL_clear_free(ctx,  sizeof(*ctx));
+    OPENSSL_clear_free(ctx, sizeof(*ctx));
 }
 
 static void *keccak_dupctx(void *ctx)
@@ -545,11 +531,11 @@ static void *keccak_dupctx(void *ctx)
 }
 
 static const OSSL_PARAM known_shake_settable_ctx_params[] = {
-    {OSSL_DIGEST_PARAM_XOFLEN, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0},
+    { OSSL_DIGEST_PARAM_XOFLEN, OSSL_PARAM_UNSIGNED_INTEGER, NULL, 0, 0 },
     OSSL_PARAM_END
 };
 static const OSSL_PARAM *shake_settable_ctx_params(ossl_unused void *ctx,
-                                                   ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return known_shake_settable_ctx_params;
 }
@@ -572,28 +558,28 @@ static int shake_set_ctx_params(void *vctx, const OSSL_PARAM params[])
     return 1;
 }
 
-#define IMPLEMENT_SHA3_functions(bitlen)                                       \
-    SHA3_newctx(sha3, SHA3_##bitlen, sha3_##bitlen, bitlen, '\x06')            \
-    PROV_FUNC_SHA3_DIGEST(sha3_##bitlen, bitlen,                               \
-                          SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),         \
-                          SHA3_FLAGS)
+#define IMPLEMENT_SHA3_functions(bitlen)                            \
+    SHA3_newctx(sha3, SHA3_##bitlen, sha3_##bitlen, bitlen, '\x06') \
+        PROV_FUNC_SHA3_DIGEST(sha3_##bitlen, bitlen,                \
+            SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),            \
+            SHA3_FLAGS)
 
-#define IMPLEMENT_KECCAK_functions(bitlen)                                     \
-    SHA3_newctx(keccak, KECCAK_##bitlen, keccak_##bitlen, bitlen, '\x01')      \
-    PROV_FUNC_SHA3_DIGEST(keccak_##bitlen, bitlen,                             \
-                          SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),         \
-                          SHA3_FLAGS)
+#define IMPLEMENT_KECCAK_functions(bitlen)                                \
+    SHA3_newctx(keccak, KECCAK_##bitlen, keccak_##bitlen, bitlen, '\x01') \
+        PROV_FUNC_SHA3_DIGEST(keccak_##bitlen, bitlen,                    \
+            SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),                  \
+            SHA3_FLAGS)
 
-#define IMPLEMENT_SHAKE_functions(bitlen)                                      \
-    SHAKE_newctx(shake, SHAKE_##bitlen, shake_##bitlen, bitlen, '\x1f')        \
-    PROV_FUNC_SHAKE_DIGEST(shake_##bitlen, bitlen,                             \
-                          SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),         \
-                          SHAKE_FLAGS)
-#define IMPLEMENT_KMAC_functions(bitlen)                                       \
-    KMAC_newctx(keccak_kmac_##bitlen, bitlen, '\x04')                          \
-    PROV_FUNC_SHAKE_DIGEST(keccak_kmac_##bitlen, bitlen,                       \
-                           SHA3_BLOCKSIZE(bitlen), KMAC_MDSIZE(bitlen),        \
-                           KMAC_FLAGS)
+#define IMPLEMENT_SHAKE_functions(bitlen)                               \
+    SHAKE_newctx(shake, SHAKE_##bitlen, shake_##bitlen, bitlen, '\x1f') \
+        PROV_FUNC_SHAKE_DIGEST(shake_##bitlen, bitlen,                  \
+            SHA3_BLOCKSIZE(bitlen), SHA3_MDSIZE(bitlen),                \
+            SHAKE_FLAGS)
+#define IMPLEMENT_KMAC_functions(bitlen)                     \
+    KMAC_newctx(keccak_kmac_##bitlen, bitlen, '\x04')        \
+        PROV_FUNC_SHAKE_DIGEST(keccak_kmac_##bitlen, bitlen, \
+            SHA3_BLOCKSIZE(bitlen), KMAC_MDSIZE(bitlen),     \
+            KMAC_FLAGS)
 
 /* ossl_sha3_224_functions */
 IMPLEMENT_SHA3_functions(224)
