@@ -1,5 +1,5 @@
 /*
- * Copyright 2016-2024 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2016-2025 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -33,7 +33,7 @@
 #include "internal/params.h"
 
 #define HKDF_MAXBUF 2048
-#define HKDF_MAXINFO (32*1024)
+#define HKDF_MAXINFO (32 * 1024)
 
 static OSSL_FUNC_kdf_newctx_fn kdf_hkdf_new;
 static OSSL_FUNC_kdf_dupctx_fn kdf_hkdf_dup;
@@ -49,26 +49,26 @@ static OSSL_FUNC_kdf_settable_ctx_params_fn kdf_tls1_3_settable_ctx_params;
 static OSSL_FUNC_kdf_set_ctx_params_fn kdf_tls1_3_set_ctx_params;
 
 static int HKDF(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
-                const unsigned char *salt, size_t salt_len,
-                const unsigned char *key, size_t key_len,
-                const unsigned char *info, size_t info_len,
-                unsigned char *okm, size_t okm_len);
+    const unsigned char *salt, size_t salt_len,
+    const unsigned char *key, size_t key_len,
+    const unsigned char *info, size_t info_len,
+    unsigned char *okm, size_t okm_len);
 static int HKDF_Extract(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
-                        const unsigned char *salt, size_t salt_len,
-                        const unsigned char *ikm, size_t ikm_len,
-                        unsigned char *prk, size_t prk_len);
+    const unsigned char *salt, size_t salt_len,
+    const unsigned char *ikm, size_t ikm_len,
+    unsigned char *prk, size_t prk_len);
 static int HKDF_Expand(const EVP_MD *evp_md,
-                       const unsigned char *prk, size_t prk_len,
-                       const unsigned char *info, size_t info_len,
-                       unsigned char *okm, size_t okm_len);
+    const unsigned char *prk, size_t prk_len,
+    const unsigned char *info, size_t info_len,
+    unsigned char *okm, size_t okm_len);
 
 /* Settable context parameters that are common across HKDF and the TLS KDF */
-#define HKDF_COMMON_SETTABLES                                           \
-        OSSL_PARAM_utf8_string(OSSL_KDF_PARAM_MODE, NULL, 0),           \
-        OSSL_PARAM_int(OSSL_KDF_PARAM_MODE, NULL),                      \
-        OSSL_PARAM_utf8_string(OSSL_KDF_PARAM_PROPERTIES, NULL, 0),     \
-        OSSL_PARAM_utf8_string(OSSL_KDF_PARAM_DIGEST, NULL, 0),         \
-        OSSL_PARAM_octet_string(OSSL_KDF_PARAM_KEY, NULL, 0),           \
+#define HKDF_COMMON_SETTABLES                                       \
+    OSSL_PARAM_utf8_string(OSSL_KDF_PARAM_MODE, NULL, 0),           \
+        OSSL_PARAM_int(OSSL_KDF_PARAM_MODE, NULL),                  \
+        OSSL_PARAM_utf8_string(OSSL_KDF_PARAM_PROPERTIES, NULL, 0), \
+        OSSL_PARAM_utf8_string(OSSL_KDF_PARAM_DIGEST, NULL, 0),     \
+        OSSL_PARAM_octet_string(OSSL_KDF_PARAM_KEY, NULL, 0),       \
         OSSL_PARAM_octet_string(OSSL_KDF_PARAM_SALT, NULL, 0)
 
 typedef struct {
@@ -135,24 +135,24 @@ static void *kdf_hkdf_dup(void *vctx)
     dest = kdf_hkdf_new(src->provctx);
     if (dest != NULL) {
         if (!ossl_prov_memdup(src->salt, src->salt_len, &dest->salt,
-                              &dest->salt_len)
-                || !ossl_prov_memdup(src->key, src->key_len,
-                                     &dest->key , &dest->key_len)
-                || !ossl_prov_memdup(src->prefix, src->prefix_len,
-                                     &dest->prefix, &dest->prefix_len)
-                || !ossl_prov_memdup(src->label, src->label_len,
-                                     &dest->label, &dest->label_len)
-                || !ossl_prov_memdup(src->data, src->data_len,
-                                     &dest->data, &dest->data_len)
-                || !ossl_prov_memdup(src->info, src->info_len,
-                                     &dest->info, &dest->info_len)
-                || !ossl_prov_digest_copy(&dest->digest, &src->digest))
+                &dest->salt_len)
+            || !ossl_prov_memdup(src->key, src->key_len,
+                &dest->key, &dest->key_len)
+            || !ossl_prov_memdup(src->prefix, src->prefix_len,
+                &dest->prefix, &dest->prefix_len)
+            || !ossl_prov_memdup(src->label, src->label_len,
+                &dest->label, &dest->label_len)
+            || !ossl_prov_memdup(src->data, src->data_len,
+                &dest->data, &dest->data_len)
+            || !ossl_prov_memdup(src->info, src->info_len,
+                &dest->info, &dest->info_len)
+            || !ossl_prov_digest_copy(&dest->digest, &src->digest))
             goto err;
         dest->mode = src->mode;
     }
     return dest;
 
- err:
+err:
     kdf_hkdf_free(dest);
     return NULL;
 }
@@ -177,7 +177,7 @@ static size_t kdf_hkdf_size(KDF_HKDF *ctx)
 }
 
 static int kdf_hkdf_derive(void *vctx, unsigned char *key, size_t keylen,
-                           const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     KDF_HKDF *ctx = (KDF_HKDF *)vctx;
     OSSL_LIB_CTX *libctx = PROV_LIBCTX_OF(ctx->provctx);
@@ -204,15 +204,15 @@ static int kdf_hkdf_derive(void *vctx, unsigned char *key, size_t keylen,
     case EVP_KDF_HKDF_MODE_EXTRACT_AND_EXPAND:
     default:
         return HKDF(libctx, md, ctx->salt, ctx->salt_len,
-                    ctx->key, ctx->key_len, ctx->info, ctx->info_len, key, keylen);
+            ctx->key, ctx->key_len, ctx->info, ctx->info_len, key, keylen);
 
     case EVP_KDF_HKDF_MODE_EXTRACT_ONLY:
         return HKDF_Extract(libctx, md, ctx->salt, ctx->salt_len,
-                            ctx->key, ctx->key_len, key, keylen);
+            ctx->key, ctx->key_len, key, keylen);
 
     case EVP_KDF_HKDF_MODE_EXPAND_ONLY:
         return HKDF_Expand(md, ctx->key, ctx->key_len, ctx->info,
-                           ctx->info_len, key, keylen);
+            ctx->info_len, key, keylen);
     }
 }
 
@@ -258,18 +258,16 @@ static int hkdf_common_set_ctx_params(KDF_HKDF *ctx, const OSSL_PARAM params[])
         OPENSSL_clear_free(ctx->key, ctx->key_len);
         ctx->key = NULL;
         if (!OSSL_PARAM_get_octet_string(p, (void **)&ctx->key, 0,
-                                         &ctx->key_len))
+                &ctx->key_len))
             return 0;
     }
 
     if ((p = OSSL_PARAM_locate_const(params, OSSL_KDF_PARAM_SALT)) != NULL) {
-        if (p->data_size != 0 && p->data != NULL) {
-            OPENSSL_free(ctx->salt);
-            ctx->salt = NULL;
-            if (!OSSL_PARAM_get_octet_string(p, (void **)&ctx->salt, 0,
-                                             &ctx->salt_len))
-                return 0;
-        }
+        OPENSSL_free(ctx->salt);
+        ctx->salt = NULL;
+        if (!OSSL_PARAM_get_octet_string(p, (void **)&ctx->salt, 0,
+                &ctx->salt_len))
+            return 0;
     }
 
     return 1;
@@ -286,15 +284,16 @@ static int kdf_hkdf_set_ctx_params(void *vctx, const OSSL_PARAM params[])
         return 0;
 
     if (ossl_param_get1_concat_octet_string(params, OSSL_KDF_PARAM_INFO,
-                                            &ctx->info, &ctx->info_len,
-                                            HKDF_MAXINFO) == 0)
+            &ctx->info, &ctx->info_len,
+            HKDF_MAXINFO)
+        == 0)
         return 0;
 
     return 1;
 }
 
 static const OSSL_PARAM *kdf_hkdf_settable_ctx_params(ossl_unused void *ctx,
-                                                      ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_settable_ctx_params[] = {
         HKDF_COMMON_SETTABLES,
@@ -327,7 +326,7 @@ static int kdf_hkdf_get_ctx_params(void *vctx, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *kdf_hkdf_gettable_ctx_params(ossl_unused void *ctx,
-                                                      ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_gettable_ctx_params[] = {
         OSSL_PARAM_size_t(OSSL_KDF_PARAM_SIZE, NULL),
@@ -338,17 +337,17 @@ static const OSSL_PARAM *kdf_hkdf_gettable_ctx_params(ossl_unused void *ctx,
 }
 
 const OSSL_DISPATCH ossl_kdf_hkdf_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))kdf_hkdf_new },
-    { OSSL_FUNC_KDF_DUPCTX, (void(*)(void))kdf_hkdf_dup },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))kdf_hkdf_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))kdf_hkdf_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))kdf_hkdf_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))kdf_hkdf_new },
+    { OSSL_FUNC_KDF_DUPCTX, (void (*)(void))kdf_hkdf_dup },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))kdf_hkdf_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))kdf_hkdf_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))kdf_hkdf_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_hkdf_settable_ctx_params },
-    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void(*)(void))kdf_hkdf_set_ctx_params },
+        (void (*)(void))kdf_hkdf_settable_ctx_params },
+    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void (*)(void))kdf_hkdf_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_hkdf_gettable_ctx_params },
-    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void(*)(void))kdf_hkdf_get_ctx_params },
+        (void (*)(void))kdf_hkdf_gettable_ctx_params },
+    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void (*)(void))kdf_hkdf_get_ctx_params },
     OSSL_DISPATCH_END
 };
 
@@ -378,10 +377,10 @@ const OSSL_DISPATCH ossl_kdf_hkdf_functions[] = {
  *     HKDF-Expand(PRK, info, L) -> OKM
  */
 static int HKDF(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
-                const unsigned char *salt, size_t salt_len,
-                const unsigned char *ikm, size_t ikm_len,
-                const unsigned char *info, size_t info_len,
-                unsigned char *okm, size_t okm_len)
+    const unsigned char *salt, size_t salt_len,
+    const unsigned char *ikm, size_t ikm_len,
+    const unsigned char *info, size_t info_len,
+    unsigned char *okm, size_t okm_len)
 {
     unsigned char prk[EVP_MAX_MD_SIZE];
     int ret, sz;
@@ -394,7 +393,7 @@ static int HKDF(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
 
     /* Step 1: HKDF-Extract(salt, IKM) -> PRK */
     if (!HKDF_Extract(libctx, evp_md,
-                      salt, salt_len, ikm, ikm_len, prk, prk_len))
+            salt, salt_len, ikm, ikm_len, prk, prk_len))
         return 0;
 
     /* Step 2: HKDF-Expand(PRK, info, L) -> OKM */
@@ -429,9 +428,9 @@ static int HKDF(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
  *   PRK = HMAC-Hash(salt, IKM)
  */
 static int HKDF_Extract(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
-                        const unsigned char *salt, size_t salt_len,
-                        const unsigned char *ikm, size_t ikm_len,
-                        unsigned char *prk, size_t prk_len)
+    const unsigned char *salt, size_t salt_len,
+    const unsigned char *ikm, size_t ikm_len,
+    unsigned char *prk, size_t prk_len)
 {
     int sz = EVP_MD_get_size(evp_md);
 
@@ -442,9 +441,8 @@ static int HKDF_Extract(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
         return 0;
     }
     /* calc: PRK = HMAC-Hash(salt, IKM) */
-    return
-        EVP_Q_mac(libctx, "HMAC", NULL, EVP_MD_get0_name(evp_md), NULL, salt,
-                  salt_len, ikm, ikm_len, prk, EVP_MD_get_size(evp_md), NULL)
+    return EVP_Q_mac(libctx, "HMAC", NULL, EVP_MD_get0_name(evp_md), NULL, salt,
+               salt_len, ikm, ikm_len, prk, EVP_MD_get_size(evp_md), NULL)
         != NULL;
 }
 
@@ -488,9 +486,9 @@ static int HKDF_Extract(OSSL_LIB_CTX *libctx, const EVP_MD *evp_md,
  *   single octet.)
  */
 static int HKDF_Expand(const EVP_MD *evp_md,
-                       const unsigned char *prk, size_t prk_len,
-                       const unsigned char *info, size_t info_len,
-                       unsigned char *okm, size_t okm_len)
+    const unsigned char *prk, size_t prk_len,
+    const unsigned char *info, size_t info_len,
+    unsigned char *okm, size_t okm_len)
 {
     HMAC_CTX *hmac;
     int ret = 0, sz;
@@ -539,9 +537,7 @@ static int HKDF_Expand(const EVP_MD *evp_md,
         if (!HMAC_Final(hmac, prev, NULL))
             goto err;
 
-        copy_len = (dig_len > okm_len - done_len) ?
-                       okm_len - done_len :
-                       dig_len;
+        copy_len = (dig_len > okm_len - done_len) ? okm_len - done_len : dig_len;
 
         memcpy(okm + done_len, prev, copy_len);
 
@@ -549,7 +545,7 @@ static int HKDF_Expand(const EVP_MD *evp_md,
     }
     ret = 1;
 
- err:
+err:
     OPENSSL_cleanse(prev, sizeof(prev));
     HMAC_CTX_free(hmac);
     return ret;
@@ -568,11 +564,11 @@ static int HKDF_Expand(const EVP_MD *evp_md,
  * The |data| value may be zero length. Returns 1 on success and 0 on failure.
  */
 static int prov_tls13_hkdf_expand(const EVP_MD *md,
-                                  const unsigned char *key, size_t keylen,
-                                  const unsigned char *prefix, size_t prefixlen,
-                                  const unsigned char *label, size_t labellen,
-                                  const unsigned char *data, size_t datalen,
-                                  unsigned char *out, size_t outlen)
+    const unsigned char *key, size_t keylen,
+    const unsigned char *prefix, size_t prefixlen,
+    const unsigned char *label, size_t labellen,
+    const unsigned char *data, size_t datalen,
+    unsigned char *out, size_t outlen)
 {
     size_t hkdflabellen;
     unsigned char hkdflabel[HKDF_MAXBUF];
@@ -585,33 +581,33 @@ static int prov_tls13_hkdf_expand(const EVP_MD *md,
      * which should always be sufficient.
      */
     if (!WPACKET_init_static_len(&pkt, hkdflabel, sizeof(hkdflabel), 0)
-            || !WPACKET_put_bytes_u16(&pkt, outlen)
-            || !WPACKET_start_sub_packet_u8(&pkt)
-            || !WPACKET_memcpy(&pkt, prefix, prefixlen)
-            || !WPACKET_memcpy(&pkt, label, labellen)
-            || !WPACKET_close(&pkt)
-            || !WPACKET_sub_memcpy_u8(&pkt, data, (data == NULL) ? 0 : datalen)
-            || !WPACKET_get_total_written(&pkt, &hkdflabellen)
-            || !WPACKET_finish(&pkt)) {
+        || !WPACKET_put_bytes_u16(&pkt, outlen)
+        || !WPACKET_start_sub_packet_u8(&pkt)
+        || !WPACKET_memcpy(&pkt, prefix, prefixlen)
+        || !WPACKET_memcpy(&pkt, label, labellen)
+        || !WPACKET_close(&pkt)
+        || !WPACKET_sub_memcpy_u8(&pkt, data, (data == NULL) ? 0 : datalen)
+        || !WPACKET_get_total_written(&pkt, &hkdflabellen)
+        || !WPACKET_finish(&pkt)) {
         WPACKET_cleanup(&pkt);
         return 0;
     }
 
     return HKDF_Expand(md, key, keylen, hkdflabel, hkdflabellen,
-                       out, outlen);
+        out, outlen);
 }
 
 static int prov_tls13_hkdf_generate_secret(OSSL_LIB_CTX *libctx,
-                                           const EVP_MD *md,
-                                           const unsigned char *prevsecret,
-                                           size_t prevsecretlen,
-                                           const unsigned char *insecret,
-                                           size_t insecretlen,
-                                           const unsigned char *prefix,
-                                           size_t prefixlen,
-                                           const unsigned char *label,
-                                           size_t labellen,
-                                           unsigned char *out, size_t outlen)
+    const EVP_MD *md,
+    const unsigned char *prevsecret,
+    size_t prevsecretlen,
+    const unsigned char *insecret,
+    size_t insecretlen,
+    const unsigned char *prefix,
+    size_t prefixlen,
+    const unsigned char *label,
+    size_t labellen,
+    unsigned char *out, size_t outlen)
 {
     size_t mdlen;
     int ret;
@@ -638,8 +634,8 @@ static int prov_tls13_hkdf_generate_secret(OSSL_LIB_CTX *libctx,
 
         /* The pre-extract derive step uses a hash of no messages */
         if (mctx == NULL
-                || EVP_DigestInit_ex(mctx, md, NULL) <= 0
-                || EVP_DigestFinal_ex(mctx, hash, NULL) <= 0) {
+            || EVP_DigestInit_ex(mctx, md, NULL) <= 0
+            || EVP_DigestFinal_ex(mctx, hash, NULL) <= 0) {
             EVP_MD_CTX_free(mctx);
             return 0;
         }
@@ -647,15 +643,15 @@ static int prov_tls13_hkdf_generate_secret(OSSL_LIB_CTX *libctx,
 
         /* Generate the pre-extract secret */
         if (!prov_tls13_hkdf_expand(md, prevsecret, prevsecretlen,
-                                    prefix, prefixlen, label, labellen,
-                                    hash, mdlen, preextractsec, mdlen))
+                prefix, prefixlen, label, labellen,
+                hash, mdlen, preextractsec, mdlen))
             return 0;
         prevsecret = preextractsec;
         prevsecretlen = mdlen;
     }
 
     ret = HKDF_Extract(libctx, md, prevsecret, prevsecretlen,
-                       insecret, insecretlen, out, outlen);
+        insecret, insecretlen, out, outlen);
 
     if (prevsecret == preextractsec)
         OPENSSL_cleanse(preextractsec, mdlen);
@@ -663,7 +659,7 @@ static int prov_tls13_hkdf_generate_secret(OSSL_LIB_CTX *libctx,
 }
 
 static int kdf_tls1_3_derive(void *vctx, unsigned char *key, size_t keylen,
-                             const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     KDF_HKDF *ctx = (KDF_HKDF *)vctx;
     const EVP_MD *md;
@@ -683,19 +679,19 @@ static int kdf_tls1_3_derive(void *vctx, unsigned char *key, size_t keylen,
 
     case EVP_KDF_HKDF_MODE_EXTRACT_ONLY:
         return prov_tls13_hkdf_generate_secret(PROV_LIBCTX_OF(ctx->provctx),
-                                               md,
-                                               ctx->salt, ctx->salt_len,
-                                               ctx->key, ctx->key_len,
-                                               ctx->prefix, ctx->prefix_len,
-                                               ctx->label, ctx->label_len,
-                                               key, keylen);
+            md,
+            ctx->salt, ctx->salt_len,
+            ctx->key, ctx->key_len,
+            ctx->prefix, ctx->prefix_len,
+            ctx->label, ctx->label_len,
+            key, keylen);
 
     case EVP_KDF_HKDF_MODE_EXPAND_ONLY:
         return prov_tls13_hkdf_expand(md, ctx->key, ctx->key_len,
-                                      ctx->prefix, ctx->prefix_len,
-                                      ctx->label, ctx->label_len,
-                                      ctx->data, ctx->data_len,
-                                      key, keylen);
+            ctx->prefix, ctx->prefix_len,
+            ctx->label, ctx->label_len,
+            ctx->data, ctx->data_len,
+            key, keylen);
     }
 }
 
@@ -719,7 +715,7 @@ static int kdf_tls1_3_set_ctx_params(void *vctx, const OSSL_PARAM params[])
         OPENSSL_free(ctx->prefix);
         ctx->prefix = NULL;
         if (!OSSL_PARAM_get_octet_string(p, (void **)&ctx->prefix, 0,
-                                         &ctx->prefix_len))
+                &ctx->prefix_len))
             return 0;
     }
 
@@ -727,21 +723,21 @@ static int kdf_tls1_3_set_ctx_params(void *vctx, const OSSL_PARAM params[])
         OPENSSL_free(ctx->label);
         ctx->label = NULL;
         if (!OSSL_PARAM_get_octet_string(p, (void **)&ctx->label, 0,
-                                         &ctx->label_len))
+                &ctx->label_len))
             return 0;
     }
 
     OPENSSL_clear_free(ctx->data, ctx->data_len);
     ctx->data = NULL;
     if ((p = OSSL_PARAM_locate_const(params, OSSL_KDF_PARAM_DATA)) != NULL
-            && !OSSL_PARAM_get_octet_string(p, (void **)&ctx->data, 0,
-                                            &ctx->data_len))
+        && !OSSL_PARAM_get_octet_string(p, (void **)&ctx->data, 0,
+            &ctx->data_len))
         return 0;
     return 1;
 }
 
 static const OSSL_PARAM *kdf_tls1_3_settable_ctx_params(ossl_unused void *ctx,
-                                                        ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_settable_ctx_params[] = {
         HKDF_COMMON_SETTABLES,
@@ -754,16 +750,16 @@ static const OSSL_PARAM *kdf_tls1_3_settable_ctx_params(ossl_unused void *ctx,
 }
 
 const OSSL_DISPATCH ossl_kdf_tls1_3_kdf_functions[] = {
-    { OSSL_FUNC_KDF_NEWCTX, (void(*)(void))kdf_hkdf_new },
-    { OSSL_FUNC_KDF_DUPCTX, (void(*)(void))kdf_hkdf_dup },
-    { OSSL_FUNC_KDF_FREECTX, (void(*)(void))kdf_hkdf_free },
-    { OSSL_FUNC_KDF_RESET, (void(*)(void))kdf_hkdf_reset },
-    { OSSL_FUNC_KDF_DERIVE, (void(*)(void))kdf_tls1_3_derive },
+    { OSSL_FUNC_KDF_NEWCTX, (void (*)(void))kdf_hkdf_new },
+    { OSSL_FUNC_KDF_DUPCTX, (void (*)(void))kdf_hkdf_dup },
+    { OSSL_FUNC_KDF_FREECTX, (void (*)(void))kdf_hkdf_free },
+    { OSSL_FUNC_KDF_RESET, (void (*)(void))kdf_hkdf_reset },
+    { OSSL_FUNC_KDF_DERIVE, (void (*)(void))kdf_tls1_3_derive },
     { OSSL_FUNC_KDF_SETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_tls1_3_settable_ctx_params },
-    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void(*)(void))kdf_tls1_3_set_ctx_params },
+        (void (*)(void))kdf_tls1_3_settable_ctx_params },
+    { OSSL_FUNC_KDF_SET_CTX_PARAMS, (void (*)(void))kdf_tls1_3_set_ctx_params },
     { OSSL_FUNC_KDF_GETTABLE_CTX_PARAMS,
-      (void(*)(void))kdf_hkdf_gettable_ctx_params },
-    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void(*)(void))kdf_hkdf_get_ctx_params },
+        (void (*)(void))kdf_hkdf_gettable_ctx_params },
+    { OSSL_FUNC_KDF_GET_CTX_PARAMS, (void (*)(void))kdf_hkdf_get_ctx_params },
     OSSL_DISPATCH_END
 };
