@@ -46,7 +46,7 @@ static OSSL_FUNC_keymgmt_export_types_fn dsa_export_types;
 static OSSL_FUNC_keymgmt_dup_fn dsa_dup;
 
 #define DSA_DEFAULT_MD "SHA256"
-#define DSA_POSSIBLE_SELECTIONS                                                \
+#define DSA_POSSIBLE_SELECTIONS \
     (OSSL_KEYMGMT_SELECT_KEYPAIR | OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS)
 
 struct dsa_gen_ctx {
@@ -68,13 +68,12 @@ struct dsa_gen_ctx {
     OSSL_CALLBACK *cb;
     void *cbarg;
 };
-typedef struct dh_name2id_st{
+typedef struct dh_name2id_st {
     const char *name;
     int id;
 } DSA_GENTYPE_NAME2ID;
 
-static const DSA_GENTYPE_NAME2ID dsatype2id[]=
-{
+static const DSA_GENTYPE_NAME2ID dsatype2id[] = {
 #ifdef FIPS_MODULE
     { "default", DSA_PARAMGEN_TYPE_FIPS_186_4 },
 #else
@@ -96,7 +95,7 @@ static int dsa_gen_type_name2id(const char *name)
 }
 
 static int dsa_key_todata(DSA *dsa, OSSL_PARAM_BLD *bld, OSSL_PARAM params[],
-                          int include_private)
+    int include_private)
 {
     const BIGNUM *priv = NULL, *pub = NULL;
 
@@ -203,8 +202,7 @@ static int dsa_import(void *keydata, int selection, const OSSL_PARAM params[])
     ok = ok && ossl_dsa_ffc_params_fromdata(dsa, params);
 
     if ((selection & OSSL_KEYMGMT_SELECT_KEYPAIR) != 0) {
-        int include_private =
-            selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
+        int include_private = selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
 
         ok = ok && ossl_dsa_key_fromdata(dsa, params, include_private);
     }
@@ -213,7 +211,7 @@ static int dsa_import(void *keydata, int selection, const OSSL_PARAM params[])
 }
 
 static int dsa_export(void *keydata, int selection, OSSL_CALLBACK *param_cb,
-                      void *cbarg)
+    void *cbarg)
 {
     DSA *dsa = keydata;
     OSSL_PARAM_BLD *tmpl;
@@ -233,8 +231,7 @@ static int dsa_export(void *keydata, int selection, OSSL_CALLBACK *param_cb,
     if ((selection & OSSL_KEYMGMT_SELECT_ALL_PARAMETERS) != 0)
         ok = ok && ossl_ffc_params_todata(ossl_dsa_get0_params(dsa), tmpl, NULL);
     if ((selection & OSSL_KEYMGMT_SELECT_KEYPAIR) != 0) {
-        int include_private =
-            selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
+        int include_private = selection & OSSL_KEYMGMT_SELECT_PRIVATE_KEY ? 1 : 0;
 
         ok = ok && dsa_key_todata(dsa, tmpl, NULL, include_private);
     }
@@ -253,18 +250,18 @@ err:
 
 /* IMEXPORT = IMPORT + EXPORT */
 
-# define DSA_IMEXPORTABLE_PARAMETERS                                           \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_P, NULL, 0),                             \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_Q, NULL, 0),                             \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_G, NULL, 0),                             \
-    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_COFACTOR, NULL, 0),                      \
-    OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_GINDEX, NULL),                          \
-    OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_PCOUNTER, NULL),                        \
-    OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_H, NULL),                               \
-    OSSL_PARAM_octet_string(OSSL_PKEY_PARAM_FFC_SEED, NULL, 0)
-# define DSA_IMEXPORTABLE_PUBLIC_KEY                    \
+#define DSA_IMEXPORTABLE_PARAMETERS                           \
+    OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_P, NULL, 0),            \
+        OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_Q, NULL, 0),        \
+        OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_G, NULL, 0),        \
+        OSSL_PARAM_BN(OSSL_PKEY_PARAM_FFC_COFACTOR, NULL, 0), \
+        OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_GINDEX, NULL),     \
+        OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_PCOUNTER, NULL),   \
+        OSSL_PARAM_int(OSSL_PKEY_PARAM_FFC_H, NULL),          \
+        OSSL_PARAM_octet_string(OSSL_PKEY_PARAM_FFC_SEED, NULL, 0)
+#define DSA_IMEXPORTABLE_PUBLIC_KEY \
     OSSL_PARAM_BN(OSSL_PKEY_PARAM_PUB_KEY, NULL, 0)
-# define DSA_IMEXPORTABLE_PRIVATE_KEY                   \
+#define DSA_IMEXPORTABLE_PRIVATE_KEY \
     OSSL_PARAM_BN(OSSL_PKEY_PARAM_PRIV_KEY, NULL, 0)
 static const OSSL_PARAM dsa_all_types[] = {
     DSA_IMEXPORTABLE_PARAMETERS,
@@ -282,10 +279,10 @@ static const OSSL_PARAM dsa_key_types[] = {
     OSSL_PARAM_END
 };
 static const OSSL_PARAM *dsa_types[] = {
-    NULL,                        /* Index 0 = none of them */
-    dsa_parameter_types,          /* Index 1 = parameter types */
-    dsa_key_types,                /* Index 2 = key types */
-    dsa_all_types                 /* Index 3 = 1 + 2 */
+    NULL, /* Index 0 = none of them */
+    dsa_parameter_types, /* Index 1 = parameter types */
+    dsa_key_types, /* Index 2 = key types */
+    dsa_all_types /* Index 3 = 1 + 2 */
 };
 
 static const OSSL_PARAM *dsa_imexport_types(int selection)
@@ -327,7 +324,7 @@ static ossl_inline int dsa_get_params(void *key, OSSL_PARAM params[])
         && !OSSL_PARAM_set_utf8_string(p, DSA_DEFAULT_MD))
         return 0;
     return ossl_ffc_params_todata(ossl_dsa_get0_params(dsa), NULL, params)
-           && dsa_key_todata(dsa, NULL, params, 1);
+        && dsa_key_todata(dsa, NULL, params, 1);
 }
 
 static const OSSL_PARAM dsa_params[] = {
@@ -403,7 +400,7 @@ static int dsa_validate(const void *keydata, int selection, int checktype)
 }
 
 static void *dsa_gen_init(void *provctx, int selection,
-                          const OSSL_PARAM params[])
+    const OSSL_PARAM params[])
 {
     OSSL_LIB_CTX *libctx = PROV_LIBCTX_OF(provctx);
     struct dsa_gen_ctx *gctx = NULL;
@@ -444,7 +441,7 @@ static int dsa_gen_set_template(void *genctx, void *templ)
 }
 
 static int dsa_set_gen_seed(struct dsa_gen_ctx *gctx, unsigned char *seed,
-                            size_t seedlen)
+    size_t seedlen)
 {
     OPENSSL_clear_free(gctx->seed, gctx->seedlen);
     gctx->seed = NULL;
@@ -462,20 +459,28 @@ static int dsa_gen_set_params(void *genctx, const OSSL_PARAM params[])
 {
     struct dsa_gen_ctx *gctx = genctx;
     const OSSL_PARAM *p;
+    int gen_type = -1;
 
     if (gctx == NULL)
         return 0;
     if (params == NULL)
         return 1;
 
-
     p = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_FFC_TYPE);
     if (p != NULL) {
         if (p->data_type != OSSL_PARAM_UTF8_STRING
-            || ((gctx->gen_type = dsa_gen_type_name2id(p->data)) == -1)) {
+            || ((gen_type = dsa_gen_type_name2id(p->data)) == -1)) {
             ERR_raise(ERR_LIB_PROV, ERR_R_PASSED_INVALID_ARGUMENT);
             return 0;
         }
+
+        /*
+         * Only assign context gen_type if it was set by dsa_gen_type_name2id
+         * must be in range:
+         * DSA_PARAMGEN_TYPE_FIPS_186_4 <= gen_type <= DSA_PARAMGEN_TYPE_FIPS_DEFAULT
+         */
+        if (gen_type != -1)
+            gctx->gen_type = gen_type;
     }
     p = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_FFC_GINDEX);
     if (p != NULL
@@ -493,7 +498,7 @@ static int dsa_gen_set_params(void *genctx, const OSSL_PARAM params[])
     if (p != NULL
         && (p->data_type != OSSL_PARAM_OCTET_STRING
             || !dsa_set_gen_seed(gctx, p->data, p->data_size)))
-            return 0;
+        return 0;
     if ((p = OSSL_PARAM_locate_const(params, OSSL_PKEY_PARAM_FFC_PBITS)) != NULL
         && !OSSL_PARAM_get_size_t(p, &gctx->pbits))
         return 0;
@@ -522,7 +527,7 @@ static int dsa_gen_set_params(void *genctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *dsa_gen_settable_params(ossl_unused void *genctx,
-                                                 ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static OSSL_PARAM settable[] = {
         OSSL_PARAM_utf8_string(OSSL_PKEY_PARAM_FFC_TYPE, NULL, 0),
@@ -565,8 +570,20 @@ static void *dsa_gen(void *genctx, OSSL_CALLBACK *osslcb, void *cbarg)
         return NULL;
 
     if (gctx->gen_type == DSA_PARAMGEN_TYPE_FIPS_DEFAULT)
-        gctx->gen_type = (gctx->pbits >= 2048 ? DSA_PARAMGEN_TYPE_FIPS_186_4 :
-                                                DSA_PARAMGEN_TYPE_FIPS_186_2);
+        gctx->gen_type = (gctx->pbits >= 2048 ? DSA_PARAMGEN_TYPE_FIPS_186_4 : DSA_PARAMGEN_TYPE_FIPS_186_2);
+
+    /*
+     * Do a bounds check on context gen_type. Must be in range:
+     * DSA_PARAMGEN_TYPE_FIPS_186_4 <= gen_type <= DSA_PARAMGEN_TYPE_FIPS_DEFAULT
+     * Noted here as this needs to be adjusted if a new type is
+     * added.
+     */
+    if (!ossl_assert((gctx->gen_type >= DSA_PARAMGEN_TYPE_FIPS_186_4)
+            && (gctx->gen_type <= DSA_PARAMGEN_TYPE_FIPS_DEFAULT))) {
+        ERR_raise_data(ERR_LIB_PROV, ERR_R_INTERNAL_ERROR,
+            "gen_type set to unsupported value %d", gctx->gen_type);
+        goto end;
+    }
 
     gctx->cb = osslcb;
     gctx->cbarg = cbarg;
@@ -595,13 +612,14 @@ static void *dsa_gen(void *genctx, OSSL_CALLBACK *osslcb, void *cbarg)
 
     if ((gctx->selection & OSSL_KEYMGMT_SELECT_DOMAIN_PARAMETERS) != 0) {
 
-         if (ossl_dsa_generate_ffc_parameters(dsa, gctx->gen_type,
-                                              gctx->pbits, gctx->qbits,
-                                              gencb) <= 0)
-             goto end;
+        if (ossl_dsa_generate_ffc_parameters(dsa, gctx->gen_type,
+                gctx->pbits, gctx->qbits,
+                gencb)
+            <= 0)
+            goto end;
     }
     ossl_ffc_params_enable_flags(ffc, FFC_PARAM_FLAG_VALIDATE_LEGACY,
-                                 gctx->gen_type == DSA_PARAMGEN_TYPE_FIPS_186_2);
+        gctx->gen_type == DSA_PARAMGEN_TYPE_FIPS_186_2);
     if ((gctx->selection & OSSL_KEYMGMT_SELECT_KEYPAIR) != 0) {
         if (ffc->p == NULL
             || ffc->q == NULL
@@ -660,13 +678,13 @@ const OSSL_DISPATCH ossl_dsa_keymgmt_functions[] = {
     { OSSL_FUNC_KEYMGMT_GEN_SET_TEMPLATE, (void (*)(void))dsa_gen_set_template },
     { OSSL_FUNC_KEYMGMT_GEN_SET_PARAMS, (void (*)(void))dsa_gen_set_params },
     { OSSL_FUNC_KEYMGMT_GEN_SETTABLE_PARAMS,
-      (void (*)(void))dsa_gen_settable_params },
+        (void (*)(void))dsa_gen_settable_params },
     { OSSL_FUNC_KEYMGMT_GEN, (void (*)(void))dsa_gen },
     { OSSL_FUNC_KEYMGMT_GEN_CLEANUP, (void (*)(void))dsa_gen_cleanup },
     { OSSL_FUNC_KEYMGMT_LOAD, (void (*)(void))dsa_load },
     { OSSL_FUNC_KEYMGMT_FREE, (void (*)(void))dsa_freedata },
-    { OSSL_FUNC_KEYMGMT_GET_PARAMS, (void (*) (void))dsa_get_params },
-    { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (void (*) (void))dsa_gettable_params },
+    { OSSL_FUNC_KEYMGMT_GET_PARAMS, (void (*)(void))dsa_get_params },
+    { OSSL_FUNC_KEYMGMT_GETTABLE_PARAMS, (void (*)(void))dsa_gettable_params },
     { OSSL_FUNC_KEYMGMT_HAS, (void (*)(void))dsa_has },
     { OSSL_FUNC_KEYMGMT_MATCH, (void (*)(void))dsa_match },
     { OSSL_FUNC_KEYMGMT_VALIDATE, (void (*)(void))dsa_validate },
