@@ -49,7 +49,7 @@ static OSSL_FUNC_mac_final_fn hmac_final;
 /* typedef EVP_MAC_IMPL */
 struct hmac_data_st {
     void *provctx;
-    HMAC_CTX *ctx;               /* HMAC context */
+    HMAC_CTX *ctx; /* HMAC context */
     PROV_DIGEST digest;
     unsigned char *key;
     size_t keylen;
@@ -140,7 +140,7 @@ static int hmac_block_size(struct hmac_data_st *macctx)
 }
 
 static int hmac_setkey(struct hmac_data_st *macctx,
-                       const unsigned char *key, size_t keylen)
+    const unsigned char *key, size_t keylen)
 {
     const EVP_MD *digest;
 
@@ -159,12 +159,12 @@ static int hmac_setkey(struct hmac_data_st *macctx,
     /* HMAC_Init_ex doesn't tolerate all zero params, so we must be careful */
     if (key != NULL || (macctx->tls_data_size == 0 && digest != NULL))
         return HMAC_Init_ex(macctx->ctx, key, keylen, digest,
-                            ossl_prov_digest_engine(&macctx->digest));
+            ossl_prov_digest_engine(&macctx->digest));
     return 1;
 }
 
 static int hmac_init(void *vmacctx, const unsigned char *key,
-                     size_t keylen, const OSSL_PARAM params[])
+    size_t keylen, const OSSL_PARAM params[])
 {
     struct hmac_data_st *macctx = vmacctx;
 
@@ -179,7 +179,7 @@ static int hmac_init(void *vmacctx, const unsigned char *key,
 }
 
 static int hmac_update(void *vmacctx, const unsigned char *data,
-                       size_t datalen)
+    size_t datalen)
 {
     struct hmac_data_st *macctx = vmacctx;
 
@@ -198,22 +198,22 @@ static int hmac_update(void *vmacctx, const unsigned char *data,
             return 0;
 
         return ssl3_cbc_digest_record(ossl_prov_digest_md(&macctx->digest),
-                                      macctx->tls_mac_out,
-                                      &macctx->tls_mac_out_size,
-                                      macctx->tls_header,
-                                      data,
-                                      datalen,
-                                      macctx->tls_data_size,
-                                      macctx->key,
-                                      macctx->keylen,
-                                      0);
+            macctx->tls_mac_out,
+            &macctx->tls_mac_out_size,
+            macctx->tls_header,
+            data,
+            datalen,
+            macctx->tls_data_size,
+            macctx->key,
+            macctx->keylen,
+            0);
     }
 
     return HMAC_Update(macctx->ctx, data, datalen);
 }
 
 static int hmac_final(void *vmacctx, unsigned char *out, size_t *outl,
-                      size_t outsize)
+    size_t outsize)
 {
     unsigned int hlen;
     struct hmac_data_st *macctx = vmacctx;
@@ -240,7 +240,7 @@ static const OSSL_PARAM known_gettable_ctx_params[] = {
     OSSL_PARAM_END
 };
 static const OSSL_PARAM *hmac_gettable_ctx_params(ossl_unused void *ctx,
-                                                  ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return known_gettable_ctx_params;
 }
@@ -251,11 +251,11 @@ static int hmac_get_ctx_params(void *vmacctx, OSSL_PARAM params[])
     OSSL_PARAM *p;
 
     if ((p = OSSL_PARAM_locate(params, OSSL_MAC_PARAM_SIZE)) != NULL
-            && !OSSL_PARAM_set_size_t(p, hmac_size(macctx)))
+        && !OSSL_PARAM_set_size_t(p, hmac_size(macctx)))
         return 0;
 
     if ((p = OSSL_PARAM_locate(params, OSSL_MAC_PARAM_BLOCK_SIZE)) != NULL
-            && !OSSL_PARAM_set_int(p, hmac_block_size(macctx)))
+        && !OSSL_PARAM_set_int(p, hmac_block_size(macctx)))
         return 0;
 
     return 1;
@@ -271,7 +271,7 @@ static const OSSL_PARAM known_settable_ctx_params[] = {
     OSSL_PARAM_END
 };
 static const OSSL_PARAM *hmac_settable_ctx_params(ossl_unused void *ctx,
-                                                  ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return known_settable_ctx_params;
 }
@@ -299,7 +299,8 @@ static int hmac_set_ctx_params(void *vmacctx, const OSSL_PARAM params[])
     }
 
     if ((p = OSSL_PARAM_locate_const(params,
-                                     OSSL_MAC_PARAM_TLS_DATA_SIZE)) != NULL) {
+             OSSL_MAC_PARAM_TLS_DATA_SIZE))
+        != NULL) {
         if (!OSSL_PARAM_get_size_t(p, &macctx->tls_data_size))
             return 0;
     }
@@ -314,10 +315,10 @@ const OSSL_DISPATCH ossl_hmac_functions[] = {
     { OSSL_FUNC_MAC_UPDATE, (void (*)(void))hmac_update },
     { OSSL_FUNC_MAC_FINAL, (void (*)(void))hmac_final },
     { OSSL_FUNC_MAC_GETTABLE_CTX_PARAMS,
-      (void (*)(void))hmac_gettable_ctx_params },
+        (void (*)(void))hmac_gettable_ctx_params },
     { OSSL_FUNC_MAC_GET_CTX_PARAMS, (void (*)(void))hmac_get_ctx_params },
     { OSSL_FUNC_MAC_SETTABLE_CTX_PARAMS,
-      (void (*)(void))hmac_settable_ctx_params },
+        (void (*)(void))hmac_settable_ctx_params },
     { OSSL_FUNC_MAC_SET_CTX_PARAMS, (void (*)(void))hmac_set_ctx_params },
     OSSL_DISPATCH_END
 };
