@@ -41,7 +41,7 @@
 static const char ossl_pers_string[] = DRBG_DEFAULT_PERS_STRING;
 
 static const OSSL_DISPATCH *find_call(const OSSL_DISPATCH *dispatch,
-                                      int function);
+    int function);
 
 static int rand_drbg_restart(PROV_DRBG *drbg);
 
@@ -66,8 +66,8 @@ static int ossl_drbg_lock_parent(PROV_DRBG *drbg)
     void *parent = drbg->parent;
 
     if (parent != NULL
-            && drbg->parent_lock != NULL
-            && !drbg->parent_lock(parent)) {
+        && drbg->parent_lock != NULL
+        && !drbg->parent_lock(parent)) {
         ERR_raise(ERR_LIB_PROV, PROV_R_PARENT_LOCKING_NOT_ENABLED);
         return 0;
     }
@@ -123,7 +123,7 @@ static unsigned int get_parent_reseed_count(PROV_DRBG *drbg)
     ossl_drbg_unlock_parent(drbg);
     return r;
 
- err:
+err:
     r = tsan_load(&drbg->reseed_counter) - 2;
     if (r == 0)
         r = UINT_MAX;
@@ -143,9 +143,9 @@ static unsigned int get_parent_reseed_count(PROV_DRBG *drbg)
  * its entropy will be used up first.
  */
 size_t ossl_drbg_get_seed(void *vdrbg, unsigned char **pout,
-                          int entropy, size_t min_len,
-                          size_t max_len, int prediction_resistance,
-                          const unsigned char *adin, size_t adin_len)
+    int entropy, size_t min_len,
+    size_t max_len, int prediction_resistance,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
     size_t bytes_needed;
@@ -173,8 +173,8 @@ size_t ossl_drbg_get_seed(void *vdrbg, unsigned char **pout,
      *       intentional and correct here.
      */
     if (!ossl_prov_drbg_generate(drbg, buffer, bytes_needed,
-                                 drbg->strength, prediction_resistance,
-                                 (unsigned char *)&drbg, sizeof(drbg))) {
+            drbg->strength, prediction_resistance,
+            (unsigned char *)&drbg, sizeof(drbg))) {
         OPENSSL_secure_clear_free(buffer, bytes_needed);
         ERR_raise(ERR_LIB_PROV, PROV_R_GENERATE_ERROR);
         return 0;
@@ -185,14 +185,14 @@ size_t ossl_drbg_get_seed(void *vdrbg, unsigned char **pout,
 
 /* Implements the cleanup_entropy() callback */
 void ossl_drbg_clear_seed(ossl_unused void *vdrbg,
-                          unsigned char *out, size_t outlen)
+    unsigned char *out, size_t outlen)
 {
     OPENSSL_secure_clear_free(out, outlen);
 }
 
 static size_t get_entropy(PROV_DRBG *drbg, unsigned char **pout, int entropy,
-                          size_t min_len, size_t max_len,
-                          int prediction_resistance)
+    size_t min_len, size_t max_len,
+    int prediction_resistance)
 {
     size_t bytes;
     unsigned int p_str;
@@ -200,7 +200,7 @@ static size_t get_entropy(PROV_DRBG *drbg, unsigned char **pout, int entropy,
     if (drbg->parent == NULL)
 #ifdef FIPS_MODULE
         return ossl_crngt_get_entropy(drbg, pout, entropy, min_len, max_len,
-                                      prediction_resistance);
+            prediction_resistance);
 #else
         /*
          * In normal use (i.e. OpenSSL's own uses), this is never called.
@@ -208,7 +208,7 @@ static size_t get_entropy(PROV_DRBG *drbg, unsigned char **pout, int entropy,
          * they always have a parent.  This remains purely for legacy reasons.
          */
         return ossl_prov_get_entropy(drbg->provctx, pout, entropy, min_len,
-                                     max_len);
+            max_len);
 #endif
 
     if (drbg->parent_get_seed == NULL) {
@@ -243,8 +243,8 @@ static size_t get_entropy(PROV_DRBG *drbg, unsigned char **pout, int entropy,
      *       intentional and correct here.
      */
     bytes = drbg->parent_get_seed(drbg->parent, pout, drbg->strength,
-                                  min_len, max_len, prediction_resistance,
-                                  (unsigned char *)&drbg, sizeof(drbg));
+        min_len, max_len, prediction_resistance,
+        (unsigned char *)&drbg, sizeof(drbg));
     ossl_drbg_unlock_parent(drbg);
     return bytes;
 }
@@ -308,7 +308,7 @@ void ossl_prov_drbg_nonce_ctx_free(void *vdngbl)
 
 /* Get a nonce from the operating system */
 static size_t prov_drbg_get_nonce(PROV_DRBG *drbg, unsigned char **pout,
-                                  size_t min_len, size_t max_len)
+    size_t min_len, size_t max_len)
 {
     size_t ret = 0, n;
     unsigned char *buf = NULL;
@@ -325,10 +325,10 @@ static size_t prov_drbg_get_nonce(PROV_DRBG *drbg, unsigned char **pout,
 
     if (drbg->parent != NULL && drbg->parent_nonce != NULL) {
         n = drbg->parent_nonce(drbg->parent, NULL, 0, drbg->min_noncelen,
-                               drbg->max_noncelen);
+            drbg->max_noncelen);
         if (n > 0 && (buf = OPENSSL_malloc(n)) != NULL) {
             ret = drbg->parent_nonce(drbg->parent, buf, 0,
-                                     drbg->min_noncelen, drbg->max_noncelen);
+                drbg->min_noncelen, drbg->max_noncelen);
             if (ret == n) {
                 *pout = buf;
                 return ret;
@@ -341,10 +341,10 @@ static size_t prov_drbg_get_nonce(PROV_DRBG *drbg, unsigned char **pout,
     memset(&data, 0, sizeof(data));
     data.drbg = drbg;
     if (!CRYPTO_atomic_add(&dngbl->rand_nonce_count, 1, &data.count,
-                           dngbl->rand_nonce_lock))
+            dngbl->rand_nonce_lock))
         return 0;
     return ossl_prov_get_nonce(drbg->provctx, pout, min_len, max_len,
-                               &data, sizeof(data));
+        &data, sizeof(data));
 }
 #endif /* PROV_RAND_GET_RANDOM_NONCE */
 
@@ -357,8 +357,8 @@ static size_t prov_drbg_get_nonce(PROV_DRBG *drbg, unsigned char **pout,
  * Returns 1 on success, 0 on failure.
  */
 int ossl_prov_drbg_instantiate(PROV_DRBG *drbg, unsigned int strength,
-                               int prediction_resistance,
-                               const unsigned char *pers, size_t perslen)
+    int prediction_resistance,
+    const unsigned char *pers, size_t perslen)
 {
     unsigned char *nonce = NULL, *entropy = NULL;
     size_t noncelen = 0, entropylen = 0;
@@ -394,8 +394,8 @@ int ossl_prov_drbg_instantiate(PROV_DRBG *drbg, unsigned int strength,
     if (drbg->min_noncelen > 0) {
         if (drbg->parent_nonce != NULL) {
             noncelen = drbg->parent_nonce(drbg->parent, NULL, drbg->strength,
-                                          drbg->min_noncelen,
-                                          drbg->max_noncelen);
+                drbg->min_noncelen,
+                drbg->max_noncelen);
             if (noncelen == 0) {
                 ERR_raise(ERR_LIB_PROV, PROV_R_ERROR_RETRIEVING_NONCE);
                 goto end;
@@ -405,10 +405,7 @@ int ossl_prov_drbg_instantiate(PROV_DRBG *drbg, unsigned int strength,
                 ERR_raise(ERR_LIB_PROV, PROV_R_ERROR_RETRIEVING_NONCE);
                 goto end;
             }
-            if (noncelen != drbg->parent_nonce(drbg->parent, nonce,
-                                               drbg->strength,
-                                               drbg->min_noncelen,
-                                               drbg->max_noncelen)) {
+            if (noncelen != drbg->parent_nonce(drbg->parent, nonce, drbg->strength, drbg->min_noncelen, drbg->max_noncelen)) {
                 ERR_raise(ERR_LIB_PROV, PROV_R_ERROR_RETRIEVING_NONCE);
                 goto end;
             }
@@ -428,10 +425,10 @@ int ossl_prov_drbg_instantiate(PROV_DRBG *drbg, unsigned int strength,
         }
 #ifndef PROV_RAND_GET_RANDOM_NONCE
         else { /* parent == NULL */
-            noncelen = prov_drbg_get_nonce(drbg, &nonce, drbg->min_noncelen, 
-                                           drbg->max_noncelen);
+            noncelen = prov_drbg_get_nonce(drbg, &nonce, drbg->min_noncelen,
+                drbg->max_noncelen);
             if (noncelen < drbg->min_noncelen
-                    || noncelen > drbg->max_noncelen) {
+                || noncelen > drbg->max_noncelen) {
                 ERR_raise(ERR_LIB_PROV, PROV_R_ERROR_RETRIEVING_NONCE);
                 goto end;
             }
@@ -447,16 +444,16 @@ int ossl_prov_drbg_instantiate(PROV_DRBG *drbg, unsigned int strength,
     }
 
     entropylen = get_entropy(drbg, &entropy, min_entropy,
-                             min_entropylen, max_entropylen,
-                             prediction_resistance);
+        min_entropylen, max_entropylen,
+        prediction_resistance);
     if (entropylen < min_entropylen
-            || entropylen > max_entropylen) {
+        || entropylen > max_entropylen) {
         ERR_raise(ERR_LIB_PROV, PROV_R_ERROR_RETRIEVING_ENTROPY);
         goto end;
     }
 
     if (!drbg->instantiate(drbg, entropy, entropylen, nonce, noncelen,
-                           pers, perslen)) {
+            pers, perslen)) {
         cleanup_entropy(drbg, entropy, entropylen);
         ERR_raise(ERR_LIB_PROV, PROV_R_ERROR_INSTANTIATING_DRBG);
         goto end;
@@ -468,7 +465,7 @@ int ossl_prov_drbg_instantiate(PROV_DRBG *drbg, unsigned int strength,
     drbg->reseed_time = time(NULL);
     tsan_store(&drbg->reseed_counter, drbg->reseed_next_counter);
 
- end:
+end:
     if (nonce != NULL)
         ossl_prov_cleanup_nonce(drbg->provctx, nonce, noncelen);
     if (drbg->state == EVP_RAND_STATE_READY)
@@ -490,11 +487,11 @@ int ossl_prov_drbg_uninstantiate(PROV_DRBG *drbg)
 }
 
 static int ossl_prov_drbg_reseed_unlocked(PROV_DRBG *drbg,
-                                          int prediction_resistance,
-                                          const unsigned char *ent,
-                                          size_t ent_len,
-                                          const unsigned char *adin,
-                                          size_t adinlen)
+    int prediction_resistance,
+    const unsigned char *ent,
+    size_t ent_len,
+    const unsigned char *adin,
+    size_t adinlen)
 {
     unsigned char *entropy = NULL;
     size_t entropylen = 0;
@@ -571,10 +568,10 @@ static int ossl_prov_drbg_reseed_unlocked(PROV_DRBG *drbg,
 
     /* Reseed using our sources in addition */
     entropylen = get_entropy(drbg, &entropy, drbg->strength,
-                             drbg->min_entropylen, drbg->max_entropylen,
-                             prediction_resistance);
+        drbg->min_entropylen, drbg->max_entropylen,
+        prediction_resistance);
     if (entropylen < drbg->min_entropylen
-            || entropylen > drbg->max_entropylen) {
+        || entropylen > drbg->max_entropylen) {
         ERR_raise(ERR_LIB_PROV, PROV_R_ERROR_RETRIEVING_ENTROPY);
         goto end;
     }
@@ -589,7 +586,7 @@ static int ossl_prov_drbg_reseed_unlocked(PROV_DRBG *drbg,
     if (drbg->parent != NULL)
         drbg->parent_reseed_counter = get_parent_reseed_count(drbg);
 
- end:
+end:
     cleanup_entropy(drbg, entropy, entropylen);
     if (drbg->state == EVP_RAND_STATE_READY)
         return 1;
@@ -604,8 +601,8 @@ static int ossl_prov_drbg_reseed_unlocked(PROV_DRBG *drbg,
  * Returns 1 on success, 0 on failure.
  */
 int ossl_prov_drbg_reseed(PROV_DRBG *drbg, int prediction_resistance,
-                          const unsigned char *ent, size_t ent_len,
-                          const unsigned char *adin, size_t adinlen)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *adin, size_t adinlen)
 {
     int ret;
 
@@ -613,7 +610,7 @@ int ossl_prov_drbg_reseed(PROV_DRBG *drbg, int prediction_resistance,
         return 0;
 
     ret = ossl_prov_drbg_reseed_unlocked(drbg, prediction_resistance, ent,
-                                         ent_len, adin, adinlen);
+        ent_len, adin, adinlen);
 
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
@@ -632,8 +629,8 @@ int ossl_prov_drbg_reseed(PROV_DRBG *drbg, int prediction_resistance,
  *
  */
 int ossl_prov_drbg_generate(PROV_DRBG *drbg, unsigned char *out, size_t outlen,
-                            unsigned int strength, int prediction_resistance,
-                            const unsigned char *adin, size_t adinlen)
+    unsigned int strength, int prediction_resistance,
+    const unsigned char *adin, size_t adinlen)
 {
     int fork_id;
     int reseed_required = 0;
@@ -690,12 +687,12 @@ int ossl_prov_drbg_generate(PROV_DRBG *drbg, unsigned char *out, size_t outlen,
             reseed_required = 1;
     }
     if (drbg->parent != NULL
-            && get_parent_reseed_count(drbg) != drbg->parent_reseed_counter)
+        && get_parent_reseed_count(drbg) != drbg->parent_reseed_counter)
         reseed_required = 1;
 
     if (reseed_required || prediction_resistance) {
         if (!ossl_prov_drbg_reseed_unlocked(drbg, prediction_resistance, NULL,
-                                            0, adin, adinlen)) {
+                0, adin, adinlen)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_RESEED_ERROR);
             goto err;
         }
@@ -712,7 +709,7 @@ int ossl_prov_drbg_generate(PROV_DRBG *drbg, unsigned char *out, size_t outlen,
     drbg->generate_counter++;
 
     ret = 1;
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
 
@@ -752,7 +749,7 @@ static int rand_drbg_restart(PROV_DRBG *drbg)
 
 /* Provider support from here down */
 static const OSSL_DISPATCH *find_call(const OSSL_DISPATCH *dispatch,
-                                      int function)
+    int function)
 {
     if (dispatch != NULL)
         while (dispatch->function_id != 0) {
@@ -790,19 +787,18 @@ int ossl_drbg_enable_locking(void *vctx)
  *
  * Returns a pointer to the new DRBG instance on success, NULL on failure.
  */
-PROV_DRBG *ossl_rand_drbg_new
-    (void *provctx, void *parent, const OSSL_DISPATCH *p_dispatch,
-     int (*dnew)(PROV_DRBG *ctx),
-     void (*dfree)(void *vctx),
-     int (*instantiate)(PROV_DRBG *drbg,
-                        const unsigned char *entropy, size_t entropylen,
-                        const unsigned char *nonce, size_t noncelen,
-                        const unsigned char *pers, size_t perslen),
-     int (*uninstantiate)(PROV_DRBG *ctx),
-     int (*reseed)(PROV_DRBG *drbg, const unsigned char *ent, size_t ent_len,
-                   const unsigned char *adin, size_t adin_len),
-     int (*generate)(PROV_DRBG *, unsigned char *out, size_t outlen,
-                     const unsigned char *adin, size_t adin_len))
+PROV_DRBG *ossl_rand_drbg_new(void *provctx, void *parent, const OSSL_DISPATCH *p_dispatch,
+    int (*dnew)(PROV_DRBG *ctx),
+    void (*dfree)(void *vctx),
+    int (*instantiate)(PROV_DRBG *drbg,
+        const unsigned char *entropy, size_t entropylen,
+        const unsigned char *nonce, size_t noncelen,
+        const unsigned char *pers, size_t perslen),
+    int (*uninstantiate)(PROV_DRBG *ctx),
+    int (*reseed)(PROV_DRBG *drbg, const unsigned char *ent, size_t ent_len,
+        const unsigned char *adin, size_t adin_len),
+    int (*generate)(PROV_DRBG *, unsigned char *out, size_t outlen,
+        const unsigned char *adin, size_t adin_len))
 {
     PROV_DRBG *drbg;
     unsigned int p_str;
@@ -870,7 +866,7 @@ PROV_DRBG *ossl_rand_drbg_new
 #endif
     return drbg;
 
- err:
+err:
     dfree(drbg);
     return NULL;
 }
@@ -944,7 +940,7 @@ int ossl_drbg_get_ctx_params(PROV_DRBG *drbg, OSSL_PARAM params[])
  * *complete to 1 if all the params were processed, or 0 otherwise
  */
 int ossl_drbg_get_ctx_params_no_lock(PROV_DRBG *drbg, OSSL_PARAM params[],
-                                     int *complete)
+    int *complete)
 {
     size_t cnt = 0;
     OSSL_PARAM *p;
@@ -999,9 +995,11 @@ int ossl_drbg_verify_digest(ossl_unused OSSL_LIB_CTX *libctx, const EVP_MD *md)
 #ifdef FIPS_MODULE
     /* FIPS 140-3 IG D.R limited DRBG digests to a specific set */
     static const char *const allowed_digests[] = {
-        "SHA1",                     /* SHA 1 allowed */
-        "SHA2-256", "SHA2-512",     /* non-truncated SHA2 allowed */
-        "SHA3-256", "SHA3-512",     /* non-truncated SHA3 allowed */
+        "SHA1", /* SHA 1 allowed */
+        "SHA2-256",
+        "SHA2-512", /* non-truncated SHA2 allowed */
+        "SHA3-256",
+        "SHA3-512", /* non-truncated SHA3 allowed */
     };
     size_t i;
 
