@@ -103,7 +103,7 @@ static void ctr_XOR(PROV_DRBG_CTR *ctr, const unsigned char *in, size_t inlen)
  * Process a complete block using BCC algorithm of SP 800-90A 10.3.3
  */
 __owur static int ctr_BCC_block(PROV_DRBG_CTR *ctr, unsigned char *out,
-                                const unsigned char *in, int len)
+    const unsigned char *in, int len)
 {
     int i, outlen = AES_BLOCK_SIZE;
 
@@ -116,7 +116,6 @@ __owur static int ctr_BCC_block(PROV_DRBG_CTR *ctr, unsigned char *out,
     return 1;
 }
 
-
 /*
  * Handle several BCC operations for as much data as we need for K and X
  */
@@ -140,7 +139,7 @@ __owur static int ctr_BCC_blocks(PROV_DRBG_CTR *ctr, const unsigned char *in)
  */
 __owur static int ctr_BCC_init(PROV_DRBG_CTR *ctr)
 {
-    unsigned char bltmp[48] = {0};
+    unsigned char bltmp[48] = { 0 };
     unsigned char num_of_blk;
 
     memset(ctr->KX, 0, 48);
@@ -154,7 +153,7 @@ __owur static int ctr_BCC_init(PROV_DRBG_CTR *ctr)
  * Process several blocks into BCC algorithm, some possibly partial
  */
 __owur static int ctr_BCC_update(PROV_DRBG_CTR *ctr,
-                                 const unsigned char *in, size_t inlen)
+    const unsigned char *in, size_t inlen)
 {
     if (in == NULL || inlen == 0)
         return 1;
@@ -199,9 +198,9 @@ __owur static int ctr_BCC_final(PROV_DRBG_CTR *ctr)
 }
 
 __owur static int ctr_df(PROV_DRBG_CTR *ctr,
-                         const unsigned char *in1, size_t in1len,
-                         const unsigned char *in2, size_t in2len,
-                         const unsigned char *in3, size_t in3len)
+    const unsigned char *in1, size_t in1len,
+    const unsigned char *in2, size_t in2len,
+    const unsigned char *in3, size_t in3len)
 {
     static unsigned char c80 = 0x80;
     size_t inlen;
@@ -240,16 +239,16 @@ __owur static int ctr_df(PROV_DRBG_CTR *ctr,
         return 0;
     /* X follows key K */
     if (!EVP_CipherUpdate(ctr->ctx_ecb, ctr->KX, &outlen, ctr->KX + ctr->keylen,
-                          AES_BLOCK_SIZE)
+            AES_BLOCK_SIZE)
         || outlen != AES_BLOCK_SIZE)
         return 0;
     if (!EVP_CipherUpdate(ctr->ctx_ecb, ctr->KX + 16, &outlen, ctr->KX,
-                          AES_BLOCK_SIZE)
+            AES_BLOCK_SIZE)
         || outlen != AES_BLOCK_SIZE)
         return 0;
     if (ctr->keylen != 16)
         if (!EVP_CipherUpdate(ctr->ctx_ecb, ctr->KX + 32, &outlen,
-                              ctr->KX + 16, AES_BLOCK_SIZE)
+                ctr->KX + 16, AES_BLOCK_SIZE)
             || outlen != AES_BLOCK_SIZE)
             return 0;
     return 1;
@@ -262,9 +261,9 @@ __owur static int ctr_df(PROV_DRBG_CTR *ctr,
  * so we handle both cases in this function instead.
  */
 __owur static int ctr_update(PROV_DRBG *drbg,
-                             const unsigned char *in1, size_t in1len,
-                             const unsigned char *in2, size_t in2len,
-                             const unsigned char *nonce, size_t noncelen)
+    const unsigned char *in1, size_t in1len,
+    const unsigned char *in2, size_t in2len,
+    const unsigned char *nonce, size_t noncelen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
     int outlen = AES_BLOCK_SIZE;
@@ -283,7 +282,7 @@ __owur static int ctr_update(PROV_DRBG *drbg,
         len = 48;
     }
     if (!EVP_CipherUpdate(ctr->ctx_ecb, out, &outlen, V_tmp, len)
-            || outlen != len)
+        || outlen != len)
         return 0;
     memcpy(ctr->K, out, ctr->keylen);
     memcpy(ctr->V, out + ctr->keylen, 16);
@@ -308,9 +307,9 @@ __owur static int ctr_update(PROV_DRBG *drbg,
 }
 
 static int drbg_ctr_instantiate(PROV_DRBG *drbg,
-                                const unsigned char *entropy, size_t entropylen,
-                                const unsigned char *nonce, size_t noncelen,
-                                const unsigned char *pers, size_t perslen)
+    const unsigned char *entropy, size_t entropylen,
+    const unsigned char *nonce, size_t noncelen,
+    const unsigned char *pers, size_t perslen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
 
@@ -329,10 +328,10 @@ static int drbg_ctr_instantiate(PROV_DRBG *drbg,
 }
 
 static int drbg_ctr_instantiate_wrapper(void *vdrbg, unsigned int strength,
-                                        int prediction_resistance,
-                                        const unsigned char *pstr,
-                                        size_t pstr_len,
-                                        const OSSL_PARAM params[])
+    int prediction_resistance,
+    const unsigned char *pstr,
+    size_t pstr_len,
+    const OSSL_PARAM params[])
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
     int ret = 0;
@@ -341,19 +340,19 @@ static int drbg_ctr_instantiate_wrapper(void *vdrbg, unsigned int strength,
         return 0;
 
     if (!ossl_prov_is_running()
-            || !drbg_ctr_set_ctx_params_locked(drbg, params))
+        || !drbg_ctr_set_ctx_params_locked(drbg, params))
         goto err;
     ret = ossl_prov_drbg_instantiate(drbg, strength, prediction_resistance,
-                                     pstr, pstr_len);
- err:
+        pstr, pstr_len);
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
 }
 
 static int drbg_ctr_reseed(PROV_DRBG *drbg,
-                           const unsigned char *entropy, size_t entropylen,
-                           const unsigned char *adin, size_t adinlen)
+    const unsigned char *entropy, size_t entropylen,
+    const unsigned char *adin, size_t adinlen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
 
@@ -367,13 +366,13 @@ static int drbg_ctr_reseed(PROV_DRBG *drbg,
 }
 
 static int drbg_ctr_reseed_wrapper(void *vdrbg, int prediction_resistance,
-                                   const unsigned char *ent, size_t ent_len,
-                                   const unsigned char *adin, size_t adin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_reseed(drbg, prediction_resistance, ent, ent_len,
-                                 adin, adin_len);
+        adin, adin_len);
 }
 
 static void ctr96_inc(unsigned char *counter)
@@ -389,8 +388,8 @@ static void ctr96_inc(unsigned char *counter)
 }
 
 static int drbg_ctr_generate(PROV_DRBG *drbg,
-                             unsigned char *out, size_t outlen,
-                             const unsigned char *adin, size_t adinlen)
+    unsigned char *out, size_t outlen,
+    const unsigned char *adin, size_t adinlen)
 {
     PROV_DRBG_CTR *ctr = (PROV_DRBG_CTR *)drbg->data;
     unsigned int ctr32, blocks;
@@ -424,7 +423,7 @@ static int drbg_ctr_generate(PROV_DRBG *drbg,
 
     do {
         if (!EVP_CipherInit_ex(ctr->ctx_ctr,
-                               NULL, NULL, NULL, ctr->V, -1))
+                NULL, NULL, NULL, ctr->V, -1))
             return 0;
 
         /*-
@@ -462,15 +461,14 @@ static int drbg_ctr_generate(PROV_DRBG *drbg,
     return 1;
 }
 
-static int drbg_ctr_generate_wrapper
-    (void *vdrbg, unsigned char *out, size_t outlen,
-     unsigned int strength, int prediction_resistance,
-     const unsigned char *adin, size_t adin_len)
+static int drbg_ctr_generate_wrapper(void *vdrbg, unsigned char *out, size_t outlen,
+    unsigned int strength, int prediction_resistance,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_generate(drbg, out, outlen, strength,
-                                   prediction_resistance, adin, adin_len);
+        prediction_resistance, adin, adin_len);
 }
 
 static int drbg_ctr_uninstantiate(PROV_DRBG *drbg)
@@ -518,7 +516,7 @@ static int drbg_ctr_verify_zeroization(void *vdrbg)
         goto err;
 
     ret = 1;
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
@@ -577,9 +575,9 @@ static int drbg_ctr_init(PROV_DRBG *drbg)
     }
 
     if (!EVP_CipherInit_ex(ctr->ctx_ecb,
-                           ctr->cipher_ecb, NULL, NULL, NULL, 1)
+            ctr->cipher_ecb, NULL, NULL, NULL, 1)
         || !EVP_CipherInit_ex(ctr->ctx_ctr,
-                              ctr->cipher_ctr, NULL, NULL, NULL, 1)) {
+            ctr->cipher_ctr, NULL, NULL, NULL, 1)) {
         ERR_raise(ERR_LIB_PROV, PROV_R_UNABLE_TO_INITIALISE_CIPHERS);
         goto err;
     }
@@ -604,7 +602,7 @@ static int drbg_ctr_init(PROV_DRBG *drbg)
         }
         /* Set key schedule for df_key */
         if (!EVP_CipherInit_ex(ctr->ctx_df,
-                               ctr->cipher_ecb, NULL, df_key, NULL, 1)) {
+                ctr->cipher_ecb, NULL, df_key, NULL, 1)) {
             ERR_raise(ERR_LIB_PROV, PROV_R_DERIVATION_FUNCTION_INIT_FAILED);
             goto err;
         }
@@ -632,12 +630,12 @@ static int drbg_ctr_new(PROV_DRBG *drbg)
 }
 
 static void *drbg_ctr_new_wrapper(void *provctx, void *parent,
-                                   const OSSL_DISPATCH *parent_dispatch)
+    const OSSL_DISPATCH *parent_dispatch)
 {
     return ossl_rand_drbg_new(provctx, parent, parent_dispatch,
-                              &drbg_ctr_new, &drbg_ctr_free,
-                              &drbg_ctr_instantiate, &drbg_ctr_uninstantiate,
-                              &drbg_ctr_reseed, &drbg_ctr_generate);
+        &drbg_ctr_new, &drbg_ctr_free,
+        &drbg_ctr_instantiate, &drbg_ctr_uninstantiate,
+        &drbg_ctr_reseed, &drbg_ctr_generate);
 }
 
 static void drbg_ctr_free(void *vdrbg)
@@ -681,12 +679,12 @@ static int drbg_ctr_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
     if (p != NULL) {
         if (ctr->cipher_ctr == NULL
             || !OSSL_PARAM_set_utf8_string(p,
-                                           EVP_CIPHER_get0_name(ctr->cipher_ctr)))
+                EVP_CIPHER_get0_name(ctr->cipher_ctr)))
             goto err;
     }
 
     ret = ossl_drbg_get_ctx_params(drbg, params);
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
 
@@ -694,7 +692,7 @@ static int drbg_ctr_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_ctr_gettable_ctx_params(ossl_unused void *vctx,
-                                                      ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_gettable_ctx_params[] = {
         OSSL_PARAM_utf8_string(OSSL_DRBG_PARAM_CIPHER, NULL, 0),
@@ -716,14 +714,15 @@ static int drbg_ctr_set_ctx_params_locked(void *vctx, const OSSL_PARAM params[])
     int i, cipher_init = 0;
 
     if ((p = OSSL_PARAM_locate_const(params, OSSL_DRBG_PARAM_USE_DF)) != NULL
-            && OSSL_PARAM_get_int(p, &i)) {
+        && OSSL_PARAM_get_int(p, &i)) {
         /* FIPS errors out in the drbg_ctr_init() call later */
         ctr->use_df = i != 0;
         cipher_init = 1;
     }
 
     if ((p = OSSL_PARAM_locate_const(params,
-                                     OSSL_DRBG_PARAM_PROPERTIES)) != NULL) {
+             OSSL_DRBG_PARAM_PROPERTIES))
+        != NULL) {
         if (p->data_type != OSSL_PARAM_UTF8_STRING)
             return 0;
         propquery = (const char *)p->data;
@@ -735,7 +734,7 @@ static int drbg_ctr_set_ctx_params_locked(void *vctx, const OSSL_PARAM params[])
         size_t ecb_str_len = sizeof("ECB") - 1;
 
         if (p->data_type != OSSL_PARAM_UTF8_STRING
-                || p->data_size < ctr_str_len)
+            || p->data_size < ctr_str_len)
             return 0;
         if (OPENSSL_strcasecmp("CTR", base + p->data_size - ctr_str_len) != 0) {
             ERR_raise(ERR_LIB_PROV, PROV_R_REQUIRE_CTR_MODE_CIPHER);
@@ -779,7 +778,7 @@ static int drbg_ctr_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_ctr_settable_ctx_params(ossl_unused void *vctx,
-                                                      ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     static const OSSL_PARAM known_settable_ctx_params[] = {
         OSSL_PARAM_utf8_string(OSSL_DRBG_PARAM_PROPERTIES, NULL, 0),
@@ -792,26 +791,26 @@ static const OSSL_PARAM *drbg_ctr_settable_ctx_params(ossl_unused void *vctx,
 }
 
 const OSSL_DISPATCH ossl_drbg_ctr_functions[] = {
-    { OSSL_FUNC_RAND_NEWCTX, (void(*)(void))drbg_ctr_new_wrapper },
-    { OSSL_FUNC_RAND_FREECTX, (void(*)(void))drbg_ctr_free },
+    { OSSL_FUNC_RAND_NEWCTX, (void (*)(void))drbg_ctr_new_wrapper },
+    { OSSL_FUNC_RAND_FREECTX, (void (*)(void))drbg_ctr_free },
     { OSSL_FUNC_RAND_INSTANTIATE,
-      (void(*)(void))drbg_ctr_instantiate_wrapper },
+        (void (*)(void))drbg_ctr_instantiate_wrapper },
     { OSSL_FUNC_RAND_UNINSTANTIATE,
-      (void(*)(void))drbg_ctr_uninstantiate_wrapper },
-    { OSSL_FUNC_RAND_GENERATE, (void(*)(void))drbg_ctr_generate_wrapper },
-    { OSSL_FUNC_RAND_RESEED, (void(*)(void))drbg_ctr_reseed_wrapper },
-    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void(*)(void))ossl_drbg_enable_locking },
-    { OSSL_FUNC_RAND_LOCK, (void(*)(void))ossl_drbg_lock },
-    { OSSL_FUNC_RAND_UNLOCK, (void(*)(void))ossl_drbg_unlock },
+        (void (*)(void))drbg_ctr_uninstantiate_wrapper },
+    { OSSL_FUNC_RAND_GENERATE, (void (*)(void))drbg_ctr_generate_wrapper },
+    { OSSL_FUNC_RAND_RESEED, (void (*)(void))drbg_ctr_reseed_wrapper },
+    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void (*)(void))ossl_drbg_enable_locking },
+    { OSSL_FUNC_RAND_LOCK, (void (*)(void))ossl_drbg_lock },
+    { OSSL_FUNC_RAND_UNLOCK, (void (*)(void))ossl_drbg_unlock },
     { OSSL_FUNC_RAND_SETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_ctr_settable_ctx_params },
-    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void(*)(void))drbg_ctr_set_ctx_params },
+        (void (*)(void))drbg_ctr_settable_ctx_params },
+    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void (*)(void))drbg_ctr_set_ctx_params },
     { OSSL_FUNC_RAND_GETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_ctr_gettable_ctx_params },
-    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void(*)(void))drbg_ctr_get_ctx_params },
+        (void (*)(void))drbg_ctr_gettable_ctx_params },
+    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void (*)(void))drbg_ctr_get_ctx_params },
     { OSSL_FUNC_RAND_VERIFY_ZEROIZATION,
-      (void(*)(void))drbg_ctr_verify_zeroization },
-    { OSSL_FUNC_RAND_GET_SEED, (void(*)(void))ossl_drbg_get_seed },
-    { OSSL_FUNC_RAND_CLEAR_SEED, (void(*)(void))ossl_drbg_clear_seed },
+        (void (*)(void))drbg_ctr_verify_zeroization },
+    { OSSL_FUNC_RAND_GET_SEED, (void (*)(void))ossl_drbg_get_seed },
+    { OSSL_FUNC_RAND_CLEAR_SEED, (void (*)(void))ossl_drbg_clear_seed },
     OSSL_DISPATCH_END
 };
