@@ -38,13 +38,13 @@ static OSSL_FUNC_rand_verify_zeroization_fn drbg_hash_verify_zeroization;
 static int drbg_hash_set_ctx_params_locked(void *vctx, const OSSL_PARAM params[]);
 
 /* 888 bits from SP800-90Ar1 10.1 table 2 */
-#define HASH_PRNG_MAX_SEEDLEN    (888/8)
+#define HASH_PRNG_MAX_SEEDLEN (888 / 8)
 
 /* 440 bits from SP800-90Ar1 10.1 table 2 */
-#define HASH_PRNG_SMALL_SEEDLEN   (440/8)
+#define HASH_PRNG_SMALL_SEEDLEN (440 / 8)
 
 /* Determine what seedlen to use based on the block length */
-#define MAX_BLOCKLEN_USING_SMALL_SEEDLEN (256/8)
+#define MAX_BLOCKLEN_USING_SMALL_SEEDLEN (256 / 8)
 #define INBYTE_IGNORE ((unsigned char)0xFF)
 
 typedef struct rand_drbg_hash_st {
@@ -67,10 +67,10 @@ typedef struct rand_drbg_hash_st {
  *    These are concatenated as part of the DigestUpdate process.
  */
 static int hash_df(PROV_DRBG *drbg, unsigned char *out,
-                   const unsigned char inbyte,
-                   const unsigned char *in, size_t inlen,
-                   const unsigned char *in2, size_t in2len,
-                   const unsigned char *in3, size_t in3len)
+    const unsigned char inbyte,
+    const unsigned char *in, size_t inlen,
+    const unsigned char *in2, size_t in2len,
+    const unsigned char *in3, size_t in3len)
 {
     PROV_DRBG_HASH *hash = (PROV_DRBG_HASH *)drbg->data;
     EVP_MD_CTX *ctx = hash->ctx;
@@ -131,8 +131,8 @@ static int hash_df(PROV_DRBG *drbg, unsigned char *out,
 
 /* Helper function that just passes 2 input parameters to hash_df() */
 static int hash_df1(PROV_DRBG *drbg, unsigned char *out,
-                    const unsigned char in_byte,
-                    const unsigned char *in1, size_t in1len)
+    const unsigned char in_byte,
+    const unsigned char *in1, size_t in1len)
 {
     return hash_df(drbg, out, in_byte, in1, in1len, NULL, 0, NULL, 0);
 }
@@ -144,7 +144,7 @@ static int hash_df1(PROV_DRBG *drbg, unsigned char *out,
  * where dst size is drbg->seedlen, and inlen <= drbg->seedlen.
  */
 static int add_bytes(PROV_DRBG *drbg, unsigned char *dst,
-                     unsigned char *in, size_t inlen)
+    unsigned char *in, size_t inlen)
 {
     size_t i;
     int result;
@@ -165,7 +165,7 @@ static int add_bytes(PROV_DRBG *drbg, unsigned char *dst,
     if (carry != 0) {
         /* Add the carry to the top of the dst if inlen is not the same size */
         for (i = drbg->seedlen - inlen; i > 0; --i, d--) {
-            *d += 1;     /* Carry can only be 1 */
+            *d += 1; /* Carry can only be 1 */
             if (*d != 0) /* exit if carry doesn't propagate to the next byte */
                 break;
         }
@@ -175,17 +175,17 @@ static int add_bytes(PROV_DRBG *drbg, unsigned char *dst,
 
 /* V = (V + Hash(inbyte || V  || [additional_input]) mod (2^seedlen) */
 static int add_hash_to_v(PROV_DRBG *drbg, unsigned char inbyte,
-                         const unsigned char *adin, size_t adinlen)
+    const unsigned char *adin, size_t adinlen)
 {
     PROV_DRBG_HASH *hash = (PROV_DRBG_HASH *)drbg->data;
     EVP_MD_CTX *ctx = hash->ctx;
 
     return EVP_DigestInit_ex(ctx, ossl_prov_digest_md(&hash->digest), NULL)
-           && EVP_DigestUpdate(ctx, &inbyte, 1)
-           && EVP_DigestUpdate(ctx, hash->V, drbg->seedlen)
-           && (adin == NULL || EVP_DigestUpdate(ctx, adin, adinlen))
-           && EVP_DigestFinal(ctx, hash->vtmp, NULL)
-           && add_bytes(drbg, hash->V, hash->vtmp, hash->blocklen);
+        && EVP_DigestUpdate(ctx, &inbyte, 1)
+        && EVP_DigestUpdate(ctx, hash->V, drbg->seedlen)
+        && (adin == NULL || EVP_DigestUpdate(ctx, adin, adinlen))
+        && EVP_DigestFinal(ctx, hash->vtmp, NULL)
+        && add_bytes(drbg, hash->V, hash->vtmp, hash->blocklen);
 }
 
 /*
@@ -216,8 +216,8 @@ static int hash_gen(PROV_DRBG *drbg, unsigned char *out, size_t outlen)
     memcpy(hash->vtmp, hash->V, drbg->seedlen);
     for (;;) {
         if (!EVP_DigestInit_ex(hash->ctx, ossl_prov_digest_md(&hash->digest),
-                               NULL)
-                || !EVP_DigestUpdate(hash->ctx, hash->vtmp, drbg->seedlen))
+                NULL)
+            || !EVP_DigestUpdate(hash->ctx, hash->vtmp, drbg->seedlen))
             return 0;
 
         if (outlen < hash->blocklen) {
@@ -248,9 +248,9 @@ static int hash_gen(PROV_DRBG *drbg, unsigned char *out, size_t outlen)
  * Returns zero if an error occurs otherwise it returns 1.
  */
 static int drbg_hash_instantiate(PROV_DRBG *drbg,
-                                 const unsigned char *ent, size_t ent_len,
-                                 const unsigned char *nonce, size_t nonce_len,
-                                 const unsigned char *pstr, size_t pstr_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *nonce, size_t nonce_len,
+    const unsigned char *pstr, size_t pstr_len)
 {
     PROV_DRBG_HASH *hash = (PROV_DRBG_HASH *)drbg->data;
 
@@ -259,17 +259,17 @@ static int drbg_hash_instantiate(PROV_DRBG *drbg,
 
     /* (Step 1-3) V = Hash_df(entropy||nonce||pers, seedlen) */
     return hash->ctx != NULL
-           && hash_df(drbg, hash->V, INBYTE_IGNORE,
-                      ent, ent_len, nonce, nonce_len, pstr, pstr_len)
-           /* (Step 4) C = Hash_df(0x00||V, seedlen) */
-           && hash_df1(drbg, hash->C, 0x00, hash->V, drbg->seedlen);
+        && hash_df(drbg, hash->V, INBYTE_IGNORE,
+            ent, ent_len, nonce, nonce_len, pstr, pstr_len)
+        /* (Step 4) C = Hash_df(0x00||V, seedlen) */
+        && hash_df1(drbg, hash->C, 0x00, hash->V, drbg->seedlen);
 }
 
 static int drbg_hash_instantiate_wrapper(void *vdrbg, unsigned int strength,
-                                         int prediction_resistance,
-                                         const unsigned char *pstr,
-                                         size_t pstr_len,
-                                         const OSSL_PARAM params[])
+    int prediction_resistance,
+    const unsigned char *pstr,
+    size_t pstr_len,
+    const OSSL_PARAM params[])
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
     int ret = 0;
@@ -278,11 +278,11 @@ static int drbg_hash_instantiate_wrapper(void *vdrbg, unsigned int strength,
         return 0;
 
     if (!ossl_prov_is_running()
-            || !drbg_hash_set_ctx_params_locked(drbg, params))
+        || !drbg_hash_set_ctx_params_locked(drbg, params))
         goto err;
     ret = ossl_prov_drbg_instantiate(drbg, strength, prediction_resistance,
-                                     pstr, pstr_len);
- err:
+        pstr, pstr_len);
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
@@ -297,15 +297,15 @@ static int drbg_hash_instantiate_wrapper(void *vdrbg, unsigned int strength,
  * Returns zero if an error occurs otherwise it returns 1.
  */
 static int drbg_hash_reseed(PROV_DRBG *drbg,
-                            const unsigned char *ent, size_t ent_len,
-                            const unsigned char *adin, size_t adin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG_HASH *hash = (PROV_DRBG_HASH *)drbg->data;
 
     /* (Step 1-2) V = Hash_df(0x01 || V || entropy_input || additional_input) */
     /* V about to be updated so use C as output instead */
     if (!hash_df(drbg, hash->C, 0x01, hash->V, drbg->seedlen, ent, ent_len,
-                 adin, adin_len))
+            adin, adin_len))
         return 0;
     memcpy(hash->V, hash->C, drbg->seedlen);
     /* (Step 4) C = Hash_df(0x00||V, seedlen) */
@@ -313,13 +313,13 @@ static int drbg_hash_reseed(PROV_DRBG *drbg,
 }
 
 static int drbg_hash_reseed_wrapper(void *vdrbg, int prediction_resistance,
-                                    const unsigned char *ent, size_t ent_len,
-                                    const unsigned char *adin, size_t adin_len)
+    const unsigned char *ent, size_t ent_len,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_reseed(drbg, prediction_resistance, ent, ent_len,
-                                 adin, adin_len);
+        adin, adin_len);
 }
 
 /*
@@ -332,8 +332,8 @@ static int drbg_hash_reseed_wrapper(void *vdrbg, int prediction_resistance,
  * Returns zero if an error occurs otherwise it returns 1.
  */
 static int drbg_hash_generate(PROV_DRBG *drbg,
-                              unsigned char *out, size_t outlen,
-                              const unsigned char *adin, size_t adin_len)
+    unsigned char *out, size_t outlen,
+    const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG_HASH *hash = (PROV_DRBG_HASH *)drbg->data;
     unsigned char counter[4];
@@ -345,29 +345,28 @@ static int drbg_hash_generate(PROV_DRBG *drbg,
     counter[3] = (unsigned char)(reseed_counter & 0xff);
 
     return hash->ctx != NULL
-           && (adin == NULL
-           /* (Step 2) if adin != NULL then V = V + Hash(0x02||V||adin) */
-               || adin_len == 0
-               || add_hash_to_v(drbg, 0x02, adin, adin_len))
-           /* (Step 3) Hashgen(outlen, V) */
-           && hash_gen(drbg, out, outlen)
-           /* (Step 4/5) H = V = (V + Hash(0x03||V) mod (2^seedlen_bits) */
-           && add_hash_to_v(drbg, 0x03, NULL, 0)
-           /* (Step 5) V = (V + H + C + reseed_counter) mod (2^seedlen_bits) */
-           /* V = (V + C) mod (2^seedlen_bits) */
-           && add_bytes(drbg, hash->V, hash->C, drbg->seedlen)
-           /* V = (V + reseed_counter) mod (2^seedlen_bits) */
-           && add_bytes(drbg, hash->V, counter, 4);
+        && (adin == NULL
+            /* (Step 2) if adin != NULL then V = V + Hash(0x02||V||adin) */
+            || adin_len == 0
+            || add_hash_to_v(drbg, 0x02, adin, adin_len))
+        /* (Step 3) Hashgen(outlen, V) */
+        && hash_gen(drbg, out, outlen)
+        /* (Step 4/5) H = V = (V + Hash(0x03||V) mod (2^seedlen_bits) */
+        && add_hash_to_v(drbg, 0x03, NULL, 0)
+        /* (Step 5) V = (V + H + C + reseed_counter) mod (2^seedlen_bits) */
+        /* V = (V + C) mod (2^seedlen_bits) */
+        && add_bytes(drbg, hash->V, hash->C, drbg->seedlen)
+        /* V = (V + reseed_counter) mod (2^seedlen_bits) */
+        && add_bytes(drbg, hash->V, counter, 4);
 }
 
-static int drbg_hash_generate_wrapper
-    (void *vdrbg, unsigned char *out, size_t outlen, unsigned int strength,
-     int prediction_resistance, const unsigned char *adin, size_t adin_len)
+static int drbg_hash_generate_wrapper(void *vdrbg, unsigned char *out, size_t outlen, unsigned int strength,
+    int prediction_resistance, const unsigned char *adin, size_t adin_len)
 {
     PROV_DRBG *drbg = (PROV_DRBG *)vdrbg;
 
     return ossl_prov_drbg_generate(drbg, out, outlen, strength,
-                                   prediction_resistance, adin, adin_len);
+        prediction_resistance, adin, adin_len);
 }
 
 static int drbg_hash_uninstantiate(PROV_DRBG *drbg)
@@ -410,7 +409,7 @@ static int drbg_hash_verify_zeroization(void *vdrbg)
     PROV_DRBG_VERIFY_ZEROIZATION(hash->vtmp);
 
     ret = 1;
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
     return ret;
@@ -437,12 +436,12 @@ static int drbg_hash_new(PROV_DRBG *ctx)
 }
 
 static void *drbg_hash_new_wrapper(void *provctx, void *parent,
-                                   const OSSL_DISPATCH *parent_dispatch)
+    const OSSL_DISPATCH *parent_dispatch)
 {
     return ossl_rand_drbg_new(provctx, parent, parent_dispatch,
-                              &drbg_hash_new, &drbg_hash_free,
-                              &drbg_hash_instantiate, &drbg_hash_uninstantiate,
-                              &drbg_hash_reseed, &drbg_hash_generate);
+        &drbg_hash_new, &drbg_hash_free,
+        &drbg_hash_instantiate, &drbg_hash_uninstantiate,
+        &drbg_hash_reseed, &drbg_hash_generate);
 }
 
 static void drbg_hash_free(void *vdrbg)
@@ -483,7 +482,7 @@ static int drbg_hash_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
     }
 
     ret = ossl_drbg_get_ctx_params(drbg, params);
- err:
+err:
     if (drbg->lock != NULL)
         CRYPTO_THREAD_unlock(drbg->lock);
 
@@ -491,7 +490,7 @@ static int drbg_hash_get_ctx_params(void *vdrbg, OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_hash_gettable_ctx_params(ossl_unused void *vctx,
-                                                       ossl_unused void *p_ctx)
+    ossl_unused void *p_ctx)
 {
     static const OSSL_PARAM known_gettable_ctx_params[] = {
         OSSL_PARAM_utf8_string(OSSL_DRBG_PARAM_DIGEST, NULL, 0),
@@ -514,7 +513,7 @@ static int drbg_hash_set_ctx_params_locked(void *vctx, const OSSL_PARAM params[]
     md = ossl_prov_digest_md(&hash->digest);
     if (md != NULL) {
         if (!ossl_drbg_verify_digest(libctx, md))
-            return 0;   /* Error already raised for us */
+            return 0; /* Error already raised for us */
 
         /* These are taken from SP 800-90 10.1 Table 2 */
         hash->blocklen = EVP_MD_get_size(md);
@@ -551,7 +550,7 @@ static int drbg_hash_set_ctx_params(void *vctx, const OSSL_PARAM params[])
 }
 
 static const OSSL_PARAM *drbg_hash_settable_ctx_params(ossl_unused void *vctx,
-                                                       ossl_unused void *p_ctx)
+    ossl_unused void *p_ctx)
 {
     static const OSSL_PARAM known_settable_ctx_params[] = {
         OSSL_PARAM_utf8_string(OSSL_DRBG_PARAM_PROPERTIES, NULL, 0),
@@ -563,26 +562,26 @@ static const OSSL_PARAM *drbg_hash_settable_ctx_params(ossl_unused void *vctx,
 }
 
 const OSSL_DISPATCH ossl_drbg_hash_functions[] = {
-    { OSSL_FUNC_RAND_NEWCTX, (void(*)(void))drbg_hash_new_wrapper },
-    { OSSL_FUNC_RAND_FREECTX, (void(*)(void))drbg_hash_free },
+    { OSSL_FUNC_RAND_NEWCTX, (void (*)(void))drbg_hash_new_wrapper },
+    { OSSL_FUNC_RAND_FREECTX, (void (*)(void))drbg_hash_free },
     { OSSL_FUNC_RAND_INSTANTIATE,
-      (void(*)(void))drbg_hash_instantiate_wrapper },
+        (void (*)(void))drbg_hash_instantiate_wrapper },
     { OSSL_FUNC_RAND_UNINSTANTIATE,
-      (void(*)(void))drbg_hash_uninstantiate_wrapper },
-    { OSSL_FUNC_RAND_GENERATE, (void(*)(void))drbg_hash_generate_wrapper },
-    { OSSL_FUNC_RAND_RESEED, (void(*)(void))drbg_hash_reseed_wrapper },
-    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void(*)(void))ossl_drbg_enable_locking },
-    { OSSL_FUNC_RAND_LOCK, (void(*)(void))ossl_drbg_lock },
-    { OSSL_FUNC_RAND_UNLOCK, (void(*)(void))ossl_drbg_unlock },
+        (void (*)(void))drbg_hash_uninstantiate_wrapper },
+    { OSSL_FUNC_RAND_GENERATE, (void (*)(void))drbg_hash_generate_wrapper },
+    { OSSL_FUNC_RAND_RESEED, (void (*)(void))drbg_hash_reseed_wrapper },
+    { OSSL_FUNC_RAND_ENABLE_LOCKING, (void (*)(void))ossl_drbg_enable_locking },
+    { OSSL_FUNC_RAND_LOCK, (void (*)(void))ossl_drbg_lock },
+    { OSSL_FUNC_RAND_UNLOCK, (void (*)(void))ossl_drbg_unlock },
     { OSSL_FUNC_RAND_SETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_hash_settable_ctx_params },
-    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void(*)(void))drbg_hash_set_ctx_params },
+        (void (*)(void))drbg_hash_settable_ctx_params },
+    { OSSL_FUNC_RAND_SET_CTX_PARAMS, (void (*)(void))drbg_hash_set_ctx_params },
     { OSSL_FUNC_RAND_GETTABLE_CTX_PARAMS,
-      (void(*)(void))drbg_hash_gettable_ctx_params },
-    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void(*)(void))drbg_hash_get_ctx_params },
+        (void (*)(void))drbg_hash_gettable_ctx_params },
+    { OSSL_FUNC_RAND_GET_CTX_PARAMS, (void (*)(void))drbg_hash_get_ctx_params },
     { OSSL_FUNC_RAND_VERIFY_ZEROIZATION,
-      (void(*)(void))drbg_hash_verify_zeroization },
-    { OSSL_FUNC_RAND_GET_SEED, (void(*)(void))ossl_drbg_get_seed },
-    { OSSL_FUNC_RAND_CLEAR_SEED, (void(*)(void))ossl_drbg_clear_seed },
+        (void (*)(void))drbg_hash_verify_zeroization },
+    { OSSL_FUNC_RAND_GET_SEED, (void (*)(void))ossl_drbg_get_seed },
+    { OSSL_FUNC_RAND_CLEAR_SEED, (void (*)(void))ossl_drbg_clear_seed },
     OSSL_DISPATCH_END
 };
