@@ -23,23 +23,23 @@
 #include "crypto/ecx.h"
 
 #ifdef S390X_EC_ASM
-# include "s390x_arch.h"
+#include "s390x_arch.h"
 
-# define S390X_CAN_SIGN(edtype)                                                \
-((OPENSSL_s390xcap_P.pcc[1] & S390X_CAPBIT(S390X_SCALAR_MULTIPLY_##edtype))    \
-&& (OPENSSL_s390xcap_P.kdsa[0] & S390X_CAPBIT(S390X_EDDSA_SIGN_##edtype))      \
-&& (OPENSSL_s390xcap_P.kdsa[0] & S390X_CAPBIT(S390X_EDDSA_VERIFY_##edtype)))
+#define S390X_CAN_SIGN(edtype)                                                    \
+    ((OPENSSL_s390xcap_P.pcc[1] & S390X_CAPBIT(S390X_SCALAR_MULTIPLY_##edtype))   \
+        && (OPENSSL_s390xcap_P.kdsa[0] & S390X_CAPBIT(S390X_EDDSA_SIGN_##edtype)) \
+        && (OPENSSL_s390xcap_P.kdsa[0] & S390X_CAPBIT(S390X_EDDSA_VERIFY_##edtype)))
 
 static int s390x_ed25519_digestsign(const ECX_KEY *edkey, unsigned char *sig,
-                                    const unsigned char *tbs, size_t tbslen);
+    const unsigned char *tbs, size_t tbslen);
 static int s390x_ed448_digestsign(const ECX_KEY *edkey, unsigned char *sig,
-                                  const unsigned char *tbs, size_t tbslen);
+    const unsigned char *tbs, size_t tbslen);
 static int s390x_ed25519_digestverify(const ECX_KEY *edkey,
-                                      const unsigned char *sig,
-                                      const unsigned char *tbs, size_t tbslen);
+    const unsigned char *sig,
+    const unsigned char *tbs, size_t tbslen);
 static int s390x_ed448_digestverify(const ECX_KEY *edkey,
-                                    const unsigned char *sig,
-                                    const unsigned char *tbs, size_t tbslen);
+    const unsigned char *sig,
+    const unsigned char *tbs, size_t tbslen);
 
 #endif /* S390X_EC_ASM */
 
@@ -52,11 +52,11 @@ enum ID_EdDSA_INSTANCE {
     ID_Ed448ph
 };
 
-#define SN_Ed25519    "Ed25519"
-#define SN_Ed25519ph  "Ed25519ph"
+#define SN_Ed25519 "Ed25519"
+#define SN_Ed25519ph "Ed25519ph"
 #define SN_Ed25519ctx "Ed25519ctx"
-#define SN_Ed448      "Ed448"
-#define SN_Ed448ph    "Ed448ph"
+#define SN_Ed448 "Ed448"
+#define SN_Ed448ph "Ed448ph"
 
 #define EDDSA_MAX_CONTEXT_STRING_LEN 255
 #define EDDSA_PREHASH_OUTPUT_LEN 64
@@ -128,7 +128,7 @@ typedef struct {
     /* The Algorithm Identifier of the signature algorithm */
     unsigned char aid_buf[OSSL_MAX_ALGORITHM_ID_SIZE];
     unsigned char *aid;
-    size_t  aid_len;
+    size_t aid_len;
 
     /* id indicating the EdDSA instance */
     int instance_id;
@@ -161,8 +161,8 @@ static void *eddsa_newctx(void *provctx, const char *propq_unused)
 }
 
 static int eddsa_digest_signverify_init(void *vpeddsactx, const char *mdname,
-                                        void *vedkey,
-                                        const OSSL_PARAM params[])
+    void *vedkey,
+    const OSSL_PARAM params[])
 {
     PROV_EDDSA_CTX *peddsactx = (PROV_EDDSA_CTX *)vpeddsactx;
     ECX_KEY *edkey = (ECX_KEY *)vedkey;
@@ -234,8 +234,8 @@ static int eddsa_digest_signverify_init(void *vpeddsactx, const char *mdname,
 }
 
 int ed25519_digest_sign(void *vpeddsactx, unsigned char *sigret,
-                        size_t *siglen, size_t sigsize,
-                        const unsigned char *tbs, size_t tbslen)
+    size_t *siglen, size_t sigsize,
+    const unsigned char *tbs, size_t tbslen)
 {
     PROV_EDDSA_CTX *peddsactx = (PROV_EDDSA_CTX *)vpeddsactx;
     const ECX_KEY *edkey = peddsactx->key;
@@ -261,9 +261,9 @@ int ed25519_digest_sign(void *vpeddsactx, unsigned char *sigret,
     /* s390x_ed25519_digestsign() does not yet support dom2 or context-strings.
        fall back to non-accelerated sign if those options are set. */
     if (S390X_CAN_SIGN(ED25519)
-            && !peddsactx->dom2_flag
-            && !peddsactx->context_string_flag
-            && peddsactx->context_string_len == 0) {
+        && !peddsactx->dom2_flag
+        && !peddsactx->context_string_flag
+        && peddsactx->context_string_len == 0) {
         if (s390x_ed25519_digestsign(edkey, sigret, tbs, tbslen) == 0) {
             ERR_raise(ERR_LIB_PROV, PROV_R_FAILED_TO_SIGN);
             return 0;
@@ -275,7 +275,7 @@ int ed25519_digest_sign(void *vpeddsactx, unsigned char *sigret,
 
     if (peddsactx->prehash_flag) {
         if (!EVP_Q_digest(peddsactx->libctx, SN_sha512, NULL, tbs, tbslen, md, &mdlen)
-                || mdlen != EDDSA_PREHASH_OUTPUT_LEN)
+            || mdlen != EDDSA_PREHASH_OUTPUT_LEN)
             return 0;
         tbs = md;
         tbslen = mdlen;
@@ -284,7 +284,8 @@ int ed25519_digest_sign(void *vpeddsactx, unsigned char *sigret,
     if (ossl_ed25519_sign(sigret, tbs, tbslen, edkey->pubkey, edkey->privkey,
             peddsactx->dom2_flag, peddsactx->prehash_flag, peddsactx->context_string_flag,
             peddsactx->context_string, peddsactx->context_string_len,
-            peddsactx->libctx, NULL) == 0) {
+            peddsactx->libctx, NULL)
+        == 0) {
         ERR_raise(ERR_LIB_PROV, PROV_R_FAILED_TO_SIGN);
         return 0;
     }
@@ -295,9 +296,9 @@ int ed25519_digest_sign(void *vpeddsactx, unsigned char *sigret,
 /* EVP_Q_digest() does not allow variable output length for XOFs,
    so we use this function */
 static int ed448_shake256(OSSL_LIB_CTX *libctx,
-                          const char *propq,
-                          const uint8_t *in, size_t inlen,
-                          uint8_t *out, size_t outlen)
+    const char *propq,
+    const uint8_t *in, size_t inlen,
+    uint8_t *out, size_t outlen)
 {
     int ret = 0;
     EVP_MD_CTX *hash_ctx = EVP_MD_CTX_new();
@@ -307,21 +308,21 @@ static int ed448_shake256(OSSL_LIB_CTX *libctx,
         goto err;
 
     if (!EVP_DigestInit_ex(hash_ctx, shake256, NULL)
-            || !EVP_DigestUpdate(hash_ctx, in, inlen)
-            || !EVP_DigestFinalXOF(hash_ctx, out, outlen))
+        || !EVP_DigestUpdate(hash_ctx, in, inlen)
+        || !EVP_DigestFinalXOF(hash_ctx, out, outlen))
         goto err;
 
     ret = 1;
 
- err:
+err:
     EVP_MD_CTX_free(hash_ctx);
     EVP_MD_free(shake256);
     return ret;
 }
 
 int ed448_digest_sign(void *vpeddsactx, unsigned char *sigret,
-                      size_t *siglen, size_t sigsize,
-                      const unsigned char *tbs, size_t tbslen)
+    size_t *siglen, size_t sigsize,
+    const unsigned char *tbs, size_t tbslen)
 {
     PROV_EDDSA_CTX *peddsactx = (PROV_EDDSA_CTX *)vpeddsactx;
     const ECX_KEY *edkey = peddsactx->key;
@@ -347,8 +348,8 @@ int ed448_digest_sign(void *vpeddsactx, unsigned char *sigret,
     /* s390x_ed448_digestsign() does not yet support context-strings or pre-hashing.
        fall back to non-accelerated sign if a context-string or pre-hasing is provided. */
     if (S390X_CAN_SIGN(ED448)
-            && peddsactx->context_string_len == 0
-            && peddsactx->prehash_flag == 0) {
+        && peddsactx->context_string_len == 0
+        && peddsactx->prehash_flag == 0) {
         if (s390x_ed448_digestsign(edkey, sigret, tbs, tbslen) == 0) {
             ERR_raise(ERR_LIB_PROV, PROV_R_FAILED_TO_SIGN);
             return 0;
@@ -366,9 +367,10 @@ int ed448_digest_sign(void *vpeddsactx, unsigned char *sigret,
     }
 
     if (ossl_ed448_sign(peddsactx->libctx, sigret, tbs, tbslen,
-                        edkey->pubkey, edkey->privkey,
-                        peddsactx->context_string, peddsactx->context_string_len,
-                        peddsactx->prehash_flag, edkey->propq) == 0) {
+            edkey->pubkey, edkey->privkey,
+            peddsactx->context_string, peddsactx->context_string_len,
+            peddsactx->prehash_flag, edkey->propq)
+        == 0) {
         ERR_raise(ERR_LIB_PROV, PROV_R_FAILED_TO_SIGN);
         return 0;
     }
@@ -377,8 +379,8 @@ int ed448_digest_sign(void *vpeddsactx, unsigned char *sigret,
 }
 
 int ed25519_digest_verify(void *vpeddsactx, const unsigned char *sig,
-                          size_t siglen, const unsigned char *tbs,
-                          size_t tbslen)
+    size_t siglen, const unsigned char *tbs,
+    size_t tbslen)
 {
     PROV_EDDSA_CTX *peddsactx = (PROV_EDDSA_CTX *)vpeddsactx;
     const ECX_KEY *edkey = peddsactx->key;
@@ -392,30 +394,30 @@ int ed25519_digest_verify(void *vpeddsactx, const unsigned char *sig,
     /* s390x_ed25519_digestverify() does not yet support dom2 or context-strings.
        fall back to non-accelerated verify if those options are set. */
     if (S390X_CAN_SIGN(ED25519)
-            && !peddsactx->dom2_flag
-            && !peddsactx->context_string_flag
-            && peddsactx->context_string_len == 0) {
+        && !peddsactx->dom2_flag
+        && !peddsactx->context_string_flag
+        && peddsactx->context_string_len == 0) {
         return s390x_ed25519_digestverify(edkey, sig, tbs, tbslen);
     }
 #endif /* S390X_EC_ASM */
 
     if (peddsactx->prehash_flag) {
         if (!EVP_Q_digest(peddsactx->libctx, SN_sha512, NULL, tbs, tbslen, md, &mdlen)
-                || mdlen != EDDSA_PREHASH_OUTPUT_LEN)
+            || mdlen != EDDSA_PREHASH_OUTPUT_LEN)
             return 0;
         tbs = md;
         tbslen = mdlen;
     }
 
     return ossl_ed25519_verify(tbs, tbslen, sig, edkey->pubkey,
-                               peddsactx->dom2_flag, peddsactx->prehash_flag, peddsactx->context_string_flag,
-                               peddsactx->context_string, peddsactx->context_string_len,
-                               peddsactx->libctx, edkey->propq);
+        peddsactx->dom2_flag, peddsactx->prehash_flag, peddsactx->context_string_flag,
+        peddsactx->context_string, peddsactx->context_string_len,
+        peddsactx->libctx, edkey->propq);
 }
 
 int ed448_digest_verify(void *vpeddsactx, const unsigned char *sig,
-                        size_t siglen, const unsigned char *tbs,
-                        size_t tbslen)
+    size_t siglen, const unsigned char *tbs,
+    size_t tbslen)
 {
     PROV_EDDSA_CTX *peddsactx = (PROV_EDDSA_CTX *)vpeddsactx;
     const ECX_KEY *edkey = peddsactx->key;
@@ -429,8 +431,8 @@ int ed448_digest_verify(void *vpeddsactx, const unsigned char *sig,
     /* s390x_ed448_digestverify() does not yet support context-strings or pre-hashing.
        fall back to non-accelerated verify if a context-string or pre-hasing is provided. */
     if (S390X_CAN_SIGN(ED448)
-            && peddsactx->context_string_len == 0
-            && peddsactx->prehash_flag == 0) {
+        && peddsactx->context_string_len == 0
+        && peddsactx->prehash_flag == 0) {
         return s390x_ed448_digestverify(edkey, sig, tbs, tbslen);
     }
 #endif /* S390X_EC_ASM */
@@ -443,8 +445,8 @@ int ed448_digest_verify(void *vpeddsactx, const unsigned char *sig,
     }
 
     return ossl_ed448_verify(peddsactx->libctx, tbs, tbslen, sig, edkey->pubkey,
-                             peddsactx->context_string, peddsactx->context_string_len,
-                             peddsactx->prehash_flag, edkey->propq);
+        peddsactx->context_string, peddsactx->context_string_len,
+        peddsactx->prehash_flag, edkey->propq);
 }
 
 static void eddsa_freectx(void *vpeddsactx)
@@ -478,7 +480,7 @@ static void *eddsa_dupctx(void *vpeddsactx)
     dstctx->key = srcctx->key;
 
     return dstctx;
- err:
+err:
     eddsa_freectx(dstctx);
     return NULL;
 }
@@ -492,8 +494,7 @@ static int eddsa_get_ctx_params(void *vpeddsactx, OSSL_PARAM *params)
         return 0;
 
     p = OSSL_PARAM_locate(params, OSSL_SIGNATURE_PARAM_ALGORITHM_ID);
-    if (p != NULL && !OSSL_PARAM_set_octet_string(p, peddsactx->aid,
-                                                  peddsactx->aid_len))
+    if (p != NULL && !OSSL_PARAM_set_octet_string(p, peddsactx->aid, peddsactx->aid_len))
         return 0;
 
     return 1;
@@ -507,7 +508,7 @@ static const OSSL_PARAM known_gettable_ctx_params[] = {
 };
 
 static const OSSL_PARAM *eddsa_gettable_ctx_params(ossl_unused void *vpeddsactx,
-                                                   ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return known_gettable_ctx_params;
 }
@@ -532,37 +533,43 @@ static int eddsa_set_ctx_params(void *vpeddsactx, const OSSL_PARAM params[])
 
         if (OPENSSL_strcasecmp(pinstance_name, SN_Ed25519) == 0) {
             peddsactx->instance_id = ID_Ed25519;
-            if (peddsactx->key->type != ECX_KEY_TYPE_ED25519) return 0;
+            if (peddsactx->key->type != ECX_KEY_TYPE_ED25519)
+                return 0;
             peddsactx->dom2_flag = 0;
             peddsactx->prehash_flag = 0;
             peddsactx->context_string_flag = 0;
+#ifndef FIPS_MODULE
         } else if (OPENSSL_strcasecmp(pinstance_name, SN_Ed25519ctx) == 0) {
             peddsactx->instance_id = ID_Ed25519ctx;
-            if (peddsactx->key->type != ECX_KEY_TYPE_ED25519) return 0;
+            if (peddsactx->key->type != ECX_KEY_TYPE_ED25519)
+                return 0;
             peddsactx->dom2_flag = 1;
             peddsactx->prehash_flag = 0;
             peddsactx->context_string_flag = 1;
+#endif
         } else if (OPENSSL_strcasecmp(pinstance_name, SN_Ed25519ph) == 0) {
             peddsactx->instance_id = ID_Ed25519ph;
-            if (peddsactx->key->type != ECX_KEY_TYPE_ED25519) return 0;
+            if (peddsactx->key->type != ECX_KEY_TYPE_ED25519)
+                return 0;
             peddsactx->dom2_flag = 1;
             peddsactx->prehash_flag = 1;
             peddsactx->context_string_flag = 0;
         } else if (OPENSSL_strcasecmp(pinstance_name, SN_Ed448) == 0) {
             peddsactx->instance_id = ID_Ed448;
-            if (peddsactx->key->type != ECX_KEY_TYPE_ED448) return 0;
+            if (peddsactx->key->type != ECX_KEY_TYPE_ED448)
+                return 0;
             peddsactx->prehash_flag = 0;
             peddsactx->context_string_flag = 0;
         } else if (OPENSSL_strcasecmp(pinstance_name, SN_Ed448ph) == 0) {
             peddsactx->instance_id = ID_Ed448ph;
-            if (peddsactx->key->type != ECX_KEY_TYPE_ED448) return 0;
+            if (peddsactx->key->type != ECX_KEY_TYPE_ED448)
+                return 0;
             peddsactx->prehash_flag = 1;
             peddsactx->context_string_flag = 0;
         } else {
             /* we did not recognize the instance */
             return 0;
         }
-
     }
 
     p = OSSL_PARAM_locate_const(params, OSSL_SIGNATURE_PARAM_CONTEXT_STRING);
@@ -585,7 +592,7 @@ static const OSSL_PARAM settable_ctx_params[] = {
 };
 
 static const OSSL_PARAM *eddsa_settable_ctx_params(ossl_unused void *vpeddsactx,
-                                                   ossl_unused void *provctx)
+    ossl_unused void *provctx)
 {
     return settable_ctx_params;
 }
@@ -593,49 +600,49 @@ static const OSSL_PARAM *eddsa_settable_ctx_params(ossl_unused void *vpeddsactx,
 const OSSL_DISPATCH ossl_ed25519_signature_functions[] = {
     { OSSL_FUNC_SIGNATURE_NEWCTX, (void (*)(void))eddsa_newctx },
     { OSSL_FUNC_SIGNATURE_DIGEST_SIGN_INIT,
-      (void (*)(void))eddsa_digest_signverify_init },
+        (void (*)(void))eddsa_digest_signverify_init },
     { OSSL_FUNC_SIGNATURE_DIGEST_SIGN,
-      (void (*)(void))ed25519_digest_sign },
+        (void (*)(void))ed25519_digest_sign },
     { OSSL_FUNC_SIGNATURE_DIGEST_VERIFY_INIT,
-      (void (*)(void))eddsa_digest_signverify_init },
+        (void (*)(void))eddsa_digest_signverify_init },
     { OSSL_FUNC_SIGNATURE_DIGEST_VERIFY,
-      (void (*)(void))ed25519_digest_verify },
+        (void (*)(void))ed25519_digest_verify },
     { OSSL_FUNC_SIGNATURE_FREECTX, (void (*)(void))eddsa_freectx },
     { OSSL_FUNC_SIGNATURE_DUPCTX, (void (*)(void))eddsa_dupctx },
     { OSSL_FUNC_SIGNATURE_GET_CTX_PARAMS, (void (*)(void))eddsa_get_ctx_params },
     { OSSL_FUNC_SIGNATURE_GETTABLE_CTX_PARAMS,
-      (void (*)(void))eddsa_gettable_ctx_params },
+        (void (*)(void))eddsa_gettable_ctx_params },
     { OSSL_FUNC_SIGNATURE_SET_CTX_PARAMS, (void (*)(void))eddsa_set_ctx_params },
     { OSSL_FUNC_SIGNATURE_SETTABLE_CTX_PARAMS,
-      (void (*)(void))eddsa_settable_ctx_params },
+        (void (*)(void))eddsa_settable_ctx_params },
     OSSL_DISPATCH_END
 };
 
 const OSSL_DISPATCH ossl_ed448_signature_functions[] = {
     { OSSL_FUNC_SIGNATURE_NEWCTX, (void (*)(void))eddsa_newctx },
     { OSSL_FUNC_SIGNATURE_DIGEST_SIGN_INIT,
-      (void (*)(void))eddsa_digest_signverify_init },
+        (void (*)(void))eddsa_digest_signverify_init },
     { OSSL_FUNC_SIGNATURE_DIGEST_SIGN,
-      (void (*)(void))ed448_digest_sign },
+        (void (*)(void))ed448_digest_sign },
     { OSSL_FUNC_SIGNATURE_DIGEST_VERIFY_INIT,
-      (void (*)(void))eddsa_digest_signverify_init },
+        (void (*)(void))eddsa_digest_signverify_init },
     { OSSL_FUNC_SIGNATURE_DIGEST_VERIFY,
-      (void (*)(void))ed448_digest_verify },
+        (void (*)(void))ed448_digest_verify },
     { OSSL_FUNC_SIGNATURE_FREECTX, (void (*)(void))eddsa_freectx },
     { OSSL_FUNC_SIGNATURE_DUPCTX, (void (*)(void))eddsa_dupctx },
     { OSSL_FUNC_SIGNATURE_GET_CTX_PARAMS, (void (*)(void))eddsa_get_ctx_params },
     { OSSL_FUNC_SIGNATURE_GETTABLE_CTX_PARAMS,
-      (void (*)(void))eddsa_gettable_ctx_params },
+        (void (*)(void))eddsa_gettable_ctx_params },
     { OSSL_FUNC_SIGNATURE_SET_CTX_PARAMS, (void (*)(void))eddsa_set_ctx_params },
     { OSSL_FUNC_SIGNATURE_SETTABLE_CTX_PARAMS,
-      (void (*)(void))eddsa_settable_ctx_params },
+        (void (*)(void))eddsa_settable_ctx_params },
     OSSL_DISPATCH_END
 };
 
 #ifdef S390X_EC_ASM
 
 static int s390x_ed25519_digestsign(const ECX_KEY *edkey, unsigned char *sig,
-                                    const unsigned char *tbs, size_t tbslen)
+    const unsigned char *tbs, size_t tbslen)
 {
     int rc;
     union {
@@ -660,7 +667,7 @@ static int s390x_ed25519_digestsign(const ECX_KEY *edkey, unsigned char *sig,
 }
 
 static int s390x_ed448_digestsign(const ECX_KEY *edkey, unsigned char *sig,
-                                  const unsigned char *tbs, size_t tbslen)
+    const unsigned char *tbs, size_t tbslen)
 {
     int rc;
     union {
@@ -687,8 +694,8 @@ static int s390x_ed448_digestsign(const ECX_KEY *edkey, unsigned char *sig,
 }
 
 static int s390x_ed25519_digestverify(const ECX_KEY *edkey,
-                                      const unsigned char *sig,
-                                      const unsigned char *tbs, size_t tbslen)
+    const unsigned char *sig,
+    const unsigned char *tbs, size_t tbslen)
 {
     union {
         struct {
@@ -704,13 +711,16 @@ static int s390x_ed25519_digestverify(const ECX_KEY *edkey,
     s390x_flip_endian32(param.ed25519.pub, edkey->pubkey);
 
     return s390x_kdsa(S390X_EDDSA_VERIFY_ED25519,
-                      &param.ed25519, tbs, tbslen) == 0 ? 1 : 0;
+               &param.ed25519, tbs, tbslen)
+            == 0
+        ? 1
+        : 0;
 }
 
 static int s390x_ed448_digestverify(const ECX_KEY *edkey,
-                                    const unsigned char *sig,
-                                    const unsigned char *tbs,
-                                    size_t tbslen)
+    const unsigned char *sig,
+    const unsigned char *tbs,
+    size_t tbslen)
 {
     union {
         struct {
@@ -729,7 +739,10 @@ static int s390x_ed448_digestverify(const ECX_KEY *edkey,
     s390x_flip_endian64(param.ed448.pub, param.ed448.pub);
 
     return s390x_kdsa(S390X_EDDSA_VERIFY_ED448,
-                      &param.ed448, tbs, tbslen) == 0 ? 1 : 0;
+               &param.ed448, tbs, tbslen)
+            == 0
+        ? 1
+        : 0;
 }
 
 #endif /* S390X_EC_ASM */
