@@ -1,5 +1,5 @@
 /*
- * Copyright 2022-2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2022-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -12,12 +12,14 @@
 #include "../ssl_local.h"
 #include "internal/quic_error.h"
 
-#define QUIC_TLS_FATAL(rl, ad, err) \
-    do { \
-        if ((rl) != NULL) (rl)->alert = (ad); \
+#define QUIC_TLS_FATAL(rl, ad, err)    \
+    do {                               \
+        if ((rl) != NULL)              \
+            (rl)->alert = (ad);        \
         ERR_raise(ERR_LIB_SSL, (err)); \
-        if ((rl) != NULL) (rl)->qtls->inerror = 1; \
-    } while(0)
+        if ((rl) != NULL)              \
+            (rl)->qtls->inerror = 1;   \
+    } while (0)
 
 struct quic_tls_st {
     QUIC_TLS_ARGS args;
@@ -89,18 +91,18 @@ static int quic_free(OSSL_RECORD_LAYER *r);
 
 static int
 quic_new_record_layer(OSSL_LIB_CTX *libctx, const char *propq, int vers,
-                      int role, int direction, int level, uint16_t epoch,
-                      unsigned char *secret, size_t secretlen,
-                      unsigned char *key, size_t keylen, unsigned char *iv,
-                      size_t ivlen, unsigned char *mackey, size_t mackeylen,
-                      const EVP_CIPHER *ciph, size_t taglen,
-                      int mactype,
-                      const EVP_MD *md, COMP_METHOD *comp,
-                      const EVP_MD *kdfdigest, BIO *prev, BIO *transport,
-                      BIO *next, BIO_ADDR *local, BIO_ADDR *peer,
-                      const OSSL_PARAM *settings, const OSSL_PARAM *options,
-                      const OSSL_DISPATCH *fns, void *cbarg, void *rlarg,
-                      OSSL_RECORD_LAYER **retrl)
+    int role, int direction, int level, uint16_t epoch,
+    unsigned char *secret, size_t secretlen,
+    unsigned char *key, size_t keylen, unsigned char *iv,
+    size_t ivlen, unsigned char *mackey, size_t mackeylen,
+    const EVP_CIPHER *ciph, size_t taglen,
+    int mactype,
+    const EVP_MD *md, COMP_METHOD *comp,
+    const EVP_MD *kdfdigest, BIO *prev, BIO *transport,
+    BIO *next, BIO_ADDR *local, BIO_ADDR *peer,
+    const OSSL_PARAM *settings, const OSSL_PARAM *options,
+    const OSSL_DISPATCH *fns, void *cbarg, void *rlarg,
+    OSSL_RECORD_LAYER **retrl)
 {
     OSSL_RECORD_LAYER *rl = OPENSSL_zalloc(sizeof(*rl));
     uint32_t enc_level;
@@ -180,15 +182,15 @@ quic_new_record_layer(OSSL_LIB_CTX *libctx, const char *propq, int vers,
     }
 
     if (!rl->qtls->args.yield_secret_cb(enc_level, qdir, suite_id,
-                                        (EVP_MD *)kdfdigest, secret, secretlen,
-                                        rl->qtls->args.yield_secret_cb_arg)) {
+            (EVP_MD *)kdfdigest, secret, secretlen,
+            rl->qtls->args.yield_secret_cb_arg)) {
         QUIC_TLS_FATAL(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
         EVP_MD_free((EVP_MD *)kdfdigest);
         goto err;
     }
 
     return 1;
- err:
+err:
     *retrl = NULL;
     quic_free(rl);
     return 0;
@@ -232,15 +234,15 @@ static int quic_processed_read_pending(OSSL_RECORD_LAYER *rl)
 }
 
 static size_t quic_get_max_records(OSSL_RECORD_LAYER *rl, uint8_t type,
-                                   size_t len,
-                                   size_t maxfrag, size_t *preffrag)
+    size_t len,
+    size_t maxfrag, size_t *preffrag)
 {
     return 1;
 }
 
 static int quic_write_records(OSSL_RECORD_LAYER *rl,
-                              OSSL_RECORD_TEMPLATE *template,
-                              size_t numtempl)
+    OSSL_RECORD_TEMPLATE *template,
+    size_t numtempl)
 {
     size_t consumed;
     unsigned char alert;
@@ -261,8 +263,8 @@ static int quic_write_records(OSSL_RECORD_LAYER *rl,
          * and manufacture a dummy record header
          */
         dummyrec[0] = (rl->level == OSSL_RECORD_PROTECTION_LEVEL_NONE)
-                        ? template->type
-                        : SSL3_RT_APPLICATION_DATA;
+            ? template->type
+            : SSL3_RT_APPLICATION_DATA;
         dummyrec[1] = (unsigned char)((template->version >> 8) & 0xff);
         dummyrec[2] = (unsigned char)(template->version & 0xff);
         /*
@@ -275,11 +277,11 @@ static int quic_write_records(OSSL_RECORD_LAYER *rl,
         dummyrec[4] = (unsigned char)(template->buflen & 0xff);
 
         rl->msg_callback(1, TLS1_3_VERSION, SSL3_RT_HEADER, dummyrec,
-                            SSL3_RT_HEADER_LENGTH, rl->cbarg);
+            SSL3_RT_HEADER_LENGTH, rl->cbarg);
 
         if (rl->level != OSSL_RECORD_PROTECTION_LEVEL_NONE) {
             rl->msg_callback(1, TLS1_3_VERSION, SSL3_RT_INNER_CONTENT_TYPE,
-                             &template->type, 1, rl->cbarg);
+                &template->type, 1, rl->cbarg);
         }
     }
 
@@ -312,9 +314,9 @@ static int quic_write_records(OSSL_RECORD_LAYER *rl,
          * failure)
          */
         if (!rl->qtls->args.crypto_send_cb(template->buf + rl->written,
-                                           template->buflen - rl->written,
-                                           &consumed,
-                                           rl->qtls->args.crypto_send_cb_arg)) {
+                template->buflen - rl->written,
+                &consumed,
+                rl->qtls->args.crypto_send_cb_arg)) {
             QUIC_TLS_FATAL(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
             return OSSL_RECORD_RETURN_FATAL;
         }
@@ -358,9 +360,9 @@ static int quic_retry_write_records(OSSL_RECORD_LAYER *rl)
 }
 
 static int quic_read_record(OSSL_RECORD_LAYER *rl, void **rechandle,
-                            int *rversion, uint8_t *type, const unsigned char **data,
-                            size_t *datalen, uint16_t *epoch,
-                            unsigned char *seq_num)
+    int *rversion, uint8_t *type, const unsigned char **data,
+    size_t *datalen, uint16_t *epoch,
+    unsigned char *seq_num)
 {
     if (rl->recread != 0 || rl->recunreleased != 0)
         return OSSL_RECORD_RETURN_FATAL;
@@ -368,7 +370,7 @@ static int quic_read_record(OSSL_RECORD_LAYER *rl, void **rechandle,
     BIO_clear_retry_flags(rl->dummybio);
 
     if (!rl->qtls->args.crypto_recv_rcd_cb(data, datalen,
-                                           rl->qtls->args.crypto_recv_rcd_cb_arg)) {
+            rl->qtls->args.crypto_recv_rcd_cb_arg)) {
         QUIC_TLS_FATAL(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
         return OSSL_RECORD_RETURN_FATAL;
     }
@@ -392,8 +394,8 @@ static int quic_read_record(OSSL_RECORD_LAYER *rl, void **rechandle,
          * and manufacture a dummy record header
          */
         dummyrec[0] = (rl->level == OSSL_RECORD_PROTECTION_LEVEL_NONE)
-                      ? SSL3_RT_HANDSHAKE
-                      : SSL3_RT_APPLICATION_DATA;
+            ? SSL3_RT_HANDSHAKE
+            : SSL3_RT_APPLICATION_DATA;
         dummyrec[1] = (unsigned char)((TLS1_2_VERSION >> 8) & 0xff);
         dummyrec[2] = (unsigned char)(TLS1_2_VERSION & 0xff);
         /*
@@ -404,21 +406,21 @@ static int quic_read_record(OSSL_RECORD_LAYER *rl, void **rechandle,
         dummyrec[4] = (unsigned char)(*datalen & 0xff);
 
         rl->msg_callback(0, TLS1_3_VERSION, SSL3_RT_HEADER, dummyrec,
-                         SSL3_RT_HEADER_LENGTH, rl->cbarg);
+            SSL3_RT_HEADER_LENGTH, rl->cbarg);
         rl->msg_callback(0, TLS1_3_VERSION, SSL3_RT_INNER_CONTENT_TYPE, type, 1,
-                         rl->cbarg);
+            rl->cbarg);
     }
 
     return OSSL_RECORD_RETURN_SUCCESS;
 }
 
 static int quic_release_record(OSSL_RECORD_LAYER *rl, void *rechandle,
-                               size_t length)
+    size_t length)
 {
     if (!ossl_assert(rl->recread > 0)
-            || !ossl_assert(rl->recunreleased <= rl->recread)
-            || !ossl_assert(rl == rechandle)
-            || !ossl_assert(length <= rl->recunreleased)) {
+        || !ossl_assert(rl->recunreleased <= rl->recread)
+        || !ossl_assert(rl == rechandle)
+        || !ossl_assert(length <= rl->recunreleased)) {
         QUIC_TLS_FATAL(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
         return OSSL_RECORD_RETURN_FATAL;
     }
@@ -429,7 +431,7 @@ static int quic_release_record(OSSL_RECORD_LAYER *rl, void *rechandle,
         return OSSL_RECORD_RETURN_SUCCESS;
 
     if (!rl->qtls->args.crypto_release_rcd_cb(rl->recread,
-                                              rl->qtls->args.crypto_release_rcd_cb_arg)) {
+            rl->qtls->args.crypto_release_rcd_cb_arg)) {
         QUIC_TLS_FATAL(rl, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
         return OSSL_RECORD_RETURN_FATAL;
     }
@@ -470,7 +472,7 @@ static void quic_set_max_pipelines(OSSL_RECORD_LAYER *rl, size_t max_pipelines)
 }
 
 static void quic_get_state(OSSL_RECORD_LAYER *rl, const char **shortstr,
-                    const char **longstr)
+    const char **longstr)
 {
     /*
      * According to the docs, valid read state strings are: "RH"/"read header",
@@ -596,10 +598,10 @@ static const OSSL_RECORD_METHOD quic_tls_record_method = {
 };
 
 static int add_transport_params_cb(SSL *s, unsigned int ext_type,
-                                   unsigned int context,
-                                   const unsigned char **out, size_t *outlen,
-                                   X509 *x, size_t chainidx, int *al,
-                                   void *add_arg)
+    unsigned int context,
+    const unsigned char **out, size_t *outlen,
+    X509 *x, size_t chainidx, int *al,
+    void *add_arg)
 {
     QUIC_TLS *qtls = add_arg;
 
@@ -609,23 +611,23 @@ static int add_transport_params_cb(SSL *s, unsigned int ext_type,
 }
 
 static void free_transport_params_cb(SSL *s, unsigned int ext_type,
-                                     unsigned int context,
-                                     const unsigned char *out,
-                                     void *add_arg)
+    unsigned int context,
+    const unsigned char *out,
+    void *add_arg)
 {
 }
 
 static int parse_transport_params_cb(SSL *s, unsigned int ext_type,
-                                     unsigned int context,
-                                     const unsigned char *in,
-                                     size_t inlen, X509 *x,
-                                     size_t chainidx,
-                                     int *al, void *parse_arg)
+    unsigned int context,
+    const unsigned char *in,
+    size_t inlen, X509 *x,
+    size_t chainidx,
+    int *al, void *parse_arg)
 {
     QUIC_TLS *qtls = parse_arg;
 
     return qtls->args.got_transport_params_cb(in, inlen,
-                                              qtls->args.got_transport_params_cb_arg);
+        qtls->args.got_transport_params_cb_arg);
 }
 
 QUIC_TLS *ossl_quic_tls_new(const QUIC_TLS_ARGS *args)
@@ -661,10 +663,10 @@ void ossl_quic_tls_free(QUIC_TLS *qtls)
 }
 
 static int raise_error(QUIC_TLS *qtls, uint64_t error_code,
-                       const char *error_msg,
-                       const char *src_file,
-                       int src_line,
-                       const char *src_func)
+    const char *error_msg,
+    const char *src_file,
+    int src_line,
+    const char *src_func)
 {
     /*
      * When QTLS fails, add a "cover letter" error with information, potentially
@@ -675,28 +677,28 @@ static int raise_error(QUIC_TLS *qtls, uint64_t error_code,
     ERR_new();
     ERR_set_debug(src_file, src_line, src_func);
     ERR_set_error(ERR_LIB_SSL, SSL_R_QUIC_HANDSHAKE_LAYER_ERROR,
-                  "handshake layer error, error code %llu (0x%llx) (\"%s\")",
-                  error_code, error_code, error_msg);
+        "handshake layer error, error code %llu (0x%llx) (\"%s\")",
+        error_code, error_code, error_msg);
     OSSL_ERR_STATE_save_to_mark(qtls->error_state);
 
     /*
      * We record the error information reported via the QUIC protocol
      * separately.
      */
-    qtls->error_code        = error_code;
-    qtls->error_msg         = error_msg;
-    qtls->inerror           = 1;
+    qtls->error_code = error_code;
+    qtls->error_msg = error_msg;
+    qtls->inerror = 1;
 
     ERR_pop_to_mark();
     return 0;
 }
 
-#define RAISE_ERROR(qtls, error_code, error_msg) \
+#define RAISE_ERROR(qtls, error_code, error_msg)   \
     raise_error((qtls), (error_code), (error_msg), \
-                OPENSSL_FILE, OPENSSL_LINE, OPENSSL_FUNC)
+        OPENSSL_FILE, OPENSSL_LINE, OPENSSL_FUNC)
 
 #define RAISE_INTERNAL_ERROR(qtls) \
-    RAISE_ERROR((qtls), QUIC_ERR_INTERNAL_ERROR, "internal error")
+    RAISE_ERROR((qtls), OSSL_QUIC_ERR_INTERNAL_ERROR, "internal error")
 
 int ossl_quic_tls_tick(QUIC_TLS *qtls)
 {
@@ -746,8 +748,8 @@ int ossl_quic_tls_tick(QUIC_TLS *qtls)
                 return RAISE_INTERNAL_ERROR(qtls);
         } else {
             if (sc->ext.alpn == NULL || sc->ext.alpn_len == 0)
-                return RAISE_ERROR(qtls, QUIC_ERR_CRYPTO_NO_APP_PROTO,
-                                   "ALPN must be configured when using QUIC");
+                return RAISE_ERROR(qtls, OSSL_QUIC_ERR_CRYPTO_NO_APP_PROTO,
+                    "ALPN must be configured when using QUIC");
         }
         if (!SSL_set_min_proto_version(qtls->args.s, TLS1_3_VERSION))
             return RAISE_INTERNAL_ERROR(qtls);
@@ -756,15 +758,15 @@ int ossl_quic_tls_tick(QUIC_TLS *qtls)
         ossl_ssl_set_custom_record_layer(sc, &quic_tls_record_method, qtls);
 
         if (!ossl_tls_add_custom_ext_intern(NULL, &sc->cert->custext,
-                                            qtls->args.is_server ? ENDPOINT_SERVER
-                                                                 : ENDPOINT_CLIENT,
-                                            TLSEXT_TYPE_quic_transport_parameters,
-                                            SSL_EXT_TLS1_3_ONLY
-                                            | SSL_EXT_CLIENT_HELLO
-                                            | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS,
-                                            add_transport_params_cb,
-                                            free_transport_params_cb, qtls,
-                                            parse_transport_params_cb, qtls))
+                qtls->args.is_server ? ENDPOINT_SERVER
+                                     : ENDPOINT_CLIENT,
+                TLSEXT_TYPE_quic_transport_parameters,
+                SSL_EXT_TLS1_3_ONLY
+                    | SSL_EXT_CLIENT_HELLO
+                    | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS,
+                add_transport_params_cb,
+                free_transport_params_cb, qtls,
+                parse_transport_params_cb, qtls))
             return RAISE_INTERNAL_ERROR(qtls);
 
         nullbio = BIO_new(BIO_s_null());
@@ -796,7 +798,7 @@ int ossl_quic_tls_tick(QUIC_TLS *qtls)
 
     if (ret <= 0) {
         err = ossl_ssl_get_error(qtls->args.s, ret,
-                                 /*check_err=*/ERR_count_to_mark() > 0);
+            /*check_err=*/ERR_count_to_mark() > 0);
 
         switch (err) {
         case SSL_ERROR_WANT_READ:
@@ -816,8 +818,8 @@ int ossl_quic_tls_tick(QUIC_TLS *qtls)
         /* Validate that we have ALPN */
         SSL_get0_alpn_selected(qtls->args.s, &alpn, &alpnlen);
         if (alpn == NULL || alpnlen == 0)
-            return RAISE_ERROR(qtls, QUIC_ERR_CRYPTO_NO_APP_PROTO,
-                               "no application protocol negotiated");
+            return RAISE_ERROR(qtls, OSSL_QUIC_ERR_CRYPTO_NO_APP_PROTO,
+                "no application protocol negotiated");
 
         qtls->complete = 1;
         ERR_pop_to_mark();
@@ -829,23 +831,23 @@ int ossl_quic_tls_tick(QUIC_TLS *qtls)
 }
 
 int ossl_quic_tls_set_transport_params(QUIC_TLS *qtls,
-                                       const unsigned char *transport_params,
-                                       size_t transport_params_len)
+    const unsigned char *transport_params,
+    size_t transport_params_len)
 {
-    qtls->local_transport_params       = transport_params;
-    qtls->local_transport_params_len   = transport_params_len;
+    qtls->local_transport_params = transport_params;
+    qtls->local_transport_params_len = transport_params_len;
     return 1;
 }
 
 int ossl_quic_tls_get_error(QUIC_TLS *qtls,
-                            uint64_t *error_code,
-                            const char **error_msg,
-                            ERR_STATE **error_state)
+    uint64_t *error_code,
+    const char **error_msg,
+    ERR_STATE **error_state)
 {
     if (qtls->inerror) {
-        *error_code     = qtls->error_code;
-        *error_msg      = qtls->error_msg;
-        *error_state    = qtls->error_state;
+        *error_code = qtls->error_code;
+        *error_msg = qtls->error_msg;
+        *error_state = qtls->error_state;
     }
 
     return qtls->inerror;
