@@ -1,5 +1,5 @@
 /*
- * Copyright 2023 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2023-2024 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -79,41 +79,45 @@ static int frame_ack(BIO *bio, PACKET *pkt)
     OSSL_QUIC_ACK_RANGE *ack_ranges = NULL;
     uint64_t total_ranges = 0;
     uint64_t i;
+    int ret = 0;
 
     if (!ossl_quic_wire_peek_frame_ack_num_ranges(pkt, &total_ranges)
         /* In case sizeof(uint64_t) > sizeof(size_t) */
         || total_ranges > SIZE_MAX / sizeof(ack_ranges[0])
         || (ack_ranges = OPENSSL_zalloc(sizeof(ack_ranges[0])
-                                        * (size_t)total_ranges)) == NULL)
-        return 0;
+                * (size_t)total_ranges))
+            == NULL)
+        return ret;
 
     ack.ack_ranges = ack_ranges;
     ack.num_ack_ranges = (size_t)total_ranges;
 
     /* Ack delay exponent is 0, so we can get the raw delay time below */
     if (!ossl_quic_wire_decode_frame_ack(pkt, 0, &ack, NULL))
-        return 0;
+        goto end;
 
     BIO_printf(bio, "    Largest acked: %llu\n",
-               (unsigned long long)ack.ack_ranges[0].end);
+        (unsigned long long)ack.ack_ranges[0].end);
     BIO_printf(bio, "    Ack delay (raw) %llu\n",
-               (unsigned long long)ossl_time2ticks(ack.delay_time));
+        (unsigned long long)ossl_time2ticks(ack.delay_time));
     BIO_printf(bio, "    Ack range count: %llu\n",
-               (unsigned long long)total_ranges - 1);
+        (unsigned long long)total_ranges - 1);
     BIO_printf(bio, "    First ack range: %llu\n",
-               (unsigned long long)(ack.ack_ranges[0].end
-                                    - ack.ack_ranges[0].start));
+        (unsigned long long)(ack.ack_ranges[0].end
+            - ack.ack_ranges[0].start));
     for (i = 1; i < total_ranges; i++) {
         BIO_printf(bio, "    Gap: %llu\n",
-                   (unsigned long long)(ack.ack_ranges[i - 1].start
-                                        - ack.ack_ranges[i].end - 2));
+            (unsigned long long)(ack.ack_ranges[i - 1].start
+                - ack.ack_ranges[i].end - 2));
         BIO_printf(bio, "    Ack range len: %llu\n",
-                   (unsigned long long)(ack.ack_ranges[i].end
-                                        - ack.ack_ranges[i].start));
+            (unsigned long long)(ack.ack_ranges[i].end
+                - ack.ack_ranges[i].start));
     }
 
+    ret = 1;
+end:
     OPENSSL_free(ack_ranges);
-    return 1;
+    return ret;
 }
 
 static int frame_reset_stream(BIO *bio, PACKET *pkt)
@@ -124,11 +128,11 @@ static int frame_reset_stream(BIO *bio, PACKET *pkt)
         return 0;
 
     BIO_printf(bio, "    Stream id: %llu\n",
-               (unsigned long long)frame_data.stream_id);
+        (unsigned long long)frame_data.stream_id);
     BIO_printf(bio, "    App Protocol Error Code: %llu\n",
-               (unsigned long long)frame_data.app_error_code);
+        (unsigned long long)frame_data.app_error_code);
     BIO_printf(bio, "    Final size: %llu\n",
-               (unsigned long long)frame_data.final_size);
+        (unsigned long long)frame_data.final_size);
 
     return 1;
 }
@@ -141,9 +145,9 @@ static int frame_stop_sending(BIO *bio, PACKET *pkt)
         return 0;
 
     BIO_printf(bio, "    Stream id: %llu\n",
-               (unsigned long long)frame_data.stream_id);
+        (unsigned long long)frame_data.stream_id);
     BIO_printf(bio, "    App Protocol Error Code: %llu\n",
-               (unsigned long long)frame_data.app_error_code);
+        (unsigned long long)frame_data.app_error_code);
 
     return 1;
 }
@@ -182,7 +186,7 @@ static int frame_stream(BIO *bio, PACKET *pkt, uint64_t frame_type)
     OSSL_QUIC_FRAME_STREAM frame_data;
 
     BIO_puts(bio, "Stream");
-    switch(frame_type) {
+    switch (frame_type) {
     case OSSL_QUIC_FRAME_TYPE_STREAM:
         BIO_puts(bio, "\n");
         break;
@@ -223,9 +227,9 @@ static int frame_stream(BIO *bio, PACKET *pkt, uint64_t frame_type)
         return 0;
 
     BIO_printf(bio, "    Stream id: %llu\n",
-               (unsigned long long)frame_data.stream_id);
+        (unsigned long long)frame_data.stream_id);
     BIO_printf(bio, "    Offset: %llu\n",
-               (unsigned long long)frame_data.offset);
+        (unsigned long long)frame_data.offset);
     /*
      * It would be nice to find a way of passing the implicit length through
      * to the msg_callback. But this is not currently possible.
@@ -256,11 +260,11 @@ static int frame_max_stream_data(BIO *bio, PACKET *pkt)
     uint64_t max_stream_data = 0;
 
     if (!ossl_quic_wire_decode_frame_max_stream_data(pkt, &stream_id,
-                                                     &max_stream_data))
+            &max_stream_data))
         return 0;
 
     BIO_printf(bio, "    Max Stream Data: %llu\n",
-               (unsigned long long)max_stream_data);
+        (unsigned long long)max_stream_data);
 
     return 1;
 }
@@ -295,7 +299,7 @@ static int frame_stream_data_blocked(BIO *bio, PACKET *pkt)
     uint64_t max_data = 0;
 
     if (!ossl_quic_wire_decode_frame_stream_data_blocked(pkt, &stream_id,
-                                                         &max_data))
+            &max_data))
         return 0;
 
     BIO_printf(bio, "    Stream id: %llu\n", (unsigned long long)stream_id);
@@ -324,14 +328,14 @@ static int frame_new_conn_id(BIO *bio, PACKET *pkt)
         return 0;
 
     BIO_printf(bio, "    Sequence Number: %llu\n",
-               (unsigned long long)frame_data.seq_num);
+        (unsigned long long)frame_data.seq_num);
     BIO_printf(bio, "    Retire prior to: %llu\n",
-               (unsigned long long)frame_data.retire_prior_to);
+        (unsigned long long)frame_data.retire_prior_to);
     BIO_puts(bio, "    Connection id: ");
     put_conn_id(bio, &frame_data.conn_id);
     BIO_puts(bio, "\n    Stateless Reset Token: ");
     put_data(bio, frame_data.stateless_reset.token,
-             sizeof(frame_data.stateless_reset.token));
+        sizeof(frame_data.stateless_reset.token));
     BIO_puts(bio, "\n");
 
     return 1;
@@ -381,7 +385,7 @@ static int frame_conn_closed(BIO *bio, PACKET *pkt)
         return 0;
 
     BIO_printf(bio, "    Error Code: %llu\n",
-               (unsigned long long)frame_data.error_code);
+        (unsigned long long)frame_data.error_code);
     BIO_puts(bio, "    Reason: ");
     put_str(bio, frame_data.reason, frame_data.reason_len);
     BIO_puts(bio, "\n");
@@ -554,7 +558,7 @@ static int trace_frame_data(BIO *bio, PACKET *pkt)
 }
 
 int ossl_quic_trace(int write_p, int version, int content_type,
-                    const void *buf, size_t msglen, SSL *ssl, void *arg)
+    const void *buf, size_t msglen, SSL *ssl, void *arg)
 {
     BIO *bio = arg;
     PACKET pkt;
@@ -570,67 +574,64 @@ int ossl_quic_trace(int write_p, int version, int content_type,
         BIO_printf(bio, " Datagram\n  Length: %zu\n", msglen);
         break;
 
-    case SSL3_RT_QUIC_PACKET:
-        {
-            QUIC_PKT_HDR hdr;
-            size_t i;
+    case SSL3_RT_QUIC_PACKET: {
+        QUIC_PKT_HDR hdr;
+        size_t i;
 
-            if (!PACKET_buf_init(&pkt, buf, msglen))
-                return 0;
-            /* Decode the packet header */
-            /*
-             * TODO(QUIC SERVER): We need to query the short connection id len
-             * here, e.g. via some API SSL_get_short_conn_id_len()
-             */
-            if (ossl_quic_wire_decode_pkt_hdr(&pkt, 0, 0, 1, &hdr, NULL) != 1)
-                return 0;
+        if (!PACKET_buf_init(&pkt, buf, msglen))
+            return 0;
+        /* Decode the packet header */
+        /*
+         * TODO(QUIC SERVER): We need to query the short connection id len
+         * here, e.g. via some API SSL_get_short_conn_id_len()
+         */
+        if (ossl_quic_wire_decode_pkt_hdr(&pkt, 0, 0, 1, &hdr, NULL) != 1)
+            return 0;
 
-            BIO_puts(bio, write_p ? "Sent" : "Received");
-            BIO_puts(bio, " Packet\n");
-            BIO_printf(bio, "  Packet Type: %s\n", packet_type(hdr.type));
-            if (hdr.type != QUIC_PKT_TYPE_1RTT)
-                BIO_printf(bio, "  Version: 0x%08lx\n",
-                           (unsigned long)hdr.version);
-            BIO_puts(bio, "  Destination Conn Id: ");
-            put_conn_id(bio, &hdr.dst_conn_id);
+        BIO_puts(bio, write_p ? "Sent" : "Received");
+        BIO_puts(bio, " Packet\n");
+        BIO_printf(bio, "  Packet Type: %s\n", packet_type(hdr.type));
+        if (hdr.type != QUIC_PKT_TYPE_1RTT)
+            BIO_printf(bio, "  Version: 0x%08lx\n",
+                (unsigned long)hdr.version);
+        BIO_puts(bio, "  Destination Conn Id: ");
+        put_conn_id(bio, &hdr.dst_conn_id);
+        BIO_puts(bio, "\n");
+        if (hdr.type != QUIC_PKT_TYPE_1RTT) {
+            BIO_puts(bio, "  Source Conn Id: ");
+            put_conn_id(bio, &hdr.src_conn_id);
             BIO_puts(bio, "\n");
-            if (hdr.type != QUIC_PKT_TYPE_1RTT) {
-                BIO_puts(bio, "  Source Conn Id: ");
-                put_conn_id(bio, &hdr.src_conn_id);
-                BIO_puts(bio, "\n");
-            }
-            BIO_printf(bio, "  Payload length: %zu\n", hdr.len);
-            if (hdr.type == QUIC_PKT_TYPE_INITIAL) {
-                BIO_puts(bio, "  Token: ");
-                put_token(bio, hdr.token, hdr.token_len);
-                BIO_puts(bio, "\n");
-            }
-            if (hdr.type != QUIC_PKT_TYPE_VERSION_NEG
-                    && hdr.type != QUIC_PKT_TYPE_RETRY) {
-                BIO_puts(bio, "  Packet Number: 0x");
-                /* Will always be at least 1 byte */
-                for (i = 0; i < hdr.pn_len; i++)
-                    BIO_printf(bio, "%02x", hdr.pn[i]);
-                BIO_puts(bio, "\n");
-            }
-            break;
         }
+        BIO_printf(bio, "  Payload length: %zu\n", hdr.len);
+        if (hdr.type == QUIC_PKT_TYPE_INITIAL) {
+            BIO_puts(bio, "  Token: ");
+            put_token(bio, hdr.token, hdr.token_len);
+            BIO_puts(bio, "\n");
+        }
+        if (hdr.type != QUIC_PKT_TYPE_VERSION_NEG
+            && hdr.type != QUIC_PKT_TYPE_RETRY) {
+            BIO_puts(bio, "  Packet Number: 0x");
+            /* Will always be at least 1 byte */
+            for (i = 0; i < hdr.pn_len; i++)
+                BIO_printf(bio, "%02x", hdr.pn[i]);
+            BIO_puts(bio, "\n");
+        }
+        break;
+    }
 
     case SSL3_RT_QUIC_FRAME_PADDING:
     case SSL3_RT_QUIC_FRAME_FULL:
-    case SSL3_RT_QUIC_FRAME_HEADER:
-        {
-            BIO_puts(bio, write_p ? "Sent" : "Received");
-            BIO_puts(bio, " Frame: ");
+    case SSL3_RT_QUIC_FRAME_HEADER: {
+        BIO_puts(bio, write_p ? "Sent" : "Received");
+        BIO_puts(bio, " Frame: ");
 
-            if (!PACKET_buf_init(&pkt, buf, msglen))
-                return 0;
-            if (!trace_frame_data(bio, &pkt)) {
-                BIO_puts(bio, "  <error processing frame data>\n");
-                return 0;
-            }
+        if (!PACKET_buf_init(&pkt, buf, msglen))
+            return 0;
+        if (!trace_frame_data(bio, &pkt)) {
+            BIO_puts(bio, "  <error processing frame data>\n");
+            return 0;
         }
-        break;
+    } break;
 
     default:
         /* Unrecognised content_type. We defer to SSL_trace */
