@@ -25,19 +25,18 @@
 #include "ssl_cert_table.h"
 #include "internal/thread_once.h"
 #ifndef OPENSSL_NO_POSIX_IO
-# include <sys/stat.h>
-# ifdef _WIN32
-#  define stat _stat
-# endif
-# ifndef S_ISDIR
-#  define S_ISDIR(a) (((a) & S_IFMT) == S_IFDIR)
-# endif
+#include <sys/stat.h>
+#ifdef _WIN32
+#define stat _stat
+#endif
+#ifndef S_ISDIR
+#define S_ISDIR(a) (((a) & S_IFMT) == S_IFDIR)
+#endif
 #endif
 
-
 static int ssl_security_default_callback(const SSL *s, const SSL_CTX *ctx,
-                                         int op, int bits, int nid, void *other,
-                                         void *ex);
+    int op, int bits, int nid, void *other,
+    void *ex);
 
 static CRYPTO_ONCE ssl_x509_store_ctx_once = CRYPTO_ONCE_STATIC_INIT;
 static volatile int ssl_x509_store_ctx_idx = -1;
@@ -45,8 +44,8 @@ static volatile int ssl_x509_store_ctx_idx = -1;
 DEFINE_RUN_ONCE_STATIC(ssl_x509_store_ctx_init)
 {
     ssl_x509_store_ctx_idx = X509_STORE_CTX_get_ex_new_index(0,
-                                                             "SSL for verify callback",
-                                                             NULL, NULL, NULL);
+        "SSL for verify callback",
+        NULL, NULL, NULL);
     return ssl_x509_store_ctx_idx >= 0;
 }
 
@@ -165,22 +164,22 @@ CERT *ssl_cert_dup(CERT *cert)
     /* Configured sigalgs copied across */
     if (cert->conf_sigalgs) {
         ret->conf_sigalgs = OPENSSL_malloc(cert->conf_sigalgslen
-                                           * sizeof(*cert->conf_sigalgs));
+            * sizeof(*cert->conf_sigalgs));
         if (ret->conf_sigalgs == NULL)
             goto err;
         memcpy(ret->conf_sigalgs, cert->conf_sigalgs,
-               cert->conf_sigalgslen * sizeof(*cert->conf_sigalgs));
+            cert->conf_sigalgslen * sizeof(*cert->conf_sigalgs));
         ret->conf_sigalgslen = cert->conf_sigalgslen;
     } else
         ret->conf_sigalgs = NULL;
 
     if (cert->client_sigalgs) {
         ret->client_sigalgs = OPENSSL_malloc(cert->client_sigalgslen
-                                             * sizeof(*cert->client_sigalgs));
+            * sizeof(*cert->client_sigalgs));
         if (ret->client_sigalgs == NULL)
             goto err;
         memcpy(ret->client_sigalgs, cert->client_sigalgs,
-               cert->client_sigalgslen * sizeof(*cert->client_sigalgs));
+            cert->client_sigalgslen * sizeof(*cert->client_sigalgs));
         ret->client_sigalgslen = cert->client_sigalgslen;
     } else
         ret->client_sigalgs = NULL;
@@ -222,7 +221,7 @@ CERT *ssl_cert_dup(CERT *cert)
 #endif
     return ret;
 
- err:
+err:
     ssl_cert_free(ret);
 
     return NULL;
@@ -236,7 +235,7 @@ void ssl_cert_clear_certs(CERT *c)
 #ifndef OPENSSL_NO_COMP_ALG
     int j;
 #endif
-    
+
     if (c == NULL)
         return;
     for (i = 0; i < c->ssl_pkey_num; i++) {
@@ -401,7 +400,7 @@ int ssl_cert_set_current(CERT *c, long op)
     return 0;
 }
 
-void ssl_cert_set_cert_cb(CERT *c, int (*cb) (SSL *ssl, void *arg), void *arg)
+void ssl_cert_set_cert_cb(CERT *c, int (*cb)(SSL *ssl, void *arg), void *arg)
 {
     c->cert_cb = cb;
     c->cert_cb_arg = arg;
@@ -514,7 +513,7 @@ static int ssl_verify_internal(SSL_CONNECTION *s, STACK_OF(X509) *sk, EVP_PKEY *
     /* Move peername from the store context params to the SSL handle's */
     X509_VERIFY_PARAM_move_peername(s->param, param);
 
- end:
+end:
     X509_STORE_CTX_free(ctx);
     return i;
 }
@@ -544,7 +543,7 @@ int ssl_verify_cert_chain(SSL_CONNECTION *s, STACK_OF(X509) *sk)
 }
 
 static void set0_CA_list(STACK_OF(X509_NAME) **ca_list,
-                        STACK_OF(X509_NAME) *name_list)
+    STACK_OF(X509_NAME) *name_list)
 {
     sk_X509_NAME_pop_free(*ca_list, X509_NAME_free);
     *ca_list = name_list;
@@ -569,7 +568,7 @@ STACK_OF(X509_NAME) *SSL_dup_CA_list(const STACK_OF(X509_NAME) *sk)
             sk_X509_NAME_pop_free(ret, X509_NAME_free);
             return NULL;
         }
-        sk_X509_NAME_push(ret, name);   /* Cannot fail after reserve call */
+        sk_X509_NAME_push(ret, name); /* Cannot fail after reserve call */
     }
     return ret;
 }
@@ -736,8 +735,8 @@ static unsigned long xname_hash(const X509_NAME *a)
 }
 
 STACK_OF(X509_NAME) *SSL_load_client_CA_file_ex(const char *file,
-                                                OSSL_LIB_CTX *libctx,
-                                                const char *propq)
+    OSSL_LIB_CTX *libctx,
+    const char *propq)
 {
     BIO *in = BIO_new(BIO_s_file());
     X509 *x = NULL;
@@ -793,11 +792,11 @@ STACK_OF(X509_NAME) *SSL_load_client_CA_file_ex(const char *file,
     }
     goto done;
 
- err:
+err:
     X509_NAME_free(xn);
     sk_X509_NAME_pop_free(ret, X509_NAME_free);
     ret = NULL;
- done:
+done:
     /* restore the old libctx */
     OSSL_LIB_CTX_set0_default(prev_libctx);
     BIO_free(in);
@@ -814,13 +813,13 @@ STACK_OF(X509_NAME) *SSL_load_client_CA_file(const char *file)
 }
 
 int SSL_add_file_cert_subjects_to_stack(STACK_OF(X509_NAME) *stack,
-                                        const char *file)
+    const char *file)
 {
     BIO *in;
     X509 *x = NULL;
     X509_NAME *xn = NULL;
     int ret = 1;
-    int (*oldcmp) (const X509_NAME *const *a, const X509_NAME *const *b);
+    int (*oldcmp)(const X509_NAME *const *a, const X509_NAME *const *b);
 
     oldcmp = sk_X509_NAME_set_cmp_func(stack, xname_sk_cmp);
 
@@ -854,9 +853,9 @@ int SSL_add_file_cert_subjects_to_stack(STACK_OF(X509_NAME) *stack,
     ERR_clear_error();
     goto done;
 
- err:
+err:
     ret = 0;
- done:
+done:
     BIO_free(in);
     X509_free(x);
     (void)sk_X509_NAME_set_cmp_func(stack, oldcmp);
@@ -864,7 +863,7 @@ int SSL_add_file_cert_subjects_to_stack(STACK_OF(X509_NAME) *stack,
 }
 
 int SSL_add_dir_cert_subjects_to_stack(STACK_OF(X509_NAME) *stack,
-                                       const char *dir)
+    const char *dir)
 {
     OPENSSL_DIR_CTX *d = NULL;
     const char *filename;
@@ -905,14 +904,14 @@ int SSL_add_dir_cert_subjects_to_stack(STACK_OF(X509_NAME) *stack,
 
     if (errno) {
         ERR_raise_data(ERR_LIB_SYS, get_last_sys_error(),
-                       "calling OPENSSL_dir_read(%s)", dir);
+            "calling OPENSSL_dir_read(%s)", dir);
         ERR_raise(ERR_LIB_SSL, ERR_R_SYS_LIB);
         goto err;
     }
 
     ret = 1;
 
- err:
+err:
     if (d)
         OPENSSL_DIR_end(&d);
 
@@ -920,7 +919,7 @@ int SSL_add_dir_cert_subjects_to_stack(STACK_OF(X509_NAME) *stack,
 }
 
 static int add_uris_recursive(STACK_OF(X509_NAME) *stack,
-                              const char *uri, int depth)
+    const char *uri, int depth)
 {
     int ok = 1;
     OSSL_STORE_CTX *ctx = NULL;
@@ -945,7 +944,7 @@ static int add_uris_recursive(STACK_OF(X509_NAME) *stack,
              */
             if (depth > 0)
                 ok = add_uris_recursive(stack, OSSL_STORE_INFO_get0_NAME(info),
-                                        depth - 1);
+                    depth - 1);
         } else if (infotype == OSSL_STORE_INFO_CERT) {
             if ((x = OSSL_STORE_INFO_get0_CERT(info)) == NULL
                 || (xn = X509_get_subject_name(x)) == NULL
@@ -967,19 +966,19 @@ static int add_uris_recursive(STACK_OF(X509_NAME) *stack,
     ERR_clear_error();
     goto done;
 
- err:
+err:
     ok = 0;
     OSSL_STORE_INFO_free(info);
- done:
+done:
     OSSL_STORE_close(ctx);
 
     return ok;
 }
 
 int SSL_add_store_cert_subjects_to_stack(STACK_OF(X509_NAME) *stack,
-                                         const char *store)
+    const char *store)
 {
-    int (*oldcmp) (const X509_NAME *const *a, const X509_NAME *const *b)
+    int (*oldcmp)(const X509_NAME *const *a, const X509_NAME *const *b)
         = sk_X509_NAME_set_cmp_func(stack, xname_sk_cmp);
     int ret = add_uris_recursive(stack, store, 1);
 
@@ -1037,7 +1036,7 @@ int ssl_build_cert_chain(SSL_CONNECTION *s, SSL_CTX *ctx, int flags)
     }
     /* Set suite B flags if needed */
     X509_STORE_CTX_set_flags(xs_ctx,
-                             c->cert_flags & SSL_CERT_FLAG_SUITEB_128_LOS);
+        c->cert_flags & SSL_CERT_FLAG_SUITEB_128_LOS);
 
     i = X509_verify_cert(xs_ctx);
     if (i <= 0 && flags & SSL_BUILD_CHAIN_FLAG_IGNORE_ERROR) {
@@ -1051,7 +1050,7 @@ int ssl_build_cert_chain(SSL_CONNECTION *s, SSL_CTX *ctx, int flags)
     if (i <= 0) {
         i = X509_STORE_CTX_get_error(xs_ctx);
         ERR_raise_data(ERR_LIB_SSL, SSL_R_CERTIFICATE_VERIFY_FAILED,
-                       "Verify error:%s", X509_verify_cert_error_string(i));
+            "Verify error:%s", X509_verify_cert_error_string(i));
 
         goto err;
     }
@@ -1086,7 +1085,7 @@ int ssl_build_cert_chain(SSL_CONNECTION *s, SSL_CTX *ctx, int flags)
     cpk->chain = chain;
     if (rv == 0)
         rv = 1;
- err:
+err:
     if (flags & SSL_BUILD_CHAIN_FLAG_CHECK)
         X509_STORE_free(chain_store);
     X509_STORE_CTX_free(xs_ctx);
@@ -1141,8 +1140,8 @@ int ssl_get_security_level_bits(const SSL *s, const SSL_CTX *ctx, int *levelp)
 }
 
 static int ssl_security_default_callback(const SSL *s, const SSL_CTX *ctx,
-                                         int op, int bits, int nid, void *other,
-                                         void *ex)
+    int op, int bits, int nid, void *other,
+    void *ex)
 {
     int level, minbits, pfs_mask;
     const SSL_CONNECTION *sc;
@@ -1161,28 +1160,26 @@ static int ssl_security_default_callback(const SSL *s, const SSL_CTX *ctx,
     switch (op) {
     case SSL_SECOP_CIPHER_SUPPORTED:
     case SSL_SECOP_CIPHER_SHARED:
-    case SSL_SECOP_CIPHER_CHECK:
-        {
-            const SSL_CIPHER *c = other;
-            /* No ciphers below security level */
-            if (bits < minbits)
-                return 0;
-            /* No unauthenticated ciphersuites */
-            if (c->algorithm_auth & SSL_aNULL)
-                return 0;
-            /* No MD5 mac ciphersuites */
-            if (c->algorithm_mac & SSL_MD5)
-                return 0;
-            /* SHA1 HMAC is 160 bits of security */
-            if (minbits > 160 && c->algorithm_mac & SSL_SHA1)
-                return 0;
-            /* Level 3: forward secure ciphersuites only */
-            pfs_mask = SSL_kDHE | SSL_kECDHE | SSL_kDHEPSK | SSL_kECDHEPSK;
-            if (level >= 3 && c->min_tls != TLS1_3_VERSION &&
-                               !(c->algorithm_mkey & pfs_mask))
-                return 0;
-            break;
-        }
+    case SSL_SECOP_CIPHER_CHECK: {
+        const SSL_CIPHER *c = other;
+        /* No ciphers below security level */
+        if (bits < minbits)
+            return 0;
+        /* No unauthenticated ciphersuites */
+        if (c->algorithm_auth & SSL_aNULL)
+            return 0;
+        /* No MD5 mac ciphersuites */
+        if (c->algorithm_mac & SSL_MD5)
+            return 0;
+        /* SHA1 HMAC is 160 bits of security */
+        if (minbits > 160 && c->algorithm_mac & SSL_SHA1)
+            return 0;
+        /* Level 3: forward secure ciphersuites only */
+        pfs_mask = SSL_kDHE | SSL_kECDHE | SSL_kDHEPSK | SSL_kECDHEPSK;
+        if (level >= 3 && c->min_tls != TLS1_3_VERSION && !(c->algorithm_mkey & pfs_mask))
+            return 0;
+        break;
+    }
     case SSL_SECOP_VERSION:
         if ((sc = SSL_CONNECTION_FROM_CONST_SSL(s)) == NULL)
             return 0;
@@ -1215,13 +1212,13 @@ static int ssl_security_default_callback(const SSL *s, const SSL_CTX *ctx,
 int ssl_security(const SSL_CONNECTION *s, int op, int bits, int nid, void *other)
 {
     return s->cert->sec_cb(SSL_CONNECTION_GET_USER_SSL(s), NULL, op, bits, nid,
-                           other, s->cert->sec_ex);
+        other, s->cert->sec_ex);
 }
 
 int ssl_ctx_security(const SSL_CTX *ctx, int op, int bits, int nid, void *other)
 {
     return ctx->cert->sec_cb(NULL, ctx, op, bits, nid, other,
-                             ctx->cert->sec_ex);
+        ctx->cert->sec_ex);
 }
 
 int ssl_cert_lookup_by_nid(int nid, size_t *pidx, SSL_CTX *ctx)
@@ -1229,13 +1226,13 @@ int ssl_cert_lookup_by_nid(int nid, size_t *pidx, SSL_CTX *ctx)
     size_t i;
 
     for (i = 0; i < OSSL_NELEM(ssl_cert_info); i++) {
-        if (ssl_cert_info[i].nid == nid) {
+        if (ssl_cert_info[i].pkey_nid == nid) {
             *pidx = i;
             return 1;
         }
     }
     for (i = 0; i < ctx->sigalg_list_len; i++) {
-        if (ctx->ssl_cert_info[i].nid == nid) {
+        if (ctx->ssl_cert_info[i].pkey_nid == nid) {
             *pidx = SSL_PKEY_NUM + i;
             return 1;
         }
@@ -1251,8 +1248,8 @@ const SSL_CERT_LOOKUP *ssl_cert_lookup_by_pkey(const EVP_PKEY *pk, size_t *pidx,
     for (i = 0; i < OSSL_NELEM(ssl_cert_info); i++) {
         const SSL_CERT_LOOKUP *tmp_lu = &ssl_cert_info[i];
 
-        if (EVP_PKEY_is_a(pk, OBJ_nid2sn(tmp_lu->nid))
-            || EVP_PKEY_is_a(pk, OBJ_nid2ln(tmp_lu->nid))) {
+        if (EVP_PKEY_is_a(pk, OBJ_nid2sn(tmp_lu->pkey_nid))
+            || EVP_PKEY_is_a(pk, OBJ_nid2ln(tmp_lu->pkey_nid))) {
             if (pidx != NULL)
                 *pidx = i;
             return tmp_lu;
@@ -1262,8 +1259,8 @@ const SSL_CERT_LOOKUP *ssl_cert_lookup_by_pkey(const EVP_PKEY *pk, size_t *pidx,
     for (i = 0; i < ctx->sigalg_list_len; i++) {
         SSL_CERT_LOOKUP *tmp_lu = &(ctx->ssl_cert_info[i]);
 
-        if (EVP_PKEY_is_a(pk, OBJ_nid2sn(tmp_lu->nid))
-            || EVP_PKEY_is_a(pk, OBJ_nid2ln(tmp_lu->nid))) {
+        if (EVP_PKEY_is_a(pk, OBJ_nid2sn(tmp_lu->pkey_nid))
+            || EVP_PKEY_is_a(pk, OBJ_nid2ln(tmp_lu->pkey_nid))) {
             if (pidx != NULL)
                 *pidx = SSL_PKEY_NUM + i;
             return &ctx->ssl_cert_info[i];
