@@ -21,7 +21,7 @@ size_t ossl_calculate_comp_expansion(int alg, size_t length)
      * Brotli: per RFC7932: N + 5 + 3 * (N >> 16)
      * ZSTD: N + 4 + 14 + 3 * (N >> 17) + 4
      */
-    
+
     switch (alg) {
     case TLSEXT_comp_cert_zlib:
         ret = length + 11 + 5 * (length >> 14);
@@ -62,9 +62,9 @@ static OSSL_COMP_CERT *OSSL_COMP_CERT_new(unsigned char *data, size_t len, size_
     OSSL_COMP_CERT *ret = NULL;
 
     if (!ossl_comp_has_alg(alg)
-            || data == NULL
-            || (ret = OPENSSL_zalloc(sizeof(*ret))) == NULL
-            || !CRYPTO_NEW_REF(&ret->references, 1))
+        || data == NULL
+        || (ret = OPENSSL_zalloc(sizeof(*ret))) == NULL
+        || !CRYPTO_NEW_REF(&ret->references, 1))
         goto err;
 
     ret->data = data;
@@ -72,7 +72,7 @@ static OSSL_COMP_CERT *OSSL_COMP_CERT_new(unsigned char *data, size_t len, size_
     ret->orig_len = orig_len;
     ret->alg = alg;
     return ret;
- err:
+err:
     ERR_raise(ERR_LIB_SSL, ERR_R_MALLOC_FAILURE);
     OPENSSL_free(data);
     OPENSSL_free(ret);
@@ -80,13 +80,13 @@ static OSSL_COMP_CERT *OSSL_COMP_CERT_new(unsigned char *data, size_t len, size_
 }
 
 __owur static OSSL_COMP_CERT *OSSL_COMP_CERT_from_compressed_data(unsigned char *data, size_t len,
-                                                                  size_t orig_len, int alg)
+    size_t orig_len, int alg)
 {
     return OSSL_COMP_CERT_new(OPENSSL_memdup(data, len), len, orig_len, alg);
 }
 
 __owur static OSSL_COMP_CERT *OSSL_COMP_CERT_from_uncompressed_data(unsigned char *data, size_t len,
-                                                                    int alg)
+    int alg)
 {
     OSSL_COMP_CERT *ret = NULL;
     size_t max_length;
@@ -110,9 +110,9 @@ __owur static OSSL_COMP_CERT *OSSL_COMP_CERT_from_uncompressed_data(unsigned cha
     }
 
     if ((max_length = ossl_calculate_comp_expansion(alg, len)) == 0
-          || method == NULL
-          || (comp_ctx = COMP_CTX_new(method)) == NULL
-          || (comp_data = OPENSSL_zalloc(max_length)) == NULL)
+        || method == NULL
+        || (comp_ctx = COMP_CTX_new(method)) == NULL
+        || (comp_data = OPENSSL_zalloc(max_length)) == NULL)
         goto err;
 
     comp_length = COMP_compress_block(comp_ctx, comp_data, max_length, data, len);
@@ -122,7 +122,7 @@ __owur static OSSL_COMP_CERT *OSSL_COMP_CERT_from_uncompressed_data(unsigned cha
     ret = OSSL_COMP_CERT_new(comp_data, comp_length, len, alg);
     comp_data = NULL;
 
- err:
+err:
     OPENSSL_free(comp_data);
     COMP_CTX_free(comp_ctx);
     return ret;
@@ -136,7 +136,7 @@ void OSSL_COMP_CERT_free(OSSL_COMP_CERT *cc)
         return;
 
     CRYPTO_DOWN_REF(&cc->references, &i);
-    REF_PRINT_COUNT("OSSL_COMP_CERT", cc);
+    REF_PRINT_COUNT("OSSL_COMP_CERT", i, cc);
     if (i > 0)
         return;
     REF_ASSERT_ISNT(i < 0);
@@ -152,7 +152,7 @@ int OSSL_COMP_CERT_up_ref(OSSL_COMP_CERT *cc)
     if (CRYPTO_UP_REF(&cc->references, &i) <= 0)
         return 0;
 
-    REF_PRINT_COUNT("OSSL_COMP_CERT", cc);
+    REF_PRINT_COUNT("OSSL_COMP_CERT", i, cc);
     REF_ASSERT_ISNT(i < 2);
     return ((i > 1) ? 1 : 0);
 }
@@ -199,9 +199,9 @@ static size_t ssl_get_cert_to_compress(SSL *ssl, CERT_PKEY *cpk, unsigned char *
     size_t ret = 0;
 
     if (sc == NULL
-            || cpk == NULL
-            || !sc->server
-            || !SSL_in_before(ssl))
+        || cpk == NULL
+        || !sc->server
+        || !SSL_in_before(ssl))
         return 0;
 
     /* Use the |tmppkt| for the to-be-compressed data */
@@ -220,7 +220,7 @@ static size_t ssl_get_cert_to_compress(SSL *ssl, CERT_PKEY *cpk, unsigned char *
         goto out;
     WPACKET_get_total_written(&tmppkt, &ret);
 
- out:
+out:
     WPACKET_cleanup(&tmppkt);
     if (ret != 0 && data != NULL)
         *data = (unsigned char *)buf.data;
@@ -236,8 +236,8 @@ static int ssl_compress_one_cert(SSL *ssl, CERT_PKEY *cpk, int alg)
     size_t length;
 
     if (cpk == NULL
-            || alg == TLSEXT_comp_cert_none
-            || !ossl_comp_has_alg(alg))
+        || alg == TLSEXT_comp_cert_none
+        || !ossl_comp_has_alg(alg))
         return 0;
 
     if ((length = ssl_get_cert_to_compress(ssl, cpk, &cert_data)) == 0)
@@ -262,8 +262,8 @@ static int ssl_compress_certs(SSL *ssl, CERT_PKEY *cpks, int alg_in)
     int count = 0;
 
     if (sc == NULL
-            || cpks == NULL
-            || !ossl_comp_has_alg(alg_in))
+        || cpks == NULL
+        || !ossl_comp_has_alg(alg_in))
         return 0;
 
     /* Look through the preferences to see what we have */
@@ -274,7 +274,7 @@ static int ssl_compress_certs(SSL *ssl, CERT_PKEY *cpks, int alg_in)
          */
         alg = sc->cert_comp_prefs[i];
         if ((alg_in == 0 && alg != TLSEXT_comp_cert_none)
-                || (alg_in != 0 && alg == alg_in)) {
+            || (alg_in != 0 && alg == alg_in)) {
 
             for (j = 0; j < SSL_PKEY_NUM; j++) {
                 /* No cert, move on */
@@ -298,7 +298,7 @@ static int ssl_compress_certs(SSL *ssl, CERT_PKEY *cpks, int alg_in)
 }
 
 static size_t ssl_get_compressed_cert(SSL *ssl, CERT_PKEY *cpk, int alg, unsigned char **data,
-                                      size_t *orig_len)
+    size_t *orig_len)
 {
     SSL_CONNECTION *sc = SSL_CONNECTION_FROM_SSL(ssl);
     size_t cert_len = 0;
@@ -307,12 +307,12 @@ static size_t ssl_get_compressed_cert(SSL *ssl, CERT_PKEY *cpk, int alg, unsigne
     OSSL_COMP_CERT *comp_cert = NULL;
 
     if (sc == NULL
-            || cpk == NULL
-            || data == NULL
-            || orig_len == NULL
-            || !sc->server
-            || !SSL_in_before(ssl)
-            || !ossl_comp_has_alg(alg))
+        || cpk == NULL
+        || data == NULL
+        || orig_len == NULL
+        || !sc->server
+        || !SSL_in_before(ssl)
+        || !ossl_comp_has_alg(alg))
         return 0;
 
     if ((cert_len = ssl_get_cert_to_compress(ssl, cpk, &cert_data)) == 0)
@@ -327,14 +327,14 @@ static size_t ssl_get_compressed_cert(SSL *ssl, CERT_PKEY *cpk, int alg, unsigne
     *orig_len = comp_cert->orig_len;
     *data = comp_cert->data;
     comp_cert->data = NULL;
- err:
+err:
     OSSL_COMP_CERT_free(comp_cert);
     return comp_len;
 }
 
 static int ossl_set1_compressed_cert(CERT *cert, int algorithm,
-                                     unsigned char *comp_data, size_t comp_length,
-                                     size_t orig_length)
+    unsigned char *comp_data, size_t comp_length,
+    size_t orig_length)
 {
     OSSL_COMP_CERT *comp_cert;
 
@@ -343,7 +343,7 @@ static int ossl_set1_compressed_cert(CERT *cert, int algorithm,
         return 0;
 
     comp_cert = OSSL_COMP_CERT_from_compressed_data(comp_data, comp_length,
-                                                    orig_length, algorithm);
+        orig_length, algorithm);
     if (comp_cert == NULL)
         return 0;
 
@@ -434,12 +434,12 @@ size_t SSL_CTX_get1_compressed_cert(SSL_CTX *ctx, int alg, unsigned char **data,
     SSL_free(new);
     return ret;
 #else
-        return 0;
+    return 0;
 #endif
 }
 
 int SSL_CTX_set1_compressed_cert(SSL_CTX *ctx, int algorithm, unsigned char *comp_data,
-                                 size_t comp_length, size_t orig_length)
+    size_t comp_length, size_t orig_length)
 {
 #ifndef OPENSSL_NO_COMP_ALG
     return ossl_set1_compressed_cert(ctx->cert, algorithm, comp_data, comp_length, orig_length);
@@ -449,7 +449,7 @@ int SSL_CTX_set1_compressed_cert(SSL_CTX *ctx, int algorithm, unsigned char *com
 }
 
 int SSL_set1_compressed_cert(SSL *ssl, int algorithm, unsigned char *comp_data,
-                             size_t comp_length, size_t orig_length)
+    size_t comp_length, size_t orig_length)
 {
 #ifndef OPENSSL_NO_COMP_ALG
     SSL_CONNECTION *sc = SSL_CONNECTION_FROM_SSL(ssl);
