@@ -1,5 +1,5 @@
 /*
- * Copyright 2014-2021 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2014-2023 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -29,10 +29,10 @@ typedef struct {
  * Provide thin wrapper callbacks which convert new style arguments to old style
  */
 static int custom_ext_add_old_cb_wrap(SSL *s, unsigned int ext_type,
-                                      unsigned int context,
-                                      const unsigned char **out,
-                                      size_t *outlen, X509 *x, size_t chainidx,
-                                      int *al, void *add_arg)
+    unsigned int context,
+    const unsigned char **out,
+    size_t *outlen, X509 *x, size_t chainidx,
+    int *al, void *add_arg)
 {
     custom_ext_add_cb_wrap *add_cb_wrap = (custom_ext_add_cb_wrap *)add_arg;
 
@@ -40,12 +40,12 @@ static int custom_ext_add_old_cb_wrap(SSL *s, unsigned int ext_type,
         return 1;
 
     return add_cb_wrap->add_cb(s, ext_type, out, outlen, al,
-                               add_cb_wrap->add_arg);
+        add_cb_wrap->add_arg);
 }
 
 static void custom_ext_free_old_cb_wrap(SSL *s, unsigned int ext_type,
-                                        unsigned int context,
-                                        const unsigned char *out, void *add_arg)
+    unsigned int context,
+    const unsigned char *out, void *add_arg)
 {
     custom_ext_add_cb_wrap *add_cb_wrap = (custom_ext_add_cb_wrap *)add_arg;
 
@@ -56,19 +56,18 @@ static void custom_ext_free_old_cb_wrap(SSL *s, unsigned int ext_type,
 }
 
 static int custom_ext_parse_old_cb_wrap(SSL *s, unsigned int ext_type,
-                                        unsigned int context,
-                                        const unsigned char *in,
-                                        size_t inlen, X509 *x, size_t chainidx,
-                                        int *al, void *parse_arg)
+    unsigned int context,
+    const unsigned char *in,
+    size_t inlen, X509 *x, size_t chainidx,
+    int *al, void *parse_arg)
 {
-    custom_ext_parse_cb_wrap *parse_cb_wrap =
-        (custom_ext_parse_cb_wrap *)parse_arg;
+    custom_ext_parse_cb_wrap *parse_cb_wrap = (custom_ext_parse_cb_wrap *)parse_arg;
 
     if (parse_cb_wrap->parse_cb == NULL)
         return 1;
 
     return parse_cb_wrap->parse_cb(s, ext_type, in, inlen, al,
-                                   parse_cb_wrap->parse_arg);
+        parse_cb_wrap->parse_arg);
 }
 
 /*
@@ -79,16 +78,16 @@ static int custom_ext_parse_old_cb_wrap(SSL *s, unsigned int ext_type,
  * client, or ENDPOINT_BOTH for either
  */
 custom_ext_method *custom_ext_find(const custom_ext_methods *exts,
-                                   ENDPOINT role, unsigned int ext_type,
-                                   size_t *idx)
+    ENDPOINT role, unsigned int ext_type,
+    size_t *idx)
 {
     size_t i;
     custom_ext_method *meth = exts->meths;
 
     for (i = 0; i < exts->meths_count; i++, meth++) {
         if (ext_type == meth->ext_type
-                && (role == ENDPOINT_BOTH || role == meth->role
-                    || meth->role == ENDPOINT_BOTH)) {
+            && (role == ENDPOINT_BOTH || role == meth->role
+                || meth->role == ENDPOINT_BOTH)) {
             if (idx != NULL)
                 *idx = i;
             return meth;
@@ -110,11 +109,12 @@ void custom_ext_init(custom_ext_methods *exts)
 }
 
 /* Pass received custom extension data to the application for parsing. */
-int custom_ext_parse(SSL *s, unsigned int context, unsigned int ext_type,
-                     const unsigned char *ext_data, size_t ext_size, X509 *x,
-                     size_t chainidx)
+int custom_ext_parse(SSL_CONNECTION *s, unsigned int context,
+    unsigned int ext_type,
+    const unsigned char *ext_data, size_t ext_size, X509 *x,
+    size_t chainidx)
 {
-    int al;
+    int al = 0;
     custom_ext_methods *exts = &s->cert->custext;
     custom_ext_method *meth;
     ENDPOINT role = ENDPOINT_BOTH;
@@ -131,9 +131,7 @@ int custom_ext_parse(SSL *s, unsigned int context, unsigned int ext_type,
     if (!extension_is_relevant(s, meth->context, context))
         return 1;
 
-    if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO
-                    | SSL_EXT_TLS1_3_SERVER_HELLO
-                    | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS)) != 0) {
+    if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO | SSL_EXT_TLS1_3_SERVER_HELLO | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS)) != 0) {
         /*
          * If it's ServerHello or EncryptedExtensions we can't have any
          * extensions not sent in ClientHello.
@@ -150,15 +148,16 @@ int custom_ext_parse(SSL *s, unsigned int context, unsigned int ext_type,
      * extensions in the response messages
      */
     if ((context & (SSL_EXT_CLIENT_HELLO | SSL_EXT_TLS1_3_CERTIFICATE_REQUEST))
-            != 0)
+        != 0)
         meth->ext_flags |= SSL_EXT_FLAG_RECEIVED;
 
     /* If no parse function set return success */
-    if (!meth->parse_cb)
+    if (meth->parse_cb == NULL)
         return 1;
 
-    if (meth->parse_cb(s, ext_type, context, ext_data, ext_size, x, chainidx,
-                       &al, meth->parse_arg) <= 0) {
+    if (meth->parse_cb(SSL_CONNECTION_GET_USER_SSL(s), ext_type, context, ext_data,
+            ext_size, x, chainidx, &al, meth->parse_arg)
+        <= 0) {
         SSLfatal(s, al, SSL_R_BAD_EXTENSION);
         return 0;
     }
@@ -170,13 +169,14 @@ int custom_ext_parse(SSL *s, unsigned int context, unsigned int ext_type,
  * Request custom extension data from the application and add to the return
  * buffer.
  */
-int custom_ext_add(SSL *s, int context, WPACKET *pkt, X509 *x, size_t chainidx,
-                   int maxversion)
+int custom_ext_add(SSL_CONNECTION *s, int context, WPACKET *pkt, X509 *x,
+    size_t chainidx, int maxversion)
 {
     custom_ext_methods *exts = &s->cert->custext;
     custom_ext_method *meth;
     size_t i;
     int al;
+    int for_comp = (context & SSL_EXT_TLS1_3_CERTIFICATE_COMPRESSION) != 0;
 
     for (i = 0; i < exts->meths_count; i++) {
         const unsigned char *out = NULL;
@@ -187,11 +187,7 @@ int custom_ext_add(SSL *s, int context, WPACKET *pkt, X509 *x, size_t chainidx,
         if (!should_add_extension(s, meth->context, context, maxversion))
             continue;
 
-        if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO
-                        | SSL_EXT_TLS1_3_SERVER_HELLO
-                        | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS
-                        | SSL_EXT_TLS1_3_CERTIFICATE
-                        | SSL_EXT_TLS1_3_HELLO_RETRY_REQUEST)) != 0) {
+        if ((context & (SSL_EXT_TLS1_2_SERVER_HELLO | SSL_EXT_TLS1_3_SERVER_HELLO | SSL_EXT_TLS1_3_ENCRYPTED_EXTENSIONS | SSL_EXT_TLS1_3_CERTIFICATE | SSL_EXT_TLS1_3_RAW_PUBLIC_KEY | SSL_EXT_TLS1_3_HELLO_RETRY_REQUEST)) != 0) {
             /* Only send extensions present in ClientHello/CertificateRequest */
             if (!(meth->ext_flags & SSL_EXT_FLAG_RECEIVED))
                 continue;
@@ -204,23 +200,29 @@ int custom_ext_add(SSL *s, int context, WPACKET *pkt, X509 *x, size_t chainidx,
             continue;
 
         if (meth->add_cb != NULL) {
-            int cb_retval = meth->add_cb(s, meth->ext_type, context, &out,
-                                         &outlen, x, chainidx, &al,
-                                         meth->add_arg);
+            int cb_retval = meth->add_cb(SSL_CONNECTION_GET_USER_SSL(s),
+                meth->ext_type, context, &out,
+                &outlen, x, chainidx, &al,
+                meth->add_arg);
 
             if (cb_retval < 0) {
-                SSLfatal(s, al, SSL_R_CALLBACK_FAILED);
-                return 0;       /* error */
+                if (!for_comp)
+                    SSLfatal(s, al, SSL_R_CALLBACK_FAILED);
+                return 0; /* error */
             }
             if (cb_retval == 0)
-                continue;       /* skip this extension */
+                continue; /* skip this extension */
         }
 
         if (!WPACKET_put_bytes_u16(pkt, meth->ext_type)
-                || !WPACKET_start_sub_packet_u16(pkt)
-                || (outlen > 0 && !WPACKET_memcpy(pkt, out, outlen))
-                || !WPACKET_close(pkt)) {
-            SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
+            || !WPACKET_start_sub_packet_u16(pkt)
+            || (outlen > 0 && !WPACKET_memcpy(pkt, out, outlen))
+            || !WPACKET_close(pkt)) {
+            if (meth->free_cb != NULL)
+                meth->free_cb(SSL_CONNECTION_GET_USER_SSL(s), meth->ext_type,
+                    context, out, meth->add_arg);
+            if (!for_comp)
+                SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
             return 0;
         }
         if ((context & SSL_EXT_CLIENT_HELLO) != 0) {
@@ -228,7 +230,11 @@ int custom_ext_add(SSL *s, int context, WPACKET *pkt, X509 *x, size_t chainidx,
              * We can't send duplicates: code logic should prevent this.
              */
             if (!ossl_assert((meth->ext_flags & SSL_EXT_FLAG_SENT) == 0)) {
-                SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
+                if (meth->free_cb != NULL)
+                    meth->free_cb(SSL_CONNECTION_GET_USER_SSL(s), meth->ext_type,
+                        context, out, meth->add_arg);
+                if (!for_comp)
+                    SSLfatal(s, SSL_AD_INTERNAL_ERROR, ERR_R_INTERNAL_ERROR);
                 return 0;
             }
             /*
@@ -239,21 +245,22 @@ int custom_ext_add(SSL *s, int context, WPACKET *pkt, X509 *x, size_t chainidx,
             meth->ext_flags |= SSL_EXT_FLAG_SENT;
         }
         if (meth->free_cb != NULL)
-            meth->free_cb(s, meth->ext_type, context, out, meth->add_arg);
+            meth->free_cb(SSL_CONNECTION_GET_USER_SSL(s), meth->ext_type,
+                context, out, meth->add_arg);
     }
     return 1;
 }
 
 /* Copy the flags from src to dst for any extensions that exist in both */
 int custom_exts_copy_flags(custom_ext_methods *dst,
-                           const custom_ext_methods *src)
+    const custom_ext_methods *src)
 {
     size_t i;
     custom_ext_method *methsrc = src->meths;
 
     for (i = 0; i < src->meths_count; i++, methsrc++) {
         custom_ext_method *methdst = custom_ext_find(dst, methsrc->role,
-                                                     methsrc->ext_type, NULL);
+            methsrc->ext_type, NULL);
 
         if (methdst == NULL)
             continue;
@@ -271,9 +278,8 @@ int custom_exts_copy(custom_ext_methods *dst, const custom_ext_methods *src)
     int err = 0;
 
     if (src->meths_count > 0) {
-        dst->meths =
-            OPENSSL_memdup(src->meths,
-                           sizeof(*src->meths) * src->meths_count);
+        dst->meths = OPENSSL_memdup(src->meths,
+            sizeof(*src->meths) * src->meths_count);
         if (dst->meths == NULL)
             return 0;
         dst->meths_count = src->meths_count;
@@ -297,9 +303,9 @@ int custom_exts_copy(custom_ext_methods *dst, const custom_ext_methods *src)
             }
 
             methdst->add_arg = OPENSSL_memdup(methsrc->add_arg,
-                                              sizeof(custom_ext_add_cb_wrap));
+                sizeof(custom_ext_add_cb_wrap));
             methdst->parse_arg = OPENSSL_memdup(methsrc->parse_arg,
-                                            sizeof(custom_ext_parse_cb_wrap));
+                sizeof(custom_ext_parse_cb_wrap));
 
             if (methdst->add_arg == NULL || methdst->parse_arg == NULL)
                 err = 1;
@@ -328,25 +334,27 @@ void custom_exts_free(custom_ext_methods *exts)
         OPENSSL_free(meth->parse_arg);
     }
     OPENSSL_free(exts->meths);
+    exts->meths = NULL;
+    exts->meths_count = 0;
 }
 
 /* Return true if a client custom extension exists, false otherwise */
 int SSL_CTX_has_client_custom_ext(const SSL_CTX *ctx, unsigned int ext_type)
 {
     return custom_ext_find(&ctx->cert->custext, ENDPOINT_CLIENT, ext_type,
-                           NULL) != NULL;
+               NULL)
+        != NULL;
 }
 
-static int add_custom_ext_intern(SSL_CTX *ctx, ENDPOINT role,
-                                 unsigned int ext_type,
-                                 unsigned int context,
-                                 SSL_custom_ext_add_cb_ex add_cb,
-                                 SSL_custom_ext_free_cb_ex free_cb,
-                                 void *add_arg,
-                                 SSL_custom_ext_parse_cb_ex parse_cb,
-                                 void *parse_arg)
+int ossl_tls_add_custom_ext_intern(SSL_CTX *ctx, custom_ext_methods *exts,
+    ENDPOINT role, unsigned int ext_type,
+    unsigned int context,
+    SSL_custom_ext_add_cb_ex add_cb,
+    SSL_custom_ext_free_cb_ex free_cb,
+    void *add_arg,
+    SSL_custom_ext_parse_cb_ex parse_cb,
+    void *parse_arg)
 {
-    custom_ext_methods *exts = &ctx->cert->custext;
     custom_ext_method *meth, *tmp;
 
     /*
@@ -356,6 +364,9 @@ static int add_custom_ext_intern(SSL_CTX *ctx, ENDPOINT role,
     if (add_cb == NULL && free_cb != NULL)
         return 0;
 
+    if (exts == NULL)
+        exts = &ctx->cert->custext;
+
 #ifndef OPENSSL_NO_CT
     /*
      * We don't want applications registering callbacks for SCT extensions
@@ -363,8 +374,9 @@ static int add_custom_ext_intern(SSL_CTX *ctx, ENDPOINT role,
      * these two things may not play well together.
      */
     if (ext_type == TLSEXT_TYPE_signed_certificate_timestamp
-            && (context & SSL_EXT_CLIENT_HELLO) != 0
-            && SSL_CTX_ct_is_enabled(ctx))
+        && (context & SSL_EXT_CLIENT_HELLO) != 0
+        && ctx != NULL
+        && SSL_CTX_ct_is_enabled(ctx))
         return 0;
 #endif
 
@@ -373,7 +385,7 @@ static int add_custom_ext_intern(SSL_CTX *ctx, ENDPOINT role,
      * for extension types that previously were not supported, but now are.
      */
     if (SSL_extension_supported(ext_type)
-            && ext_type != TLSEXT_TYPE_signed_certificate_timestamp)
+        && ext_type != TLSEXT_TYPE_signed_certificate_timestamp)
         return 0;
 
     /* Extension type must fit in 16 bits */
@@ -383,7 +395,7 @@ static int add_custom_ext_intern(SSL_CTX *ctx, ENDPOINT role,
     if (custom_ext_find(exts, role, ext_type, NULL))
         return 0;
     tmp = OPENSSL_realloc(exts->meths,
-                          (exts->meths_count + 1) * sizeof(custom_ext_method));
+        (exts->meths_count + 1) * sizeof(custom_ext_method));
     if (tmp == NULL)
         return 0;
 
@@ -403,12 +415,12 @@ static int add_custom_ext_intern(SSL_CTX *ctx, ENDPOINT role,
 }
 
 static int add_old_custom_ext(SSL_CTX *ctx, ENDPOINT role,
-                              unsigned int ext_type,
-                              unsigned int context,
-                              custom_ext_add_cb add_cb,
-                              custom_ext_free_cb free_cb,
-                              void *add_arg,
-                              custom_ext_parse_cb parse_cb, void *parse_arg)
+    unsigned int ext_type,
+    unsigned int context,
+    custom_ext_add_cb add_cb,
+    custom_ext_free_cb free_cb,
+    void *add_arg,
+    custom_ext_parse_cb parse_cb, void *parse_arg)
 {
     custom_ext_add_cb_wrap *add_cb_wrap
         = OPENSSL_malloc(sizeof(*add_cb_wrap));
@@ -428,13 +440,13 @@ static int add_old_custom_ext(SSL_CTX *ctx, ENDPOINT role,
     parse_cb_wrap->parse_arg = parse_arg;
     parse_cb_wrap->parse_cb = parse_cb;
 
-    ret = add_custom_ext_intern(ctx, role, ext_type,
-                                context,
-                                custom_ext_add_old_cb_wrap,
-                                custom_ext_free_old_cb_wrap,
-                                add_cb_wrap,
-                                custom_ext_parse_old_cb_wrap,
-                                parse_cb_wrap);
+    ret = ossl_tls_add_custom_ext_intern(ctx, NULL, role, ext_type,
+        context,
+        custom_ext_add_old_cb_wrap,
+        custom_ext_free_old_cb_wrap,
+        add_cb_wrap,
+        custom_ext_parse_old_cb_wrap,
+        parse_cb_wrap);
 
     if (!ret) {
         OPENSSL_free(add_cb_wrap);
@@ -446,42 +458,43 @@ static int add_old_custom_ext(SSL_CTX *ctx, ENDPOINT role,
 
 /* Application level functions to add the old custom extension callbacks */
 int SSL_CTX_add_client_custom_ext(SSL_CTX *ctx, unsigned int ext_type,
-                                  custom_ext_add_cb add_cb,
-                                  custom_ext_free_cb free_cb,
-                                  void *add_arg,
-                                  custom_ext_parse_cb parse_cb, void *parse_arg)
+    custom_ext_add_cb add_cb,
+    custom_ext_free_cb free_cb,
+    void *add_arg,
+    custom_ext_parse_cb parse_cb, void *parse_arg)
 {
     return add_old_custom_ext(ctx, ENDPOINT_CLIENT, ext_type,
-                              SSL_EXT_TLS1_2_AND_BELOW_ONLY
-                              | SSL_EXT_CLIENT_HELLO
-                              | SSL_EXT_TLS1_2_SERVER_HELLO
-                              | SSL_EXT_IGNORE_ON_RESUMPTION,
-                              add_cb, free_cb, add_arg, parse_cb, parse_arg);
+        SSL_EXT_TLS1_2_AND_BELOW_ONLY
+            | SSL_EXT_CLIENT_HELLO
+            | SSL_EXT_TLS1_2_SERVER_HELLO
+            | SSL_EXT_IGNORE_ON_RESUMPTION,
+        add_cb, free_cb, add_arg, parse_cb, parse_arg);
 }
 
 int SSL_CTX_add_server_custom_ext(SSL_CTX *ctx, unsigned int ext_type,
-                                  custom_ext_add_cb add_cb,
-                                  custom_ext_free_cb free_cb,
-                                  void *add_arg,
-                                  custom_ext_parse_cb parse_cb, void *parse_arg)
+    custom_ext_add_cb add_cb,
+    custom_ext_free_cb free_cb,
+    void *add_arg,
+    custom_ext_parse_cb parse_cb, void *parse_arg)
 {
     return add_old_custom_ext(ctx, ENDPOINT_SERVER, ext_type,
-                              SSL_EXT_TLS1_2_AND_BELOW_ONLY
-                              | SSL_EXT_CLIENT_HELLO
-                              | SSL_EXT_TLS1_2_SERVER_HELLO
-                              | SSL_EXT_IGNORE_ON_RESUMPTION,
-                              add_cb, free_cb, add_arg, parse_cb, parse_arg);
+        SSL_EXT_TLS1_2_AND_BELOW_ONLY
+            | SSL_EXT_CLIENT_HELLO
+            | SSL_EXT_TLS1_2_SERVER_HELLO
+            | SSL_EXT_IGNORE_ON_RESUMPTION,
+        add_cb, free_cb, add_arg, parse_cb, parse_arg);
 }
 
 int SSL_CTX_add_custom_ext(SSL_CTX *ctx, unsigned int ext_type,
-                           unsigned int context,
-                           SSL_custom_ext_add_cb_ex add_cb,
-                           SSL_custom_ext_free_cb_ex free_cb,
-                           void *add_arg,
-                           SSL_custom_ext_parse_cb_ex parse_cb, void *parse_arg)
+    unsigned int context,
+    SSL_custom_ext_add_cb_ex add_cb,
+    SSL_custom_ext_free_cb_ex free_cb,
+    void *add_arg,
+    SSL_custom_ext_parse_cb_ex parse_cb, void *parse_arg)
 {
-    return add_custom_ext_intern(ctx, ENDPOINT_BOTH, ext_type, context, add_cb,
-                                 free_cb, add_arg, parse_cb, parse_arg);
+    return ossl_tls_add_custom_ext_intern(ctx, NULL, ENDPOINT_BOTH, ext_type,
+        context, add_cb, free_cb, add_arg,
+        parse_cb, parse_arg);
 }
 
 int SSL_extension_supported(unsigned int ext_type)
@@ -522,6 +535,9 @@ int SSL_extension_supported(unsigned int ext_type)
     case TLSEXT_TYPE_certificate_authorities:
     case TLSEXT_TYPE_psk:
     case TLSEXT_TYPE_post_handshake_auth:
+    case TLSEXT_TYPE_compress_certificate:
+    case TLSEXT_TYPE_client_cert_type:
+    case TLSEXT_TYPE_server_cert_type:
         return 1;
     default:
         return 0;
