@@ -23,9 +23,9 @@
 static int debug = 0;
 
 static unsigned int clnt_psk_callback(SSL *ssl, const char *hint,
-                                      char *ident, unsigned int max_ident_len,
-                                      unsigned char *psk,
-                                      unsigned int max_psk_len)
+    char *ident, unsigned int max_ident_len,
+    unsigned char *psk,
+    unsigned int max_psk_len)
 {
     BIO_snprintf(ident, max_ident_len, "psk");
 
@@ -37,8 +37,8 @@ static unsigned int clnt_psk_callback(SSL *ssl, const char *hint,
 }
 
 static unsigned int srvr_psk_callback(SSL *ssl, const char *identity,
-                                      unsigned char *psk,
-                                      unsigned int max_psk_len)
+    unsigned char *psk,
+    unsigned int max_psk_len)
 {
     if (max_psk_len > 20)
         max_psk_len = 20;
@@ -55,21 +55,22 @@ static int mtu_test(SSL_CTX *ctx, const char *cs, int no_etm)
     size_t mtus[30];
     unsigned char buf[600];
     int rv = 0;
+    SSL_CONNECTION *clnt_sc;
 
     memset(buf, 0x5a, sizeof(buf));
 
     if (!TEST_true(create_ssl_objects(ctx, ctx, &srvr_ssl, &clnt_ssl,
-                                      NULL, NULL)))
+            NULL, NULL)))
         goto end;
 
     if (no_etm)
         SSL_set_options(srvr_ssl, SSL_OP_NO_ENCRYPT_THEN_MAC);
 
     if (!TEST_true(SSL_set_cipher_list(srvr_ssl, cs))
-            || !TEST_true(SSL_set_cipher_list(clnt_ssl, cs))
-            || !TEST_ptr(sc_bio = SSL_get_rbio(srvr_ssl))
-            || !TEST_true(create_ssl_connection(clnt_ssl, srvr_ssl,
-                                                SSL_ERROR_NONE)))
+        || !TEST_true(SSL_set_cipher_list(clnt_ssl, cs))
+        || !TEST_ptr(sc_bio = SSL_get_rbio(srvr_ssl))
+        || !TEST_true(create_ssl_connection(clnt_ssl, srvr_ssl,
+            SSL_ERROR_NONE)))
         goto end;
 
     if (debug)
@@ -82,8 +83,8 @@ static int mtu_test(SSL_CTX *ctx, const char *cs, int no_etm)
         mtus[i] = DTLS_get_data_mtu(clnt_ssl);
         if (debug)
             TEST_info("%s%s MTU for record mtu %d = %lu",
-                      cs, no_etm ? "-noEtM" : "",
-                      500 + i, (unsigned long)mtus[i]);
+                cs, no_etm ? "-noEtM" : "",
+                500 + i, (unsigned long)mtus[i]);
         if (!TEST_size_t_ne(mtus[i], 0)) {
             TEST_info("Cipher %s MTU %d", cs, 500 + i);
             goto end;
@@ -115,8 +116,8 @@ static int mtu_test(SSL_CTX *ctx, const char *cs, int no_etm)
                  * that made a record *larger* than the record MTU 500+j!
                  */
                 TEST_error("%s: s=%lu, mtus[i]=%lu, reclen=%lu, i=%d",
-                           cs, (unsigned long)s, (unsigned long)mtus[i],
-                           (unsigned long)reclen, 500 + i);
+                    cs, (unsigned long)s, (unsigned long)mtus[i],
+                    (unsigned long)reclen, 500 + i);
                 goto end;
             }
             if (!TEST_false(s > mtus[i] && reclen <= (size_t)(500 + i))) {
@@ -126,16 +127,18 @@ static int mtu_test(SSL_CTX *ctx, const char *cs, int no_etm)
                  * was overly pessimistic.
                  */
                 TEST_error("%s: s=%lu, mtus[i]=%lu, reclen=%lu, i=%d",
-                           cs, (unsigned long)s, (unsigned long)mtus[i],
-                           (unsigned long)reclen, 500 + i);
+                    cs, (unsigned long)s, (unsigned long)mtus[i],
+                    (unsigned long)reclen, 500 + i);
                 goto end;
             }
         }
     }
+    if (!TEST_ptr(clnt_sc = SSL_CONNECTION_FROM_SSL_ONLY(clnt_ssl)))
+        goto end;
     rv = 1;
-    if (SSL_READ_ETM(clnt_ssl))
+    if (SSL_READ_ETM(clnt_sc))
         rv = 2;
- end:
+end:
     SSL_free(clnt_ssl);
     SSL_free(srvr_ssl);
     return rv;
@@ -168,7 +171,7 @@ static int run_mtu_tests(void)
         const char *cipher_name = SSL_CIPHER_get_name(cipher);
 
         /* As noted above, only one test for each enc/mac variant. */
-        if (strncmp(cipher_name, "PSK-", 4) != 0)
+        if (!HAS_PREFIX(cipher_name, "PSK-"))
             continue;
 
         if (!TEST_int_gt(ret = mtu_test(ctx, cipher_name, 0), 0))
@@ -183,7 +186,7 @@ static int run_mtu_tests(void)
         TEST_info("%s without EtM OK", cipher_name);
     }
 
- end:
+end:
     SSL_CTX_free(ctx);
     return ret;
 }
@@ -206,7 +209,7 @@ static int test_server_mtu_larger_than_max_fragment_length(void)
 #endif
 
     if (!TEST_true(create_ssl_objects(ctx, ctx, &srvr_ssl, &clnt_ssl,
-                                      NULL, NULL)))
+            NULL, NULL)))
         goto end;
 
     SSL_set_options(srvr_ssl, SSL_OP_NO_QUERY_MTU);
@@ -214,15 +217,15 @@ static int test_server_mtu_larger_than_max_fragment_length(void)
         goto end;
 
     SSL_set_tlsext_max_fragment_length(clnt_ssl,
-                                       TLSEXT_max_fragment_length_512);
+        TLSEXT_max_fragment_length_512);
 
     if (!TEST_true(create_ssl_connection(srvr_ssl, clnt_ssl,
-                                         SSL_ERROR_NONE)))
+            SSL_ERROR_NONE)))
         goto end;
 
     rv = 1;
 
- end:
+end:
     SSL_free(clnt_ssl);
     SSL_free(srvr_ssl);
     SSL_CTX_free(ctx);
