@@ -15,7 +15,7 @@
 #include "ssltestlib.h"
 #include "../testutil.h"
 #if defined(OPENSSL_THREADS) && !defined(CRYPTO_TDEBUG)
-# include "../threadstest.h"
+#include "../threadstest.h"
 #endif
 #include "internal/quic_ssl.h"
 #include "internal/quic_wire_pkt.h"
@@ -80,6 +80,7 @@ static void qtest_reset_time(void);
 static int using_fake_time = 0;
 static OSSL_TIME fake_now;
 static CRYPTO_RWLOCK *fake_now_lock = NULL;
+static OSSL_TIME start_time;
 
 static OSSL_TIME fake_now_cb(void *arg)
 {
@@ -87,8 +88,8 @@ static OSSL_TIME fake_now_cb(void *arg)
 }
 
 static void noise_msg_callback(int write_p, int version, int content_type,
-                               const void *buf, size_t len, SSL *ssl,
-                               void *arg)
+    const void *buf, size_t len, SSL *ssl,
+    void *arg)
 {
     struct noise_args_data_st *noiseargs = (struct noise_args_data_st *)arg;
 
@@ -115,23 +116,23 @@ static void noise_msg_callback(int write_p, int version, int content_type,
 
 #ifndef OPENSSL_NO_SSL_TRACE
     if ((noiseargs->flags & QTEST_FLAG_CLIENT_TRACE) != 0
-            && !SSL_is_server(ssl))
+        && !SSL_is_server(ssl))
         SSL_trace(write_p, version, content_type, buf, len, ssl,
-                  noiseargs->tracebio);
+            noiseargs->tracebio);
 #endif
 }
 
 int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
-                              SSL_CTX *serverctx, char *certfile, char *keyfile,
-                              int flags, QUIC_TSERVER **qtserv, SSL **cssl,
-                              QTEST_FAULT **fault, BIO **tracebio)
+    SSL_CTX *serverctx, char *certfile, char *keyfile,
+    int flags, QUIC_TSERVER **qtserv, SSL **cssl,
+    QTEST_FAULT **fault, BIO **tracebio)
 {
     /* ALPN value as recognised by QUIC_TSERVER */
     unsigned char alpn[] = { 8, 'o', 's', 's', 'l', 't', 'e', 's', 't' };
-    QUIC_TSERVER_ARGS tserver_args = {0};
+    QUIC_TSERVER_ARGS tserver_args = { 0 };
     BIO *cbio = NULL, *sbio = NULL, *fisbio = NULL;
     BIO_ADDR *peeraddr = NULL;
-    struct in_addr ina = {0};
+    struct in_addr ina = { 0 };
     BIO *tmpbio = NULL;
 
     *qtserv = NULL;
@@ -197,12 +198,12 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
             goto err;
 
         if (!TEST_true(BIO_dgram_set_caps(cbio, BIO_DGRAM_CAP_HANDLES_DST_ADDR))
-                || !TEST_true(BIO_dgram_set_caps(sbio, BIO_DGRAM_CAP_HANDLES_DST_ADDR)))
+            || !TEST_true(BIO_dgram_set_caps(sbio, BIO_DGRAM_CAP_HANDLES_DST_ADDR)))
             goto err;
 
         /* Dummy server address */
         if (!TEST_true(BIO_ADDR_rawmake(peeraddr, AF_INET, &ina, sizeof(ina),
-                                        htons(0))))
+                htons(0))))
             goto err;
     }
 
@@ -221,6 +222,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
 
     if ((flags & QTEST_FLAG_NOISE) != 0) {
         BIO *noisebio;
+        struct bio_noise_now_cb_st now_cb = { fake_now_cb, NULL };
 
         /*
          * It is an error to not have a QTEST_FAULT object when introducing noise
@@ -233,12 +235,24 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
         if (!TEST_ptr(noisebio))
             goto err;
         cbio = BIO_push(noisebio, cbio);
+        if ((flags & QTEST_FLAG_FAKE_TIME) != 0) {
+            if (!TEST_int_eq(BIO_ctrl(cbio, BIO_CTRL_NOISE_SET_NOW_CB,
+                                 0, &now_cb),
+                    1))
+                goto err;
+        }
 
         noisebio = BIO_new(bio_f_noisy_dgram_filter());
 
         if (!TEST_ptr(noisebio))
             goto err;
         sbio = BIO_push(noisebio, sbio);
+        if ((flags & QTEST_FLAG_FAKE_TIME) != 0) {
+            if (!TEST_int_eq(BIO_ctrl(sbio, BIO_CTRL_NOISE_SET_NOW_CB,
+                                 0, &now_cb),
+                    1))
+                goto err;
+        }
         /*
          * TODO(QUIC SERVER):
          *    Currently the simplistic handler of the quic tserver cannot cope
@@ -260,7 +274,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
     SSL_set_bio(*cssl, cbio, cbio);
 
     if (!TEST_true(SSL_set_blocking_mode(*cssl,
-                                         (flags & QTEST_FLAG_BLOCK) != 0 ? 1 : 0)))
+            (flags & QTEST_FLAG_BLOCK) != 0 ? 1 : 0)))
         goto err;
 
     if (!TEST_true(SSL_set1_initial_peer_addr(*cssl, peeraddr)))
@@ -301,7 +315,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
     }
 
     if (!TEST_ptr(*qtserv = ossl_quic_tserver_new(&tserver_args, certfile,
-                                                  keyfile)))
+                      keyfile)))
         goto err;
 
     /* Ownership of fisbio and sbio is now held by *qtserv */
@@ -310,7 +324,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
 
     if ((flags & QTEST_FLAG_NOISE) != 0)
         ossl_quic_tserver_set_msg_callback(*qtserv, noise_msg_callback,
-                                           &(*fault)->noiseargs);
+            &(*fault)->noiseargs);
 
     if (fault != NULL)
         (*fault)->qtserv = *qtserv;
@@ -318,7 +332,7 @@ int qtest_create_quic_objects(OSSL_LIB_CTX *libctx, SSL_CTX *clientctx,
     BIO_ADDR_free(peeraddr);
 
     return 1;
- err:
+err:
     SSL_CTX_free(tserver_args.ctx);
     BIO_ADDR_free(peeraddr);
     BIO_free_all(cbio);
@@ -365,6 +379,16 @@ static void qtest_reset_time(void)
     qtest_add_time(1);
 }
 
+void qtest_start_stopwatch(void)
+{
+    start_time = qtest_get_time();
+}
+
+uint64_t qtest_get_stopwatch_time(void)
+{
+    return ossl_time2ms(ossl_time_subtract(qtest_get_time(), start_time));
+}
+
 QTEST_FAULT *qtest_create_injector(QUIC_TSERVER *ts)
 {
     QTEST_FAULT *f;
@@ -375,7 +399,6 @@ QTEST_FAULT *qtest_create_injector(QUIC_TSERVER *ts)
 
     f->qtserv = ts;
     return f;
-
 }
 
 int qtest_supports_blocking(void)
@@ -387,7 +410,7 @@ int qtest_supports_blocking(void)
 #endif
 }
 
-#define MAXLOOPS    1000
+#define MAXLOOPS 1000
 
 #if defined(OPENSSL_THREADS) && !defined(CRYPTO_TDEBUG)
 static int globserverret = 0;
@@ -418,7 +441,7 @@ int qtest_wait_for_timeout(SSL *s, QUIC_TSERVER *qtserv)
 
     /* Don't wait if either BIO has data waiting */
     if (BIO_pending(SSL_get_rbio(s)) > 0
-            || BIO_pending(ossl_quic_tserver_get0_rbio(qtserv)) > 0)
+        || BIO_pending(ossl_quic_tserver_get0_rbio(qtserv)) > 0)
         return 1;
 
     /*
@@ -451,7 +474,7 @@ int qtest_wait_for_timeout(SSL *s, QUIC_TSERVER *qtserv)
 }
 
 int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
-                                    int wanterr)
+    int wanterr)
 {
     int retc = -1, rets = 0, abortctr = 0, ret = 0;
     int clienterr = 0, servererr = 0;
@@ -506,7 +529,7 @@ int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
                         rets = 1;
                 } else {
                     if (err != SSL_ERROR_WANT_READ
-                            && err != SSL_ERROR_WANT_WRITE) {
+                        && err != SSL_ERROR_WANT_WRITE) {
                         TEST_info("SSL_connect() failed %d, %d", retc, err);
                         TEST_openssl_errors();
                         clienterr = 1;
@@ -540,9 +563,9 @@ int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
                 goto err;
         }
     } while ((retc <= 0 && !clienterr)
-             || (rets <= 0 && !servererr
+        || (rets <= 0 && !servererr
 #if defined(OPENSSL_THREADS) && !defined(CRYPTO_TDEBUG)
-                 && !tsan_load(&abortserverthread)
+            && !tsan_load(&abortserverthread)
 #endif
                 ));
 
@@ -558,7 +581,7 @@ int qtest_create_quic_connection_ex(QUIC_TSERVER *qtserv, SSL *clientssl,
 
     if (!clienterr && !servererr)
         ret = 1;
- err:
+err:
     return ret;
 }
 
@@ -579,7 +602,7 @@ static void run_server_shutdown_thread(void)
      */
     do {
         ossl_quic_tserver_tick(globtserv);
-    } while(!tsan_load(&shutdowndone));
+    } while (!tsan_load(&shutdowndone));
 }
 #endif
 
@@ -653,10 +676,10 @@ int qtest_check_server_transport_err(QUIC_TSERVER *qtserv, uint64_t code)
         return 0;
 
     cause = ossl_quic_tserver_get_terminate_cause(qtserv);
-    if  (!TEST_ptr(cause)
-            || !TEST_true(cause->remote)
-            || !TEST_false(cause->app)
-            || !TEST_uint64_t_eq(cause->error_code, code))
+    if (!TEST_ptr(cause)
+        || !TEST_true(cause->remote)
+        || !TEST_false(cause->app)
+        || !TEST_uint64_t_eq(cause->error_code, code))
         return 0;
 
     return 1;
@@ -664,12 +687,12 @@ int qtest_check_server_transport_err(QUIC_TSERVER *qtserv, uint64_t code)
 
 int qtest_check_server_protocol_err(QUIC_TSERVER *qtserv)
 {
-    return qtest_check_server_transport_err(qtserv, QUIC_ERR_PROTOCOL_VIOLATION);
+    return qtest_check_server_transport_err(qtserv, OSSL_QUIC_ERR_PROTOCOL_VIOLATION);
 }
 
 int qtest_check_server_frame_encoding_err(QUIC_TSERVER *qtserv)
 {
-    return qtest_check_server_transport_err(qtserv, QUIC_ERR_FRAME_ENCODING_ERROR);
+    return qtest_check_server_transport_err(qtserv, OSSL_QUIC_ERR_FRAME_ENCODING_ERROR);
 }
 
 void qtest_fault_free(QTEST_FAULT *fault)
@@ -684,11 +707,11 @@ void qtest_fault_free(QTEST_FAULT *fault)
 }
 
 static int packet_plain_mutate(const QUIC_PKT_HDR *hdrin,
-                               const OSSL_QTX_IOVEC *iovecin, size_t numin,
-                               QUIC_PKT_HDR **hdrout,
-                               const OSSL_QTX_IOVEC **iovecout,
-                               size_t *numout,
-                               void *arg)
+    const OSSL_QTX_IOVEC *iovecin, size_t numin,
+    QUIC_PKT_HDR **hdrout,
+    const OSSL_QTX_IOVEC **iovecout,
+    size_t *numout,
+    void *arg)
 {
     QTEST_FAULT *fault = arg;
     size_t i, bufsz = 0;
@@ -723,9 +746,9 @@ static int packet_plain_mutate(const QUIC_PKT_HDR *hdrin,
 
     /* Cast below is safe because we allocated the buffer */
     if (fault->pplaincb != NULL
-            && !fault->pplaincb(fault, &fault->pplainhdr,
-                                (unsigned char *)fault->pplainio.buf,
-                                fault->pplainio.buf_len, fault->pplaincbarg))
+        && !fault->pplaincb(fault, &fault->pplainhdr,
+            (unsigned char *)fault->pplainio.buf,
+            fault->pplainio.buf_len, fault->pplaincbarg))
         return 0;
 
     *hdrout = &fault->pplainhdr;
@@ -747,16 +770,16 @@ static void packet_plain_finish(void *arg)
 }
 
 int qtest_fault_set_packet_plain_listener(QTEST_FAULT *fault,
-                                          qtest_fault_on_packet_plain_cb pplaincb,
-                                          void *pplaincbarg)
+    qtest_fault_on_packet_plain_cb pplaincb,
+    void *pplaincbarg)
 {
     fault->pplaincb = pplaincb;
     fault->pplaincbarg = pplaincbarg;
 
     return ossl_quic_tserver_set_plain_packet_mutator(fault->qtserv,
-                                                      packet_plain_mutate,
-                                                      packet_plain_finish,
-                                                      fault);
+        packet_plain_mutate,
+        packet_plain_finish,
+        fault);
 }
 
 /* To be called from a packet_plain_listener callback */
@@ -796,7 +819,7 @@ int qtest_fault_resize_plain_packet(QTEST_FAULT *fault, size_t newlen)
  * callback
  */
 int qtest_fault_prepend_frame(QTEST_FAULT *fault, const unsigned char *frame,
-                              size_t frame_len)
+    size_t frame_len)
 {
     unsigned char *buf;
     size_t old_len;
@@ -814,7 +837,7 @@ int qtest_fault_prepend_frame(QTEST_FAULT *fault, const unsigned char *frame,
 
     /* Extend the size of the packet by the size of the new frame */
     if (!TEST_true(qtest_fault_resize_plain_packet(fault,
-                                                   old_len + frame_len)))
+            old_len + frame_len)))
         return 0;
 
     memmove(buf + frame_len, buf, old_len);
@@ -824,8 +847,8 @@ int qtest_fault_prepend_frame(QTEST_FAULT *fault, const unsigned char *frame,
 }
 
 static int handshake_mutate(const unsigned char *msgin, size_t msginlen,
-                            unsigned char **msgout, size_t *msgoutlen,
-                            void *arg)
+    unsigned char **msgout, size_t *msgoutlen,
+    void *arg)
 {
     QTEST_FAULT *fault = arg;
     unsigned char *buf;
@@ -843,15 +866,14 @@ static int handshake_mutate(const unsigned char *msgin, size_t msginlen,
     memcpy(buf, msgin, msginlen);
 
     if (!PACKET_buf_init(&pkt, buf, msginlen)
-            || !PACKET_get_1(&pkt, &msgtype)
-            || !PACKET_get_net_3(&pkt, &payloadlen)
-            || PACKET_remaining(&pkt) != payloadlen)
+        || !PACKET_get_1(&pkt, &msgtype)
+        || !PACKET_get_net_3(&pkt, &payloadlen)
+        || PACKET_remaining(&pkt) != payloadlen)
         return 0;
 
     /* Parse specific message types */
     switch (msgtype) {
-    case SSL3_MT_ENCRYPTED_EXTENSIONS:
-    {
+    case SSL3_MT_ENCRYPTED_EXTENSIONS: {
         QTEST_ENCRYPTED_EXTENSIONS ee;
 
         if (fault->encextcb == NULL)
@@ -873,8 +895,8 @@ static int handshake_mutate(const unsigned char *msgin, size_t msginlen,
     }
 
     if (fault->handshakecb != NULL
-            && !fault->handshakecb(fault, buf, fault->handbuflen,
-                                   fault->handshakecbarg))
+        && !fault->handshakecb(fault, buf, fault->handbuflen,
+            fault->handshakecbarg))
         return 0;
 
     *msgout = buf;
@@ -892,29 +914,29 @@ static void handshake_finish(void *arg)
 }
 
 int qtest_fault_set_handshake_listener(QTEST_FAULT *fault,
-                                       qtest_fault_on_handshake_cb handshakecb,
-                                       void *handshakecbarg)
+    qtest_fault_on_handshake_cb handshakecb,
+    void *handshakecbarg)
 {
     fault->handshakecb = handshakecb;
     fault->handshakecbarg = handshakecbarg;
 
     return ossl_quic_tserver_set_handshake_mutator(fault->qtserv,
-                                                   handshake_mutate,
-                                                   handshake_finish,
-                                                   fault);
+        handshake_mutate,
+        handshake_finish,
+        fault);
 }
 
 int qtest_fault_set_hand_enc_ext_listener(QTEST_FAULT *fault,
-                                          qtest_fault_on_enc_ext_cb encextcb,
-                                          void *encextcbarg)
+    qtest_fault_on_enc_ext_cb encextcb,
+    void *encextcbarg)
 {
     fault->encextcb = encextcb;
     fault->encextcbarg = encextcbarg;
 
     return ossl_quic_tserver_set_handshake_mutator(fault->qtserv,
-                                                   handshake_mutate,
-                                                   handshake_finish,
-                                                   fault);
+        handshake_mutate,
+        handshake_finish,
+        fault);
 }
 
 /* To be called from a handshake_listener callback */
@@ -955,16 +977,16 @@ int qtest_fault_resize_message(QTEST_FAULT *fault, size_t newlen)
 
     /* Fixup the handshake message header */
     fault->handbuf[1] = (unsigned char)((newlen >> 16) & 0xff);
-    fault->handbuf[2] = (unsigned char)((newlen >>  8) & 0xff);
-    fault->handbuf[3] = (unsigned char)((newlen      ) & 0xff);
+    fault->handbuf[2] = (unsigned char)((newlen >> 8) & 0xff);
+    fault->handbuf[3] = (unsigned char)((newlen) & 0xff);
 
     return 1;
 }
 
 int qtest_fault_delete_extension(QTEST_FAULT *fault,
-                                 unsigned int exttype, unsigned char *ext,
-                                 size_t *extlen,
-                                 BUF_MEM *old_ext)
+    unsigned int exttype, unsigned char *ext,
+    size_t *extlen,
+    BUF_MEM *old_ext)
 {
     PACKET pkt, sub, subext;
     WPACKET old_ext_wpkt;
@@ -983,7 +1005,7 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
     do {
         start = PACKET_data(&sub);
         if (!PACKET_get_net_2(&sub, &type)
-                || !PACKET_get_length_prefixed_2(&sub, &subext))
+            || !PACKET_get_length_prefixed_2(&sub, &subext))
             return 0;
     } while (type != exttype);
 
@@ -995,7 +1017,7 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
             return 0;
 
         if (!WPACKET_memcpy(&old_ext_wpkt, PACKET_data(&subext),
-                            PACKET_remaining(&subext))
+                PACKET_remaining(&subext))
             || !WPACKET_get_total_written(&old_ext_wpkt, &w)) {
             WPACKET_cleanup(&old_ext_wpkt);
             return 0;
@@ -1023,7 +1045,7 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
 
     /* Fixup the length bytes for the extension block */
     ext[0] = (unsigned char)((newlen >> 8) & 0xff);
-    ext[1] = (unsigned char)((newlen     ) & 0xff);
+    ext[1] = (unsigned char)((newlen) & 0xff);
 
     /*
      * Length of the whole extension block is the new payload length plus the
@@ -1041,15 +1063,15 @@ int qtest_fault_delete_extension(QTEST_FAULT *fault,
     return 1;
 }
 
-#define BIO_TYPE_CIPHER_PACKET_FILTER  (0x80 | BIO_TYPE_FILTER)
+#define BIO_TYPE_CIPHER_PACKET_FILTER (0x80 | BIO_TYPE_FILTER)
 
 static BIO_METHOD *pcipherbiometh = NULL;
 
-# define BIO_MSG_N(array, stride, n) (*(BIO_MSG *)((char *)(array) + (n)*(stride)))
+#define BIO_MSG_N(array, stride, n) (*(BIO_MSG *)((char *)(array) + (n) * (stride)))
 
 static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
-                            size_t num_msg, uint64_t flags,
-                            size_t *num_processed)
+    size_t num_msg, uint64_t flags,
+    size_t *num_processed)
 {
     QTEST_FAULT *fault;
     BIO *next = BIO_next(b);
@@ -1064,7 +1086,7 @@ static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
 
     fault = BIO_get_data(b);
     if (fault == NULL
-            || (fault->pciphercb == NULL && fault->datagramcb == NULL))
+        || (fault->pciphercb == NULL && fault->datagramcb == NULL))
         return BIO_sendmmsg(next, msg, stride, num_msg, flags, num_processed);
 
     if (num_msg == 0) {
@@ -1104,7 +1126,7 @@ static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
                  * const is safe
                  */
                 if (!fault->pciphercb(fault, &hdr, (unsigned char *)hdr.data,
-                                    hdr.len, fault->pciphercbarg))
+                        hdr.len, fault->pciphercbarg))
                     goto out;
 
                 /*
@@ -1118,8 +1140,8 @@ static int pcipher_sendmmsg(BIO *b, BIO_MSG *msg, size_t stride,
         }
 
         if (fault->datagramcb != NULL
-                && !fault->datagramcb(fault, &fault->msg, stride,
-                                      fault->datagramcbarg))
+            && !fault->datagramcb(fault, &fault->msg, stride,
+                fault->datagramcbarg))
             goto out;
 
         if (!BIO_sendmmsg(next, &fault->msg, stride, 1, flags, &tmpnump)) {
@@ -1163,19 +1185,19 @@ BIO_METHOD *qtest_get_bio_method(void)
         return NULL;
 
     if (!TEST_true(BIO_meth_set_sendmmsg(tmp, pcipher_sendmmsg))
-            || !TEST_true(BIO_meth_set_ctrl(tmp, pcipher_ctrl)))
+        || !TEST_true(BIO_meth_set_ctrl(tmp, pcipher_ctrl)))
         goto err;
 
     pcipherbiometh = tmp;
     tmp = NULL;
- err:
+err:
     BIO_meth_free(tmp);
     return pcipherbiometh;
 }
 
 int qtest_fault_set_packet_cipher_listener(QTEST_FAULT *fault,
-                                           qtest_fault_on_packet_cipher_cb pciphercb,
-                                           void *pciphercbarg)
+    qtest_fault_on_packet_cipher_cb pciphercb,
+    void *pciphercbarg)
 {
     fault->pciphercb = pciphercb;
     fault->pciphercbarg = pciphercbarg;
@@ -1184,8 +1206,8 @@ int qtest_fault_set_packet_cipher_listener(QTEST_FAULT *fault,
 }
 
 int qtest_fault_set_datagram_listener(QTEST_FAULT *fault,
-                                      qtest_fault_on_datagram_cb datagramcb,
-                                      void *datagramcbarg)
+    qtest_fault_on_datagram_cb datagramcb,
+    void *datagramcbarg)
 {
     fault->datagramcb = datagramcb;
     fault->datagramcbarg = datagramcbarg;
@@ -1197,17 +1219,42 @@ int qtest_fault_set_datagram_listener(QTEST_FAULT *fault,
 int qtest_fault_resize_datagram(QTEST_FAULT *fault, size_t newlen)
 {
     if (newlen > fault->msgalloc)
-            return 0;
+        return 0;
 
     if (newlen > fault->msg.data_len)
         memset((unsigned char *)fault->msg.data + fault->msg.data_len, 0,
-                newlen - fault->msg.data_len);
+            newlen - fault->msg.data_len);
 
     fault->msg.data_len = newlen;
 
     return 1;
 }
 
+int qtest_fault_set_bw_limit(QTEST_FAULT *fault,
+    size_t ctos_bw, size_t stoc_bw,
+    int noise_rate)
+{
+    BIO *sbio = fault->noiseargs.sbio;
+    BIO *cbio = fault->noiseargs.cbio;
+
+    if (!TEST_ptr(sbio) || !TEST_ptr(cbio))
+        return 0;
+    if (!TEST_int_eq(BIO_ctrl(sbio, BIO_CTRL_NOISE_RATE, noise_rate, NULL), 1))
+        return 0;
+    if (!TEST_int_eq(BIO_ctrl(cbio, BIO_CTRL_NOISE_RATE, noise_rate, NULL), 1))
+        return 0;
+    /* We set the bandwidth limit on the sending side */
+    if (!TEST_int_eq(BIO_ctrl(cbio, BIO_CTRL_NOISE_SEND_BANDWIDTH,
+                         (long)ctos_bw, NULL),
+            1))
+        return 0;
+    if (!TEST_int_eq(BIO_ctrl(sbio, BIO_CTRL_NOISE_SEND_BANDWIDTH,
+                         (long)stoc_bw, NULL),
+            1))
+        return 0;
+    return 1;
+}
+
 int bio_msg_copy(BIO_MSG *dst, BIO_MSG *src)
 {
     /*
