@@ -12,7 +12,7 @@
  * when the deprecated calls are not hidden
  */
 #ifndef OPENSSL_NO_DEPRECATED_3_0
-# define OPENSSL_SUPPRESS_DEPRECATED
+#define OPENSSL_SUPPRESS_DEPRECATED
 #endif
 
 #include <string.h>
@@ -24,9 +24,9 @@
 #include "../testutil.h"
 
 #if (!defined(OPENSSL_NO_KTLS) || !defined(OPENSSL_NO_QUIC)) && !defined(OPENSSL_NO_POSIX_IO) && !defined(OPENSSL_NO_SOCK)
-# define OSSL_USE_SOCKETS 1
-# include "internal/sockets.h"
-# include <openssl/bio.h>
+#define OSSL_USE_SOCKETS 1
+#include "internal/sockets.h"
+#include <openssl/bio.h>
 #endif
 
 static int tls_dump_new(BIO *bi);
@@ -38,10 +38,10 @@ static int tls_dump_gets(BIO *bp, char *buf, int size);
 static int tls_dump_puts(BIO *bp, const char *str);
 
 /* Choose a sufficiently large type likely to be unused for this custom BIO */
-#define BIO_TYPE_TLS_DUMP_FILTER   (0x80 | BIO_TYPE_FILTER)
-#define BIO_TYPE_MEMPACKET_TEST    0x81
-#define BIO_TYPE_ALWAYS_RETRY      0x82
-#define BIO_TYPE_MAYBE_RETRY       (0x83 | BIO_TYPE_FILTER)
+#define BIO_TYPE_TLS_DUMP_FILTER (0x80 | BIO_TYPE_FILTER)
+#define BIO_TYPE_MEMPACKET_TEST 0x81
+#define BIO_TYPE_ALWAYS_RETRY 0x82
+#define BIO_TYPE_MAYBE_RETRY (0x83 | BIO_TYPE_FILTER)
 
 static BIO_METHOD *method_tls_dump = NULL;
 static BIO_METHOD *meth_mem = NULL;
@@ -54,7 +54,7 @@ const BIO_METHOD *bio_f_tls_dump_filter(void)
 {
     if (method_tls_dump == NULL) {
         method_tls_dump = BIO_meth_new(BIO_TYPE_TLS_DUMP_FILTER,
-                                        "TLS dump filter");
+            "TLS dump filter");
         if (method_tls_dump == NULL
             || !BIO_meth_set_write(method_tls_dump, tls_dump_write)
             || !BIO_meth_set_read(method_tls_dump, tls_dump_read)
@@ -96,29 +96,28 @@ static void copy_flags(BIO *bio)
     BIO_set_flags(bio, flags);
 }
 
-#define RECORD_CONTENT_TYPE     0
-#define RECORD_VERSION_HI       1
-#define RECORD_VERSION_LO       2
-#define RECORD_EPOCH_HI         3
-#define RECORD_EPOCH_LO         4
-#define RECORD_SEQUENCE_START   5
-#define RECORD_SEQUENCE_END     10
-#define RECORD_LEN_HI           11
-#define RECORD_LEN_LO           12
-
-#define MSG_TYPE                0
-#define MSG_LEN_HI              1
-#define MSG_LEN_MID             2
-#define MSG_LEN_LO              3
-#define MSG_SEQ_HI              4
-#define MSG_SEQ_LO              5
-#define MSG_FRAG_OFF_HI         6
-#define MSG_FRAG_OFF_MID        7
-#define MSG_FRAG_OFF_LO         8
-#define MSG_FRAG_LEN_HI         9
-#define MSG_FRAG_LEN_MID        10
-#define MSG_FRAG_LEN_LO         11
+#define RECORD_CONTENT_TYPE 0
+#define RECORD_VERSION_HI 1
+#define RECORD_VERSION_LO 2
+#define RECORD_EPOCH_HI 3
+#define RECORD_EPOCH_LO 4
+#define RECORD_SEQUENCE_START 5
+#define RECORD_SEQUENCE_END 10
+#define RECORD_LEN_HI 11
+#define RECORD_LEN_LO 12
 
+#define MSG_TYPE 0
+#define MSG_LEN_HI 1
+#define MSG_LEN_MID 2
+#define MSG_LEN_LO 3
+#define MSG_SEQ_HI 4
+#define MSG_SEQ_LO 5
+#define MSG_FRAG_OFF_HI 6
+#define MSG_FRAG_OFF_MID 7
+#define MSG_FRAG_OFF_LO 8
+#define MSG_FRAG_LEN_HI 9
+#define MSG_FRAG_LEN_MID 10
+#define MSG_FRAG_LEN_LO 11
 
 static void dump_data(const char *data, int len)
 {
@@ -141,7 +140,7 @@ static void dump_data(const char *data, int len)
         content = rec[RECORD_CONTENT_TYPE];
         printf("** Record Content-type: %d\n", content);
         printf("** Record Version: %02x%02x\n",
-               rec[RECORD_VERSION_HI], rec[RECORD_VERSION_LO]);
+            rec[RECORD_VERSION_HI], rec[RECORD_VERSION_LO]);
         epoch = (rec[RECORD_EPOCH_HI] << 8) | rec[RECORD_EPOCH_LO];
         printf("** Record Epoch: %d\n", epoch);
         printf("** Record Sequence: ");
@@ -158,22 +157,22 @@ static void dump_data(const char *data, int len)
             if (epoch > 0) {
                 printf("**---- HANDSHAKE MESSAGE FRAGMENT ENCRYPTED ----\n");
             } else if (rem < DTLS1_HM_HEADER_LENGTH
-                    || reclen < DTLS1_HM_HEADER_LENGTH) {
+                || reclen < DTLS1_HM_HEADER_LENGTH) {
                 printf("**---- HANDSHAKE MESSAGE FRAGMENT TRUNCATED ----\n");
             } else {
                 printf("*** Message Type: %d\n", rec[MSG_TYPE]);
                 msglen = (rec[MSG_LEN_HI] << 16) | (rec[MSG_LEN_MID] << 8)
-                         | rec[MSG_LEN_LO];
+                    | rec[MSG_LEN_LO];
                 printf("*** Message Length: %d\n", msglen);
                 printf("*** Message sequence: %d\n",
-                       (rec[MSG_SEQ_HI] << 8) | rec[MSG_SEQ_LO]);
+                    (rec[MSG_SEQ_HI] << 8) | rec[MSG_SEQ_LO]);
                 fragoff = (rec[MSG_FRAG_OFF_HI] << 16)
-                          | (rec[MSG_FRAG_OFF_MID] << 8)
-                          | rec[MSG_FRAG_OFF_LO];
+                    | (rec[MSG_FRAG_OFF_MID] << 8)
+                    | rec[MSG_FRAG_OFF_LO];
                 printf("*** Message Fragment offset: %d\n", fragoff);
                 fraglen = (rec[MSG_FRAG_LEN_HI] << 16)
-                          | (rec[MSG_FRAG_LEN_MID] << 8)
-                          | rec[MSG_FRAG_LEN_LO];
+                    | (rec[MSG_FRAG_LEN_MID] << 8)
+                    | rec[MSG_FRAG_LEN_LO];
                 printf("*** Message Fragment len: %d\n", fraglen);
                 if (fragoff + fraglen > msglen)
                     printf("***---- HANDSHAKE MESSAGE FRAGMENT INVALID ----\n");
@@ -252,7 +251,6 @@ static int tls_dump_puts(BIO *bio, const char *str)
     return tls_dump_write(bio, str, strlen(str));
 }
 
-
 struct mempacket_st {
     unsigned char *data;
     int len;
@@ -292,7 +290,7 @@ const BIO_METHOD *bio_s_mempacket_test(void)
 {
     if (meth_mem == NULL) {
         if (!TEST_ptr(meth_mem = BIO_meth_new(BIO_TYPE_MEMPACKET_TEST,
-                                              "Mem Packet Test"))
+                          "Mem Packet Test"))
             || !TEST_true(BIO_meth_set_write(meth_mem, mempacket_test_write))
             || !TEST_true(BIO_meth_set_read(meth_mem, mempacket_test_read))
             || !TEST_true(BIO_meth_set_puts(meth_mem, mempacket_test_puts))
@@ -339,13 +337,13 @@ static int mempacket_test_free(BIO *bio)
 }
 
 /* Record Header values */
-#define EPOCH_HI        3
-#define EPOCH_LO        4
+#define EPOCH_HI 3
+#define EPOCH_LO 4
 #define RECORD_SEQUENCE 10
-#define RECORD_LEN_HI   11
-#define RECORD_LEN_LO   12
+#define RECORD_LEN_HI 11
+#define RECORD_LEN_LO 12
 
-#define STANDARD_PACKET                 0
+#define STANDARD_PACKET 0
 
 static int mempacket_test_read(BIO *bio, char *out, int outl)
 {
@@ -369,7 +367,7 @@ static int mempacket_test_read(BIO *bio, char *out, int outl)
         outl = thispkt->len;
 
     if (thispkt->type != INJECT_PACKET_IGNORE_REC_SEQ
-            && (ctx->injected || ctx->droprec >= 0)) {
+        && (ctx->injected || ctx->droprec >= 0)) {
         /*
          * Overwrite the record sequence number. We strictly number them in
          * the order received. Since we are actually a reliable transport
@@ -393,7 +391,7 @@ static int mempacket_test_read(BIO *bio, char *out, int outl)
             } while (seq > 0);
 
             len = ((rec[RECORD_LEN_HI] << 8) | rec[RECORD_LEN_LO])
-                  + DTLS1_RT_HEADER_LENGTH;
+                + DTLS1_RT_HEADER_LENGTH;
             if (rem < (int)len)
                 return -1;
             if (ctx->droprec == (int)ctx->currrec && ctx->dropepoch == epoch) {
@@ -445,7 +443,7 @@ int mempacket_swap_epoch(BIO *bio)
             return 0;
         epoch = (rec[EPOCH_HI] << 8) | rec[EPOCH_LO];
         len = ((rec[RECORD_LEN_HI] << 8) | rec[RECORD_LEN_LO])
-                + DTLS1_RT_HEADER_LENGTH;
+            + DTLS1_RT_HEADER_LENGTH;
         if (rem < len)
             return 0;
 
@@ -570,14 +568,14 @@ int mempacket_dup_last_packet(BIO *bio)
 }
 
 int mempacket_test_inject(BIO *bio, const char *in, int inl, int pktnum,
-                          int type)
+    int type)
 {
     MEMPACKET_TEST_CTX *ctx = BIO_get_data(bio);
     MEMPACKET *thispkt = NULL, *looppkt, *nextpkt, *allpkts[3];
     int i, duprec;
     const unsigned char *inu = (const unsigned char *)in;
     size_t len = ((inu[RECORD_LEN_HI] << 8) | inu[RECORD_LEN_LO])
-                 + DTLS1_RT_HEADER_LENGTH;
+        + DTLS1_RT_HEADER_LENGTH;
 
     if (ctx == NULL)
         return -1;
@@ -598,7 +596,7 @@ int mempacket_test_inject(BIO *bio, const char *in, int inl, int pktnum,
     if (pktnum >= 0) {
         if (ctx->noinject)
             return -1;
-        ctx->injected  = 1;
+        ctx->injected = 1;
     } else {
         ctx->noinject = 1;
     }
@@ -651,7 +649,7 @@ int mempacket_test_inject(BIO *bio, const char *in, int inl, int pktnum,
                     ctx->lastpkt++;
                 else
                     return inl;
-            } while(1);
+            } while (1);
         } else if (looppkt->num == thispkt->num) {
             if (!ctx->noinject) {
                 /* We injected two packets with the same packet number! */
@@ -676,7 +674,7 @@ int mempacket_test_inject(BIO *bio, const char *in, int inl, int pktnum,
 
     return inl;
 
- err:
+err:
     for (i = 0; i < (ctx->duprec > 0 ? 3 : 1); i++)
         mempacket_free(allpkts[i]);
     return -1;
@@ -762,21 +760,21 @@ const BIO_METHOD *bio_s_always_retry(void)
 {
     if (meth_always_retry == NULL) {
         if (!TEST_ptr(meth_always_retry = BIO_meth_new(BIO_TYPE_ALWAYS_RETRY,
-                                                       "Always Retry"))
+                          "Always Retry"))
             || !TEST_true(BIO_meth_set_write(meth_always_retry,
-                                             always_retry_write))
+                always_retry_write))
             || !TEST_true(BIO_meth_set_read(meth_always_retry,
-                                            always_retry_read))
+                always_retry_read))
             || !TEST_true(BIO_meth_set_puts(meth_always_retry,
-                                            always_retry_puts))
+                always_retry_puts))
             || !TEST_true(BIO_meth_set_gets(meth_always_retry,
-                                            always_retry_gets))
+                always_retry_gets))
             || !TEST_true(BIO_meth_set_ctrl(meth_always_retry,
-                                            always_retry_ctrl))
+                always_retry_ctrl))
             || !TEST_true(BIO_meth_set_create(meth_always_retry,
-                                              always_retry_new))
+                always_retry_new))
             || !TEST_true(BIO_meth_set_destroy(meth_always_retry,
-                                               always_retry_free)))
+                always_retry_free)))
             return NULL;
     }
     return meth_always_retry;
@@ -862,15 +860,15 @@ const BIO_METHOD *bio_s_maybe_retry(void)
 {
     if (meth_maybe_retry == NULL) {
         if (!TEST_ptr(meth_maybe_retry = BIO_meth_new(BIO_TYPE_MAYBE_RETRY,
-                                                      "Maybe Retry"))
+                          "Maybe Retry"))
             || !TEST_true(BIO_meth_set_write(meth_maybe_retry,
-                                             maybe_retry_write))
+                maybe_retry_write))
             || !TEST_true(BIO_meth_set_ctrl(meth_maybe_retry,
-                                            maybe_retry_ctrl))
+                maybe_retry_ctrl))
             || !TEST_true(BIO_meth_set_create(meth_maybe_retry,
-                                              maybe_retry_new))
+                maybe_retry_new))
             || !TEST_true(BIO_meth_set_destroy(meth_maybe_retry,
-                                               maybe_retry_free)))
+                maybe_retry_free)))
             return NULL;
     }
     return meth_maybe_retry;
@@ -944,9 +942,9 @@ static long maybe_retry_ctrl(BIO *bio, int cmd, long num, void *ptr)
 }
 
 int create_ssl_ctx_pair(OSSL_LIB_CTX *libctx, const SSL_METHOD *sm,
-                        const SSL_METHOD *cm, int min_proto_version,
-                        int max_proto_version, SSL_CTX **sctx, SSL_CTX **cctx,
-                        char *certfile, char *privkeyfile)
+    const SSL_METHOD *cm, int min_proto_version,
+    int max_proto_version, SSL_CTX **sctx, SSL_CTX **cctx,
+    char *certfile, char *privkeyfile)
 {
     SSL_CTX *serverctx = NULL;
     SSL_CTX *clientctx = NULL;
@@ -956,7 +954,7 @@ int create_ssl_ctx_pair(OSSL_LIB_CTX *libctx, const SSL_METHOD *sm,
             serverctx = *sctx;
         else if (!TEST_ptr(serverctx = SSL_CTX_new_ex(libctx, NULL, sm))
             || !TEST_true(SSL_CTX_set_options(serverctx,
-                                              SSL_OP_ALLOW_CLIENT_RENEGOTIATION)))
+                SSL_OP_ALLOW_CLIENT_RENEGOTIATION)))
             goto err;
     }
 
@@ -968,41 +966,43 @@ int create_ssl_ctx_pair(OSSL_LIB_CTX *libctx, const SSL_METHOD *sm,
     }
 
 #if !defined(OPENSSL_NO_TLS1_3) \
-    && defined(OPENSSL_NO_EC) \
+    && defined(OPENSSL_NO_EC)   \
     && defined(OPENSSL_NO_DH)
     /*
      * There are no usable built-in TLSv1.3 groups if ec and dh are both
      * disabled
      */
     if (max_proto_version == 0
-            && (sm == TLS_server_method() || cm == TLS_client_method()))
+        && (sm == TLS_server_method() || cm == TLS_client_method()))
         max_proto_version = TLS1_2_VERSION;
 #endif
 
     if (serverctx != NULL
-            && ((min_proto_version > 0
-                 && !TEST_true(SSL_CTX_set_min_proto_version(serverctx,
-                                                            min_proto_version)))
-                || (max_proto_version > 0
-                    && !TEST_true(SSL_CTX_set_max_proto_version(serverctx,
-                                                                max_proto_version)))))
+        && ((min_proto_version > 0
+                && !TEST_true(SSL_CTX_set_min_proto_version(serverctx,
+                    min_proto_version)))
+            || (max_proto_version > 0
+                && !TEST_true(SSL_CTX_set_max_proto_version(serverctx,
+                    max_proto_version)))))
         goto err;
     if (clientctx != NULL
         && ((min_proto_version > 0
-             && !TEST_true(SSL_CTX_set_min_proto_version(clientctx,
-                                                         min_proto_version)))
+                && !TEST_true(SSL_CTX_set_min_proto_version(clientctx,
+                    min_proto_version)))
             || (max_proto_version > 0
                 && !TEST_true(SSL_CTX_set_max_proto_version(clientctx,
-                                                            max_proto_version)))))
+                    max_proto_version)))))
         goto err;
 
     if (serverctx != NULL && certfile != NULL && privkeyfile != NULL) {
         if (!TEST_int_eq(SSL_CTX_use_certificate_file(serverctx, certfile,
-                                                      SSL_FILETYPE_PEM), 1)
-                || !TEST_int_eq(SSL_CTX_use_PrivateKey_file(serverctx,
-                                                            privkeyfile,
-                                                            SSL_FILETYPE_PEM), 1)
-                || !TEST_int_eq(SSL_CTX_check_private_key(serverctx), 1))
+                             SSL_FILETYPE_PEM),
+                1)
+            || !TEST_int_eq(SSL_CTX_use_PrivateKey_file(serverctx,
+                                privkeyfile,
+                                SSL_FILETYPE_PEM),
+                1)
+            || !TEST_int_eq(SSL_CTX_check_private_key(serverctx), 1))
             goto err;
     }
 
@@ -1012,7 +1012,7 @@ int create_ssl_ctx_pair(OSSL_LIB_CTX *libctx, const SSL_METHOD *sm,
         *cctx = clientctx;
     return 1;
 
- err:
+err:
     if (sctx != NULL && *sctx == NULL)
         SSL_CTX_free(serverctx);
     if (cctx != NULL && *cctx == NULL)
@@ -1020,7 +1020,7 @@ int create_ssl_ctx_pair(OSSL_LIB_CTX *libctx, const SSL_METHOD *sm,
     return 0;
 }
 
-#define MAXLOOPS    1000000
+#define MAXLOOPS 1000000
 
 #if defined(OSSL_USE_SOCKETS)
 
@@ -1049,31 +1049,31 @@ int create_test_sockets(int *cfdp, int *sfdp, int socktype, BIO_ADDR *saddr)
     socklen_t slen = sizeof(sin);
     int afd = -1, cfd = -1, sfd = -1;
 
-    memset ((char *) &sin, 0, sizeof(sin));
+    memset((char *)&sin, 0, sizeof(sin));
     sin.sin_family = AF_INET;
     sin.sin_addr.s_addr = inet_addr(host);
 
     afd = BIO_socket(AF_INET, socktype,
-                     socktype == SOCK_STREAM ? IPPROTO_TCP : IPPROTO_UDP, 0);
+        socktype == SOCK_STREAM ? IPPROTO_TCP : IPPROTO_UDP, 0);
     if (afd == INVALID_SOCKET)
         return 0;
 
-    if (bind(afd, (struct sockaddr*)&sin, sizeof(sin)) < 0)
+    if (bind(afd, (struct sockaddr *)&sin, sizeof(sin)) < 0)
         goto out;
 
-    if (getsockname(afd, (struct sockaddr*)&sin, &slen) < 0)
+    if (getsockname(afd, (struct sockaddr *)&sin, &slen) < 0)
         goto out;
 
     if (saddr != NULL
-            && !BIO_ADDR_rawmake(saddr, sin.sin_family, &sin.sin_addr,
-                                 sizeof(sin.sin_addr), sin.sin_port))
+        && !BIO_ADDR_rawmake(saddr, sin.sin_family, &sin.sin_addr,
+            sizeof(sin.sin_addr), sin.sin_port))
         goto out;
 
     if (socktype == SOCK_STREAM && listen(afd, 1) < 0)
         goto out;
 
     cfd = BIO_socket(AF_INET, socktype,
-                     socktype == SOCK_STREAM ? IPPROTO_TCP : IPPROTO_UDP, 0);
+        socktype == SOCK_STREAM ? IPPROTO_TCP : IPPROTO_UDP, 0);
     if (cfd == INVALID_SOCKET)
         goto out;
 
@@ -1095,7 +1095,7 @@ int create_test_sockets(int *cfdp, int *sfdp, int socktype, BIO_ADDR *saddr)
         if (sfd == -1 && errno != EAGAIN)
             goto out;
 
-        if (!cfd_connected && connect(cfd, (struct sockaddr*)&sin, sizeof(sin)) < 0)
+        if (!cfd_connected && connect(cfd, (struct sockaddr *)&sin, sizeof(sin)) < 0)
             goto out;
         else
             cfd_connected = 1;
@@ -1120,11 +1120,11 @@ success:
 }
 
 int create_ssl_objects2(SSL_CTX *serverctx, SSL_CTX *clientctx, SSL **sssl,
-                          SSL **cssl, int sfd, int cfd)
+    SSL **cssl, int sfd, int cfd)
 {
     SSL *serverssl = NULL, *clientssl = NULL;
     BIO *s_to_c_bio = NULL, *c_to_s_bio = NULL;
-    BIO_POLL_DESCRIPTOR rdesc = {0}, wdesc = {0};
+    BIO_POLL_DESCRIPTOR rdesc = { 0 }, wdesc = { 0 };
 
     if (*sssl != NULL)
         serverssl = *sssl;
@@ -1136,11 +1136,11 @@ int create_ssl_objects2(SSL_CTX *serverctx, SSL_CTX *clientctx, SSL **sssl,
         goto error;
 
     if (!TEST_ptr(s_to_c_bio = BIO_new_socket(sfd, BIO_NOCLOSE))
-            || !TEST_ptr(c_to_s_bio = BIO_new_socket(cfd, BIO_NOCLOSE)))
+        || !TEST_ptr(c_to_s_bio = BIO_new_socket(cfd, BIO_NOCLOSE)))
         goto error;
 
     if (!TEST_false(SSL_get_rpoll_descriptor(clientssl, &rdesc)
-        || !TEST_false(SSL_get_wpoll_descriptor(clientssl, &wdesc))))
+            || !TEST_false(SSL_get_wpoll_descriptor(clientssl, &wdesc))))
         goto error;
 
     SSL_set_bio(clientssl, c_to_s_bio, c_to_s_bio);
@@ -1166,7 +1166,7 @@ int create_ssl_objects2(SSL_CTX *serverctx, SSL_CTX *clientctx, SSL **sssl,
     *cssl = clientssl;
     return 1;
 
- error:
+error:
     SSL_free(serverssl);
     SSL_free(clientssl);
     BIO_free(s_to_c_bio);
@@ -1187,7 +1187,7 @@ int wait_until_sock_readable(int sock)
  * NOTE: Transfers control of the BIOs - this function will free them on error
  */
 int create_ssl_objects(SSL_CTX *serverctx, SSL_CTX *clientctx, SSL **sssl,
-                          SSL **cssl, BIO *s_to_c_fbio, BIO *c_to_s_fbio)
+    SSL **cssl, BIO *s_to_c_fbio, BIO *c_to_s_fbio)
 {
     SSL *serverssl = NULL, *clientssl = NULL;
     BIO *s_to_c_bio = NULL, *c_to_s_bio = NULL;
@@ -1203,19 +1203,19 @@ int create_ssl_objects(SSL_CTX *serverctx, SSL_CTX *clientctx, SSL **sssl,
 
     if (SSL_is_dtls(clientssl)) {
         if (!TEST_ptr(s_to_c_bio = BIO_new(bio_s_mempacket_test()))
-                || !TEST_ptr(c_to_s_bio = BIO_new(bio_s_mempacket_test())))
+            || !TEST_ptr(c_to_s_bio = BIO_new(bio_s_mempacket_test())))
             goto error;
     } else {
         if (!TEST_ptr(s_to_c_bio = BIO_new(BIO_s_mem()))
-                || !TEST_ptr(c_to_s_bio = BIO_new(BIO_s_mem())))
+            || !TEST_ptr(c_to_s_bio = BIO_new(BIO_s_mem())))
             goto error;
     }
 
     if (s_to_c_fbio != NULL
-            && !TEST_ptr(s_to_c_bio = BIO_push(s_to_c_fbio, s_to_c_bio)))
+        && !TEST_ptr(s_to_c_bio = BIO_push(s_to_c_fbio, s_to_c_bio)))
         goto error;
     if (c_to_s_fbio != NULL
-            && !TEST_ptr(c_to_s_bio = BIO_push(c_to_s_fbio, c_to_s_bio)))
+        && !TEST_ptr(c_to_s_bio = BIO_push(c_to_s_fbio, c_to_s_bio)))
         goto error;
 
     /* Set Non-blocking IO behaviour */
@@ -1231,7 +1231,7 @@ int create_ssl_objects(SSL_CTX *serverctx, SSL_CTX *clientctx, SSL **sssl,
     *cssl = clientssl;
     return 1;
 
- error:
+error:
     SSL_free(serverssl);
     SSL_free(clientssl);
     BIO_free(s_to_c_bio);
@@ -1253,7 +1253,7 @@ int create_ssl_objects(SSL_CTX *serverctx, SSL_CTX *clientctx, SSL **sssl,
  * attempt could be restarted by a subsequent call to this function.
  */
 int create_bare_ssl_connection(SSL *serverssl, SSL *clientssl, int want,
-                               int read, int listen)
+    int read, int listen)
 {
     int retc = -1, rets = -1, err, abortctr = 0, ret = 0;
     int clienterr = 0, servererr = 0;
@@ -1318,8 +1318,8 @@ int create_bare_ssl_connection(SSL *serverssl, SSL *clientssl, int want,
         }
 
         if (!servererr && rets <= 0
-                && err != SSL_ERROR_WANT_READ
-                && err != SSL_ERROR_WANT_X509_LOOKUP) {
+            && err != SSL_ERROR_WANT_READ
+            && err != SSL_ERROR_WANT_X509_LOOKUP) {
             TEST_info("SSL_accept() failed %d, %d", rets, err);
             if (want != SSL_ERROR_SSL)
                 TEST_openssl_errors();
@@ -1360,10 +1360,10 @@ int create_bare_ssl_connection(SSL *serverssl, SSL *clientssl, int want,
              */
             OSSL_sleep(50);
         }
-    } while (retc <=0 || rets <= 0);
+    } while (retc <= 0 || rets <= 0);
 
     ret = 1;
- err:
+err:
 #ifndef OPENSSL_NO_SOCK
     BIO_ADDR_free(peer);
 #endif
@@ -1393,7 +1393,7 @@ int create_ssl_connection(SSL *serverssl, SSL *clientssl, int want)
             if (!TEST_ulong_eq(readbytes, 0))
                 return 0;
         } else if (!TEST_int_eq(SSL_get_error(clientssl, 0),
-                                SSL_ERROR_WANT_READ)) {
+                       SSL_ERROR_WANT_READ)) {
             return 0;
         }
     }
@@ -1435,12 +1435,12 @@ SSL_SESSION *create_a_psk(SSL *ssl, size_t mdsize)
     }
     sess = SSL_SESSION_new();
     if (!TEST_ptr(sess)
-            || !TEST_ptr(cipher)
-            || !TEST_true(SSL_SESSION_set1_master_key(sess, key, mdsize))
-            || !TEST_true(SSL_SESSION_set_cipher(sess, cipher))
-            || !TEST_true(
-                    SSL_SESSION_set_protocol_version(sess,
-                                                     TLS1_3_VERSION))) {
+        || !TEST_ptr(cipher)
+        || !TEST_true(SSL_SESSION_set1_master_key(sess, key, mdsize))
+        || !TEST_true(SSL_SESSION_set_cipher(sess, cipher))
+        || !TEST_true(
+            SSL_SESSION_set_protocol_version(sess,
+                TLS1_3_VERSION))) {
         SSL_SESSION_free(sess);
         return NULL;
     }
@@ -1450,7 +1450,7 @@ SSL_SESSION *create_a_psk(SSL *ssl, size_t mdsize)
 #define NUM_EXTRA_CERTS 40
 
 int ssl_ctx_add_large_cert_chain(OSSL_LIB_CTX *libctx, SSL_CTX *sctx,
-                                 const char *cert_file)
+    const char *cert_file)
 {
     BIO *certbio = NULL;
     X509 *chaincert = NULL;
@@ -1477,8 +1477,7 @@ int ssl_ctx_add_large_cert_chain(OSSL_LIB_CTX *libctx, SSL_CTX *sctx,
      * test we need to have a message larger than that.
      */
     certlen = i2d_X509(chaincert, NULL);
-    OPENSSL_assert(certlen * NUM_EXTRA_CERTS >
-                   (SSL3_RT_MAX_PLAIN_LENGTH * 4) / 3);
+    OPENSSL_assert(certlen * NUM_EXTRA_CERTS > (SSL3_RT_MAX_PLAIN_LENGTH * 4) / 3);
     for (i = 0; i < NUM_EXTRA_CERTS; i++) {
         if (!X509_up_ref(chaincert))
             goto end;
@@ -1489,7 +1488,7 @@ int ssl_ctx_add_large_cert_chain(OSSL_LIB_CTX *libctx, SSL_CTX *sctx,
     }
 
     ret = 1;
- end:
+end:
     BIO_free(certbio);
     X509_free(chaincert);
     return ret;
