@@ -14,7 +14,7 @@
 #include "internal/time.h"
 
 #if defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 200112L
-# include <signal.h>
+#include <signal.h>
 #endif
 
 static int test_sanity_null_zero(void)
@@ -30,20 +30,124 @@ static int test_sanity_null_zero(void)
 
 static int test_sanity_enum_size(void)
 {
-    enum smallchoices { sa, sb, sc };
-    enum medchoices { ma, mb, mc, md, me, mf, mg, mh, mi, mj, mk, ml };
+    enum smallchoices { sa,
+        sb,
+        sc };
+    enum medchoices { ma,
+        mb,
+        mc,
+        md,
+        me,
+        mf,
+        mg,
+        mh,
+        mi,
+        mj,
+        mk,
+        ml };
     enum largechoices {
-        a01, b01, c01, d01, e01, f01, g01, h01, i01, j01,
-        a02, b02, c02, d02, e02, f02, g02, h02, i02, j02,
-        a03, b03, c03, d03, e03, f03, g03, h03, i03, j03,
-        a04, b04, c04, d04, e04, f04, g04, h04, i04, j04,
-        a05, b05, c05, d05, e05, f05, g05, h05, i05, j05,
-        a06, b06, c06, d06, e06, f06, g06, h06, i06, j06,
-        a07, b07, c07, d07, e07, f07, g07, h07, i07, j07,
-        a08, b08, c08, d08, e08, f08, g08, h08, i08, j08,
-        a09, b09, c09, d09, e09, f09, g09, h09, i09, j09,
-        a10, b10, c10, d10, e10, f10, g10, h10, i10, j10,
-        xxx };
+        a01,
+        b01,
+        c01,
+        d01,
+        e01,
+        f01,
+        g01,
+        h01,
+        i01,
+        j01,
+        a02,
+        b02,
+        c02,
+        d02,
+        e02,
+        f02,
+        g02,
+        h02,
+        i02,
+        j02,
+        a03,
+        b03,
+        c03,
+        d03,
+        e03,
+        f03,
+        g03,
+        h03,
+        i03,
+        j03,
+        a04,
+        b04,
+        c04,
+        d04,
+        e04,
+        f04,
+        g04,
+        h04,
+        i04,
+        j04,
+        a05,
+        b05,
+        c05,
+        d05,
+        e05,
+        f05,
+        g05,
+        h05,
+        i05,
+        j05,
+        a06,
+        b06,
+        c06,
+        d06,
+        e06,
+        f06,
+        g06,
+        h06,
+        i06,
+        j06,
+        a07,
+        b07,
+        c07,
+        d07,
+        e07,
+        f07,
+        g07,
+        h07,
+        i07,
+        j07,
+        a08,
+        b08,
+        c08,
+        d08,
+        e08,
+        f08,
+        g08,
+        h08,
+        i08,
+        j08,
+        a09,
+        b09,
+        c09,
+        d09,
+        e09,
+        f09,
+        g09,
+        h09,
+        i09,
+        j09,
+        a10,
+        b10,
+        c10,
+        d10,
+        e10,
+        f10,
+        g10,
+        h10,
+        i10,
+        j10,
+        xxx
+    };
 
     /* Enum size */
     if (!TEST_size_t_eq(sizeof(enum smallchoices), sizeof(int))
@@ -84,24 +188,24 @@ static int test_sanity_range(void)
 {
     /* Verify some types are the correct size */
     if (!TEST_size_t_eq(sizeof(int8_t), 1)
-            || !TEST_size_t_eq(sizeof(uint8_t), 1)
-            || !TEST_size_t_eq(sizeof(int16_t), 2)
-            || !TEST_size_t_eq(sizeof(uint16_t), 2)
-            || !TEST_size_t_eq(sizeof(int32_t), 4)
-            || !TEST_size_t_eq(sizeof(uint32_t), 4)
-            || !TEST_size_t_eq(sizeof(int64_t), 8)
-            || !TEST_size_t_eq(sizeof(uint64_t), 8)
+        || !TEST_size_t_eq(sizeof(uint8_t), 1)
+        || !TEST_size_t_eq(sizeof(int16_t), 2)
+        || !TEST_size_t_eq(sizeof(uint16_t), 2)
+        || !TEST_size_t_eq(sizeof(int32_t), 4)
+        || !TEST_size_t_eq(sizeof(uint32_t), 4)
+        || !TEST_size_t_eq(sizeof(int64_t), 8)
+        || !TEST_size_t_eq(sizeof(uint64_t), 8)
 #ifdef UINT128_MAX
-            || !TEST_size_t_eq(sizeof(int128_t), 16)
-            || !TEST_size_t_eq(sizeof(uint128_t), 16)
+        || !TEST_size_t_eq(sizeof(int128_t), 16)
+        || !TEST_size_t_eq(sizeof(uint128_t), 16)
 #endif
-            || !TEST_size_t_eq(sizeof(char), 1)
-            || !TEST_size_t_eq(sizeof(unsigned char), 1))
+        || !TEST_size_t_eq(sizeof(char), 1)
+        || !TEST_size_t_eq(sizeof(unsigned char), 1))
         return 0;
 
     /* We want our long longs to be at least 64 bits */
     if (!TEST_size_t_ge(sizeof(long long int), 8)
-            || !TEST_size_t_ge(sizeof(unsigned long long int), 8))
+        || !TEST_size_t_ge(sizeof(unsigned long long int), 8))
         return 0;
 
     /*
@@ -110,8 +214,8 @@ static int test_sanity_range(void)
      * an int128_t, so this check is for at least 64 bits.
      */
     if (!TEST_size_t_ge(sizeof(ossl_intmax_t), 8)
-            || !TEST_size_t_ge(sizeof(ossl_uintmax_t), 8)
-            || !TEST_size_t_ge(sizeof(ossl_uintmax_t), sizeof(size_t)))
+        || !TEST_size_t_ge(sizeof(ossl_uintmax_t), 8)
+        || !TEST_size_t_ge(sizeof(ossl_uintmax_t), sizeof(size_t)))
         return 0;
 
     /* This isn't possible to check using the framework functions */
@@ -147,7 +251,7 @@ alrm_handler(int sig)
 
 static int test_sanity_sleep(int i)
 {
-    const struct sleep_test_vector * const td = sleep_test_vectors + i;
+    const struct sleep_test_vector *const td = sleep_test_vectors + i;
     OSSL_TIME start = ossl_time_now();
     uint64_t ms;
 
