@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2022 The OpenSSL Project Authors. All Rights Reserved.
+ * Copyright 2002-2020 The OpenSSL Project Authors. All Rights Reserved.
  *
  * Licensed under the Apache License 2.0 (the "License").  You may not use
  * this file except in compliance with the License.  You can obtain a copy
@@ -14,7 +14,6 @@
 #include "apps_ui.h"
 #include "testutil.h"
 
-
 #include <openssl/ui.h>
 
 /* Old style PEM password callback */
@@ -36,16 +35,16 @@ static int test_old(void)
     char pass[16];
     int ok = 0;
 
-    if (!TEST_ptr(ui_method =
-                  UI_UTIL_wrap_read_pem_callback( test_pem_password_cb, 0))
-            || !TEST_ptr(ui = UI_new_method(ui_method)))
+    if (!TEST_ptr(ui_method = UI_UTIL_wrap_read_pem_callback(test_pem_password_cb, 0))
+        || !TEST_ptr(ui = UI_new_method(ui_method)))
         goto err;
 
     /* The wrapper passes the UI userdata as the callback userdata param */
     UI_add_user_data(ui, defpass);
 
     if (UI_add_input_string(ui, "prompt", UI_INPUT_FLAG_DEFAULT_PWD,
-                             pass, 0, sizeof(pass) - 1) <= 0)
+            pass, 0, sizeof(pass) - 1)
+        <= 0)
         goto err;
 
     switch (UI_process(ui)) {
@@ -61,7 +60,7 @@ static int test_old(void)
     if (TEST_str_eq(pass, defpass))
         ok = 1;
 
- err:
+err:
     UI_free(ui);
     UI_destroy_method(ui_method);
 
@@ -80,7 +79,7 @@ static int test_new_ui(void)
 
     (void)setup_ui_method();
     if (TEST_int_gt(password_callback(pass, sizeof(pass), 0, &cb_data), 0)
-            && TEST_str_eq(pass, cb_data.password))
+        && TEST_str_eq(pass, cb_data.password))
         ok = 1;
     destroy_ui_method();
     return ok;
